/**
 * @license
 * Copyright 2024 Google LLC. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * =============================================================================
 */
(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
	typeof define === 'function' && define.amd ? define(['exports'], factory) :
	(global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.tf = global.tf || {}));
})(this, (function (exports) { 'use strict';

	function _mergeNamespaces(n, m) {
		m.forEach(function (e) {
			e && typeof e !== 'string' && !Array.isArray(e) && Object.keys(e).forEach(function (k) {
				if (k !== 'default' && !(k in n)) {
					var d = Object.getOwnPropertyDescriptor(e, k);
					Object.defineProperty(n, k, d.get ? d : {
						enumerable: true,
						get: function () { return e[k]; }
					});
				}
			});
		});
		return n;
	}

	var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

	function getDefaultExportFromCjs (x) {
		return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, 'default') ? x['default'] : x;
	}

	function getDefaultExportFromNamespaceIfPresent (n) {
		return n && Object.prototype.hasOwnProperty.call(n, 'default') ? n['default'] : n;
	}

	function getDefaultExportFromNamespaceIfNotNamed (n) {
		return n && Object.prototype.hasOwnProperty.call(n, 'default') && Object.keys(n).length === 1 ? n['default'] : n;
	}

	function getAugmentedNamespace(n) {
	  if (n.__esModule) return n;
	  var f = n.default;
		if (typeof f == "function") {
			var a = function a () {
				if (this instanceof a) {
					var args = [null];
					args.push.apply(args, arguments);
					var Ctor = Function.bind.apply(f, args);
					return new Ctor();
				}
				return f.apply(this, arguments);
			};
			a.prototype = f.prototype;
	  } else a = {};
	  Object.defineProperty(a, '__esModule', {value: true});
		Object.keys(n).forEach(function (k) {
			var d = Object.getOwnPropertyDescriptor(n, k);
			Object.defineProperty(a, k, d.get ? d : {
				enumerable: true,
				get: function () {
					return n[k];
				}
			});
		});
		return a;
	}

	var es_symbol = {};

	var es_symbol_constructor = {};

	function _AsyncGenerator(gen) {
	  var front, back;
	  function resume(key, arg) {
	    try {
	      var result = gen[key](arg),
	        value = result.value,
	        overloaded = value instanceof _OverloadYield;
	      Promise.resolve(overloaded ? value.v : value).then(function (arg) {
	        if (overloaded) {
	          var nextKey = "return" === key ? "return" : "next";
	          if (!value.k || arg.done) return resume(nextKey, arg);
	          arg = gen[nextKey](arg).value;
	        }
	        settle(result.done ? "return" : "normal", arg);
	      }, function (err) {
	        resume("throw", err);
	      });
	    } catch (err) {
	      settle("throw", err);
	    }
	  }
	  function settle(type, value) {
	    switch (type) {
	      case "return":
	        front.resolve({
	          value: value,
	          done: !0
	        });
	        break;
	      case "throw":
	        front.reject(value);
	        break;
	      default:
	        front.resolve({
	          value: value,
	          done: !1
	        });
	    }
	    (front = front.next) ? resume(front.key, front.arg) : back = null;
	  }
	  this._invoke = function (key, arg) {
	    return new Promise(function (resolve, reject) {
	      var request = {
	        key: key,
	        arg: arg,
	        resolve: resolve,
	        reject: reject,
	        next: null
	      };
	      back ? back = back.next = request : (front = back = request, resume(key, arg));
	    });
	  }, "function" != typeof gen.return && (this.return = void 0);
	}
	_AsyncGenerator.prototype["function" == typeof Symbol && Symbol.asyncIterator || "@@asyncIterator"] = function () {
	  return this;
	}, _AsyncGenerator.prototype.next = function (arg) {
	  return this._invoke("next", arg);
	}, _AsyncGenerator.prototype.throw = function (arg) {
	  return this._invoke("throw", arg);
	}, _AsyncGenerator.prototype.return = function (arg) {
	  return this._invoke("return", arg);
	};
	function _OverloadYield(value, kind) {
	  this.v = value, this.k = kind;
	}
	function old_createMetadataMethodsForProperty(metadataMap, kind, property, decoratorFinishedRef) {
	  return {
	    getMetadata: function (key) {
	      old_assertNotFinished(decoratorFinishedRef, "getMetadata"), old_assertMetadataKey(key);
	      var metadataForKey = metadataMap[key];
	      if (void 0 !== metadataForKey) if (1 === kind) {
	        var pub = metadataForKey.public;
	        if (void 0 !== pub) return pub[property];
	      } else if (2 === kind) {
	        var priv = metadataForKey.private;
	        if (void 0 !== priv) return priv.get(property);
	      } else if (Object.hasOwnProperty.call(metadataForKey, "constructor")) return metadataForKey.constructor;
	    },
	    setMetadata: function (key, value) {
	      old_assertNotFinished(decoratorFinishedRef, "setMetadata"), old_assertMetadataKey(key);
	      var metadataForKey = metadataMap[key];
	      if (void 0 === metadataForKey && (metadataForKey = metadataMap[key] = {}), 1 === kind) {
	        var pub = metadataForKey.public;
	        void 0 === pub && (pub = metadataForKey.public = {}), pub[property] = value;
	      } else if (2 === kind) {
	        var priv = metadataForKey.priv;
	        void 0 === priv && (priv = metadataForKey.private = new Map()), priv.set(property, value);
	      } else metadataForKey.constructor = value;
	    }
	  };
	}
	function old_convertMetadataMapToFinal(obj, metadataMap) {
	  var parentMetadataMap = obj[Symbol.metadata || Symbol.for("Symbol.metadata")],
	    metadataKeys = Object.getOwnPropertySymbols(metadataMap);
	  if (0 !== metadataKeys.length) {
	    for (var i = 0; i < metadataKeys.length; i++) {
	      var key = metadataKeys[i],
	        metaForKey = metadataMap[key],
	        parentMetaForKey = parentMetadataMap ? parentMetadataMap[key] : null,
	        pub = metaForKey.public,
	        parentPub = parentMetaForKey ? parentMetaForKey.public : null;
	      pub && parentPub && Object.setPrototypeOf(pub, parentPub);
	      var priv = metaForKey.private;
	      if (priv) {
	        var privArr = Array.from(priv.values()),
	          parentPriv = parentMetaForKey ? parentMetaForKey.private : null;
	        parentPriv && (privArr = privArr.concat(parentPriv)), metaForKey.private = privArr;
	      }
	      parentMetaForKey && Object.setPrototypeOf(metaForKey, parentMetaForKey);
	    }
	    parentMetadataMap && Object.setPrototypeOf(metadataMap, parentMetadataMap), obj[Symbol.metadata || Symbol.for("Symbol.metadata")] = metadataMap;
	  }
	}
	function old_createAddInitializerMethod(initializers, decoratorFinishedRef) {
	  return function (initializer) {
	    old_assertNotFinished(decoratorFinishedRef, "addInitializer"), old_assertCallable(initializer, "An initializer"), initializers.push(initializer);
	  };
	}
	function old_memberDec(dec, name, desc, metadataMap, initializers, kind, isStatic, isPrivate, value) {
	  var kindStr;
	  switch (kind) {
	    case 1:
	      kindStr = "accessor";
	      break;
	    case 2:
	      kindStr = "method";
	      break;
	    case 3:
	      kindStr = "getter";
	      break;
	    case 4:
	      kindStr = "setter";
	      break;
	    default:
	      kindStr = "field";
	  }
	  var metadataKind,
	    metadataName,
	    ctx = {
	      kind: kindStr,
	      name: isPrivate ? "#" + name : name,
	      isStatic: isStatic,
	      isPrivate: isPrivate
	    },
	    decoratorFinishedRef = {
	      v: !1
	    };
	  if (0 !== kind && (ctx.addInitializer = old_createAddInitializerMethod(initializers, decoratorFinishedRef)), isPrivate) {
	    metadataKind = 2, metadataName = Symbol(name);
	    var access = {};
	    0 === kind ? (access.get = desc.get, access.set = desc.set) : 2 === kind ? access.get = function () {
	      return desc.value;
	    } : (1 !== kind && 3 !== kind || (access.get = function () {
	      return desc.get.call(this);
	    }), 1 !== kind && 4 !== kind || (access.set = function (v) {
	      desc.set.call(this, v);
	    })), ctx.access = access;
	  } else metadataKind = 1, metadataName = name;
	  try {
	    return dec(value, Object.assign(ctx, old_createMetadataMethodsForProperty(metadataMap, metadataKind, metadataName, decoratorFinishedRef)));
	  } finally {
	    decoratorFinishedRef.v = !0;
	  }
	}
	function old_assertNotFinished(decoratorFinishedRef, fnName) {
	  if (decoratorFinishedRef.v) throw new Error("attempted to call " + fnName + " after decoration was finished");
	}
	function old_assertMetadataKey(key) {
	  if ("symbol" != typeof key) throw new TypeError("Metadata keys must be symbols, received: " + key);
	}
	function old_assertCallable(fn, hint) {
	  if ("function" != typeof fn) throw new TypeError(hint + " must be a function");
	}
	function old_assertValidReturnValue(kind, value) {
	  var type = typeof value;
	  if (1 === kind) {
	    if ("object" !== type || null === value) throw new TypeError("accessor decorators must return an object with get, set, or init properties or void 0");
	    void 0 !== value.get && old_assertCallable(value.get, "accessor.get"), void 0 !== value.set && old_assertCallable(value.set, "accessor.set"), void 0 !== value.init && old_assertCallable(value.init, "accessor.init"), void 0 !== value.initializer && old_assertCallable(value.initializer, "accessor.initializer");
	  } else if ("function" !== type) {
	    var hint;
	    throw hint = 0 === kind ? "field" : 10 === kind ? "class" : "method", new TypeError(hint + " decorators must return a function or void 0");
	  }
	}
	function old_getInit(desc) {
	  var initializer;
	  return null == (initializer = desc.init) && (initializer = desc.initializer) && "undefined" != typeof console && console.warn(".initializer has been renamed to .init as of March 2022"), initializer;
	}
	function old_applyMemberDec(ret, base, decInfo, name, kind, isStatic, isPrivate, metadataMap, initializers) {
	  var desc,
	    initializer,
	    value,
	    newValue,
	    get,
	    set,
	    decs = decInfo[0];
	  if (isPrivate ? desc = 0 === kind || 1 === kind ? {
	    get: decInfo[3],
	    set: decInfo[4]
	  } : 3 === kind ? {
	    get: decInfo[3]
	  } : 4 === kind ? {
	    set: decInfo[3]
	  } : {
	    value: decInfo[3]
	  } : 0 !== kind && (desc = Object.getOwnPropertyDescriptor(base, name)), 1 === kind ? value = {
	    get: desc.get,
	    set: desc.set
	  } : 2 === kind ? value = desc.value : 3 === kind ? value = desc.get : 4 === kind && (value = desc.set), "function" == typeof decs) void 0 !== (newValue = old_memberDec(decs, name, desc, metadataMap, initializers, kind, isStatic, isPrivate, value)) && (old_assertValidReturnValue(kind, newValue), 0 === kind ? initializer = newValue : 1 === kind ? (initializer = old_getInit(newValue), get = newValue.get || value.get, set = newValue.set || value.set, value = {
	    get: get,
	    set: set
	  }) : value = newValue);else for (var i = decs.length - 1; i >= 0; i--) {
	    var newInit;
	    if (void 0 !== (newValue = old_memberDec(decs[i], name, desc, metadataMap, initializers, kind, isStatic, isPrivate, value))) old_assertValidReturnValue(kind, newValue), 0 === kind ? newInit = newValue : 1 === kind ? (newInit = old_getInit(newValue), get = newValue.get || value.get, set = newValue.set || value.set, value = {
	      get: get,
	      set: set
	    }) : value = newValue, void 0 !== newInit && (void 0 === initializer ? initializer = newInit : "function" == typeof initializer ? initializer = [initializer, newInit] : initializer.push(newInit));
	  }
	  if (0 === kind || 1 === kind) {
	    if (void 0 === initializer) initializer = function (instance, init) {
	      return init;
	    };else if ("function" != typeof initializer) {
	      var ownInitializers = initializer;
	      initializer = function (instance, init) {
	        for (var value = init, i = 0; i < ownInitializers.length; i++) value = ownInitializers[i].call(instance, value);
	        return value;
	      };
	    } else {
	      var originalInitializer = initializer;
	      initializer = function (instance, init) {
	        return originalInitializer.call(instance, init);
	      };
	    }
	    ret.push(initializer);
	  }
	  0 !== kind && (1 === kind ? (desc.get = value.get, desc.set = value.set) : 2 === kind ? desc.value = value : 3 === kind ? desc.get = value : 4 === kind && (desc.set = value), isPrivate ? 1 === kind ? (ret.push(function (instance, args) {
	    return value.get.call(instance, args);
	  }), ret.push(function (instance, args) {
	    return value.set.call(instance, args);
	  })) : 2 === kind ? ret.push(value) : ret.push(function (instance, args) {
	    return value.call(instance, args);
	  }) : Object.defineProperty(base, name, desc));
	}
	function old_applyMemberDecs(ret, Class, protoMetadataMap, staticMetadataMap, decInfos) {
	  for (var protoInitializers, staticInitializers, existingProtoNonFields = new Map(), existingStaticNonFields = new Map(), i = 0; i < decInfos.length; i++) {
	    var decInfo = decInfos[i];
	    if (Array.isArray(decInfo)) {
	      var base,
	        metadataMap,
	        initializers,
	        kind = decInfo[1],
	        name = decInfo[2],
	        isPrivate = decInfo.length > 3,
	        isStatic = kind >= 5;
	      if (isStatic ? (base = Class, metadataMap = staticMetadataMap, 0 !== (kind -= 5) && (initializers = staticInitializers = staticInitializers || [])) : (base = Class.prototype, metadataMap = protoMetadataMap, 0 !== kind && (initializers = protoInitializers = protoInitializers || [])), 0 !== kind && !isPrivate) {
	        var existingNonFields = isStatic ? existingStaticNonFields : existingProtoNonFields,
	          existingKind = existingNonFields.get(name) || 0;
	        if (!0 === existingKind || 3 === existingKind && 4 !== kind || 4 === existingKind && 3 !== kind) throw new Error("Attempted to decorate a public method/accessor that has the same name as a previously decorated public method/accessor. This is not currently supported by the decorators plugin. Property name was: " + name);
	        !existingKind && kind > 2 ? existingNonFields.set(name, kind) : existingNonFields.set(name, !0);
	      }
	      old_applyMemberDec(ret, base, decInfo, name, kind, isStatic, isPrivate, metadataMap, initializers);
	    }
	  }
	  old_pushInitializers(ret, protoInitializers), old_pushInitializers(ret, staticInitializers);
	}
	function old_pushInitializers(ret, initializers) {
	  initializers && ret.push(function (instance) {
	    for (var i = 0; i < initializers.length; i++) initializers[i].call(instance);
	    return instance;
	  });
	}
	function old_applyClassDecs(ret, targetClass, metadataMap, classDecs) {
	  if (classDecs.length > 0) {
	    for (var initializers = [], newClass = targetClass, name = targetClass.name, i = classDecs.length - 1; i >= 0; i--) {
	      var decoratorFinishedRef = {
	        v: !1
	      };
	      try {
	        var ctx = Object.assign({
	            kind: "class",
	            name: name,
	            addInitializer: old_createAddInitializerMethod(initializers, decoratorFinishedRef)
	          }, old_createMetadataMethodsForProperty(metadataMap, 0, name, decoratorFinishedRef)),
	          nextNewClass = classDecs[i](newClass, ctx);
	      } finally {
	        decoratorFinishedRef.v = !0;
	      }
	      void 0 !== nextNewClass && (old_assertValidReturnValue(10, nextNewClass), newClass = nextNewClass);
	    }
	    ret.push(newClass, function () {
	      for (var i = 0; i < initializers.length; i++) initializers[i].call(newClass);
	    });
	  }
	}
	function _applyDecs(targetClass, memberDecs, classDecs) {
	  var ret = [],
	    staticMetadataMap = {},
	    protoMetadataMap = {};
	  return old_applyMemberDecs(ret, targetClass, protoMetadataMap, staticMetadataMap, memberDecs), old_convertMetadataMapToFinal(targetClass.prototype, protoMetadataMap), old_applyClassDecs(ret, targetClass, staticMetadataMap, classDecs), old_convertMetadataMapToFinal(targetClass, staticMetadataMap), ret;
	}
	function applyDecs2203Factory() {
	  function createAddInitializerMethod(initializers, decoratorFinishedRef) {
	    return function (initializer) {
	      !function (decoratorFinishedRef, fnName) {
	        if (decoratorFinishedRef.v) throw new Error("attempted to call " + fnName + " after decoration was finished");
	      }(decoratorFinishedRef, "addInitializer"), assertCallable(initializer, "An initializer"), initializers.push(initializer);
	    };
	  }
	  function memberDec(dec, name, desc, initializers, kind, isStatic, isPrivate, value) {
	    var kindStr;
	    switch (kind) {
	      case 1:
	        kindStr = "accessor";
	        break;
	      case 2:
	        kindStr = "method";
	        break;
	      case 3:
	        kindStr = "getter";
	        break;
	      case 4:
	        kindStr = "setter";
	        break;
	      default:
	        kindStr = "field";
	    }
	    var get,
	      set,
	      ctx = {
	        kind: kindStr,
	        name: isPrivate ? "#" + name : name,
	        static: isStatic,
	        private: isPrivate
	      },
	      decoratorFinishedRef = {
	        v: !1
	      };
	    0 !== kind && (ctx.addInitializer = createAddInitializerMethod(initializers, decoratorFinishedRef)), 0 === kind ? isPrivate ? (get = desc.get, set = desc.set) : (get = function () {
	      return this[name];
	    }, set = function (v) {
	      this[name] = v;
	    }) : 2 === kind ? get = function () {
	      return desc.value;
	    } : (1 !== kind && 3 !== kind || (get = function () {
	      return desc.get.call(this);
	    }), 1 !== kind && 4 !== kind || (set = function (v) {
	      desc.set.call(this, v);
	    })), ctx.access = get && set ? {
	      get: get,
	      set: set
	    } : get ? {
	      get: get
	    } : {
	      set: set
	    };
	    try {
	      return dec(value, ctx);
	    } finally {
	      decoratorFinishedRef.v = !0;
	    }
	  }
	  function assertCallable(fn, hint) {
	    if ("function" != typeof fn) throw new TypeError(hint + " must be a function");
	  }
	  function assertValidReturnValue(kind, value) {
	    var type = typeof value;
	    if (1 === kind) {
	      if ("object" !== type || null === value) throw new TypeError("accessor decorators must return an object with get, set, or init properties or void 0");
	      void 0 !== value.get && assertCallable(value.get, "accessor.get"), void 0 !== value.set && assertCallable(value.set, "accessor.set"), void 0 !== value.init && assertCallable(value.init, "accessor.init");
	    } else if ("function" !== type) {
	      var hint;
	      throw hint = 0 === kind ? "field" : 10 === kind ? "class" : "method", new TypeError(hint + " decorators must return a function or void 0");
	    }
	  }
	  function applyMemberDec(ret, base, decInfo, name, kind, isStatic, isPrivate, initializers) {
	    var desc,
	      init,
	      value,
	      newValue,
	      get,
	      set,
	      decs = decInfo[0];
	    if (isPrivate ? desc = 0 === kind || 1 === kind ? {
	      get: decInfo[3],
	      set: decInfo[4]
	    } : 3 === kind ? {
	      get: decInfo[3]
	    } : 4 === kind ? {
	      set: decInfo[3]
	    } : {
	      value: decInfo[3]
	    } : 0 !== kind && (desc = Object.getOwnPropertyDescriptor(base, name)), 1 === kind ? value = {
	      get: desc.get,
	      set: desc.set
	    } : 2 === kind ? value = desc.value : 3 === kind ? value = desc.get : 4 === kind && (value = desc.set), "function" == typeof decs) void 0 !== (newValue = memberDec(decs, name, desc, initializers, kind, isStatic, isPrivate, value)) && (assertValidReturnValue(kind, newValue), 0 === kind ? init = newValue : 1 === kind ? (init = newValue.init, get = newValue.get || value.get, set = newValue.set || value.set, value = {
	      get: get,
	      set: set
	    }) : value = newValue);else for (var i = decs.length - 1; i >= 0; i--) {
	      var newInit;
	      if (void 0 !== (newValue = memberDec(decs[i], name, desc, initializers, kind, isStatic, isPrivate, value))) assertValidReturnValue(kind, newValue), 0 === kind ? newInit = newValue : 1 === kind ? (newInit = newValue.init, get = newValue.get || value.get, set = newValue.set || value.set, value = {
	        get: get,
	        set: set
	      }) : value = newValue, void 0 !== newInit && (void 0 === init ? init = newInit : "function" == typeof init ? init = [init, newInit] : init.push(newInit));
	    }
	    if (0 === kind || 1 === kind) {
	      if (void 0 === init) init = function (instance, init) {
	        return init;
	      };else if ("function" != typeof init) {
	        var ownInitializers = init;
	        init = function (instance, init) {
	          for (var value = init, i = 0; i < ownInitializers.length; i++) value = ownInitializers[i].call(instance, value);
	          return value;
	        };
	      } else {
	        var originalInitializer = init;
	        init = function (instance, init) {
	          return originalInitializer.call(instance, init);
	        };
	      }
	      ret.push(init);
	    }
	    0 !== kind && (1 === kind ? (desc.get = value.get, desc.set = value.set) : 2 === kind ? desc.value = value : 3 === kind ? desc.get = value : 4 === kind && (desc.set = value), isPrivate ? 1 === kind ? (ret.push(function (instance, args) {
	      return value.get.call(instance, args);
	    }), ret.push(function (instance, args) {
	      return value.set.call(instance, args);
	    })) : 2 === kind ? ret.push(value) : ret.push(function (instance, args) {
	      return value.call(instance, args);
	    }) : Object.defineProperty(base, name, desc));
	  }
	  function pushInitializers(ret, initializers) {
	    initializers && ret.push(function (instance) {
	      for (var i = 0; i < initializers.length; i++) initializers[i].call(instance);
	      return instance;
	    });
	  }
	  return function (targetClass, memberDecs, classDecs) {
	    var ret = [];
	    return function (ret, Class, decInfos) {
	      for (var protoInitializers, staticInitializers, existingProtoNonFields = new Map(), existingStaticNonFields = new Map(), i = 0; i < decInfos.length; i++) {
	        var decInfo = decInfos[i];
	        if (Array.isArray(decInfo)) {
	          var base,
	            initializers,
	            kind = decInfo[1],
	            name = decInfo[2],
	            isPrivate = decInfo.length > 3,
	            isStatic = kind >= 5;
	          if (isStatic ? (base = Class, 0 != (kind -= 5) && (initializers = staticInitializers = staticInitializers || [])) : (base = Class.prototype, 0 !== kind && (initializers = protoInitializers = protoInitializers || [])), 0 !== kind && !isPrivate) {
	            var existingNonFields = isStatic ? existingStaticNonFields : existingProtoNonFields,
	              existingKind = existingNonFields.get(name) || 0;
	            if (!0 === existingKind || 3 === existingKind && 4 !== kind || 4 === existingKind && 3 !== kind) throw new Error("Attempted to decorate a public method/accessor that has the same name as a previously decorated public method/accessor. This is not currently supported by the decorators plugin. Property name was: " + name);
	            !existingKind && kind > 2 ? existingNonFields.set(name, kind) : existingNonFields.set(name, !0);
	          }
	          applyMemberDec(ret, base, decInfo, name, kind, isStatic, isPrivate, initializers);
	        }
	      }
	      pushInitializers(ret, protoInitializers), pushInitializers(ret, staticInitializers);
	    }(ret, targetClass, memberDecs), function (ret, targetClass, classDecs) {
	      if (classDecs.length > 0) {
	        for (var initializers = [], newClass = targetClass, name = targetClass.name, i = classDecs.length - 1; i >= 0; i--) {
	          var decoratorFinishedRef = {
	            v: !1
	          };
	          try {
	            var nextNewClass = classDecs[i](newClass, {
	              kind: "class",
	              name: name,
	              addInitializer: createAddInitializerMethod(initializers, decoratorFinishedRef)
	            });
	          } finally {
	            decoratorFinishedRef.v = !0;
	          }
	          void 0 !== nextNewClass && (assertValidReturnValue(10, nextNewClass), newClass = nextNewClass);
	        }
	        ret.push(newClass, function () {
	          for (var i = 0; i < initializers.length; i++) initializers[i].call(newClass);
	        });
	      }
	    }(ret, targetClass, classDecs), ret;
	  };
	}
	var applyDecs2203Impl;
	function _applyDecs2203(targetClass, memberDecs, classDecs) {
	  return (applyDecs2203Impl = applyDecs2203Impl || applyDecs2203Factory())(targetClass, memberDecs, classDecs);
	}
	function applyDecs2203RFactory() {
	  function createAddInitializerMethod(initializers, decoratorFinishedRef) {
	    return function (initializer) {
	      !function (decoratorFinishedRef, fnName) {
	        if (decoratorFinishedRef.v) throw new Error("attempted to call " + fnName + " after decoration was finished");
	      }(decoratorFinishedRef, "addInitializer"), assertCallable(initializer, "An initializer"), initializers.push(initializer);
	    };
	  }
	  function memberDec(dec, name, desc, initializers, kind, isStatic, isPrivate, value) {
	    var kindStr;
	    switch (kind) {
	      case 1:
	        kindStr = "accessor";
	        break;
	      case 2:
	        kindStr = "method";
	        break;
	      case 3:
	        kindStr = "getter";
	        break;
	      case 4:
	        kindStr = "setter";
	        break;
	      default:
	        kindStr = "field";
	    }
	    var get,
	      set,
	      ctx = {
	        kind: kindStr,
	        name: isPrivate ? "#" + name : name,
	        static: isStatic,
	        private: isPrivate
	      },
	      decoratorFinishedRef = {
	        v: !1
	      };
	    0 !== kind && (ctx.addInitializer = createAddInitializerMethod(initializers, decoratorFinishedRef)), 0 === kind ? isPrivate ? (get = desc.get, set = desc.set) : (get = function () {
	      return this[name];
	    }, set = function (v) {
	      this[name] = v;
	    }) : 2 === kind ? get = function () {
	      return desc.value;
	    } : (1 !== kind && 3 !== kind || (get = function () {
	      return desc.get.call(this);
	    }), 1 !== kind && 4 !== kind || (set = function (v) {
	      desc.set.call(this, v);
	    })), ctx.access = get && set ? {
	      get: get,
	      set: set
	    } : get ? {
	      get: get
	    } : {
	      set: set
	    };
	    try {
	      return dec(value, ctx);
	    } finally {
	      decoratorFinishedRef.v = !0;
	    }
	  }
	  function assertCallable(fn, hint) {
	    if ("function" != typeof fn) throw new TypeError(hint + " must be a function");
	  }
	  function assertValidReturnValue(kind, value) {
	    var type = typeof value;
	    if (1 === kind) {
	      if ("object" !== type || null === value) throw new TypeError("accessor decorators must return an object with get, set, or init properties or void 0");
	      void 0 !== value.get && assertCallable(value.get, "accessor.get"), void 0 !== value.set && assertCallable(value.set, "accessor.set"), void 0 !== value.init && assertCallable(value.init, "accessor.init");
	    } else if ("function" !== type) {
	      var hint;
	      throw hint = 0 === kind ? "field" : 10 === kind ? "class" : "method", new TypeError(hint + " decorators must return a function or void 0");
	    }
	  }
	  function applyMemberDec(ret, base, decInfo, name, kind, isStatic, isPrivate, initializers) {
	    var desc,
	      init,
	      value,
	      newValue,
	      get,
	      set,
	      decs = decInfo[0];
	    if (isPrivate ? desc = 0 === kind || 1 === kind ? {
	      get: decInfo[3],
	      set: decInfo[4]
	    } : 3 === kind ? {
	      get: decInfo[3]
	    } : 4 === kind ? {
	      set: decInfo[3]
	    } : {
	      value: decInfo[3]
	    } : 0 !== kind && (desc = Object.getOwnPropertyDescriptor(base, name)), 1 === kind ? value = {
	      get: desc.get,
	      set: desc.set
	    } : 2 === kind ? value = desc.value : 3 === kind ? value = desc.get : 4 === kind && (value = desc.set), "function" == typeof decs) void 0 !== (newValue = memberDec(decs, name, desc, initializers, kind, isStatic, isPrivate, value)) && (assertValidReturnValue(kind, newValue), 0 === kind ? init = newValue : 1 === kind ? (init = newValue.init, get = newValue.get || value.get, set = newValue.set || value.set, value = {
	      get: get,
	      set: set
	    }) : value = newValue);else for (var i = decs.length - 1; i >= 0; i--) {
	      var newInit;
	      if (void 0 !== (newValue = memberDec(decs[i], name, desc, initializers, kind, isStatic, isPrivate, value))) assertValidReturnValue(kind, newValue), 0 === kind ? newInit = newValue : 1 === kind ? (newInit = newValue.init, get = newValue.get || value.get, set = newValue.set || value.set, value = {
	        get: get,
	        set: set
	      }) : value = newValue, void 0 !== newInit && (void 0 === init ? init = newInit : "function" == typeof init ? init = [init, newInit] : init.push(newInit));
	    }
	    if (0 === kind || 1 === kind) {
	      if (void 0 === init) init = function (instance, init) {
	        return init;
	      };else if ("function" != typeof init) {
	        var ownInitializers = init;
	        init = function (instance, init) {
	          for (var value = init, i = 0; i < ownInitializers.length; i++) value = ownInitializers[i].call(instance, value);
	          return value;
	        };
	      } else {
	        var originalInitializer = init;
	        init = function (instance, init) {
	          return originalInitializer.call(instance, init);
	        };
	      }
	      ret.push(init);
	    }
	    0 !== kind && (1 === kind ? (desc.get = value.get, desc.set = value.set) : 2 === kind ? desc.value = value : 3 === kind ? desc.get = value : 4 === kind && (desc.set = value), isPrivate ? 1 === kind ? (ret.push(function (instance, args) {
	      return value.get.call(instance, args);
	    }), ret.push(function (instance, args) {
	      return value.set.call(instance, args);
	    })) : 2 === kind ? ret.push(value) : ret.push(function (instance, args) {
	      return value.call(instance, args);
	    }) : Object.defineProperty(base, name, desc));
	  }
	  function applyMemberDecs(Class, decInfos) {
	    for (var protoInitializers, staticInitializers, ret = [], existingProtoNonFields = new Map(), existingStaticNonFields = new Map(), i = 0; i < decInfos.length; i++) {
	      var decInfo = decInfos[i];
	      if (Array.isArray(decInfo)) {
	        var base,
	          initializers,
	          kind = decInfo[1],
	          name = decInfo[2],
	          isPrivate = decInfo.length > 3,
	          isStatic = kind >= 5;
	        if (isStatic ? (base = Class, 0 !== (kind -= 5) && (initializers = staticInitializers = staticInitializers || [])) : (base = Class.prototype, 0 !== kind && (initializers = protoInitializers = protoInitializers || [])), 0 !== kind && !isPrivate) {
	          var existingNonFields = isStatic ? existingStaticNonFields : existingProtoNonFields,
	            existingKind = existingNonFields.get(name) || 0;
	          if (!0 === existingKind || 3 === existingKind && 4 !== kind || 4 === existingKind && 3 !== kind) throw new Error("Attempted to decorate a public method/accessor that has the same name as a previously decorated public method/accessor. This is not currently supported by the decorators plugin. Property name was: " + name);
	          !existingKind && kind > 2 ? existingNonFields.set(name, kind) : existingNonFields.set(name, !0);
	        }
	        applyMemberDec(ret, base, decInfo, name, kind, isStatic, isPrivate, initializers);
	      }
	    }
	    return pushInitializers(ret, protoInitializers), pushInitializers(ret, staticInitializers), ret;
	  }
	  function pushInitializers(ret, initializers) {
	    initializers && ret.push(function (instance) {
	      for (var i = 0; i < initializers.length; i++) initializers[i].call(instance);
	      return instance;
	    });
	  }
	  return function (targetClass, memberDecs, classDecs) {
	    return {
	      e: applyMemberDecs(targetClass, memberDecs),
	      get c() {
	        return function (targetClass, classDecs) {
	          if (classDecs.length > 0) {
	            for (var initializers = [], newClass = targetClass, name = targetClass.name, i = classDecs.length - 1; i >= 0; i--) {
	              var decoratorFinishedRef = {
	                v: !1
	              };
	              try {
	                var nextNewClass = classDecs[i](newClass, {
	                  kind: "class",
	                  name: name,
	                  addInitializer: createAddInitializerMethod(initializers, decoratorFinishedRef)
	                });
	              } finally {
	                decoratorFinishedRef.v = !0;
	              }
	              void 0 !== nextNewClass && (assertValidReturnValue(10, nextNewClass), newClass = nextNewClass);
	            }
	            return [newClass, function () {
	              for (var i = 0; i < initializers.length; i++) initializers[i].call(newClass);
	            }];
	          }
	        }(targetClass, classDecs);
	      }
	    };
	  };
	}
	function _applyDecs2203R(targetClass, memberDecs, classDecs) {
	  return (_applyDecs2203R = applyDecs2203RFactory())(targetClass, memberDecs, classDecs);
	}
	function createAddInitializerMethod(initializers, decoratorFinishedRef) {
	  return function (initializer) {
	    assertNotFinished(decoratorFinishedRef, "addInitializer"), assertCallable(initializer, "An initializer"), initializers.push(initializer);
	  };
	}
	function assertInstanceIfPrivate(has, target) {
	  if (!has(target)) throw new TypeError("Attempted to access private element on non-instance");
	}
	function memberDec(dec, name, desc, initializers, kind, isStatic, isPrivate, value, hasPrivateBrand) {
	  var kindStr;
	  switch (kind) {
	    case 1:
	      kindStr = "accessor";
	      break;
	    case 2:
	      kindStr = "method";
	      break;
	    case 3:
	      kindStr = "getter";
	      break;
	    case 4:
	      kindStr = "setter";
	      break;
	    default:
	      kindStr = "field";
	  }
	  var get,
	    set,
	    ctx = {
	      kind: kindStr,
	      name: isPrivate ? "#" + name : name,
	      static: isStatic,
	      private: isPrivate
	    },
	    decoratorFinishedRef = {
	      v: !1
	    };
	  if (0 !== kind && (ctx.addInitializer = createAddInitializerMethod(initializers, decoratorFinishedRef)), isPrivate || 0 !== kind && 2 !== kind) {
	    if (2 === kind) get = function (target) {
	      return assertInstanceIfPrivate(hasPrivateBrand, target), desc.value;
	    };else {
	      var t = 0 === kind || 1 === kind;
	      (t || 3 === kind) && (get = isPrivate ? function (target) {
	        return assertInstanceIfPrivate(hasPrivateBrand, target), desc.get.call(target);
	      } : function (target) {
	        return desc.get.call(target);
	      }), (t || 4 === kind) && (set = isPrivate ? function (target, value) {
	        assertInstanceIfPrivate(hasPrivateBrand, target), desc.set.call(target, value);
	      } : function (target, value) {
	        desc.set.call(target, value);
	      });
	    }
	  } else get = function (target) {
	    return target[name];
	  }, 0 === kind && (set = function (target, v) {
	    target[name] = v;
	  });
	  var has = isPrivate ? hasPrivateBrand.bind() : function (target) {
	    return name in target;
	  };
	  ctx.access = get && set ? {
	    get: get,
	    set: set,
	    has: has
	  } : get ? {
	    get: get,
	    has: has
	  } : {
	    set: set,
	    has: has
	  };
	  try {
	    return dec(value, ctx);
	  } finally {
	    decoratorFinishedRef.v = !0;
	  }
	}
	function assertNotFinished(decoratorFinishedRef, fnName) {
	  if (decoratorFinishedRef.v) throw new Error("attempted to call " + fnName + " after decoration was finished");
	}
	function assertCallable(fn, hint) {
	  if ("function" != typeof fn) throw new TypeError(hint + " must be a function");
	}
	function assertValidReturnValue(kind, value) {
	  var type = typeof value;
	  if (1 === kind) {
	    if ("object" !== type || null === value) throw new TypeError("accessor decorators must return an object with get, set, or init properties or void 0");
	    void 0 !== value.get && assertCallable(value.get, "accessor.get"), void 0 !== value.set && assertCallable(value.set, "accessor.set"), void 0 !== value.init && assertCallable(value.init, "accessor.init");
	  } else if ("function" !== type) {
	    var hint;
	    throw hint = 0 === kind ? "field" : 10 === kind ? "class" : "method", new TypeError(hint + " decorators must return a function or void 0");
	  }
	}
	function curryThis1(fn) {
	  return function () {
	    return fn(this);
	  };
	}
	function curryThis2(fn) {
	  return function (value) {
	    fn(this, value);
	  };
	}
	function applyMemberDec(ret, base, decInfo, name, kind, isStatic, isPrivate, initializers, hasPrivateBrand) {
	  var desc,
	    init,
	    value,
	    newValue,
	    get,
	    set,
	    decs = decInfo[0];
	  if (isPrivate ? desc = 0 === kind || 1 === kind ? {
	    get: curryThis1(decInfo[3]),
	    set: curryThis2(decInfo[4])
	  } : 3 === kind ? {
	    get: decInfo[3]
	  } : 4 === kind ? {
	    set: decInfo[3]
	  } : {
	    value: decInfo[3]
	  } : 0 !== kind && (desc = Object.getOwnPropertyDescriptor(base, name)), 1 === kind ? value = {
	    get: desc.get,
	    set: desc.set
	  } : 2 === kind ? value = desc.value : 3 === kind ? value = desc.get : 4 === kind && (value = desc.set), "function" == typeof decs) void 0 !== (newValue = memberDec(decs, name, desc, initializers, kind, isStatic, isPrivate, value, hasPrivateBrand)) && (assertValidReturnValue(kind, newValue), 0 === kind ? init = newValue : 1 === kind ? (init = newValue.init, get = newValue.get || value.get, set = newValue.set || value.set, value = {
	    get: get,
	    set: set
	  }) : value = newValue);else for (var i = decs.length - 1; i >= 0; i--) {
	    var newInit;
	    if (void 0 !== (newValue = memberDec(decs[i], name, desc, initializers, kind, isStatic, isPrivate, value, hasPrivateBrand))) assertValidReturnValue(kind, newValue), 0 === kind ? newInit = newValue : 1 === kind ? (newInit = newValue.init, get = newValue.get || value.get, set = newValue.set || value.set, value = {
	      get: get,
	      set: set
	    }) : value = newValue, void 0 !== newInit && (void 0 === init ? init = newInit : "function" == typeof init ? init = [init, newInit] : init.push(newInit));
	  }
	  if (0 === kind || 1 === kind) {
	    if (void 0 === init) init = function (instance, init) {
	      return init;
	    };else if ("function" != typeof init) {
	      var ownInitializers = init;
	      init = function (instance, init) {
	        for (var value = init, i = 0; i < ownInitializers.length; i++) value = ownInitializers[i].call(instance, value);
	        return value;
	      };
	    } else {
	      var originalInitializer = init;
	      init = function (instance, init) {
	        return originalInitializer.call(instance, init);
	      };
	    }
	    ret.push(init);
	  }
	  0 !== kind && (1 === kind ? (desc.get = value.get, desc.set = value.set) : 2 === kind ? desc.value = value : 3 === kind ? desc.get = value : 4 === kind && (desc.set = value), isPrivate ? 1 === kind ? (ret.push(function (instance, args) {
	    return value.get.call(instance, args);
	  }), ret.push(function (instance, args) {
	    return value.set.call(instance, args);
	  })) : 2 === kind ? ret.push(value) : ret.push(function (instance, args) {
	    return value.call(instance, args);
	  }) : Object.defineProperty(base, name, desc));
	}
	function applyMemberDecs(Class, decInfos, instanceBrand) {
	  for (var protoInitializers, staticInitializers, staticBrand, ret = [], existingProtoNonFields = new Map(), existingStaticNonFields = new Map(), i = 0; i < decInfos.length; i++) {
	    var decInfo = decInfos[i];
	    if (Array.isArray(decInfo)) {
	      var base,
	        initializers,
	        kind = decInfo[1],
	        name = decInfo[2],
	        isPrivate = decInfo.length > 3,
	        isStatic = kind >= 5,
	        hasPrivateBrand = instanceBrand;
	      if (isStatic ? (base = Class, 0 !== (kind -= 5) && (initializers = staticInitializers = staticInitializers || []), isPrivate && !staticBrand && (staticBrand = function (_) {
	        return _checkInRHS(_) === Class;
	      }), hasPrivateBrand = staticBrand) : (base = Class.prototype, 0 !== kind && (initializers = protoInitializers = protoInitializers || [])), 0 !== kind && !isPrivate) {
	        var existingNonFields = isStatic ? existingStaticNonFields : existingProtoNonFields,
	          existingKind = existingNonFields.get(name) || 0;
	        if (!0 === existingKind || 3 === existingKind && 4 !== kind || 4 === existingKind && 3 !== kind) throw new Error("Attempted to decorate a public method/accessor that has the same name as a previously decorated public method/accessor. This is not currently supported by the decorators plugin. Property name was: " + name);
	        !existingKind && kind > 2 ? existingNonFields.set(name, kind) : existingNonFields.set(name, !0);
	      }
	      applyMemberDec(ret, base, decInfo, name, kind, isStatic, isPrivate, initializers, hasPrivateBrand);
	    }
	  }
	  return pushInitializers(ret, protoInitializers), pushInitializers(ret, staticInitializers), ret;
	}
	function pushInitializers(ret, initializers) {
	  initializers && ret.push(function (instance) {
	    for (var i = 0; i < initializers.length; i++) initializers[i].call(instance);
	    return instance;
	  });
	}
	function applyClassDecs(targetClass, classDecs) {
	  if (classDecs.length > 0) {
	    for (var initializers = [], newClass = targetClass, name = targetClass.name, i = classDecs.length - 1; i >= 0; i--) {
	      var decoratorFinishedRef = {
	        v: !1
	      };
	      try {
	        var nextNewClass = classDecs[i](newClass, {
	          kind: "class",
	          name: name,
	          addInitializer: createAddInitializerMethod(initializers, decoratorFinishedRef)
	        });
	      } finally {
	        decoratorFinishedRef.v = !0;
	      }
	      void 0 !== nextNewClass && (assertValidReturnValue(10, nextNewClass), newClass = nextNewClass);
	    }
	    return [newClass, function () {
	      for (var i = 0; i < initializers.length; i++) initializers[i].call(newClass);
	    }];
	  }
	}
	function _applyDecs2301(targetClass, memberDecs, classDecs, instanceBrand) {
	  return {
	    e: applyMemberDecs(targetClass, memberDecs, instanceBrand),
	    get c() {
	      return applyClassDecs(targetClass, classDecs);
	    }
	  };
	}
	function _asyncGeneratorDelegate(inner) {
	  var iter = {},
	    waiting = !1;
	  function pump(key, value) {
	    return waiting = !0, value = new Promise(function (resolve) {
	      resolve(inner[key](value));
	    }), {
	      done: !1,
	      value: new _OverloadYield(value, 1)
	    };
	  }
	  return iter["undefined" != typeof Symbol && Symbol.iterator || "@@iterator"] = function () {
	    return this;
	  }, iter.next = function (value) {
	    return waiting ? (waiting = !1, value) : pump("next", value);
	  }, "function" == typeof inner.throw && (iter.throw = function (value) {
	    if (waiting) throw waiting = !1, value;
	    return pump("throw", value);
	  }), "function" == typeof inner.return && (iter.return = function (value) {
	    return waiting ? (waiting = !1, value) : pump("return", value);
	  }), iter;
	}
	function _asyncIterator(iterable) {
	  var method,
	    async,
	    sync,
	    retry = 2;
	  for ("undefined" != typeof Symbol && (async = Symbol.asyncIterator, sync = Symbol.iterator); retry--;) {
	    if (async && null != (method = iterable[async])) return method.call(iterable);
	    if (sync && null != (method = iterable[sync])) return new AsyncFromSyncIterator(method.call(iterable));
	    async = "@@asyncIterator", sync = "@@iterator";
	  }
	  throw new TypeError("Object is not async iterable");
	}
	function AsyncFromSyncIterator(s) {
	  function AsyncFromSyncIteratorContinuation(r) {
	    if (Object(r) !== r) return Promise.reject(new TypeError(r + " is not an object."));
	    var done = r.done;
	    return Promise.resolve(r.value).then(function (value) {
	      return {
	        value: value,
	        done: done
	      };
	    });
	  }
	  return AsyncFromSyncIterator = function (s) {
	    this.s = s, this.n = s.next;
	  }, AsyncFromSyncIterator.prototype = {
	    s: null,
	    n: null,
	    next: function () {
	      return AsyncFromSyncIteratorContinuation(this.n.apply(this.s, arguments));
	    },
	    return: function (value) {
	      var ret = this.s.return;
	      return void 0 === ret ? Promise.resolve({
	        value: value,
	        done: !0
	      }) : AsyncFromSyncIteratorContinuation(ret.apply(this.s, arguments));
	    },
	    throw: function (value) {
	      var thr = this.s.return;
	      return void 0 === thr ? Promise.reject(value) : AsyncFromSyncIteratorContinuation(thr.apply(this.s, arguments));
	    }
	  }, new AsyncFromSyncIterator(s);
	}
	function _awaitAsyncGenerator(value) {
	  return new _OverloadYield(value, 0);
	}
	function _checkInRHS(value) {
	  if (Object(value) !== value) throw TypeError("right-hand side of 'in' should be an object, got " + (null !== value ? typeof value : "null"));
	  return value;
	}
	function _defineAccessor(type, obj, key, fn) {
	  var desc = {
	    configurable: !0,
	    enumerable: !0
	  };
	  return desc[type] = fn, Object.defineProperty(obj, key, desc);
	}
	function _iterableToArrayLimit(arr, i) {
	  var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"];
	  if (null != _i) {
	    var _s,
	      _e,
	      _x,
	      _r,
	      _arr = [],
	      _n = !0,
	      _d = !1;
	    try {
	      if (_x = (_i = _i.call(arr)).next, 0 === i) {
	        if (Object(_i) !== _i) return;
	        _n = !1;
	      } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0);
	    } catch (err) {
	      _d = !0, _e = err;
	    } finally {
	      try {
	        if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return;
	      } finally {
	        if (_d) throw _e;
	      }
	    }
	    return _arr;
	  }
	}
	function _iterableToArrayLimitLoose(arr, i) {
	  var _i = arr && ("undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]);
	  if (null != _i) {
	    var _s,
	      _arr = [];
	    for (_i = _i.call(arr); arr.length < i && !(_s = _i.next()).done;) _arr.push(_s.value);
	    return _arr;
	  }
	}
	var REACT_ELEMENT_TYPE;
	function _jsx(type, props, key, children) {
	  REACT_ELEMENT_TYPE || (REACT_ELEMENT_TYPE = "function" == typeof Symbol && Symbol.for && Symbol.for("react.element") || 60103);
	  var defaultProps = type && type.defaultProps,
	    childrenLength = arguments.length - 3;
	  if (props || 0 === childrenLength || (props = {
	    children: void 0
	  }), 1 === childrenLength) props.children = children;else if (childrenLength > 1) {
	    for (var childArray = new Array(childrenLength), i = 0; i < childrenLength; i++) childArray[i] = arguments[i + 3];
	    props.children = childArray;
	  }
	  if (props && defaultProps) for (var propName in defaultProps) void 0 === props[propName] && (props[propName] = defaultProps[propName]);else props || (props = defaultProps || {});
	  return {
	    $$typeof: REACT_ELEMENT_TYPE,
	    type: type,
	    key: void 0 === key ? null : "" + key,
	    ref: null,
	    props: props,
	    _owner: null
	  };
	}
	function ownKeys$5(object, enumerableOnly) {
	  var keys = Object.keys(object);
	  if (Object.getOwnPropertySymbols) {
	    var symbols = Object.getOwnPropertySymbols(object);
	    enumerableOnly && (symbols = symbols.filter(function (sym) {
	      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
	    })), keys.push.apply(keys, symbols);
	  }
	  return keys;
	}
	function _objectSpread2(target) {
	  for (var i = 1; i < arguments.length; i++) {
	    var source = null != arguments[i] ? arguments[i] : {};
	    i % 2 ? ownKeys$5(Object(source), !0).forEach(function (key) {
	      _defineProperty(target, key, source[key]);
	    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$5(Object(source)).forEach(function (key) {
	      Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
	    });
	  }
	  return target;
	}
	function _regeneratorRuntime() {
	  "use strict"; /*! regenerator-runtime -- Copyright (c) 2014-present, Facebook, Inc. -- license (MIT): https://github.com/facebook/regenerator/blob/main/LICENSE */
	  _regeneratorRuntime = function () {
	    return exports;
	  };
	  var exports = {},
	    Op = Object.prototype,
	    hasOwn = Op.hasOwnProperty,
	    defineProperty = Object.defineProperty || function (obj, key, desc) {
	      obj[key] = desc.value;
	    },
	    $Symbol = "function" == typeof Symbol ? Symbol : {},
	    iteratorSymbol = $Symbol.iterator || "@@iterator",
	    asyncIteratorSymbol = $Symbol.asyncIterator || "@@asyncIterator",
	    toStringTagSymbol = $Symbol.toStringTag || "@@toStringTag";
	  function define(obj, key, value) {
	    return Object.defineProperty(obj, key, {
	      value: value,
	      enumerable: !0,
	      configurable: !0,
	      writable: !0
	    }), obj[key];
	  }
	  try {
	    define({}, "");
	  } catch (err) {
	    define = function (obj, key, value) {
	      return obj[key] = value;
	    };
	  }
	  function wrap(innerFn, outerFn, self, tryLocsList) {
	    var protoGenerator = outerFn && outerFn.prototype instanceof Generator ? outerFn : Generator,
	      generator = Object.create(protoGenerator.prototype),
	      context = new Context(tryLocsList || []);
	    return defineProperty(generator, "_invoke", {
	      value: makeInvokeMethod(innerFn, self, context)
	    }), generator;
	  }
	  function tryCatch(fn, obj, arg) {
	    try {
	      return {
	        type: "normal",
	        arg: fn.call(obj, arg)
	      };
	    } catch (err) {
	      return {
	        type: "throw",
	        arg: err
	      };
	    }
	  }
	  exports.wrap = wrap;
	  var ContinueSentinel = {};
	  function Generator() {}
	  function GeneratorFunction() {}
	  function GeneratorFunctionPrototype() {}
	  var IteratorPrototype = {};
	  define(IteratorPrototype, iteratorSymbol, function () {
	    return this;
	  });
	  var getProto = Object.getPrototypeOf,
	    NativeIteratorPrototype = getProto && getProto(getProto(values([])));
	  NativeIteratorPrototype && NativeIteratorPrototype !== Op && hasOwn.call(NativeIteratorPrototype, iteratorSymbol) && (IteratorPrototype = NativeIteratorPrototype);
	  var Gp = GeneratorFunctionPrototype.prototype = Generator.prototype = Object.create(IteratorPrototype);
	  function defineIteratorMethods(prototype) {
	    ["next", "throw", "return"].forEach(function (method) {
	      define(prototype, method, function (arg) {
	        return this._invoke(method, arg);
	      });
	    });
	  }
	  function AsyncIterator(generator, PromiseImpl) {
	    function invoke(method, arg, resolve, reject) {
	      var record = tryCatch(generator[method], generator, arg);
	      if ("throw" !== record.type) {
	        var result = record.arg,
	          value = result.value;
	        return value && "object" == typeof value && hasOwn.call(value, "__await") ? PromiseImpl.resolve(value.__await).then(function (value) {
	          invoke("next", value, resolve, reject);
	        }, function (err) {
	          invoke("throw", err, resolve, reject);
	        }) : PromiseImpl.resolve(value).then(function (unwrapped) {
	          result.value = unwrapped, resolve(result);
	        }, function (error) {
	          return invoke("throw", error, resolve, reject);
	        });
	      }
	      reject(record.arg);
	    }
	    var previousPromise;
	    defineProperty(this, "_invoke", {
	      value: function (method, arg) {
	        function callInvokeWithMethodAndArg() {
	          return new PromiseImpl(function (resolve, reject) {
	            invoke(method, arg, resolve, reject);
	          });
	        }
	        return previousPromise = previousPromise ? previousPromise.then(callInvokeWithMethodAndArg, callInvokeWithMethodAndArg) : callInvokeWithMethodAndArg();
	      }
	    });
	  }
	  function makeInvokeMethod(innerFn, self, context) {
	    var state = "suspendedStart";
	    return function (method, arg) {
	      if ("executing" === state) throw new Error("Generator is already running");
	      if ("completed" === state) {
	        if ("throw" === method) throw arg;
	        return doneResult();
	      }
	      for (context.method = method, context.arg = arg;;) {
	        var delegate = context.delegate;
	        if (delegate) {
	          var delegateResult = maybeInvokeDelegate(delegate, context);
	          if (delegateResult) {
	            if (delegateResult === ContinueSentinel) continue;
	            return delegateResult;
	          }
	        }
	        if ("next" === context.method) context.sent = context._sent = context.arg;else if ("throw" === context.method) {
	          if ("suspendedStart" === state) throw state = "completed", context.arg;
	          context.dispatchException(context.arg);
	        } else "return" === context.method && context.abrupt("return", context.arg);
	        state = "executing";
	        var record = tryCatch(innerFn, self, context);
	        if ("normal" === record.type) {
	          if (state = context.done ? "completed" : "suspendedYield", record.arg === ContinueSentinel) continue;
	          return {
	            value: record.arg,
	            done: context.done
	          };
	        }
	        "throw" === record.type && (state = "completed", context.method = "throw", context.arg = record.arg);
	      }
	    };
	  }
	  function maybeInvokeDelegate(delegate, context) {
	    var methodName = context.method,
	      method = delegate.iterator[methodName];
	    if (undefined === method) return context.delegate = null, "throw" === methodName && delegate.iterator.return && (context.method = "return", context.arg = undefined, maybeInvokeDelegate(delegate, context), "throw" === context.method) || "return" !== methodName && (context.method = "throw", context.arg = new TypeError("The iterator does not provide a '" + methodName + "' method")), ContinueSentinel;
	    var record = tryCatch(method, delegate.iterator, context.arg);
	    if ("throw" === record.type) return context.method = "throw", context.arg = record.arg, context.delegate = null, ContinueSentinel;
	    var info = record.arg;
	    return info ? info.done ? (context[delegate.resultName] = info.value, context.next = delegate.nextLoc, "return" !== context.method && (context.method = "next", context.arg = undefined), context.delegate = null, ContinueSentinel) : info : (context.method = "throw", context.arg = new TypeError("iterator result is not an object"), context.delegate = null, ContinueSentinel);
	  }
	  function pushTryEntry(locs) {
	    var entry = {
	      tryLoc: locs[0]
	    };
	    1 in locs && (entry.catchLoc = locs[1]), 2 in locs && (entry.finallyLoc = locs[2], entry.afterLoc = locs[3]), this.tryEntries.push(entry);
	  }
	  function resetTryEntry(entry) {
	    var record = entry.completion || {};
	    record.type = "normal", delete record.arg, entry.completion = record;
	  }
	  function Context(tryLocsList) {
	    this.tryEntries = [{
	      tryLoc: "root"
	    }], tryLocsList.forEach(pushTryEntry, this), this.reset(!0);
	  }
	  function values(iterable) {
	    if (iterable) {
	      var iteratorMethod = iterable[iteratorSymbol];
	      if (iteratorMethod) return iteratorMethod.call(iterable);
	      if ("function" == typeof iterable.next) return iterable;
	      if (!isNaN(iterable.length)) {
	        var i = -1,
	          next = function next() {
	            for (; ++i < iterable.length;) if (hasOwn.call(iterable, i)) return next.value = iterable[i], next.done = !1, next;
	            return next.value = undefined, next.done = !0, next;
	          };
	        return next.next = next;
	      }
	    }
	    return {
	      next: doneResult
	    };
	  }
	  function doneResult() {
	    return {
	      value: undefined,
	      done: !0
	    };
	  }
	  return GeneratorFunction.prototype = GeneratorFunctionPrototype, defineProperty(Gp, "constructor", {
	    value: GeneratorFunctionPrototype,
	    configurable: !0
	  }), defineProperty(GeneratorFunctionPrototype, "constructor", {
	    value: GeneratorFunction,
	    configurable: !0
	  }), GeneratorFunction.displayName = define(GeneratorFunctionPrototype, toStringTagSymbol, "GeneratorFunction"), exports.isGeneratorFunction = function (genFun) {
	    var ctor = "function" == typeof genFun && genFun.constructor;
	    return !!ctor && (ctor === GeneratorFunction || "GeneratorFunction" === (ctor.displayName || ctor.name));
	  }, exports.mark = function (genFun) {
	    return Object.setPrototypeOf ? Object.setPrototypeOf(genFun, GeneratorFunctionPrototype) : (genFun.__proto__ = GeneratorFunctionPrototype, define(genFun, toStringTagSymbol, "GeneratorFunction")), genFun.prototype = Object.create(Gp), genFun;
	  }, exports.awrap = function (arg) {
	    return {
	      __await: arg
	    };
	  }, defineIteratorMethods(AsyncIterator.prototype), define(AsyncIterator.prototype, asyncIteratorSymbol, function () {
	    return this;
	  }), exports.AsyncIterator = AsyncIterator, exports.async = function (innerFn, outerFn, self, tryLocsList, PromiseImpl) {
	    void 0 === PromiseImpl && (PromiseImpl = Promise);
	    var iter = new AsyncIterator(wrap(innerFn, outerFn, self, tryLocsList), PromiseImpl);
	    return exports.isGeneratorFunction(outerFn) ? iter : iter.next().then(function (result) {
	      return result.done ? result.value : iter.next();
	    });
	  }, defineIteratorMethods(Gp), define(Gp, toStringTagSymbol, "Generator"), define(Gp, iteratorSymbol, function () {
	    return this;
	  }), define(Gp, "toString", function () {
	    return "[object Generator]";
	  }), exports.keys = function (val) {
	    var object = Object(val),
	      keys = [];
	    for (var key in object) keys.push(key);
	    return keys.reverse(), function next() {
	      for (; keys.length;) {
	        var key = keys.pop();
	        if (key in object) return next.value = key, next.done = !1, next;
	      }
	      return next.done = !0, next;
	    };
	  }, exports.values = values, Context.prototype = {
	    constructor: Context,
	    reset: function (skipTempReset) {
	      if (this.prev = 0, this.next = 0, this.sent = this._sent = undefined, this.done = !1, this.delegate = null, this.method = "next", this.arg = undefined, this.tryEntries.forEach(resetTryEntry), !skipTempReset) for (var name in this) "t" === name.charAt(0) && hasOwn.call(this, name) && !isNaN(+name.slice(1)) && (this[name] = undefined);
	    },
	    stop: function () {
	      this.done = !0;
	      var rootRecord = this.tryEntries[0].completion;
	      if ("throw" === rootRecord.type) throw rootRecord.arg;
	      return this.rval;
	    },
	    dispatchException: function (exception) {
	      if (this.done) throw exception;
	      var context = this;
	      function handle(loc, caught) {
	        return record.type = "throw", record.arg = exception, context.next = loc, caught && (context.method = "next", context.arg = undefined), !!caught;
	      }
	      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
	        var entry = this.tryEntries[i],
	          record = entry.completion;
	        if ("root" === entry.tryLoc) return handle("end");
	        if (entry.tryLoc <= this.prev) {
	          var hasCatch = hasOwn.call(entry, "catchLoc"),
	            hasFinally = hasOwn.call(entry, "finallyLoc");
	          if (hasCatch && hasFinally) {
	            if (this.prev < entry.catchLoc) return handle(entry.catchLoc, !0);
	            if (this.prev < entry.finallyLoc) return handle(entry.finallyLoc);
	          } else if (hasCatch) {
	            if (this.prev < entry.catchLoc) return handle(entry.catchLoc, !0);
	          } else {
	            if (!hasFinally) throw new Error("try statement without catch or finally");
	            if (this.prev < entry.finallyLoc) return handle(entry.finallyLoc);
	          }
	        }
	      }
	    },
	    abrupt: function (type, arg) {
	      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
	        var entry = this.tryEntries[i];
	        if (entry.tryLoc <= this.prev && hasOwn.call(entry, "finallyLoc") && this.prev < entry.finallyLoc) {
	          var finallyEntry = entry;
	          break;
	        }
	      }
	      finallyEntry && ("break" === type || "continue" === type) && finallyEntry.tryLoc <= arg && arg <= finallyEntry.finallyLoc && (finallyEntry = null);
	      var record = finallyEntry ? finallyEntry.completion : {};
	      return record.type = type, record.arg = arg, finallyEntry ? (this.method = "next", this.next = finallyEntry.finallyLoc, ContinueSentinel) : this.complete(record);
	    },
	    complete: function (record, afterLoc) {
	      if ("throw" === record.type) throw record.arg;
	      return "break" === record.type || "continue" === record.type ? this.next = record.arg : "return" === record.type ? (this.rval = this.arg = record.arg, this.method = "return", this.next = "end") : "normal" === record.type && afterLoc && (this.next = afterLoc), ContinueSentinel;
	    },
	    finish: function (finallyLoc) {
	      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
	        var entry = this.tryEntries[i];
	        if (entry.finallyLoc === finallyLoc) return this.complete(entry.completion, entry.afterLoc), resetTryEntry(entry), ContinueSentinel;
	      }
	    },
	    catch: function (tryLoc) {
	      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
	        var entry = this.tryEntries[i];
	        if (entry.tryLoc === tryLoc) {
	          var record = entry.completion;
	          if ("throw" === record.type) {
	            var thrown = record.arg;
	            resetTryEntry(entry);
	          }
	          return thrown;
	        }
	      }
	      throw new Error("illegal catch attempt");
	    },
	    delegateYield: function (iterable, resultName, nextLoc) {
	      return this.delegate = {
	        iterator: values(iterable),
	        resultName: resultName,
	        nextLoc: nextLoc
	      }, "next" === this.method && (this.arg = undefined), ContinueSentinel;
	    }
	  }, exports;
	}
	function _typeof(obj) {
	  "@babel/helpers - typeof";

	  return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) {
	    return typeof obj;
	  } : function (obj) {
	    return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
	  }, _typeof(obj);
	}
	function _wrapRegExp() {
	  _wrapRegExp = function (re, groups) {
	    return new BabelRegExp(re, void 0, groups);
	  };
	  var _super = RegExp.prototype,
	    _groups = new WeakMap();
	  function BabelRegExp(re, flags, groups) {
	    var _this = new RegExp(re, flags);
	    return _groups.set(_this, groups || _groups.get(re)), _setPrototypeOf(_this, BabelRegExp.prototype);
	  }
	  function buildGroups(result, re) {
	    var g = _groups.get(re);
	    return Object.keys(g).reduce(function (groups, name) {
	      var i = g[name];
	      if ("number" == typeof i) groups[name] = result[i];else {
	        for (var k = 0; void 0 === result[i[k]] && k + 1 < i.length;) k++;
	        groups[name] = result[i[k]];
	      }
	      return groups;
	    }, Object.create(null));
	  }
	  return _inherits(BabelRegExp, RegExp), BabelRegExp.prototype.exec = function (str) {
	    var result = _super.exec.call(this, str);
	    if (result) {
	      result.groups = buildGroups(result, this);
	      var indices = result.indices;
	      indices && (indices.groups = buildGroups(indices, this));
	    }
	    return result;
	  }, BabelRegExp.prototype[Symbol.replace] = function (str, substitution) {
	    if ("string" == typeof substitution) {
	      var groups = _groups.get(this);
	      return _super[Symbol.replace].call(this, str, substitution.replace(/\$<([^>]+)>/g, function (_, name) {
	        var group = groups[name];
	        return "$" + (Array.isArray(group) ? group.join("$") : group);
	      }));
	    }
	    if ("function" == typeof substitution) {
	      var _this = this;
	      return _super[Symbol.replace].call(this, str, function () {
	        var args = arguments;
	        return "object" != typeof args[args.length - 1] && (args = [].slice.call(args)).push(buildGroups(args, _this)), substitution.apply(this, args);
	      });
	    }
	    return _super[Symbol.replace].call(this, str, substitution);
	  }, _wrapRegExp.apply(this, arguments);
	}
	function _AwaitValue(value) {
	  this.wrapped = value;
	}
	function _wrapAsyncGenerator(fn) {
	  return function () {
	    return new _AsyncGenerator(fn.apply(this, arguments));
	  };
	}
	function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
	  try {
	    var info = gen[key](arg);
	    var value = info.value;
	  } catch (error) {
	    reject(error);
	    return;
	  }
	  if (info.done) {
	    resolve(value);
	  } else {
	    Promise.resolve(value).then(_next, _throw);
	  }
	}
	function _asyncToGenerator(fn) {
	  return function () {
	    var self = this,
	      args = arguments;
	    return new Promise(function (resolve, reject) {
	      var gen = fn.apply(self, args);
	      function _next(value) {
	        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
	      }
	      function _throw(err) {
	        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
	      }
	      _next(undefined);
	    });
	  };
	}
	function _classCallCheck(instance, Constructor) {
	  if (!(instance instanceof Constructor)) {
	    throw new TypeError("Cannot call a class as a function");
	  }
	}
	function _defineProperties(target, props) {
	  for (var i = 0; i < props.length; i++) {
	    var descriptor = props[i];
	    descriptor.enumerable = descriptor.enumerable || false;
	    descriptor.configurable = true;
	    if ("value" in descriptor) descriptor.writable = true;
	    Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor);
	  }
	}
	function _createClass(Constructor, protoProps, staticProps) {
	  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
	  if (staticProps) _defineProperties(Constructor, staticProps);
	  Object.defineProperty(Constructor, "prototype", {
	    writable: false
	  });
	  return Constructor;
	}
	function _defineEnumerableProperties(obj, descs) {
	  for (var key in descs) {
	    var desc = descs[key];
	    desc.configurable = desc.enumerable = true;
	    if ("value" in desc) desc.writable = true;
	    Object.defineProperty(obj, key, desc);
	  }
	  if (Object.getOwnPropertySymbols) {
	    var objectSymbols = Object.getOwnPropertySymbols(descs);
	    for (var i = 0; i < objectSymbols.length; i++) {
	      var sym = objectSymbols[i];
	      var desc = descs[sym];
	      desc.configurable = desc.enumerable = true;
	      if ("value" in desc) desc.writable = true;
	      Object.defineProperty(obj, sym, desc);
	    }
	  }
	  return obj;
	}
	function _defaults(obj, defaults) {
	  var keys = Object.getOwnPropertyNames(defaults);
	  for (var i = 0; i < keys.length; i++) {
	    var key = keys[i];
	    var value = Object.getOwnPropertyDescriptor(defaults, key);
	    if (value && value.configurable && obj[key] === undefined) {
	      Object.defineProperty(obj, key, value);
	    }
	  }
	  return obj;
	}
	function _defineProperty(obj, key, value) {
	  key = _toPropertyKey(key);
	  if (key in obj) {
	    Object.defineProperty(obj, key, {
	      value: value,
	      enumerable: true,
	      configurable: true,
	      writable: true
	    });
	  } else {
	    obj[key] = value;
	  }
	  return obj;
	}
	function _extends() {
	  _extends = Object.assign ? Object.assign.bind() : function (target) {
	    for (var i = 1; i < arguments.length; i++) {
	      var source = arguments[i];
	      for (var key in source) {
	        if (Object.prototype.hasOwnProperty.call(source, key)) {
	          target[key] = source[key];
	        }
	      }
	    }
	    return target;
	  };
	  return _extends.apply(this, arguments);
	}
	function _objectSpread(target) {
	  for (var i = 1; i < arguments.length; i++) {
	    var source = arguments[i] != null ? Object(arguments[i]) : {};
	    var ownKeys = Object.keys(source);
	    if (typeof Object.getOwnPropertySymbols === 'function') {
	      ownKeys.push.apply(ownKeys, Object.getOwnPropertySymbols(source).filter(function (sym) {
	        return Object.getOwnPropertyDescriptor(source, sym).enumerable;
	      }));
	    }
	    ownKeys.forEach(function (key) {
	      _defineProperty(target, key, source[key]);
	    });
	  }
	  return target;
	}
	function _inherits(subClass, superClass) {
	  if (typeof superClass !== "function" && superClass !== null) {
	    throw new TypeError("Super expression must either be null or a function");
	  }
	  subClass.prototype = Object.create(superClass && superClass.prototype, {
	    constructor: {
	      value: subClass,
	      writable: true,
	      configurable: true
	    }
	  });
	  Object.defineProperty(subClass, "prototype", {
	    writable: false
	  });
	  if (superClass) _setPrototypeOf(subClass, superClass);
	}
	function _inheritsLoose(subClass, superClass) {
	  subClass.prototype = Object.create(superClass.prototype);
	  subClass.prototype.constructor = subClass;
	  _setPrototypeOf(subClass, superClass);
	}
	function _getPrototypeOf(o) {
	  _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf.bind() : function _getPrototypeOf(o) {
	    return o.__proto__ || Object.getPrototypeOf(o);
	  };
	  return _getPrototypeOf(o);
	}
	function _setPrototypeOf(o, p) {
	  _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) {
	    o.__proto__ = p;
	    return o;
	  };
	  return _setPrototypeOf(o, p);
	}
	function _isNativeReflectConstruct() {
	  if (typeof Reflect === "undefined" || !Reflect.construct) return false;
	  if (Reflect.construct.sham) return false;
	  if (typeof Proxy === "function") return true;
	  try {
	    Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {}));
	    return true;
	  } catch (e) {
	    return false;
	  }
	}
	function _construct(Parent, args, Class) {
	  if (_isNativeReflectConstruct()) {
	    _construct = Reflect.construct.bind();
	  } else {
	    _construct = function _construct(Parent, args, Class) {
	      var a = [null];
	      a.push.apply(a, args);
	      var Constructor = Function.bind.apply(Parent, a);
	      var instance = new Constructor();
	      if (Class) _setPrototypeOf(instance, Class.prototype);
	      return instance;
	    };
	  }
	  return _construct.apply(null, arguments);
	}
	function _isNativeFunction(fn) {
	  return Function.toString.call(fn).indexOf("[native code]") !== -1;
	}
	function _wrapNativeSuper(Class) {
	  var _cache = typeof Map === "function" ? new Map() : undefined;
	  _wrapNativeSuper = function _wrapNativeSuper(Class) {
	    if (Class === null || !_isNativeFunction(Class)) return Class;
	    if (typeof Class !== "function") {
	      throw new TypeError("Super expression must either be null or a function");
	    }
	    if (typeof _cache !== "undefined") {
	      if (_cache.has(Class)) return _cache.get(Class);
	      _cache.set(Class, Wrapper);
	    }
	    function Wrapper() {
	      return _construct(Class, arguments, _getPrototypeOf(this).constructor);
	    }
	    Wrapper.prototype = Object.create(Class.prototype, {
	      constructor: {
	        value: Wrapper,
	        enumerable: false,
	        writable: true,
	        configurable: true
	      }
	    });
	    return _setPrototypeOf(Wrapper, Class);
	  };
	  return _wrapNativeSuper(Class);
	}
	function _instanceof(left, right) {
	  if (right != null && typeof Symbol !== "undefined" && right[Symbol.hasInstance]) {
	    return !!right[Symbol.hasInstance](left);
	  } else {
	    return left instanceof right;
	  }
	}
	function _interopRequireDefault(obj) {
	  return obj && obj.__esModule ? obj : {
	    default: obj
	  };
	}
	function _getRequireWildcardCache(nodeInterop) {
	  if (typeof WeakMap !== "function") return null;
	  var cacheBabelInterop = new WeakMap();
	  var cacheNodeInterop = new WeakMap();
	  return (_getRequireWildcardCache = function (nodeInterop) {
	    return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
	  })(nodeInterop);
	}
	function _interopRequireWildcard(obj, nodeInterop) {
	  if (!nodeInterop && obj && obj.__esModule) {
	    return obj;
	  }
	  if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
	    return {
	      default: obj
	    };
	  }
	  var cache = _getRequireWildcardCache(nodeInterop);
	  if (cache && cache.has(obj)) {
	    return cache.get(obj);
	  }
	  var newObj = {};
	  var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
	  for (var key in obj) {
	    if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
	      var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
	      if (desc && (desc.get || desc.set)) {
	        Object.defineProperty(newObj, key, desc);
	      } else {
	        newObj[key] = obj[key];
	      }
	    }
	  }
	  newObj.default = obj;
	  if (cache) {
	    cache.set(obj, newObj);
	  }
	  return newObj;
	}
	function _newArrowCheck(innerThis, boundThis) {
	  if (innerThis !== boundThis) {
	    throw new TypeError("Cannot instantiate an arrow function");
	  }
	}
	function _objectDestructuringEmpty(obj) {
	  if (obj == null) throw new TypeError("Cannot destructure " + obj);
	}
	function _objectWithoutPropertiesLoose(source, excluded) {
	  if (source == null) return {};
	  var target = {};
	  var sourceKeys = Object.keys(source);
	  var key, i;
	  for (i = 0; i < sourceKeys.length; i++) {
	    key = sourceKeys[i];
	    if (excluded.indexOf(key) >= 0) continue;
	    target[key] = source[key];
	  }
	  return target;
	}
	function _objectWithoutProperties(source, excluded) {
	  if (source == null) return {};
	  var target = _objectWithoutPropertiesLoose(source, excluded);
	  var key, i;
	  if (Object.getOwnPropertySymbols) {
	    var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
	    for (i = 0; i < sourceSymbolKeys.length; i++) {
	      key = sourceSymbolKeys[i];
	      if (excluded.indexOf(key) >= 0) continue;
	      if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
	      target[key] = source[key];
	    }
	  }
	  return target;
	}
	function _assertThisInitialized(self) {
	  if (self === void 0) {
	    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
	  }
	  return self;
	}
	function _possibleConstructorReturn(self, call) {
	  if (call && (typeof call === "object" || typeof call === "function")) {
	    return call;
	  } else if (call !== void 0) {
	    throw new TypeError("Derived constructors may only return object or undefined");
	  }
	  return _assertThisInitialized(self);
	}
	function _createSuper(Derived) {
	  var hasNativeReflectConstruct = _isNativeReflectConstruct();
	  return function _createSuperInternal() {
	    var Super = _getPrototypeOf(Derived),
	      result;
	    if (hasNativeReflectConstruct) {
	      var NewTarget = _getPrototypeOf(this).constructor;
	      result = Reflect.construct(Super, arguments, NewTarget);
	    } else {
	      result = Super.apply(this, arguments);
	    }
	    return _possibleConstructorReturn(this, result);
	  };
	}
	function _superPropBase(object, property) {
	  while (!Object.prototype.hasOwnProperty.call(object, property)) {
	    object = _getPrototypeOf(object);
	    if (object === null) break;
	  }
	  return object;
	}
	function _get() {
	  if (typeof Reflect !== "undefined" && Reflect.get) {
	    _get = Reflect.get.bind();
	  } else {
	    _get = function _get(target, property, receiver) {
	      var base = _superPropBase(target, property);
	      if (!base) return;
	      var desc = Object.getOwnPropertyDescriptor(base, property);
	      if (desc.get) {
	        return desc.get.call(arguments.length < 3 ? target : receiver);
	      }
	      return desc.value;
	    };
	  }
	  return _get.apply(this, arguments);
	}
	function set$4(target, property, value, receiver) {
	  if (typeof Reflect !== "undefined" && Reflect.set) {
	    set$4 = Reflect.set;
	  } else {
	    set$4 = function set(target, property, value, receiver) {
	      var base = _superPropBase(target, property);
	      var desc;
	      if (base) {
	        desc = Object.getOwnPropertyDescriptor(base, property);
	        if (desc.set) {
	          desc.set.call(receiver, value);
	          return true;
	        } else if (!desc.writable) {
	          return false;
	        }
	      }
	      desc = Object.getOwnPropertyDescriptor(receiver, property);
	      if (desc) {
	        if (!desc.writable) {
	          return false;
	        }
	        desc.value = value;
	        Object.defineProperty(receiver, property, desc);
	      } else {
	        _defineProperty(receiver, property, value);
	      }
	      return true;
	    };
	  }
	  return set$4(target, property, value, receiver);
	}
	function _set(target, property, value, receiver, isStrict) {
	  var s = set$4(target, property, value, receiver || target);
	  if (!s && isStrict) {
	    throw new TypeError('failed to set property');
	  }
	  return value;
	}
	function _taggedTemplateLiteral(strings, raw) {
	  if (!raw) {
	    raw = strings.slice(0);
	  }
	  return Object.freeze(Object.defineProperties(strings, {
	    raw: {
	      value: Object.freeze(raw)
	    }
	  }));
	}
	function _taggedTemplateLiteralLoose(strings, raw) {
	  if (!raw) {
	    raw = strings.slice(0);
	  }
	  strings.raw = raw;
	  return strings;
	}
	function _readOnlyError(name) {
	  throw new TypeError("\"" + name + "\" is read-only");
	}
	function _writeOnlyError(name) {
	  throw new TypeError("\"" + name + "\" is write-only");
	}
	function _classNameTDZError(name) {
	  throw new ReferenceError("Class \"" + name + "\" cannot be referenced in computed property keys.");
	}
	function _temporalUndefined() {}
	function _tdz(name) {
	  throw new ReferenceError(name + " is not defined - temporal dead zone");
	}
	function _temporalRef(val, name) {
	  return val === _temporalUndefined ? _tdz(name) : val;
	}
	function _slicedToArray(arr, i) {
	  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();
	}
	function _slicedToArrayLoose(arr, i) {
	  return _arrayWithHoles(arr) || _iterableToArrayLimitLoose(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();
	}
	function _toArray(arr) {
	  return _arrayWithHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableRest();
	}
	function _toConsumableArray(arr) {
	  return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread();
	}
	function _arrayWithoutHoles(arr) {
	  if (Array.isArray(arr)) return _arrayLikeToArray(arr);
	}
	function _arrayWithHoles(arr) {
	  if (Array.isArray(arr)) return arr;
	}
	function _maybeArrayLike(next, arr, i) {
	  if (arr && !Array.isArray(arr) && typeof arr.length === "number") {
	    var len = arr.length;
	    return _arrayLikeToArray(arr, i !== void 0 && i < len ? i : len);
	  }
	  return next(arr, i);
	}
	function _iterableToArray(iter) {
	  if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter);
	}
	function _unsupportedIterableToArray(o, minLen) {
	  if (!o) return;
	  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
	  var n = Object.prototype.toString.call(o).slice(8, -1);
	  if (n === "Object" && o.constructor) n = o.constructor.name;
	  if (n === "Map" || n === "Set") return Array.from(o);
	  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
	}
	function _arrayLikeToArray(arr, len) {
	  if (len == null || len > arr.length) len = arr.length;
	  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];
	  return arr2;
	}
	function _nonIterableSpread() {
	  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
	}
	function _nonIterableRest() {
	  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
	}
	function _createForOfIteratorHelper(o, allowArrayLike) {
	  var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];
	  if (!it) {
	    if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
	      if (it) o = it;
	      var i = 0;
	      var F = function () {};
	      return {
	        s: F,
	        n: function () {
	          if (i >= o.length) return {
	            done: true
	          };
	          return {
	            done: false,
	            value: o[i++]
	          };
	        },
	        e: function (e) {
	          throw e;
	        },
	        f: F
	      };
	    }
	    throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
	  }
	  var normalCompletion = true,
	    didErr = false,
	    err;
	  return {
	    s: function () {
	      it = it.call(o);
	    },
	    n: function () {
	      var step = it.next();
	      normalCompletion = step.done;
	      return step;
	    },
	    e: function (e) {
	      didErr = true;
	      err = e;
	    },
	    f: function () {
	      try {
	        if (!normalCompletion && it.return != null) it.return();
	      } finally {
	        if (didErr) throw err;
	      }
	    }
	  };
	}
	function _createForOfIteratorHelperLoose(o, allowArrayLike) {
	  var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"];
	  if (it) return (it = it.call(o)).next.bind(it);
	  if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
	    if (it) o = it;
	    var i = 0;
	    return function () {
	      if (i >= o.length) return {
	        done: true
	      };
	      return {
	        done: false,
	        value: o[i++]
	      };
	    };
	  }
	  throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
	}
	function _skipFirstGeneratorNext(fn) {
	  return function () {
	    var it = fn.apply(this, arguments);
	    it.next();
	    return it;
	  };
	}
	function _toPrimitive(input, hint) {
	  if (typeof input !== "object" || input === null) return input;
	  var prim = input[Symbol.toPrimitive];
	  if (prim !== undefined) {
	    var res = prim.call(input, hint || "default");
	    if (typeof res !== "object") return res;
	    throw new TypeError("@@toPrimitive must return a primitive value.");
	  }
	  return (hint === "string" ? String : Number)(input);
	}
	function _toPropertyKey(arg) {
	  var key = _toPrimitive(arg, "string");
	  return typeof key === "symbol" ? key : String(key);
	}
	function _initializerWarningHelper(descriptor, context) {
	  throw new Error('Decorating class property failed. Please ensure that ' + 'proposal-class-properties is enabled and runs after the decorators transform.');
	}
	function _initializerDefineProperty(target, property, descriptor, context) {
	  if (!descriptor) return;
	  Object.defineProperty(target, property, {
	    enumerable: descriptor.enumerable,
	    configurable: descriptor.configurable,
	    writable: descriptor.writable,
	    value: descriptor.initializer ? descriptor.initializer.call(context) : void 0
	  });
	}
	function _applyDecoratedDescriptor(target, property, decorators, descriptor, context) {
	  var desc = {};
	  Object.keys(descriptor).forEach(function (key) {
	    desc[key] = descriptor[key];
	  });
	  desc.enumerable = !!desc.enumerable;
	  desc.configurable = !!desc.configurable;
	  if ('value' in desc || desc.initializer) {
	    desc.writable = true;
	  }
	  desc = decorators.slice().reverse().reduce(function (desc, decorator) {
	    return decorator(target, property, desc) || desc;
	  }, desc);
	  if (context && desc.initializer !== void 0) {
	    desc.value = desc.initializer ? desc.initializer.call(context) : void 0;
	    desc.initializer = undefined;
	  }
	  if (desc.initializer === void 0) {
	    Object.defineProperty(target, property, desc);
	    desc = null;
	  }
	  return desc;
	}
	var id$3 = 0;
	function _classPrivateFieldLooseKey(name) {
	  return "__private_" + id$3++ + "_" + name;
	}
	function _classPrivateFieldLooseBase(receiver, privateKey) {
	  if (!Object.prototype.hasOwnProperty.call(receiver, privateKey)) {
	    throw new TypeError("attempted to use private field on non-instance");
	  }
	  return receiver;
	}
	function _classPrivateFieldGet(receiver, privateMap) {
	  var descriptor = _classExtractFieldDescriptor(receiver, privateMap, "get");
	  return _classApplyDescriptorGet(receiver, descriptor);
	}
	function _classPrivateFieldSet(receiver, privateMap, value) {
	  var descriptor = _classExtractFieldDescriptor(receiver, privateMap, "set");
	  _classApplyDescriptorSet(receiver, descriptor, value);
	  return value;
	}
	function _classPrivateFieldDestructureSet(receiver, privateMap) {
	  var descriptor = _classExtractFieldDescriptor(receiver, privateMap, "set");
	  return _classApplyDescriptorDestructureSet(receiver, descriptor);
	}
	function _classExtractFieldDescriptor(receiver, privateMap, action) {
	  if (!privateMap.has(receiver)) {
	    throw new TypeError("attempted to " + action + " private field on non-instance");
	  }
	  return privateMap.get(receiver);
	}
	function _classStaticPrivateFieldSpecGet(receiver, classConstructor, descriptor) {
	  _classCheckPrivateStaticAccess(receiver, classConstructor);
	  _classCheckPrivateStaticFieldDescriptor(descriptor, "get");
	  return _classApplyDescriptorGet(receiver, descriptor);
	}
	function _classStaticPrivateFieldSpecSet(receiver, classConstructor, descriptor, value) {
	  _classCheckPrivateStaticAccess(receiver, classConstructor);
	  _classCheckPrivateStaticFieldDescriptor(descriptor, "set");
	  _classApplyDescriptorSet(receiver, descriptor, value);
	  return value;
	}
	function _classStaticPrivateMethodGet(receiver, classConstructor, method) {
	  _classCheckPrivateStaticAccess(receiver, classConstructor);
	  return method;
	}
	function _classStaticPrivateMethodSet() {
	  throw new TypeError("attempted to set read only static private field");
	}
	function _classApplyDescriptorGet(receiver, descriptor) {
	  if (descriptor.get) {
	    return descriptor.get.call(receiver);
	  }
	  return descriptor.value;
	}
	function _classApplyDescriptorSet(receiver, descriptor, value) {
	  if (descriptor.set) {
	    descriptor.set.call(receiver, value);
	  } else {
	    if (!descriptor.writable) {
	      throw new TypeError("attempted to set read only private field");
	    }
	    descriptor.value = value;
	  }
	}
	function _classApplyDescriptorDestructureSet(receiver, descriptor) {
	  if (descriptor.set) {
	    if (!("__destrObj" in descriptor)) {
	      descriptor.__destrObj = {
	        set value(v) {
	          descriptor.set.call(receiver, v);
	        }
	      };
	    }
	    return descriptor.__destrObj;
	  } else {
	    if (!descriptor.writable) {
	      throw new TypeError("attempted to set read only private field");
	    }
	    return descriptor;
	  }
	}
	function _classStaticPrivateFieldDestructureSet(receiver, classConstructor, descriptor) {
	  _classCheckPrivateStaticAccess(receiver, classConstructor);
	  _classCheckPrivateStaticFieldDescriptor(descriptor, "set");
	  return _classApplyDescriptorDestructureSet(receiver, descriptor);
	}
	function _classCheckPrivateStaticAccess(receiver, classConstructor) {
	  if (receiver !== classConstructor) {
	    throw new TypeError("Private static access of wrong provenance");
	  }
	}
	function _classCheckPrivateStaticFieldDescriptor(descriptor, action) {
	  if (descriptor === undefined) {
	    throw new TypeError("attempted to " + action + " private static field before its declaration");
	  }
	}
	function _decorate(decorators, factory, superClass, mixins) {
	  var api = _getDecoratorsApi();
	  if (mixins) {
	    for (var i = 0; i < mixins.length; i++) {
	      api = mixins[i](api);
	    }
	  }
	  var r = factory(function initialize(O) {
	    api.initializeInstanceElements(O, decorated.elements);
	  }, superClass);
	  var decorated = api.decorateClass(_coalesceClassElements(r.d.map(_createElementDescriptor)), decorators);
	  api.initializeClassElements(r.F, decorated.elements);
	  return api.runClassFinishers(r.F, decorated.finishers);
	}
	function _getDecoratorsApi() {
	  _getDecoratorsApi = function () {
	    return api;
	  };
	  var api = {
	    elementsDefinitionOrder: [["method"], ["field"]],
	    initializeInstanceElements: function (O, elements) {
	      ["method", "field"].forEach(function (kind) {
	        elements.forEach(function (element) {
	          if (element.kind === kind && element.placement === "own") {
	            this.defineClassElement(O, element);
	          }
	        }, this);
	      }, this);
	    },
	    initializeClassElements: function (F, elements) {
	      var proto = F.prototype;
	      ["method", "field"].forEach(function (kind) {
	        elements.forEach(function (element) {
	          var placement = element.placement;
	          if (element.kind === kind && (placement === "static" || placement === "prototype")) {
	            var receiver = placement === "static" ? F : proto;
	            this.defineClassElement(receiver, element);
	          }
	        }, this);
	      }, this);
	    },
	    defineClassElement: function (receiver, element) {
	      var descriptor = element.descriptor;
	      if (element.kind === "field") {
	        var initializer = element.initializer;
	        descriptor = {
	          enumerable: descriptor.enumerable,
	          writable: descriptor.writable,
	          configurable: descriptor.configurable,
	          value: initializer === void 0 ? void 0 : initializer.call(receiver)
	        };
	      }
	      Object.defineProperty(receiver, element.key, descriptor);
	    },
	    decorateClass: function (elements, decorators) {
	      var newElements = [];
	      var finishers = [];
	      var placements = {
	        static: [],
	        prototype: [],
	        own: []
	      };
	      elements.forEach(function (element) {
	        this.addElementPlacement(element, placements);
	      }, this);
	      elements.forEach(function (element) {
	        if (!_hasDecorators(element)) return newElements.push(element);
	        var elementFinishersExtras = this.decorateElement(element, placements);
	        newElements.push(elementFinishersExtras.element);
	        newElements.push.apply(newElements, elementFinishersExtras.extras);
	        finishers.push.apply(finishers, elementFinishersExtras.finishers);
	      }, this);
	      if (!decorators) {
	        return {
	          elements: newElements,
	          finishers: finishers
	        };
	      }
	      var result = this.decorateConstructor(newElements, decorators);
	      finishers.push.apply(finishers, result.finishers);
	      result.finishers = finishers;
	      return result;
	    },
	    addElementPlacement: function (element, placements, silent) {
	      var keys = placements[element.placement];
	      if (!silent && keys.indexOf(element.key) !== -1) {
	        throw new TypeError("Duplicated element (" + element.key + ")");
	      }
	      keys.push(element.key);
	    },
	    decorateElement: function (element, placements) {
	      var extras = [];
	      var finishers = [];
	      for (var decorators = element.decorators, i = decorators.length - 1; i >= 0; i--) {
	        var keys = placements[element.placement];
	        keys.splice(keys.indexOf(element.key), 1);
	        var elementObject = this.fromElementDescriptor(element);
	        var elementFinisherExtras = this.toElementFinisherExtras((0, decorators[i])(elementObject) || elementObject);
	        element = elementFinisherExtras.element;
	        this.addElementPlacement(element, placements);
	        if (elementFinisherExtras.finisher) {
	          finishers.push(elementFinisherExtras.finisher);
	        }
	        var newExtras = elementFinisherExtras.extras;
	        if (newExtras) {
	          for (var j = 0; j < newExtras.length; j++) {
	            this.addElementPlacement(newExtras[j], placements);
	          }
	          extras.push.apply(extras, newExtras);
	        }
	      }
	      return {
	        element: element,
	        finishers: finishers,
	        extras: extras
	      };
	    },
	    decorateConstructor: function (elements, decorators) {
	      var finishers = [];
	      for (var i = decorators.length - 1; i >= 0; i--) {
	        var obj = this.fromClassDescriptor(elements);
	        var elementsAndFinisher = this.toClassDescriptor((0, decorators[i])(obj) || obj);
	        if (elementsAndFinisher.finisher !== undefined) {
	          finishers.push(elementsAndFinisher.finisher);
	        }
	        if (elementsAndFinisher.elements !== undefined) {
	          elements = elementsAndFinisher.elements;
	          for (var j = 0; j < elements.length - 1; j++) {
	            for (var k = j + 1; k < elements.length; k++) {
	              if (elements[j].key === elements[k].key && elements[j].placement === elements[k].placement) {
	                throw new TypeError("Duplicated element (" + elements[j].key + ")");
	              }
	            }
	          }
	        }
	      }
	      return {
	        elements: elements,
	        finishers: finishers
	      };
	    },
	    fromElementDescriptor: function (element) {
	      var obj = {
	        kind: element.kind,
	        key: element.key,
	        placement: element.placement,
	        descriptor: element.descriptor
	      };
	      var desc = {
	        value: "Descriptor",
	        configurable: true
	      };
	      Object.defineProperty(obj, Symbol.toStringTag, desc);
	      if (element.kind === "field") obj.initializer = element.initializer;
	      return obj;
	    },
	    toElementDescriptors: function (elementObjects) {
	      if (elementObjects === undefined) return;
	      return _toArray(elementObjects).map(function (elementObject) {
	        var element = this.toElementDescriptor(elementObject);
	        this.disallowProperty(elementObject, "finisher", "An element descriptor");
	        this.disallowProperty(elementObject, "extras", "An element descriptor");
	        return element;
	      }, this);
	    },
	    toElementDescriptor: function (elementObject) {
	      var kind = String(elementObject.kind);
	      if (kind !== "method" && kind !== "field") {
	        throw new TypeError('An element descriptor\'s .kind property must be either "method" or' + ' "field", but a decorator created an element descriptor with' + ' .kind "' + kind + '"');
	      }
	      var key = _toPropertyKey(elementObject.key);
	      var placement = String(elementObject.placement);
	      if (placement !== "static" && placement !== "prototype" && placement !== "own") {
	        throw new TypeError('An element descriptor\'s .placement property must be one of "static",' + ' "prototype" or "own", but a decorator created an element descriptor' + ' with .placement "' + placement + '"');
	      }
	      var descriptor = elementObject.descriptor;
	      this.disallowProperty(elementObject, "elements", "An element descriptor");
	      var element = {
	        kind: kind,
	        key: key,
	        placement: placement,
	        descriptor: Object.assign({}, descriptor)
	      };
	      if (kind !== "field") {
	        this.disallowProperty(elementObject, "initializer", "A method descriptor");
	      } else {
	        this.disallowProperty(descriptor, "get", "The property descriptor of a field descriptor");
	        this.disallowProperty(descriptor, "set", "The property descriptor of a field descriptor");
	        this.disallowProperty(descriptor, "value", "The property descriptor of a field descriptor");
	        element.initializer = elementObject.initializer;
	      }
	      return element;
	    },
	    toElementFinisherExtras: function (elementObject) {
	      var element = this.toElementDescriptor(elementObject);
	      var finisher = _optionalCallableProperty(elementObject, "finisher");
	      var extras = this.toElementDescriptors(elementObject.extras);
	      return {
	        element: element,
	        finisher: finisher,
	        extras: extras
	      };
	    },
	    fromClassDescriptor: function (elements) {
	      var obj = {
	        kind: "class",
	        elements: elements.map(this.fromElementDescriptor, this)
	      };
	      var desc = {
	        value: "Descriptor",
	        configurable: true
	      };
	      Object.defineProperty(obj, Symbol.toStringTag, desc);
	      return obj;
	    },
	    toClassDescriptor: function (obj) {
	      var kind = String(obj.kind);
	      if (kind !== "class") {
	        throw new TypeError('A class descriptor\'s .kind property must be "class", but a decorator' + ' created a class descriptor with .kind "' + kind + '"');
	      }
	      this.disallowProperty(obj, "key", "A class descriptor");
	      this.disallowProperty(obj, "placement", "A class descriptor");
	      this.disallowProperty(obj, "descriptor", "A class descriptor");
	      this.disallowProperty(obj, "initializer", "A class descriptor");
	      this.disallowProperty(obj, "extras", "A class descriptor");
	      var finisher = _optionalCallableProperty(obj, "finisher");
	      var elements = this.toElementDescriptors(obj.elements);
	      return {
	        elements: elements,
	        finisher: finisher
	      };
	    },
	    runClassFinishers: function (constructor, finishers) {
	      for (var i = 0; i < finishers.length; i++) {
	        var newConstructor = (0, finishers[i])(constructor);
	        if (newConstructor !== undefined) {
	          if (typeof newConstructor !== "function") {
	            throw new TypeError("Finishers must return a constructor.");
	          }
	          constructor = newConstructor;
	        }
	      }
	      return constructor;
	    },
	    disallowProperty: function (obj, name, objectType) {
	      if (obj[name] !== undefined) {
	        throw new TypeError(objectType + " can't have a ." + name + " property.");
	      }
	    }
	  };
	  return api;
	}
	function _createElementDescriptor(def) {
	  var key = _toPropertyKey(def.key);
	  var descriptor;
	  if (def.kind === "method") {
	    descriptor = {
	      value: def.value,
	      writable: true,
	      configurable: true,
	      enumerable: false
	    };
	  } else if (def.kind === "get") {
	    descriptor = {
	      get: def.value,
	      configurable: true,
	      enumerable: false
	    };
	  } else if (def.kind === "set") {
	    descriptor = {
	      set: def.value,
	      configurable: true,
	      enumerable: false
	    };
	  } else if (def.kind === "field") {
	    descriptor = {
	      configurable: true,
	      writable: true,
	      enumerable: true
	    };
	  }
	  var element = {
	    kind: def.kind === "field" ? "field" : "method",
	    key: key,
	    placement: def.static ? "static" : def.kind === "field" ? "own" : "prototype",
	    descriptor: descriptor
	  };
	  if (def.decorators) element.decorators = def.decorators;
	  if (def.kind === "field") element.initializer = def.value;
	  return element;
	}
	function _coalesceGetterSetter(element, other) {
	  if (element.descriptor.get !== undefined) {
	    other.descriptor.get = element.descriptor.get;
	  } else {
	    other.descriptor.set = element.descriptor.set;
	  }
	}
	function _coalesceClassElements(elements) {
	  var newElements = [];
	  var isSameElement = function (other) {
	    return other.kind === "method" && other.key === element.key && other.placement === element.placement;
	  };
	  for (var i = 0; i < elements.length; i++) {
	    var element = elements[i];
	    var other;
	    if (element.kind === "method" && (other = newElements.find(isSameElement))) {
	      if (_isDataDescriptor(element.descriptor) || _isDataDescriptor(other.descriptor)) {
	        if (_hasDecorators(element) || _hasDecorators(other)) {
	          throw new ReferenceError("Duplicated methods (" + element.key + ") can't be decorated.");
	        }
	        other.descriptor = element.descriptor;
	      } else {
	        if (_hasDecorators(element)) {
	          if (_hasDecorators(other)) {
	            throw new ReferenceError("Decorators can't be placed on different accessors with for " + "the same property (" + element.key + ").");
	          }
	          other.decorators = element.decorators;
	        }
	        _coalesceGetterSetter(element, other);
	      }
	    } else {
	      newElements.push(element);
	    }
	  }
	  return newElements;
	}
	function _hasDecorators(element) {
	  return element.decorators && element.decorators.length;
	}
	function _isDataDescriptor(desc) {
	  return desc !== undefined && !(desc.value === undefined && desc.writable === undefined);
	}
	function _optionalCallableProperty(obj, name) {
	  var value = obj[name];
	  if (value !== undefined && typeof value !== "function") {
	    throw new TypeError("Expected '" + name + "' to be a function");
	  }
	  return value;
	}
	function _classPrivateMethodGet(receiver, privateSet, fn) {
	  if (!privateSet.has(receiver)) {
	    throw new TypeError("attempted to get private field on non-instance");
	  }
	  return fn;
	}
	function _checkPrivateRedeclaration(obj, privateCollection) {
	  if (privateCollection.has(obj)) {
	    throw new TypeError("Cannot initialize the same private elements twice on an object");
	  }
	}
	function _classPrivateFieldInitSpec(obj, privateMap, value) {
	  _checkPrivateRedeclaration(obj, privateMap);
	  privateMap.set(obj, value);
	}
	function _classPrivateMethodInitSpec(obj, privateSet) {
	  _checkPrivateRedeclaration(obj, privateSet);
	  privateSet.add(obj);
	}
	function _classPrivateMethodSet() {
	  throw new TypeError("attempted to reassign private method");
	}
	function _identity(x) {
	  return x;
	}

	var check = function check(it) {
	  return it && it.Math == Math && it;
	};

	// https://github.com/zloirock/core-js/issues/86#issuecomment-115759028
	var global$Z =
	// eslint-disable-next-line es/no-global-this -- safe
	check((typeof globalThis === "undefined" ? "undefined" : _typeof(globalThis)) == 'object' && globalThis) || check((typeof window === "undefined" ? "undefined" : _typeof(window)) == 'object' && window) ||
	// eslint-disable-next-line no-restricted-globals -- safe
	check((typeof self === "undefined" ? "undefined" : _typeof(self)) == 'object' && self) || check(_typeof(commonjsGlobal) == 'object' && commonjsGlobal) ||
	// eslint-disable-next-line no-new-func -- fallback
	function () {
	  return this;
	}() || Function('return this')();
	var global$_ = /*@__PURE__*/getDefaultExportFromCjs(global$Z);

	var objectGetOwnPropertyDescriptor = {};

	var fails$1m = function fails(exec) {
	  try {
	    return !!exec();
	  } catch (error) {
	    return true;
	  }
	};
	var fails$1n = /*@__PURE__*/getDefaultExportFromCjs(fails$1m);

	var fails$1l = fails$1m;

	// Detect IE8's incomplete defineProperty implementation
	var descriptors = !fails$1l(function () {
	  // eslint-disable-next-line es/no-object-defineproperty -- required for testing
	  return Object.defineProperty({}, 1, {
	    get: function get() {
	      return 7;
	    }
	  })[1] != 7;
	});
	var descriptors$1 = /*@__PURE__*/getDefaultExportFromCjs(descriptors);

	var fails$1k = fails$1m;
	var functionBindNative = !fails$1k(function () {
	  // eslint-disable-next-line es/no-function-prototype-bind -- safe
	  var test = function () {/* empty */}.bind();
	  // eslint-disable-next-line no-prototype-builtins -- safe
	  return typeof test != 'function' || test.hasOwnProperty('prototype');
	});
	var functionBindNative$1 = /*@__PURE__*/getDefaultExportFromCjs(functionBindNative);

	var NATIVE_BIND$4 = functionBindNative;
	var call$E = Function.prototype.call;
	var functionCall = NATIVE_BIND$4 ? call$E.bind(call$E) : function () {
	  return call$E.apply(call$E, arguments);
	};
	var functionCall$1 = /*@__PURE__*/getDefaultExportFromCjs(functionCall);

	var objectPropertyIsEnumerable = {};

	'use strict';
	var $propertyIsEnumerable$2 = {}.propertyIsEnumerable;
	// eslint-disable-next-line es/no-object-getownpropertydescriptor -- safe
	var getOwnPropertyDescriptor$a = Object.getOwnPropertyDescriptor;

	// Nashorn ~ JDK8 bug
	var NASHORN_BUG = getOwnPropertyDescriptor$a && !$propertyIsEnumerable$2.call({
	  1: 2
	}, 1);

	// `Object.prototype.propertyIsEnumerable` method implementation
	// https://tc39.es/ecma262/#sec-object.prototype.propertyisenumerable
	var f$8 = objectPropertyIsEnumerable.f = NASHORN_BUG ? function propertyIsEnumerable(V) {
	  var descriptor = getOwnPropertyDescriptor$a(this, V);
	  return !!descriptor && descriptor.enumerable;
	} : $propertyIsEnumerable$2;

	var createPropertyDescriptor$c = function createPropertyDescriptor(bitmap, value) {
	  return {
	    enumerable: !(bitmap & 1),
	    configurable: !(bitmap & 2),
	    writable: !(bitmap & 4),
	    value: value
	  };
	};
	var createPropertyDescriptor$d = /*@__PURE__*/getDefaultExportFromCjs(createPropertyDescriptor$c);

	var NATIVE_BIND$3 = functionBindNative;
	var FunctionPrototype$4 = Function.prototype;
	var call$D = FunctionPrototype$4.call;
	var uncurryThisWithBind = NATIVE_BIND$3 && FunctionPrototype$4.bind.bind(call$D, call$D);
	var functionUncurryThis = NATIVE_BIND$3 ? uncurryThisWithBind : function (fn) {
	  return function () {
	    return call$D.apply(fn, arguments);
	  };
	};
	var functionUncurryThis$1 = /*@__PURE__*/getDefaultExportFromCjs(functionUncurryThis);

	var uncurryThis$1j = functionUncurryThis;
	var toString$A = uncurryThis$1j({}.toString);
	var stringSlice$i = uncurryThis$1j(''.slice);
	var classofRaw$2 = function classofRaw(it) {
	  return stringSlice$i(toString$A(it), 8, -1);
	};
	var classofRaw$3 = /*@__PURE__*/getDefaultExportFromCjs(classofRaw$2);

	var uncurryThis$1i = functionUncurryThis;
	var fails$1j = fails$1m;
	var classof$o = classofRaw$2;
	var $Object$5 = Object;
	var split$7 = uncurryThis$1i(''.split);

	// fallback for non-array-like ES3 and non-enumerable old V8 strings
	var indexedObject = fails$1j(function () {
	  // throws an error in rhino, see https://github.com/mozilla/rhino/issues/346
	  // eslint-disable-next-line no-prototype-builtins -- safe
	  return !$Object$5('z').propertyIsEnumerable(0);
	}) ? function (it) {
	  return classof$o(it) == 'String' ? split$7(it, '') : $Object$5(it);
	} : $Object$5;
	var indexedObject$1 = /*@__PURE__*/getDefaultExportFromCjs(indexedObject);

	// we can't use just `it == null` since of `document.all` special case
	// https://tc39.es/ecma262/#sec-IsHTMLDDA-internal-slot-aec
	var isNullOrUndefined$e = function isNullOrUndefined(it) {
	  return it === null || it === undefined;
	};
	var isNullOrUndefined$f = /*@__PURE__*/getDefaultExportFromCjs(isNullOrUndefined$e);

	var isNullOrUndefined$d = isNullOrUndefined$e;
	var $TypeError$p = TypeError;

	// `RequireObjectCoercible` abstract operation
	// https://tc39.es/ecma262/#sec-requireobjectcoercible
	var requireObjectCoercible$j = function requireObjectCoercible(it) {
	  if (isNullOrUndefined$d(it)) throw $TypeError$p("Can't call method on " + it);
	  return it;
	};
	var requireObjectCoercible$k = /*@__PURE__*/getDefaultExportFromCjs(requireObjectCoercible$j);

	// toObject with fallback for non-array-like ES3 strings
	var IndexedObject$5 = indexedObject;
	var requireObjectCoercible$i = requireObjectCoercible$j;
	var toIndexedObject$j = function toIndexedObject(it) {
	  return IndexedObject$5(requireObjectCoercible$i(it));
	};
	var toIndexedObject$k = /*@__PURE__*/getDefaultExportFromCjs(toIndexedObject$j);

	var documentAll$2 = (typeof document === "undefined" ? "undefined" : _typeof(document)) == 'object' && document.all;

	// https://tc39.es/ecma262/#sec-IsHTMLDDA-internal-slot
	// eslint-disable-next-line unicorn/no-typeof-undefined -- required for testing
	var IS_HTMLDDA = typeof documentAll$2 == 'undefined' && documentAll$2 !== undefined;
	var documentAll_1 = {
	  all: documentAll$2,
	  IS_HTMLDDA: IS_HTMLDDA
	};
	var documentAll$3 = /*@__PURE__*/getDefaultExportFromCjs(documentAll_1);

	var $documentAll$1 = documentAll_1;
	var documentAll$1 = $documentAll$1.all;

	// `IsCallable` abstract operation
	// https://tc39.es/ecma262/#sec-iscallable
	var isCallable$z = $documentAll$1.IS_HTMLDDA ? function (argument) {
	  return typeof argument == 'function' || argument === documentAll$1;
	} : function (argument) {
	  return typeof argument == 'function';
	};
	var isCallable$A = /*@__PURE__*/getDefaultExportFromCjs(isCallable$z);

	var isCallable$y = isCallable$z;
	var $documentAll = documentAll_1;
	var documentAll = $documentAll.all;
	var isObject$z = $documentAll.IS_HTMLDDA ? function (it) {
	  return _typeof(it) == 'object' ? it !== null : isCallable$y(it) || it === documentAll;
	} : function (it) {
	  return _typeof(it) == 'object' ? it !== null : isCallable$y(it);
	};
	var isObject$A = /*@__PURE__*/getDefaultExportFromCjs(isObject$z);

	var global$Y = global$Z;
	var isCallable$x = isCallable$z;
	var aFunction = function aFunction(argument) {
	  return isCallable$x(argument) ? argument : undefined;
	};
	var getBuiltIn$m = function getBuiltIn(namespace, method) {
	  return arguments.length < 2 ? aFunction(global$Y[namespace]) : global$Y[namespace] && global$Y[namespace][method];
	};
	var getBuiltIn$n = /*@__PURE__*/getDefaultExportFromCjs(getBuiltIn$m);

	var uncurryThis$1h = functionUncurryThis;
	var objectIsPrototypeOf = uncurryThis$1h({}.isPrototypeOf);
	var objectIsPrototypeOf$1 = /*@__PURE__*/getDefaultExportFromCjs(objectIsPrototypeOf);

	var engineUserAgent = typeof navigator != 'undefined' && String(navigator.userAgent) || '';
	var engineUserAgent$1 = /*@__PURE__*/getDefaultExportFromCjs(engineUserAgent);

	var global$X = global$Z;
	var userAgent$6 = engineUserAgent;
	var process$5 = global$X.process;
	var Deno$1 = global$X.Deno;
	var versions = process$5 && process$5.versions || Deno$1 && Deno$1.version;
	var v8 = versions && versions.v8;
	var match, version$8;
	if (v8) {
	  match = v8.split('.');
	  // in old Chrome, versions of V8 isn't V8 = Chrome / 10
	  // but their correct versions are not interesting for us
	  version$8 = match[0] > 0 && match[0] < 4 ? 1 : +(match[0] + match[1]);
	}

	// BrowserFS NodeJS `process` polyfill incorrectly set `.v8` to `0.0`
	// so check `userAgent` even if `.v8` exists, but 0
	if (!version$8 && userAgent$6) {
	  match = userAgent$6.match(/Edge\/(\d+)/);
	  if (!match || match[1] >= 74) {
	    match = userAgent$6.match(/Chrome\/(\d+)/);
	    if (match) version$8 = +match[1];
	  }
	}
	var engineV8Version = version$8;
	var engineV8Version$1 = /*@__PURE__*/getDefaultExportFromCjs(engineV8Version);

	/* eslint-disable es/no-symbol -- required for testing */
	var V8_VERSION$3 = engineV8Version;
	var fails$1i = fails$1m;

	// eslint-disable-next-line es/no-object-getownpropertysymbols -- required for testing
	var symbolConstructorDetection = !!Object.getOwnPropertySymbols && !fails$1i(function () {
	  var symbol = Symbol();
	  // Chrome 38 Symbol has incorrect toString conversion
	  // `get-own-property-symbols` polyfill symbols converted to object are not Symbol instances
	  return !String(symbol) || !(Object(symbol) instanceof Symbol) ||
	  // Chrome 38-40 symbols are not inherited from DOM collections prototypes to instances
	  !Symbol.sham && V8_VERSION$3 && V8_VERSION$3 < 41;
	});
	var symbolConstructorDetection$1 = /*@__PURE__*/getDefaultExportFromCjs(symbolConstructorDetection);

	var NATIVE_SYMBOL$6 = symbolConstructorDetection;
	var useSymbolAsUid = NATIVE_SYMBOL$6 && !Symbol.sham && _typeof(Symbol.iterator) == 'symbol';
	var useSymbolAsUid$1 = /*@__PURE__*/getDefaultExportFromCjs(useSymbolAsUid);

	var getBuiltIn$l = getBuiltIn$m;
	var isCallable$w = isCallable$z;
	var isPrototypeOf$b = objectIsPrototypeOf;
	var USE_SYMBOL_AS_UID$1 = useSymbolAsUid;
	var $Object$4 = Object;
	var isSymbol$7 = USE_SYMBOL_AS_UID$1 ? function (it) {
	  return _typeof(it) == 'symbol';
	} : function (it) {
	  var $Symbol = getBuiltIn$l('Symbol');
	  return isCallable$w($Symbol) && isPrototypeOf$b($Symbol.prototype, $Object$4(it));
	};
	var isSymbol$8 = /*@__PURE__*/getDefaultExportFromCjs(isSymbol$7);

	var $String$7 = String;
	var tryToString$7 = function tryToString(argument) {
	  try {
	    return $String$7(argument);
	  } catch (error) {
	    return 'Object';
	  }
	};
	var tryToString$8 = /*@__PURE__*/getDefaultExportFromCjs(tryToString$7);

	var isCallable$v = isCallable$z;
	var tryToString$6 = tryToString$7;
	var $TypeError$o = TypeError;

	// `Assert: IsCallable(argument) is true`
	var aCallable$l = function aCallable(argument) {
	  if (isCallable$v(argument)) return argument;
	  throw $TypeError$o(tryToString$6(argument) + ' is not a function');
	};
	var aCallable$m = /*@__PURE__*/getDefaultExportFromCjs(aCallable$l);

	var aCallable$k = aCallable$l;
	var isNullOrUndefined$c = isNullOrUndefined$e;

	// `GetMethod` abstract operation
	// https://tc39.es/ecma262/#sec-getmethod
	var getMethod$9 = function getMethod(V, P) {
	  var func = V[P];
	  return isNullOrUndefined$c(func) ? undefined : aCallable$k(func);
	};
	var getMethod$a = /*@__PURE__*/getDefaultExportFromCjs(getMethod$9);

	var call$C = functionCall;
	var isCallable$u = isCallable$z;
	var isObject$y = isObject$z;
	var $TypeError$n = TypeError;

	// `OrdinaryToPrimitive` abstract operation
	// https://tc39.es/ecma262/#sec-ordinarytoprimitive
	var ordinaryToPrimitive$2 = function ordinaryToPrimitive(input, pref) {
	  var fn, val;
	  if (pref === 'string' && isCallable$u(fn = input.toString) && !isObject$y(val = call$C(fn, input))) return val;
	  if (isCallable$u(fn = input.valueOf) && !isObject$y(val = call$C(fn, input))) return val;
	  if (pref !== 'string' && isCallable$u(fn = input.toString) && !isObject$y(val = call$C(fn, input))) return val;
	  throw $TypeError$n("Can't convert object to primitive value");
	};
	var ordinaryToPrimitive$3 = /*@__PURE__*/getDefaultExportFromCjs(ordinaryToPrimitive$2);

	var shared$a = {exports: {}};

	var isPure = false;
	var isPure$1 = /*@__PURE__*/getDefaultExportFromCjs(isPure);

	var global$W = global$Z;

	// eslint-disable-next-line es/no-object-defineproperty -- safe
	var defineProperty$e = Object.defineProperty;
	var defineGlobalProperty$3 = function defineGlobalProperty(key, value) {
	  try {
	    defineProperty$e(global$W, key, {
	      value: value,
	      configurable: true,
	      writable: true
	    });
	  } catch (error) {
	    global$W[key] = value;
	  }
	  return value;
	};
	var defineGlobalProperty$4 = /*@__PURE__*/getDefaultExportFromCjs(defineGlobalProperty$3);

	var global$V = global$Z;
	var defineGlobalProperty$2 = defineGlobalProperty$3;
	var SHARED = '__core-js_shared__';
	var store$3 = global$V[SHARED] || defineGlobalProperty$2(SHARED, {});
	var sharedStore = store$3;
	var sharedStore$1 = /*@__PURE__*/getDefaultExportFromCjs(sharedStore);

	var shared$8 = shared$a.exports;
	var IS_PURE$k = isPure;
	var store$2 = sharedStore;
	(shared$a.exports = function (key, value) {
	  return store$2[key] || (store$2[key] = value !== undefined ? value : {});
	})('versions', []).push({
	  version: '3.29.1',
	  mode: IS_PURE$k ? 'pure' : 'global',
	  copyright: '© 2014-2023 Denis Pushkarev (zloirock.ru)',
	  license: 'https://github.com/zloirock/core-js/blob/v3.29.1/LICENSE',
	  source: 'https://github.com/zloirock/core-js'
	});
	var sharedExports = shared$a.exports;
	var shared$9 = /*@__PURE__*/getDefaultExportFromCjs(sharedExports);

	var requireObjectCoercible$h = requireObjectCoercible$j;
	var $Object$3 = Object;

	// `ToObject` abstract operation
	// https://tc39.es/ecma262/#sec-toobject
	var toObject$t = function toObject(argument) {
	  return $Object$3(requireObjectCoercible$h(argument));
	};
	var toObject$u = /*@__PURE__*/getDefaultExportFromCjs(toObject$t);

	var uncurryThis$1g = functionUncurryThis;
	var toObject$s = toObject$t;
	var hasOwnProperty = uncurryThis$1g({}.hasOwnProperty);

	// `HasOwnProperty` abstract operation
	// https://tc39.es/ecma262/#sec-hasownproperty
	// eslint-disable-next-line es/no-object-hasown -- safe
	var hasOwnProperty_1 = Object.hasOwn || function hasOwn(it, key) {
	  return hasOwnProperty(toObject$s(it), key);
	};
	var hasOwnProperty$1 = /*@__PURE__*/getDefaultExportFromCjs(hasOwnProperty_1);

	var uncurryThis$1f = functionUncurryThis;
	var id$2 = 0;
	var postfix = Math.random();
	var toString$z = uncurryThis$1f(1.0.toString);
	var uid$6 = function uid(key) {
	  return 'Symbol(' + (key === undefined ? '' : key) + ')_' + toString$z(++id$2 + postfix, 36);
	};
	var uid$7 = /*@__PURE__*/getDefaultExportFromCjs(uid$6);

	var global$U = global$Z;
	var shared$7 = sharedExports;
	var hasOwn$w = hasOwnProperty_1;
	var uid$5 = uid$6;
	var NATIVE_SYMBOL$5 = symbolConstructorDetection;
	var USE_SYMBOL_AS_UID = useSymbolAsUid;
	var _Symbol$2 = global$U.Symbol;
	var WellKnownSymbolsStore$1 = shared$7('wks');
	var createWellKnownSymbol = USE_SYMBOL_AS_UID ? _Symbol$2['for'] || _Symbol$2 : _Symbol$2 && _Symbol$2.withoutSetter || uid$5;
	var wellKnownSymbol$z = function wellKnownSymbol(name) {
	  if (!hasOwn$w(WellKnownSymbolsStore$1, name)) {
	    WellKnownSymbolsStore$1[name] = NATIVE_SYMBOL$5 && hasOwn$w(_Symbol$2, name) ? _Symbol$2[name] : createWellKnownSymbol('Symbol.' + name);
	  }
	  return WellKnownSymbolsStore$1[name];
	};
	var wellKnownSymbol$A = /*@__PURE__*/getDefaultExportFromCjs(wellKnownSymbol$z);

	var call$B = functionCall;
	var isObject$x = isObject$z;
	var isSymbol$6 = isSymbol$7;
	var getMethod$8 = getMethod$9;
	var ordinaryToPrimitive$1 = ordinaryToPrimitive$2;
	var wellKnownSymbol$y = wellKnownSymbol$z;
	var $TypeError$m = TypeError;
	var TO_PRIMITIVE$1 = wellKnownSymbol$y('toPrimitive');

	// `ToPrimitive` abstract operation
	// https://tc39.es/ecma262/#sec-toprimitive
	var toPrimitive$4 = function toPrimitive(input, pref) {
	  if (!isObject$x(input) || isSymbol$6(input)) return input;
	  var exoticToPrim = getMethod$8(input, TO_PRIMITIVE$1);
	  var result;
	  if (exoticToPrim) {
	    if (pref === undefined) pref = 'default';
	    result = call$B(exoticToPrim, input, pref);
	    if (!isObject$x(result) || isSymbol$6(result)) return result;
	    throw $TypeError$m("Can't convert object to primitive value");
	  }
	  if (pref === undefined) pref = 'number';
	  return ordinaryToPrimitive$1(input, pref);
	};
	var toPrimitive$5 = /*@__PURE__*/getDefaultExportFromCjs(toPrimitive$4);

	var toPrimitive$3 = toPrimitive$4;
	var isSymbol$5 = isSymbol$7;

	// `ToPropertyKey` abstract operation
	// https://tc39.es/ecma262/#sec-topropertykey
	var toPropertyKey$8 = function toPropertyKey(argument) {
	  var key = toPrimitive$3(argument, 'string');
	  return isSymbol$5(key) ? key : key + '';
	};
	var toPropertyKey$9 = /*@__PURE__*/getDefaultExportFromCjs(toPropertyKey$8);

	var global$T = global$Z;
	var isObject$w = isObject$z;
	var document$3 = global$T.document;
	// typeof document.createElement is 'object' in old IE
	var EXISTS$1 = isObject$w(document$3) && isObject$w(document$3.createElement);
	var documentCreateElement$2 = function documentCreateElement(it) {
	  return EXISTS$1 ? document$3.createElement(it) : {};
	};
	var documentCreateElement$3 = /*@__PURE__*/getDefaultExportFromCjs(documentCreateElement$2);

	var DESCRIPTORS$J = descriptors;
	var fails$1h = fails$1m;
	var createElement$1 = documentCreateElement$2;

	// Thanks to IE8 for its funny defineProperty
	var ie8DomDefine = !DESCRIPTORS$J && !fails$1h(function () {
	  // eslint-disable-next-line es/no-object-defineproperty -- required for testing
	  return Object.defineProperty(createElement$1('div'), 'a', {
	    get: function get() {
	      return 7;
	    }
	  }).a != 7;
	});
	var ie8DomDefine$1 = /*@__PURE__*/getDefaultExportFromCjs(ie8DomDefine);

	var DESCRIPTORS$I = descriptors;
	var call$A = functionCall;
	var propertyIsEnumerableModule$2 = objectPropertyIsEnumerable;
	var createPropertyDescriptor$b = createPropertyDescriptor$c;
	var toIndexedObject$i = toIndexedObject$j;
	var toPropertyKey$7 = toPropertyKey$8;
	var hasOwn$v = hasOwnProperty_1;
	var IE8_DOM_DEFINE$1 = ie8DomDefine;

	// eslint-disable-next-line es/no-object-getownpropertydescriptor -- safe
	var $getOwnPropertyDescriptor$2 = Object.getOwnPropertyDescriptor;

	// `Object.getOwnPropertyDescriptor` method
	// https://tc39.es/ecma262/#sec-object.getownpropertydescriptor
	var f$7 = objectGetOwnPropertyDescriptor.f = DESCRIPTORS$I ? $getOwnPropertyDescriptor$2 : function getOwnPropertyDescriptor(O, P) {
	  O = toIndexedObject$i(O);
	  P = toPropertyKey$7(P);
	  if (IE8_DOM_DEFINE$1) try {
	    return $getOwnPropertyDescriptor$2(O, P);
	  } catch (error) {/* empty */}
	  if (hasOwn$v(O, P)) return createPropertyDescriptor$b(!call$A(propertyIsEnumerableModule$2.f, O, P), O[P]);
	};

	var objectDefineProperty = {};

	var DESCRIPTORS$H = descriptors;
	var fails$1g = fails$1m;

	// V8 ~ Chrome 36-
	// https://bugs.chromium.org/p/v8/issues/detail?id=3334
	var v8PrototypeDefineBug = DESCRIPTORS$H && fails$1g(function () {
	  // eslint-disable-next-line es/no-object-defineproperty -- required for testing
	  return Object.defineProperty(function () {/* empty */}, 'prototype', {
	    value: 42,
	    writable: false
	  }).prototype != 42;
	});
	var v8PrototypeDefineBug$1 = /*@__PURE__*/getDefaultExportFromCjs(v8PrototypeDefineBug);

	var isObject$v = isObject$z;
	var $String$6 = String;
	var $TypeError$l = TypeError;

	// `Assert: Type(argument) is Object`
	var anObject$D = function anObject(argument) {
	  if (isObject$v(argument)) return argument;
	  throw $TypeError$l($String$6(argument) + ' is not an object');
	};
	var anObject$E = /*@__PURE__*/getDefaultExportFromCjs(anObject$D);

	var DESCRIPTORS$G = descriptors;
	var IE8_DOM_DEFINE = ie8DomDefine;
	var V8_PROTOTYPE_DEFINE_BUG$1 = v8PrototypeDefineBug;
	var anObject$C = anObject$D;
	var toPropertyKey$6 = toPropertyKey$8;
	var $TypeError$k = TypeError;
	// eslint-disable-next-line es/no-object-defineproperty -- safe
	var $defineProperty$1 = Object.defineProperty;
	// eslint-disable-next-line es/no-object-getownpropertydescriptor -- safe
	var $getOwnPropertyDescriptor$1 = Object.getOwnPropertyDescriptor;
	var ENUMERABLE = 'enumerable';
	var CONFIGURABLE$1 = 'configurable';
	var WRITABLE = 'writable';

	// `Object.defineProperty` method
	// https://tc39.es/ecma262/#sec-object.defineproperty
	var f$6 = objectDefineProperty.f = DESCRIPTORS$G ? V8_PROTOTYPE_DEFINE_BUG$1 ? function defineProperty(O, P, Attributes) {
	  anObject$C(O);
	  P = toPropertyKey$6(P);
	  anObject$C(Attributes);
	  if (typeof O === 'function' && P === 'prototype' && 'value' in Attributes && WRITABLE in Attributes && !Attributes[WRITABLE]) {
	    var current = $getOwnPropertyDescriptor$1(O, P);
	    if (current && current[WRITABLE]) {
	      O[P] = Attributes.value;
	      Attributes = {
	        configurable: CONFIGURABLE$1 in Attributes ? Attributes[CONFIGURABLE$1] : current[CONFIGURABLE$1],
	        enumerable: ENUMERABLE in Attributes ? Attributes[ENUMERABLE] : current[ENUMERABLE],
	        writable: false
	      };
	    }
	  }
	  return $defineProperty$1(O, P, Attributes);
	} : $defineProperty$1 : function defineProperty(O, P, Attributes) {
	  anObject$C(O);
	  P = toPropertyKey$6(P);
	  anObject$C(Attributes);
	  if (IE8_DOM_DEFINE) try {
	    return $defineProperty$1(O, P, Attributes);
	  } catch (error) {/* empty */}
	  if ('get' in Attributes || 'set' in Attributes) throw $TypeError$k('Accessors not supported');
	  if ('value' in Attributes) O[P] = Attributes.value;
	  return O;
	};

	var DESCRIPTORS$F = descriptors;
	var definePropertyModule$b = objectDefineProperty;
	var createPropertyDescriptor$a = createPropertyDescriptor$c;
	var createNonEnumerableProperty$f = DESCRIPTORS$F ? function (object, key, value) {
	  return definePropertyModule$b.f(object, key, createPropertyDescriptor$a(1, value));
	} : function (object, key, value) {
	  object[key] = value;
	  return object;
	};
	var createNonEnumerableProperty$g = /*@__PURE__*/getDefaultExportFromCjs(createNonEnumerableProperty$f);

	var makeBuiltIn$5 = {exports: {}};

	var DESCRIPTORS$E = descriptors;
	var hasOwn$u = hasOwnProperty_1;
	var FunctionPrototype$3 = Function.prototype;
	// eslint-disable-next-line es/no-object-getownpropertydescriptor -- safe
	var getDescriptor = DESCRIPTORS$E && Object.getOwnPropertyDescriptor;
	var EXISTS = hasOwn$u(FunctionPrototype$3, 'name');
	// additional protection from minified / mangled / dropped function names
	var PROPER = EXISTS && function something() {/* empty */}.name === 'something';
	var CONFIGURABLE = EXISTS && (!DESCRIPTORS$E || DESCRIPTORS$E && getDescriptor(FunctionPrototype$3, 'name').configurable);
	var functionName = {
	  EXISTS: EXISTS,
	  PROPER: PROPER,
	  CONFIGURABLE: CONFIGURABLE
	};
	var functionName$1 = /*@__PURE__*/getDefaultExportFromCjs(functionName);

	var uncurryThis$1e = functionUncurryThis;
	var isCallable$t = isCallable$z;
	var store$1 = sharedStore;
	var functionToString$1 = uncurryThis$1e(Function.toString);

	// this helper broken in `core-js@3.4.1-3.4.4`, so we can't use `shared` helper
	if (!isCallable$t(store$1.inspectSource)) {
	  store$1.inspectSource = function (it) {
	    return functionToString$1(it);
	  };
	}
	var inspectSource$3 = store$1.inspectSource;
	var inspectSource$4 = /*@__PURE__*/getDefaultExportFromCjs(inspectSource$3);

	var global$S = global$Z;
	var isCallable$s = isCallable$z;
	var WeakMap$2 = global$S.WeakMap;
	var weakMapBasicDetection = isCallable$s(WeakMap$2) && /native code/.test(String(WeakMap$2));
	var weakMapBasicDetection$1 = /*@__PURE__*/getDefaultExportFromCjs(weakMapBasicDetection);

	var shared$6 = sharedExports;
	var uid$4 = uid$6;
	var keys$2 = shared$6('keys');
	var sharedKey$4 = function sharedKey(key) {
	  return keys$2[key] || (keys$2[key] = uid$4(key));
	};
	var sharedKey$5 = /*@__PURE__*/getDefaultExportFromCjs(sharedKey$4);

	var hiddenKeys$6 = {};
	var hiddenKeys$7 = /*@__PURE__*/getDefaultExportFromCjs(hiddenKeys$6);

	var NATIVE_WEAK_MAP$1 = weakMapBasicDetection;
	var global$R = global$Z;
	var isObject$u = isObject$z;
	var createNonEnumerableProperty$e = createNonEnumerableProperty$f;
	var hasOwn$t = hasOwnProperty_1;
	var shared$5 = sharedStore;
	var sharedKey$3 = sharedKey$4;
	var hiddenKeys$5 = hiddenKeys$6;
	var OBJECT_ALREADY_INITIALIZED = 'Object already initialized';
	var TypeError$8 = global$R.TypeError;
	var WeakMap$1 = global$R.WeakMap;
	var set$3, get$4, has;
	var enforce = function enforce(it) {
	  return has(it) ? get$4(it) : set$3(it, {});
	};
	var getterFor$1 = function getterFor(TYPE) {
	  return function (it) {
	    var state;
	    if (!isObject$u(it) || (state = get$4(it)).type !== TYPE) {
	      throw TypeError$8('Incompatible receiver, ' + TYPE + ' required');
	    }
	    return state;
	  };
	};
	if (NATIVE_WEAK_MAP$1 || shared$5.state) {
	  var store = shared$5.state || (shared$5.state = new WeakMap$1());
	  /* eslint-disable no-self-assign -- prototype methods protection */
	  store.get = store.get;
	  store.has = store.has;
	  store.set = store.set;
	  /* eslint-enable no-self-assign -- prototype methods protection */
	  set$3 = function set(it, metadata) {
	    if (store.has(it)) throw TypeError$8(OBJECT_ALREADY_INITIALIZED);
	    metadata.facade = it;
	    store.set(it, metadata);
	    return metadata;
	  };
	  get$4 = function get(it) {
	    return store.get(it) || {};
	  };
	  has = function has(it) {
	    return store.has(it);
	  };
	} else {
	  var STATE = sharedKey$3('state');
	  hiddenKeys$5[STATE] = true;
	  set$3 = function set(it, metadata) {
	    if (hasOwn$t(it, STATE)) throw TypeError$8(OBJECT_ALREADY_INITIALIZED);
	    metadata.facade = it;
	    createNonEnumerableProperty$e(it, STATE, metadata);
	    return metadata;
	  };
	  get$4 = function get(it) {
	    return hasOwn$t(it, STATE) ? it[STATE] : {};
	  };
	  has = function has(it) {
	    return hasOwn$t(it, STATE);
	  };
	}
	var internalState = {
	  set: set$3,
	  get: get$4,
	  has: has,
	  enforce: enforce,
	  getterFor: getterFor$1
	};
	var internalState$1 = /*@__PURE__*/getDefaultExportFromCjs(internalState);

	var makeBuiltIn_1 = makeBuiltIn$5.exports;
	var uncurryThis$1d = functionUncurryThis;
	var fails$1f = fails$1m;
	var isCallable$r = isCallable$z;
	var hasOwn$s = hasOwnProperty_1;
	var DESCRIPTORS$D = descriptors;
	var CONFIGURABLE_FUNCTION_NAME$2 = functionName.CONFIGURABLE;
	var inspectSource$2 = inspectSource$3;
	var InternalStateModule$d = internalState;
	var enforceInternalState$4 = InternalStateModule$d.enforce;
	var getInternalState$a = InternalStateModule$d.get;
	var $String$5 = String;
	// eslint-disable-next-line es/no-object-defineproperty -- safe
	var defineProperty$d = Object.defineProperty;
	var stringSlice$h = uncurryThis$1d(''.slice);
	var replace$d = uncurryThis$1d(''.replace);
	var join$7 = uncurryThis$1d([].join);
	var CONFIGURABLE_LENGTH = DESCRIPTORS$D && !fails$1f(function () {
	  return defineProperty$d(function () {/* empty */}, 'length', {
	    value: 8
	  }).length !== 8;
	});
	var TEMPLATE = String(String).split('String');
	var makeBuiltIn$3 = makeBuiltIn$5.exports = function (value, name, options) {
	  if (stringSlice$h($String$5(name), 0, 7) === 'Symbol(') {
	    name = '[' + replace$d($String$5(name), /^Symbol\(([^)]*)\)/, '$1') + ']';
	  }
	  if (options && options.getter) name = 'get ' + name;
	  if (options && options.setter) name = 'set ' + name;
	  if (!hasOwn$s(value, 'name') || CONFIGURABLE_FUNCTION_NAME$2 && value.name !== name) {
	    if (DESCRIPTORS$D) defineProperty$d(value, 'name', {
	      value: name,
	      configurable: true
	    });else value.name = name;
	  }
	  if (CONFIGURABLE_LENGTH && options && hasOwn$s(options, 'arity') && value.length !== options.arity) {
	    defineProperty$d(value, 'length', {
	      value: options.arity
	    });
	  }
	  try {
	    if (options && hasOwn$s(options, 'constructor') && options.constructor) {
	      if (DESCRIPTORS$D) defineProperty$d(value, 'prototype', {
	        writable: false
	      });
	      // in V8 ~ Chrome 53, prototypes of some methods, like `Array.prototype.values`, are non-writable
	    } else if (value.prototype) value.prototype = undefined;
	  } catch (error) {/* empty */}
	  var state = enforceInternalState$4(value);
	  if (!hasOwn$s(state, 'source')) {
	    state.source = join$7(TEMPLATE, typeof name == 'string' ? name : '');
	  }
	  return value;
	};

	// add fake Function#toString for correct work wrapped methods / constructors with methods like LoDash isNative
	// eslint-disable-next-line no-extend-native -- required
	Function.prototype.toString = makeBuiltIn$3(function toString() {
	  return isCallable$r(this) && getInternalState$a(this).source || inspectSource$2(this);
	}, 'toString');
	var makeBuiltInExports = makeBuiltIn$5.exports;
	var makeBuiltIn$4 = /*@__PURE__*/getDefaultExportFromCjs(makeBuiltInExports);

	var isCallable$q = isCallable$z;
	var definePropertyModule$a = objectDefineProperty;
	var makeBuiltIn$2 = makeBuiltInExports;
	var defineGlobalProperty$1 = defineGlobalProperty$3;
	var defineBuiltIn$m = function defineBuiltIn(O, key, value, options) {
	  if (!options) options = {};
	  var simple = options.enumerable;
	  var name = options.name !== undefined ? options.name : key;
	  if (isCallable$q(value)) makeBuiltIn$2(value, name, options);
	  if (options.global) {
	    if (simple) O[key] = value;else defineGlobalProperty$1(key, value);
	  } else {
	    try {
	      if (!options.unsafe) delete O[key];else if (O[key]) simple = true;
	    } catch (error) {/* empty */}
	    if (simple) O[key] = value;else definePropertyModule$a.f(O, key, {
	      value: value,
	      enumerable: false,
	      configurable: !options.nonConfigurable,
	      writable: !options.nonWritable
	    });
	  }
	  return O;
	};
	var defineBuiltIn$n = /*@__PURE__*/getDefaultExportFromCjs(defineBuiltIn$m);

	var objectGetOwnPropertyNames = {};

	var ceil$4 = Math.ceil;
	var floor$d = Math.floor;

	// `Math.trunc` method
	// https://tc39.es/ecma262/#sec-math.trunc
	// eslint-disable-next-line es/no-math-trunc -- safe
	var mathTrunc = Math.trunc || function trunc(x) {
	  var n = +x;
	  return (n > 0 ? floor$d : ceil$4)(n);
	};
	var mathTrunc$1 = /*@__PURE__*/getDefaultExportFromCjs(mathTrunc);

	var trunc$1 = mathTrunc;

	// `ToIntegerOrInfinity` abstract operation
	// https://tc39.es/ecma262/#sec-tointegerorinfinity
	var toIntegerOrInfinity$l = function toIntegerOrInfinity(argument) {
	  var number = +argument;
	  // eslint-disable-next-line no-self-compare -- NaN check
	  return number !== number || number === 0 ? 0 : trunc$1(number);
	};
	var toIntegerOrInfinity$m = /*@__PURE__*/getDefaultExportFromCjs(toIntegerOrInfinity$l);

	var toIntegerOrInfinity$k = toIntegerOrInfinity$l;
	var max$b = Math.max;
	var min$e = Math.min;

	// Helper for a popular repeating case of the spec:
	// Let integer be ? ToInteger(index).
	// If integer < 0, let result be max((length + integer), 0); else let result be min(integer, length).
	var toAbsoluteIndex$a = function toAbsoluteIndex(index, length) {
	  var integer = toIntegerOrInfinity$k(index);
	  return integer < 0 ? max$b(integer + length, 0) : min$e(integer, length);
	};
	var toAbsoluteIndex$b = /*@__PURE__*/getDefaultExportFromCjs(toAbsoluteIndex$a);

	var toIntegerOrInfinity$j = toIntegerOrInfinity$l;
	var min$d = Math.min;

	// `ToLength` abstract operation
	// https://tc39.es/ecma262/#sec-tolength
	var toLength$d = function toLength(argument) {
	  return argument > 0 ? min$d(toIntegerOrInfinity$j(argument), 0x1FFFFFFFFFFFFF) : 0; // 2 ** 53 - 1 == 9007199254740991
	};

	var toLength$e = /*@__PURE__*/getDefaultExportFromCjs(toLength$d);

	var toLength$c = toLength$d;

	// `LengthOfArrayLike` abstract operation
	// https://tc39.es/ecma262/#sec-lengthofarraylike
	var lengthOfArrayLike$t = function lengthOfArrayLike(obj) {
	  return toLength$c(obj.length);
	};
	var lengthOfArrayLike$u = /*@__PURE__*/getDefaultExportFromCjs(lengthOfArrayLike$t);

	var toIndexedObject$h = toIndexedObject$j;
	var toAbsoluteIndex$9 = toAbsoluteIndex$a;
	var lengthOfArrayLike$s = lengthOfArrayLike$t;

	// `Array.prototype.{ indexOf, includes }` methods implementation
	var createMethod$7 = function createMethod(IS_INCLUDES) {
	  return function ($this, el, fromIndex) {
	    var O = toIndexedObject$h($this);
	    var length = lengthOfArrayLike$s(O);
	    var index = toAbsoluteIndex$9(fromIndex, length);
	    var value;
	    // Array#includes uses SameValueZero equality algorithm
	    // eslint-disable-next-line no-self-compare -- NaN check
	    if (IS_INCLUDES && el != el) while (length > index) {
	      value = O[index++];
	      // eslint-disable-next-line no-self-compare -- NaN check
	      if (value != value) return true;
	      // Array#indexOf ignores holes, Array#includes - not
	    } else for (; length > index; index++) {
	      if ((IS_INCLUDES || index in O) && O[index] === el) return IS_INCLUDES || index || 0;
	    }
	    return !IS_INCLUDES && -1;
	  };
	};
	var arrayIncludes = {
	  // `Array.prototype.includes` method
	  // https://tc39.es/ecma262/#sec-array.prototype.includes
	  includes: createMethod$7(true),
	  // `Array.prototype.indexOf` method
	  // https://tc39.es/ecma262/#sec-array.prototype.indexof
	  indexOf: createMethod$7(false)
	};
	var arrayIncludes$1 = /*@__PURE__*/getDefaultExportFromCjs(arrayIncludes);

	var uncurryThis$1c = functionUncurryThis;
	var hasOwn$r = hasOwnProperty_1;
	var toIndexedObject$g = toIndexedObject$j;
	var indexOf$2 = arrayIncludes.indexOf;
	var hiddenKeys$4 = hiddenKeys$6;
	var push$e = uncurryThis$1c([].push);
	var objectKeysInternal = function objectKeysInternal(object, names) {
	  var O = toIndexedObject$g(object);
	  var i = 0;
	  var result = [];
	  var key;
	  for (key in O) !hasOwn$r(hiddenKeys$4, key) && hasOwn$r(O, key) && push$e(result, key);
	  // Don't enum bug & hidden keys
	  while (names.length > i) if (hasOwn$r(O, key = names[i++])) {
	    ~indexOf$2(result, key) || push$e(result, key);
	  }
	  return result;
	};
	var objectKeysInternal$1 = /*@__PURE__*/getDefaultExportFromCjs(objectKeysInternal);

	// IE8- don't enum bug keys
	var enumBugKeys$3 = ['constructor', 'hasOwnProperty', 'isPrototypeOf', 'propertyIsEnumerable', 'toLocaleString', 'toString', 'valueOf'];
	var enumBugKeys$4 = /*@__PURE__*/getDefaultExportFromCjs(enumBugKeys$3);

	var internalObjectKeys$1 = objectKeysInternal;
	var enumBugKeys$2 = enumBugKeys$3;
	var hiddenKeys$3 = enumBugKeys$2.concat('length', 'prototype');

	// `Object.getOwnPropertyNames` method
	// https://tc39.es/ecma262/#sec-object.getownpropertynames
	// eslint-disable-next-line es/no-object-getownpropertynames -- safe
	var f$5 = objectGetOwnPropertyNames.f = Object.getOwnPropertyNames || function getOwnPropertyNames(O) {
	  return internalObjectKeys$1(O, hiddenKeys$3);
	};

	var objectGetOwnPropertySymbols = {};

	// eslint-disable-next-line es/no-object-getownpropertysymbols -- safe
	var f$4 = objectGetOwnPropertySymbols.f = Object.getOwnPropertySymbols;

	var getBuiltIn$k = getBuiltIn$m;
	var uncurryThis$1b = functionUncurryThis;
	var getOwnPropertyNamesModule$2 = objectGetOwnPropertyNames;
	var getOwnPropertySymbolsModule$3 = objectGetOwnPropertySymbols;
	var anObject$B = anObject$D;
	var concat$6 = uncurryThis$1b([].concat);

	// all object keys, includes non-enumerable and symbols
	var ownKeys$3 = getBuiltIn$k('Reflect', 'ownKeys') || function ownKeys(it) {
	  var keys = getOwnPropertyNamesModule$2.f(anObject$B(it));
	  var getOwnPropertySymbols = getOwnPropertySymbolsModule$3.f;
	  return getOwnPropertySymbols ? concat$6(keys, getOwnPropertySymbols(it)) : keys;
	};
	var ownKeys$4 = /*@__PURE__*/getDefaultExportFromCjs(ownKeys$3);

	var hasOwn$q = hasOwnProperty_1;
	var ownKeys$2 = ownKeys$3;
	var getOwnPropertyDescriptorModule$6 = objectGetOwnPropertyDescriptor;
	var definePropertyModule$9 = objectDefineProperty;
	var copyConstructorProperties$5 = function copyConstructorProperties(target, source, exceptions) {
	  var keys = ownKeys$2(source);
	  var defineProperty = definePropertyModule$9.f;
	  var getOwnPropertyDescriptor = getOwnPropertyDescriptorModule$6.f;
	  for (var i = 0; i < keys.length; i++) {
	    var key = keys[i];
	    if (!hasOwn$q(target, key) && !(exceptions && hasOwn$q(exceptions, key))) {
	      defineProperty(target, key, getOwnPropertyDescriptor(source, key));
	    }
	  }
	};
	var copyConstructorProperties$6 = /*@__PURE__*/getDefaultExportFromCjs(copyConstructorProperties$5);

	var fails$1e = fails$1m;
	var isCallable$p = isCallable$z;
	var replacement = /#|\.prototype\./;
	var isForced$5 = function isForced(feature, detection) {
	  var value = data[normalize(feature)];
	  return value == POLYFILL ? true : value == NATIVE ? false : isCallable$p(detection) ? fails$1e(detection) : !!detection;
	};
	var normalize = isForced$5.normalize = function (string) {
	  return String(string).replace(replacement, '.').toLowerCase();
	};
	var data = isForced$5.data = {};
	var NATIVE = isForced$5.NATIVE = 'N';
	var POLYFILL = isForced$5.POLYFILL = 'P';
	var isForced_1 = isForced$5;
	var isForced$6 = /*@__PURE__*/getDefaultExportFromCjs(isForced_1);

	var global$Q = global$Z;
	var getOwnPropertyDescriptor$9 = objectGetOwnPropertyDescriptor.f;
	var createNonEnumerableProperty$d = createNonEnumerableProperty$f;
	var defineBuiltIn$l = defineBuiltIn$m;
	var defineGlobalProperty = defineGlobalProperty$3;
	var copyConstructorProperties$4 = copyConstructorProperties$5;
	var isForced$4 = isForced_1;

	/*
	  options.target         - name of the target object
	  options.global         - target is the global object
	  options.stat           - export as static methods of target
	  options.proto          - export as prototype methods of target
	  options.real           - real prototype method for the `pure` version
	  options.forced         - export even if the native feature is available
	  options.bind           - bind methods to the target, required for the `pure` version
	  options.wrap           - wrap constructors to preventing global pollution, required for the `pure` version
	  options.unsafe         - use the simple assignment of property instead of delete + defineProperty
	  options.sham           - add a flag to not completely full polyfills
	  options.enumerable     - export as enumerable property
	  options.dontCallGetSet - prevent calling a getter on target
	  options.name           - the .name of the function if it does not match the key
	*/
	var _export = function _export(options, source) {
	  var TARGET = options.target;
	  var GLOBAL = options.global;
	  var STATIC = options.stat;
	  var FORCED, target, key, targetProperty, sourceProperty, descriptor;
	  if (GLOBAL) {
	    target = global$Q;
	  } else if (STATIC) {
	    target = global$Q[TARGET] || defineGlobalProperty(TARGET, {});
	  } else {
	    target = (global$Q[TARGET] || {}).prototype;
	  }
	  if (target) for (key in source) {
	    sourceProperty = source[key];
	    if (options.dontCallGetSet) {
	      descriptor = getOwnPropertyDescriptor$9(target, key);
	      targetProperty = descriptor && descriptor.value;
	    } else targetProperty = target[key];
	    FORCED = isForced$4(GLOBAL ? key : TARGET + (STATIC ? '.' : '#') + key, options.forced);
	    // contained in target
	    if (!FORCED && targetProperty !== undefined) {
	      if (_typeof(sourceProperty) == _typeof(targetProperty)) continue;
	      copyConstructorProperties$4(sourceProperty, targetProperty);
	    }
	    // add a flag to not completely full polyfills
	    if (options.sham || targetProperty && targetProperty.sham) {
	      createNonEnumerableProperty$d(sourceProperty, 'sham', true);
	    }
	    defineBuiltIn$l(target, key, sourceProperty, options);
	  }
	};
	var _export$1 = /*@__PURE__*/getDefaultExportFromCjs(_export);

	var wellKnownSymbol$x = wellKnownSymbol$z;
	var TO_STRING_TAG$5 = wellKnownSymbol$x('toStringTag');
	var test$2 = {};
	test$2[TO_STRING_TAG$5] = 'z';
	var toStringTagSupport = String(test$2) === '[object z]';
	var toStringTagSupport$1 = /*@__PURE__*/getDefaultExportFromCjs(toStringTagSupport);

	var TO_STRING_TAG_SUPPORT$2 = toStringTagSupport;
	var isCallable$o = isCallable$z;
	var classofRaw$1 = classofRaw$2;
	var wellKnownSymbol$w = wellKnownSymbol$z;
	var TO_STRING_TAG$4 = wellKnownSymbol$w('toStringTag');
	var $Object$2 = Object;

	// ES3 wrong here
	var CORRECT_ARGUMENTS = classofRaw$1(function () {
	  return arguments;
	}()) == 'Arguments';

	// fallback for IE11 Script Access Denied error
	var tryGet = function tryGet(it, key) {
	  try {
	    return it[key];
	  } catch (error) {/* empty */}
	};

	// getting tag from ES6+ `Object.prototype.toString`
	var classof$m = TO_STRING_TAG_SUPPORT$2 ? classofRaw$1 : function (it) {
	  var O, tag, result;
	  return it === undefined ? 'Undefined' : it === null ? 'Null'
	  // @@toStringTag case
	  : typeof (tag = tryGet(O = $Object$2(it), TO_STRING_TAG$4)) == 'string' ? tag
	  // builtinTag case
	  : CORRECT_ARGUMENTS ? classofRaw$1(O)
	  // ES3 arguments fallback
	  : (result = classofRaw$1(O)) == 'Object' && isCallable$o(O.callee) ? 'Arguments' : result;
	};
	var classof$n = /*@__PURE__*/getDefaultExportFromCjs(classof$m);

	var classof$l = classof$m;
	var $String$4 = String;
	var toString$x = function toString(argument) {
	  if (classof$l(argument) === 'Symbol') throw TypeError('Cannot convert a Symbol value to a string');
	  return $String$4(argument);
	};
	var toString$y = /*@__PURE__*/getDefaultExportFromCjs(toString$x);

	var objectDefineProperties = {};

	var internalObjectKeys = objectKeysInternal;
	var enumBugKeys$1 = enumBugKeys$3;

	// `Object.keys` method
	// https://tc39.es/ecma262/#sec-object.keys
	// eslint-disable-next-line es/no-object-keys -- safe
	var objectKeys$5 = Object.keys || function keys(O) {
	  return internalObjectKeys(O, enumBugKeys$1);
	};
	var objectKeys$6 = /*@__PURE__*/getDefaultExportFromCjs(objectKeys$5);

	var DESCRIPTORS$C = descriptors;
	var V8_PROTOTYPE_DEFINE_BUG = v8PrototypeDefineBug;
	var definePropertyModule$8 = objectDefineProperty;
	var anObject$A = anObject$D;
	var toIndexedObject$f = toIndexedObject$j;
	var objectKeys$4 = objectKeys$5;

	// `Object.defineProperties` method
	// https://tc39.es/ecma262/#sec-object.defineproperties
	// eslint-disable-next-line es/no-object-defineproperties -- safe
	var f$3 = objectDefineProperties.f = DESCRIPTORS$C && !V8_PROTOTYPE_DEFINE_BUG ? Object.defineProperties : function defineProperties(O, Properties) {
	  anObject$A(O);
	  var props = toIndexedObject$f(Properties);
	  var keys = objectKeys$4(Properties);
	  var length = keys.length;
	  var index = 0;
	  var key;
	  while (length > index) definePropertyModule$8.f(O, key = keys[index++], props[key]);
	  return O;
	};

	var getBuiltIn$j = getBuiltIn$m;
	var html$2 = getBuiltIn$j('document', 'documentElement');
	var html$3 = /*@__PURE__*/getDefaultExportFromCjs(html$2);

	/* global ActiveXObject -- old IE, WSH */
	var anObject$z = anObject$D;
	var definePropertiesModule$1 = objectDefineProperties;
	var enumBugKeys = enumBugKeys$3;
	var hiddenKeys$2 = hiddenKeys$6;
	var html$1 = html$2;
	var documentCreateElement$1 = documentCreateElement$2;
	var sharedKey$2 = sharedKey$4;
	var GT = '>';
	var LT = '<';
	var PROTOTYPE$2 = 'prototype';
	var SCRIPT = 'script';
	var IE_PROTO$1 = sharedKey$2('IE_PROTO');
	var EmptyConstructor = function EmptyConstructor() {/* empty */};
	var scriptTag = function scriptTag(content) {
	  return LT + SCRIPT + GT + content + LT + '/' + SCRIPT + GT;
	};

	// Create object with fake `null` prototype: use ActiveX Object with cleared prototype
	var NullProtoObjectViaActiveX = function NullProtoObjectViaActiveX(activeXDocument) {
	  activeXDocument.write(scriptTag(''));
	  activeXDocument.close();
	  var temp = activeXDocument.parentWindow.Object;
	  activeXDocument = null; // avoid memory leak
	  return temp;
	};

	// Create object with fake `null` prototype: use iframe Object with cleared prototype
	var NullProtoObjectViaIFrame = function NullProtoObjectViaIFrame() {
	  // Thrash, waste and sodomy: IE GC bug
	  var iframe = documentCreateElement$1('iframe');
	  var JS = 'java' + SCRIPT + ':';
	  var iframeDocument;
	  iframe.style.display = 'none';
	  html$1.appendChild(iframe);
	  // https://github.com/zloirock/core-js/issues/475
	  iframe.src = String(JS);
	  iframeDocument = iframe.contentWindow.document;
	  iframeDocument.open();
	  iframeDocument.write(scriptTag('document.F=Object'));
	  iframeDocument.close();
	  return iframeDocument.F;
	};

	// Check for document.domain and active x support
	// No need to use active x approach when document.domain is not set
	// see https://github.com/es-shims/es5-shim/issues/150
	// variation of https://github.com/kitcambridge/es5-shim/commit/4f738ac066346
	// avoid IE GC bug
	var activeXDocument;
	var _NullProtoObject = function NullProtoObject() {
	  try {
	    activeXDocument = new ActiveXObject('htmlfile');
	  } catch (error) {/* ignore */}
	  _NullProtoObject = typeof document != 'undefined' ? document.domain && activeXDocument ? NullProtoObjectViaActiveX(activeXDocument) // old IE
	  : NullProtoObjectViaIFrame() : NullProtoObjectViaActiveX(activeXDocument); // WSH
	  var length = enumBugKeys.length;
	  while (length--) delete _NullProtoObject[PROTOTYPE$2][enumBugKeys[length]];
	  return _NullProtoObject();
	};
	hiddenKeys$2[IE_PROTO$1] = true;

	// `Object.create` method
	// https://tc39.es/ecma262/#sec-object.create
	// eslint-disable-next-line es/no-object-create -- safe
	var objectCreate = Object.create || function create(O, Properties) {
	  var result;
	  if (O !== null) {
	    EmptyConstructor[PROTOTYPE$2] = anObject$z(O);
	    result = new EmptyConstructor();
	    EmptyConstructor[PROTOTYPE$2] = null;
	    // add "__proto__" for Object.getPrototypeOf polyfill
	    result[IE_PROTO$1] = O;
	  } else result = _NullProtoObject();
	  return Properties === undefined ? result : definePropertiesModule$1.f(result, Properties);
	};
	var objectCreate$1 = /*@__PURE__*/getDefaultExportFromCjs(objectCreate);

	var objectGetOwnPropertyNamesExternal = {};

	'use strict';
	var toPropertyKey$5 = toPropertyKey$8;
	var definePropertyModule$7 = objectDefineProperty;
	var createPropertyDescriptor$9 = createPropertyDescriptor$c;
	var createProperty$9 = function createProperty(object, key, value) {
	  var propertyKey = toPropertyKey$5(key);
	  if (propertyKey in object) definePropertyModule$7.f(object, propertyKey, createPropertyDescriptor$9(0, value));else object[propertyKey] = value;
	};
	var createProperty$a = /*@__PURE__*/getDefaultExportFromCjs(createProperty$9);

	var toAbsoluteIndex$8 = toAbsoluteIndex$a;
	var lengthOfArrayLike$r = lengthOfArrayLike$t;
	var createProperty$8 = createProperty$9;
	var $Array$9 = Array;
	var max$a = Math.max;
	var arraySliceSimple = function arraySliceSimple(O, start, end) {
	  var length = lengthOfArrayLike$r(O);
	  var k = toAbsoluteIndex$8(start, length);
	  var fin = toAbsoluteIndex$8(end === undefined ? length : end, length);
	  var result = $Array$9(max$a(fin - k, 0));
	  for (var n = 0; k < fin; k++, n++) createProperty$8(result, n, O[k]);
	  result.length = n;
	  return result;
	};
	var arraySliceSimple$1 = /*@__PURE__*/getDefaultExportFromCjs(arraySliceSimple);

	var classof$k = classofRaw$2;
	var toIndexedObject$e = toIndexedObject$j;
	var $getOwnPropertyNames$1 = objectGetOwnPropertyNames.f;
	var arraySlice$c = arraySliceSimple;
	var windowNames = (typeof window === "undefined" ? "undefined" : _typeof(window)) == 'object' && window && Object.getOwnPropertyNames ? Object.getOwnPropertyNames(window) : [];
	var getWindowNames = function getWindowNames(it) {
	  try {
	    return $getOwnPropertyNames$1(it);
	  } catch (error) {
	    return arraySlice$c(windowNames);
	  }
	};

	// fallback for IE11 buggy Object.getOwnPropertyNames with iframe and window
	var f$2 = objectGetOwnPropertyNamesExternal.f = function getOwnPropertyNames(it) {
	  return windowNames && classof$k(it) == 'Window' ? getWindowNames(it) : $getOwnPropertyNames$1(toIndexedObject$e(it));
	};

	var makeBuiltIn$1 = makeBuiltInExports;
	var defineProperty$c = objectDefineProperty;
	var defineBuiltInAccessor$h = function defineBuiltInAccessor(target, name, descriptor) {
	  if (descriptor.get) makeBuiltIn$1(descriptor.get, name, {
	    getter: true
	  });
	  if (descriptor.set) makeBuiltIn$1(descriptor.set, name, {
	    setter: true
	  });
	  return defineProperty$c.f(target, name, descriptor);
	};
	var defineBuiltInAccessor$i = /*@__PURE__*/getDefaultExportFromCjs(defineBuiltInAccessor$h);

	var wellKnownSymbolWrapped = {};

	var wellKnownSymbol$v = wellKnownSymbol$z;
	var f$1 = wellKnownSymbolWrapped.f = wellKnownSymbol$v;

	var global$P = global$Z;
	var path$2 = global$P;
	var path$3 = /*@__PURE__*/getDefaultExportFromCjs(path$2);

	var path$1 = path$2;
	var hasOwn$p = hasOwnProperty_1;
	var wrappedWellKnownSymbolModule$1 = wellKnownSymbolWrapped;
	var defineProperty$b = objectDefineProperty.f;
	var wellKnownSymbolDefine = function wellKnownSymbolDefine(NAME) {
	  var _Symbol = path$1.Symbol || (path$1.Symbol = {});
	  if (!hasOwn$p(_Symbol, NAME)) defineProperty$b(_Symbol, NAME, {
	    value: wrappedWellKnownSymbolModule$1.f(NAME)
	  });
	};
	var wellKnownSymbolDefine$1 = /*@__PURE__*/getDefaultExportFromCjs(wellKnownSymbolDefine);

	var call$z = functionCall;
	var getBuiltIn$i = getBuiltIn$m;
	var wellKnownSymbol$u = wellKnownSymbol$z;
	var defineBuiltIn$k = defineBuiltIn$m;
	var symbolDefineToPrimitive = function symbolDefineToPrimitive() {
	  var _Symbol = getBuiltIn$i('Symbol');
	  var SymbolPrototype = _Symbol && _Symbol.prototype;
	  var valueOf = SymbolPrototype && SymbolPrototype.valueOf;
	  var TO_PRIMITIVE = wellKnownSymbol$u('toPrimitive');
	  if (SymbolPrototype && !SymbolPrototype[TO_PRIMITIVE]) {
	    // `Symbol.prototype[@@toPrimitive]` method
	    // https://tc39.es/ecma262/#sec-symbol.prototype-@@toprimitive
	    // eslint-disable-next-line no-unused-vars -- required for .length
	    defineBuiltIn$k(SymbolPrototype, TO_PRIMITIVE, function (hint) {
	      return call$z(valueOf, this);
	    }, {
	      arity: 1
	    });
	  }
	};
	var symbolDefineToPrimitive$1 = /*@__PURE__*/getDefaultExportFromCjs(symbolDefineToPrimitive);

	var defineProperty$a = objectDefineProperty.f;
	var hasOwn$o = hasOwnProperty_1;
	var wellKnownSymbol$t = wellKnownSymbol$z;
	var TO_STRING_TAG$3 = wellKnownSymbol$t('toStringTag');
	var setToStringTag$d = function setToStringTag(target, TAG, STATIC) {
	  if (target && !STATIC) target = target.prototype;
	  if (target && !hasOwn$o(target, TO_STRING_TAG$3)) {
	    defineProperty$a(target, TO_STRING_TAG$3, {
	      configurable: true,
	      value: TAG
	    });
	  }
	};
	var setToStringTag$e = /*@__PURE__*/getDefaultExportFromCjs(setToStringTag$d);

	var classofRaw = classofRaw$2;
	var uncurryThis$1a = functionUncurryThis;
	var functionUncurryThisClause = function functionUncurryThisClause(fn) {
	  // Nashorn bug:
	  //   https://github.com/zloirock/core-js/issues/1128
	  //   https://github.com/zloirock/core-js/issues/1130
	  if (classofRaw(fn) === 'Function') return uncurryThis$1a(fn);
	};
	var functionUncurryThisClause$1 = /*@__PURE__*/getDefaultExportFromCjs(functionUncurryThisClause);

	var uncurryThis$19 = functionUncurryThisClause;
	var aCallable$j = aCallable$l;
	var NATIVE_BIND$2 = functionBindNative;
	var bind$e = uncurryThis$19(uncurryThis$19.bind);

	// optional / simple context binding
	var functionBindContext = function functionBindContext(fn, that) {
	  aCallable$j(fn);
	  return that === undefined ? fn : NATIVE_BIND$2 ? bind$e(fn, that) : function /* ...args */
	  () {
	    return fn.apply(that, arguments);
	  };
	};
	var functionBindContext$1 = /*@__PURE__*/getDefaultExportFromCjs(functionBindContext);

	var classof$j = classofRaw$2;

	// `IsArray` abstract operation
	// https://tc39.es/ecma262/#sec-isarray
	// eslint-disable-next-line es/no-array-isarray -- safe
	var isArray$9 = Array.isArray || function isArray(argument) {
	  return classof$j(argument) == 'Array';
	};
	var isArray$a = /*@__PURE__*/getDefaultExportFromCjs(isArray$9);

	var uncurryThis$18 = functionUncurryThis;
	var fails$1d = fails$1m;
	var isCallable$n = isCallable$z;
	var classof$i = classof$m;
	var getBuiltIn$h = getBuiltIn$m;
	var inspectSource$1 = inspectSource$3;
	var noop = function noop() {/* empty */};
	var empty = [];
	var construct$1 = getBuiltIn$h('Reflect', 'construct');
	var constructorRegExp = /^\s*(?:class|function)\b/;
	var exec$a = uncurryThis$18(constructorRegExp.exec);
	var INCORRECT_TO_STRING$2 = !constructorRegExp.exec(noop);
	var isConstructorModern = function isConstructor(argument) {
	  if (!isCallable$n(argument)) return false;
	  try {
	    construct$1(noop, empty, argument);
	    return true;
	  } catch (error) {
	    return false;
	  }
	};
	var isConstructorLegacy = function isConstructor(argument) {
	  if (!isCallable$n(argument)) return false;
	  switch (classof$i(argument)) {
	    case 'AsyncFunction':
	    case 'GeneratorFunction':
	    case 'AsyncGeneratorFunction':
	      return false;
	  }
	  try {
	    // we can't check .prototype since constructors produced by .bind haven't it
	    // `Function#toString` throws on some built-it function in some legacy engines
	    // (for example, `DOMQuad` and similar in FF41-)
	    return INCORRECT_TO_STRING$2 || !!exec$a(constructorRegExp, inspectSource$1(argument));
	  } catch (error) {
	    return true;
	  }
	};
	isConstructorLegacy.sham = true;

	// `IsConstructor` abstract operation
	// https://tc39.es/ecma262/#sec-isconstructor
	var isConstructor$6 = !construct$1 || fails$1d(function () {
	  var called;
	  return isConstructorModern(isConstructorModern.call) || !isConstructorModern(Object) || !isConstructorModern(function () {
	    called = true;
	  }) || called;
	}) ? isConstructorLegacy : isConstructorModern;
	var isConstructor$7 = /*@__PURE__*/getDefaultExportFromCjs(isConstructor$6);

	var isArray$8 = isArray$9;
	var isConstructor$5 = isConstructor$6;
	var isObject$t = isObject$z;
	var wellKnownSymbol$s = wellKnownSymbol$z;
	var SPECIES$6 = wellKnownSymbol$s('species');
	var $Array$8 = Array;

	// a part of `ArraySpeciesCreate` abstract operation
	// https://tc39.es/ecma262/#sec-arrayspeciescreate
	var arraySpeciesConstructor$1 = function arraySpeciesConstructor(originalArray) {
	  var C;
	  if (isArray$8(originalArray)) {
	    C = originalArray.constructor;
	    // cross-realm fallback
	    if (isConstructor$5(C) && (C === $Array$8 || isArray$8(C.prototype))) C = undefined;else if (isObject$t(C)) {
	      C = C[SPECIES$6];
	      if (C === null) C = undefined;
	    }
	  }
	  return C === undefined ? $Array$8 : C;
	};
	var arraySpeciesConstructor$2 = /*@__PURE__*/getDefaultExportFromCjs(arraySpeciesConstructor$1);

	var arraySpeciesConstructor = arraySpeciesConstructor$1;

	// `ArraySpeciesCreate` abstract operation
	// https://tc39.es/ecma262/#sec-arrayspeciescreate
	var arraySpeciesCreate$5 = function arraySpeciesCreate(originalArray, length) {
	  return new (arraySpeciesConstructor(originalArray))(length === 0 ? 0 : length);
	};
	var arraySpeciesCreate$6 = /*@__PURE__*/getDefaultExportFromCjs(arraySpeciesCreate$5);

	var bind$d = functionBindContext;
	var uncurryThis$17 = functionUncurryThis;
	var IndexedObject$4 = indexedObject;
	var toObject$r = toObject$t;
	var lengthOfArrayLike$q = lengthOfArrayLike$t;
	var arraySpeciesCreate$4 = arraySpeciesCreate$5;
	var push$d = uncurryThis$17([].push);

	// `Array.prototype.{ forEach, map, filter, some, every, find, findIndex, filterReject }` methods implementation
	var createMethod$6 = function createMethod(TYPE) {
	  var IS_MAP = TYPE == 1;
	  var IS_FILTER = TYPE == 2;
	  var IS_SOME = TYPE == 3;
	  var IS_EVERY = TYPE == 4;
	  var IS_FIND_INDEX = TYPE == 6;
	  var IS_FILTER_REJECT = TYPE == 7;
	  var NO_HOLES = TYPE == 5 || IS_FIND_INDEX;
	  return function ($this, callbackfn, that, specificCreate) {
	    var O = toObject$r($this);
	    var self = IndexedObject$4(O);
	    var boundFunction = bind$d(callbackfn, that);
	    var length = lengthOfArrayLike$q(self);
	    var index = 0;
	    var create = specificCreate || arraySpeciesCreate$4;
	    var target = IS_MAP ? create($this, length) : IS_FILTER || IS_FILTER_REJECT ? create($this, 0) : undefined;
	    var value, result;
	    for (; length > index; index++) if (NO_HOLES || index in self) {
	      value = self[index];
	      result = boundFunction(value, index, O);
	      if (TYPE) {
	        if (IS_MAP) target[index] = result; // map
	        else if (result) switch (TYPE) {
	          case 3:
	            return true;
	          // some
	          case 5:
	            return value;
	          // find
	          case 6:
	            return index;
	          // findIndex
	          case 2:
	            push$d(target, value);
	          // filter
	        } else switch (TYPE) {
	          case 4:
	            return false;
	          // every
	          case 7:
	            push$d(target, value);
	          // filterReject
	        }
	      }
	    }

	    return IS_FIND_INDEX ? -1 : IS_SOME || IS_EVERY ? IS_EVERY : target;
	  };
	};
	var arrayIteration = {
	  // `Array.prototype.forEach` method
	  // https://tc39.es/ecma262/#sec-array.prototype.foreach
	  forEach: createMethod$6(0),
	  // `Array.prototype.map` method
	  // https://tc39.es/ecma262/#sec-array.prototype.map
	  map: createMethod$6(1),
	  // `Array.prototype.filter` method
	  // https://tc39.es/ecma262/#sec-array.prototype.filter
	  filter: createMethod$6(2),
	  // `Array.prototype.some` method
	  // https://tc39.es/ecma262/#sec-array.prototype.some
	  some: createMethod$6(3),
	  // `Array.prototype.every` method
	  // https://tc39.es/ecma262/#sec-array.prototype.every
	  every: createMethod$6(4),
	  // `Array.prototype.find` method
	  // https://tc39.es/ecma262/#sec-array.prototype.find
	  find: createMethod$6(5),
	  // `Array.prototype.findIndex` method
	  // https://tc39.es/ecma262/#sec-array.prototype.findIndex
	  findIndex: createMethod$6(6),
	  // `Array.prototype.filterReject` method
	  // https://github.com/tc39/proposal-array-filtering
	  filterReject: createMethod$6(7)
	};
	var arrayIteration$1 = /*@__PURE__*/getDefaultExportFromCjs(arrayIteration);

	'use strict';
	var $$2X = _export;
	var global$O = global$Z;
	var call$y = functionCall;
	var uncurryThis$16 = functionUncurryThis;
	var IS_PURE$j = isPure;
	var DESCRIPTORS$B = descriptors;
	var NATIVE_SYMBOL$4 = symbolConstructorDetection;
	var fails$1c = fails$1m;
	var hasOwn$n = hasOwnProperty_1;
	var isPrototypeOf$a = objectIsPrototypeOf;
	var anObject$y = anObject$D;
	var toIndexedObject$d = toIndexedObject$j;
	var toPropertyKey$4 = toPropertyKey$8;
	var $toString$3 = toString$x;
	var createPropertyDescriptor$8 = createPropertyDescriptor$c;
	var nativeObjectCreate = objectCreate;
	var objectKeys$3 = objectKeys$5;
	var getOwnPropertyNamesModule$1 = objectGetOwnPropertyNames;
	var getOwnPropertyNamesExternal = objectGetOwnPropertyNamesExternal;
	var getOwnPropertySymbolsModule$2 = objectGetOwnPropertySymbols;
	var getOwnPropertyDescriptorModule$5 = objectGetOwnPropertyDescriptor;
	var definePropertyModule$6 = objectDefineProperty;
	var definePropertiesModule = objectDefineProperties;
	var propertyIsEnumerableModule$1 = objectPropertyIsEnumerable;
	var defineBuiltIn$j = defineBuiltIn$m;
	var defineBuiltInAccessor$g = defineBuiltInAccessor$h;
	var shared$4 = sharedExports;
	var sharedKey$1 = sharedKey$4;
	var hiddenKeys$1 = hiddenKeys$6;
	var uid$3 = uid$6;
	var wellKnownSymbol$r = wellKnownSymbol$z;
	var wrappedWellKnownSymbolModule = wellKnownSymbolWrapped;
	var defineWellKnownSymbol$d = wellKnownSymbolDefine;
	var defineSymbolToPrimitive$1 = symbolDefineToPrimitive;
	var setToStringTag$c = setToStringTag$d;
	var InternalStateModule$c = internalState;
	var $forEach$2 = arrayIteration.forEach;
	var HIDDEN = sharedKey$1('hidden');
	var SYMBOL = 'Symbol';
	var PROTOTYPE$1 = 'prototype';
	var setInternalState$b = InternalStateModule$c.set;
	var getInternalState$9 = InternalStateModule$c.getterFor(SYMBOL);
	var ObjectPrototype$5 = Object[PROTOTYPE$1];
	var $Symbol = global$O.Symbol;
	var SymbolPrototype$1 = $Symbol && $Symbol[PROTOTYPE$1];
	var TypeError$7 = global$O.TypeError;
	var QObject = global$O.QObject;
	var nativeGetOwnPropertyDescriptor$2 = getOwnPropertyDescriptorModule$5.f;
	var nativeDefineProperty$1 = definePropertyModule$6.f;
	var nativeGetOwnPropertyNames = getOwnPropertyNamesExternal.f;
	var nativePropertyIsEnumerable = propertyIsEnumerableModule$1.f;
	var push$c = uncurryThis$16([].push);
	var AllSymbols = shared$4('symbols');
	var ObjectPrototypeSymbols = shared$4('op-symbols');
	var WellKnownSymbolsStore = shared$4('wks');

	// Don't use setters in Qt Script, https://github.com/zloirock/core-js/issues/173
	var USE_SETTER = !QObject || !QObject[PROTOTYPE$1] || !QObject[PROTOTYPE$1].findChild;

	// fallback for old Android, https://code.google.com/p/v8/issues/detail?id=687
	var setSymbolDescriptor = DESCRIPTORS$B && fails$1c(function () {
	  return nativeObjectCreate(nativeDefineProperty$1({}, 'a', {
	    get: function get() {
	      return nativeDefineProperty$1(this, 'a', {
	        value: 7
	      }).a;
	    }
	  })).a != 7;
	}) ? function (O, P, Attributes) {
	  var ObjectPrototypeDescriptor = nativeGetOwnPropertyDescriptor$2(ObjectPrototype$5, P);
	  if (ObjectPrototypeDescriptor) delete ObjectPrototype$5[P];
	  nativeDefineProperty$1(O, P, Attributes);
	  if (ObjectPrototypeDescriptor && O !== ObjectPrototype$5) {
	    nativeDefineProperty$1(ObjectPrototype$5, P, ObjectPrototypeDescriptor);
	  }
	} : nativeDefineProperty$1;
	var wrap = function wrap(tag, description) {
	  var symbol = AllSymbols[tag] = nativeObjectCreate(SymbolPrototype$1);
	  setInternalState$b(symbol, {
	    type: SYMBOL,
	    tag: tag,
	    description: description
	  });
	  if (!DESCRIPTORS$B) symbol.description = description;
	  return symbol;
	};
	var $defineProperty = function defineProperty(O, P, Attributes) {
	  if (O === ObjectPrototype$5) $defineProperty(ObjectPrototypeSymbols, P, Attributes);
	  anObject$y(O);
	  var key = toPropertyKey$4(P);
	  anObject$y(Attributes);
	  if (hasOwn$n(AllSymbols, key)) {
	    if (!Attributes.enumerable) {
	      if (!hasOwn$n(O, HIDDEN)) nativeDefineProperty$1(O, HIDDEN, createPropertyDescriptor$8(1, {}));
	      O[HIDDEN][key] = true;
	    } else {
	      if (hasOwn$n(O, HIDDEN) && O[HIDDEN][key]) O[HIDDEN][key] = false;
	      Attributes = nativeObjectCreate(Attributes, {
	        enumerable: createPropertyDescriptor$8(0, false)
	      });
	    }
	    return setSymbolDescriptor(O, key, Attributes);
	  }
	  return nativeDefineProperty$1(O, key, Attributes);
	};
	var $defineProperties = function defineProperties(O, Properties) {
	  anObject$y(O);
	  var properties = toIndexedObject$d(Properties);
	  var keys = objectKeys$3(properties).concat($getOwnPropertySymbols(properties));
	  $forEach$2(keys, function (key) {
	    if (!DESCRIPTORS$B || call$y($propertyIsEnumerable$1, properties, key)) $defineProperty(O, key, properties[key]);
	  });
	  return O;
	};
	var $create = function create(O, Properties) {
	  return Properties === undefined ? nativeObjectCreate(O) : $defineProperties(nativeObjectCreate(O), Properties);
	};
	var $propertyIsEnumerable$1 = function propertyIsEnumerable(V) {
	  var P = toPropertyKey$4(V);
	  var enumerable = call$y(nativePropertyIsEnumerable, this, P);
	  if (this === ObjectPrototype$5 && hasOwn$n(AllSymbols, P) && !hasOwn$n(ObjectPrototypeSymbols, P)) return false;
	  return enumerable || !hasOwn$n(this, P) || !hasOwn$n(AllSymbols, P) || hasOwn$n(this, HIDDEN) && this[HIDDEN][P] ? enumerable : true;
	};
	var $getOwnPropertyDescriptor = function getOwnPropertyDescriptor(O, P) {
	  var it = toIndexedObject$d(O);
	  var key = toPropertyKey$4(P);
	  if (it === ObjectPrototype$5 && hasOwn$n(AllSymbols, key) && !hasOwn$n(ObjectPrototypeSymbols, key)) return;
	  var descriptor = nativeGetOwnPropertyDescriptor$2(it, key);
	  if (descriptor && hasOwn$n(AllSymbols, key) && !(hasOwn$n(it, HIDDEN) && it[HIDDEN][key])) {
	    descriptor.enumerable = true;
	  }
	  return descriptor;
	};
	var $getOwnPropertyNames = function getOwnPropertyNames(O) {
	  var names = nativeGetOwnPropertyNames(toIndexedObject$d(O));
	  var result = [];
	  $forEach$2(names, function (key) {
	    if (!hasOwn$n(AllSymbols, key) && !hasOwn$n(hiddenKeys$1, key)) push$c(result, key);
	  });
	  return result;
	};
	var $getOwnPropertySymbols = function $getOwnPropertySymbols(O) {
	  var IS_OBJECT_PROTOTYPE = O === ObjectPrototype$5;
	  var names = nativeGetOwnPropertyNames(IS_OBJECT_PROTOTYPE ? ObjectPrototypeSymbols : toIndexedObject$d(O));
	  var result = [];
	  $forEach$2(names, function (key) {
	    if (hasOwn$n(AllSymbols, key) && (!IS_OBJECT_PROTOTYPE || hasOwn$n(ObjectPrototype$5, key))) {
	      push$c(result, AllSymbols[key]);
	    }
	  });
	  return result;
	};

	// `Symbol` constructor
	// https://tc39.es/ecma262/#sec-symbol-constructor
	if (!NATIVE_SYMBOL$4) {
	  $Symbol = function _Symbol() {
	    if (isPrototypeOf$a(SymbolPrototype$1, this)) throw TypeError$7('Symbol is not a constructor');
	    var description = !arguments.length || arguments[0] === undefined ? undefined : $toString$3(arguments[0]);
	    var tag = uid$3(description);
	    var setter = function setter(value) {
	      if (this === ObjectPrototype$5) call$y(setter, ObjectPrototypeSymbols, value);
	      if (hasOwn$n(this, HIDDEN) && hasOwn$n(this[HIDDEN], tag)) this[HIDDEN][tag] = false;
	      setSymbolDescriptor(this, tag, createPropertyDescriptor$8(1, value));
	    };
	    if (DESCRIPTORS$B && USE_SETTER) setSymbolDescriptor(ObjectPrototype$5, tag, {
	      configurable: true,
	      set: setter
	    });
	    return wrap(tag, description);
	  };
	  SymbolPrototype$1 = $Symbol[PROTOTYPE$1];
	  defineBuiltIn$j(SymbolPrototype$1, 'toString', function toString() {
	    return getInternalState$9(this).tag;
	  });
	  defineBuiltIn$j($Symbol, 'withoutSetter', function (description) {
	    return wrap(uid$3(description), description);
	  });
	  propertyIsEnumerableModule$1.f = $propertyIsEnumerable$1;
	  definePropertyModule$6.f = $defineProperty;
	  definePropertiesModule.f = $defineProperties;
	  getOwnPropertyDescriptorModule$5.f = $getOwnPropertyDescriptor;
	  getOwnPropertyNamesModule$1.f = getOwnPropertyNamesExternal.f = $getOwnPropertyNames;
	  getOwnPropertySymbolsModule$2.f = $getOwnPropertySymbols;
	  wrappedWellKnownSymbolModule.f = function (name) {
	    return wrap(wellKnownSymbol$r(name), name);
	  };
	  if (DESCRIPTORS$B) {
	    // https://github.com/tc39/proposal-Symbol-description
	    defineBuiltInAccessor$g(SymbolPrototype$1, 'description', {
	      configurable: true,
	      get: function description() {
	        return getInternalState$9(this).description;
	      }
	    });
	    if (!IS_PURE$j) {
	      defineBuiltIn$j(ObjectPrototype$5, 'propertyIsEnumerable', $propertyIsEnumerable$1, {
	        unsafe: true
	      });
	    }
	  }
	}
	$$2X({
	  global: true,
	  constructor: true,
	  wrap: true,
	  forced: !NATIVE_SYMBOL$4,
	  sham: !NATIVE_SYMBOL$4
	}, {
	  Symbol: $Symbol
	});
	$forEach$2(objectKeys$3(WellKnownSymbolsStore), function (name) {
	  defineWellKnownSymbol$d(name);
	});
	$$2X({
	  target: SYMBOL,
	  stat: true,
	  forced: !NATIVE_SYMBOL$4
	}, {
	  useSetter: function useSetter() {
	    USE_SETTER = true;
	  },
	  useSimple: function useSimple() {
	    USE_SETTER = false;
	  }
	});
	$$2X({
	  target: 'Object',
	  stat: true,
	  forced: !NATIVE_SYMBOL$4,
	  sham: !DESCRIPTORS$B
	}, {
	  // `Object.create` method
	  // https://tc39.es/ecma262/#sec-object.create
	  create: $create,
	  // `Object.defineProperty` method
	  // https://tc39.es/ecma262/#sec-object.defineproperty
	  defineProperty: $defineProperty,
	  // `Object.defineProperties` method
	  // https://tc39.es/ecma262/#sec-object.defineproperties
	  defineProperties: $defineProperties,
	  // `Object.getOwnPropertyDescriptor` method
	  // https://tc39.es/ecma262/#sec-object.getownpropertydescriptors
	  getOwnPropertyDescriptor: $getOwnPropertyDescriptor
	});
	$$2X({
	  target: 'Object',
	  stat: true,
	  forced: !NATIVE_SYMBOL$4
	}, {
	  // `Object.getOwnPropertyNames` method
	  // https://tc39.es/ecma262/#sec-object.getownpropertynames
	  getOwnPropertyNames: $getOwnPropertyNames
	});

	// `Symbol.prototype[@@toPrimitive]` method
	// https://tc39.es/ecma262/#sec-symbol.prototype-@@toprimitive
	defineSymbolToPrimitive$1();

	// `Symbol.prototype[@@toStringTag]` property
	// https://tc39.es/ecma262/#sec-symbol.prototype-@@tostringtag
	setToStringTag$c($Symbol, SYMBOL);
	hiddenKeys$1[HIDDEN] = true;

	var es_symbol_for = {};

	var NATIVE_SYMBOL$3 = symbolConstructorDetection;

	/* eslint-disable es/no-symbol -- safe */
	var symbolRegistryDetection = NATIVE_SYMBOL$3 && !!Symbol['for'] && !!Symbol.keyFor;
	var symbolRegistryDetection$1 = /*@__PURE__*/getDefaultExportFromCjs(symbolRegistryDetection);

	var $$2W = _export;
	var getBuiltIn$g = getBuiltIn$m;
	var hasOwn$m = hasOwnProperty_1;
	var toString$w = toString$x;
	var shared$3 = sharedExports;
	var NATIVE_SYMBOL_REGISTRY$1 = symbolRegistryDetection;
	var StringToSymbolRegistry = shared$3('string-to-symbol-registry');
	var SymbolToStringRegistry$1 = shared$3('symbol-to-string-registry');

	// `Symbol.for` method
	// https://tc39.es/ecma262/#sec-symbol.for
	$$2W({
	  target: 'Symbol',
	  stat: true,
	  forced: !NATIVE_SYMBOL_REGISTRY$1
	}, {
	  'for': function _for(key) {
	    var string = toString$w(key);
	    if (hasOwn$m(StringToSymbolRegistry, string)) return StringToSymbolRegistry[string];
	    var symbol = getBuiltIn$g('Symbol')(string);
	    StringToSymbolRegistry[string] = symbol;
	    SymbolToStringRegistry$1[symbol] = string;
	    return symbol;
	  }
	});

	var es_symbol_keyFor = {};

	var $$2V = _export;
	var hasOwn$l = hasOwnProperty_1;
	var isSymbol$4 = isSymbol$7;
	var tryToString$5 = tryToString$7;
	var shared$2 = sharedExports;
	var NATIVE_SYMBOL_REGISTRY = symbolRegistryDetection;
	var SymbolToStringRegistry = shared$2('symbol-to-string-registry');

	// `Symbol.keyFor` method
	// https://tc39.es/ecma262/#sec-symbol.keyfor
	$$2V({
	  target: 'Symbol',
	  stat: true,
	  forced: !NATIVE_SYMBOL_REGISTRY
	}, {
	  keyFor: function keyFor(sym) {
	    if (!isSymbol$4(sym)) throw TypeError(tryToString$5(sym) + ' is not a symbol');
	    if (hasOwn$l(SymbolToStringRegistry, sym)) return SymbolToStringRegistry[sym];
	  }
	});

	var es_json_stringify = {};

	var NATIVE_BIND$1 = functionBindNative;
	var FunctionPrototype$2 = Function.prototype;
	var apply$b = FunctionPrototype$2.apply;
	var call$x = FunctionPrototype$2.call;

	// eslint-disable-next-line es/no-reflect -- safe
	var functionApply$1 = (typeof Reflect === "undefined" ? "undefined" : _typeof(Reflect)) == 'object' && Reflect.apply || (NATIVE_BIND$1 ? call$x.bind(apply$b) : function () {
	  return call$x.apply(apply$b, arguments);
	});
	var functionApply$2 = /*@__PURE__*/getDefaultExportFromCjs(functionApply$1);

	var uncurryThis$15 = functionUncurryThis;
	var arraySlice$a = uncurryThis$15([].slice);
	var arraySlice$b = /*@__PURE__*/getDefaultExportFromCjs(arraySlice$a);

	var uncurryThis$14 = functionUncurryThis;
	var isArray$7 = isArray$9;
	var isCallable$m = isCallable$z;
	var classof$h = classofRaw$2;
	var toString$v = toString$x;
	var push$b = uncurryThis$14([].push);
	var getJsonReplacerFunction = function getJsonReplacerFunction(replacer) {
	  if (isCallable$m(replacer)) return replacer;
	  if (!isArray$7(replacer)) return;
	  var rawLength = replacer.length;
	  var keys = [];
	  for (var i = 0; i < rawLength; i++) {
	    var element = replacer[i];
	    if (typeof element == 'string') push$b(keys, element);else if (typeof element == 'number' || classof$h(element) == 'Number' || classof$h(element) == 'String') push$b(keys, toString$v(element));
	  }
	  var keysLength = keys.length;
	  var root = true;
	  return function (key, value) {
	    if (root) {
	      root = false;
	      return value;
	    }
	    if (isArray$7(this)) return value;
	    for (var j = 0; j < keysLength; j++) if (keys[j] === key) return value;
	  };
	};
	var getJsonReplacerFunction$1 = /*@__PURE__*/getDefaultExportFromCjs(getJsonReplacerFunction);

	var $$2U = _export;
	var getBuiltIn$f = getBuiltIn$m;
	var apply$a = functionApply$1;
	var call$w = functionCall;
	var uncurryThis$13 = functionUncurryThis;
	var fails$1b = fails$1m;
	var isCallable$l = isCallable$z;
	var isSymbol$3 = isSymbol$7;
	var arraySlice$9 = arraySlice$a;
	var getReplacerFunction = getJsonReplacerFunction;
	var NATIVE_SYMBOL$2 = symbolConstructorDetection;
	var $String$3 = String;
	var $stringify = getBuiltIn$f('JSON', 'stringify');
	var exec$9 = uncurryThis$13(/./.exec);
	var charAt$e = uncurryThis$13(''.charAt);
	var charCodeAt$5 = uncurryThis$13(''.charCodeAt);
	var replace$c = uncurryThis$13(''.replace);
	var numberToString$2 = uncurryThis$13(1.0.toString);
	var tester = /[\uD800-\uDFFF]/g;
	var low = /^[\uD800-\uDBFF]$/;
	var hi = /^[\uDC00-\uDFFF]$/;
	var WRONG_SYMBOLS_CONVERSION = !NATIVE_SYMBOL$2 || fails$1b(function () {
	  var symbol = getBuiltIn$f('Symbol')();
	  // MS Edge converts symbol values to JSON as {}
	  return $stringify([symbol]) != '[null]'
	  // WebKit converts symbol values to JSON as null
	  || $stringify({
	    a: symbol
	  }) != '{}'
	  // V8 throws on boxed symbols
	  || $stringify(Object(symbol)) != '{}';
	});

	// https://github.com/tc39/proposal-well-formed-stringify
	var ILL_FORMED_UNICODE = fails$1b(function () {
	  return $stringify("\uDF06\uD834") !== "\"\\udf06\\ud834\"" || $stringify("\uDEAD") !== "\"\\udead\"";
	});
	var stringifyWithSymbolsFix = function stringifyWithSymbolsFix(it, replacer) {
	  var args = arraySlice$9(arguments);
	  var $replacer = getReplacerFunction(replacer);
	  if (!isCallable$l($replacer) && (it === undefined || isSymbol$3(it))) return; // IE8 returns string on undefined
	  args[1] = function (key, value) {
	    // some old implementations (like WebKit) could pass numbers as keys
	    if (isCallable$l($replacer)) value = call$w($replacer, this, $String$3(key), value);
	    if (!isSymbol$3(value)) return value;
	  };
	  return apply$a($stringify, null, args);
	};
	var fixIllFormed = function fixIllFormed(match, offset, string) {
	  var prev = charAt$e(string, offset - 1);
	  var next = charAt$e(string, offset + 1);
	  if (exec$9(low, match) && !exec$9(hi, next) || exec$9(hi, match) && !exec$9(low, prev)) {
	    return "\\u" + numberToString$2(charCodeAt$5(match, 0), 16);
	  }
	  return match;
	};
	if ($stringify) {
	  // `JSON.stringify` method
	  // https://tc39.es/ecma262/#sec-json.stringify
	  $$2U({
	    target: 'JSON',
	    stat: true,
	    arity: 3,
	    forced: WRONG_SYMBOLS_CONVERSION || ILL_FORMED_UNICODE
	  }, {
	    // eslint-disable-next-line no-unused-vars -- required for `.length`
	    stringify: function stringify(it, replacer, space) {
	      var args = arraySlice$9(arguments);
	      var result = apply$a(WRONG_SYMBOLS_CONVERSION ? stringifyWithSymbolsFix : $stringify, null, args);
	      return ILL_FORMED_UNICODE && typeof result == 'string' ? replace$c(result, tester, fixIllFormed) : result;
	    }
	  });
	}

	var es_object_getOwnPropertySymbols = {};

	var $$2T = _export;
	var NATIVE_SYMBOL$1 = symbolConstructorDetection;
	var fails$1a = fails$1m;
	var getOwnPropertySymbolsModule$1 = objectGetOwnPropertySymbols;
	var toObject$q = toObject$t;

	// V8 ~ Chrome 38 and 39 `Object.getOwnPropertySymbols` fails on primitives
	// https://bugs.chromium.org/p/v8/issues/detail?id=3443
	var FORCED$D = !NATIVE_SYMBOL$1 || fails$1a(function () {
	  getOwnPropertySymbolsModule$1.f(1);
	});

	// `Object.getOwnPropertySymbols` method
	// https://tc39.es/ecma262/#sec-object.getownpropertysymbols
	$$2T({
	  target: 'Object',
	  stat: true,
	  forced: FORCED$D
	}, {
	  getOwnPropertySymbols: function getOwnPropertySymbols(it) {
	    var $getOwnPropertySymbols = getOwnPropertySymbolsModule$1.f;
	    return $getOwnPropertySymbols ? $getOwnPropertySymbols(toObject$q(it)) : [];
	  }
	});

	var es_symbol_description = {};

	// `Symbol.prototype.description` getter
	// https://tc39.es/ecma262/#sec-symbol.prototype.description
	'use strict';
	var $$2S = _export;
	var DESCRIPTORS$A = descriptors;
	var global$N = global$Z;
	var uncurryThis$12 = functionUncurryThis;
	var hasOwn$k = hasOwnProperty_1;
	var isCallable$k = isCallable$z;
	var isPrototypeOf$9 = objectIsPrototypeOf;
	var toString$u = toString$x;
	var defineBuiltInAccessor$f = defineBuiltInAccessor$h;
	var copyConstructorProperties$3 = copyConstructorProperties$5;
	var NativeSymbol = global$N.Symbol;
	var SymbolPrototype = NativeSymbol && NativeSymbol.prototype;
	if (DESCRIPTORS$A && isCallable$k(NativeSymbol) && (!('description' in SymbolPrototype) ||
	// Safari 12 bug
	NativeSymbol().description !== undefined)) {
	  var EmptyStringDescriptionStore = {};
	  // wrap Symbol constructor for correct work with undefined description
	  var SymbolWrapper = function _Symbol() {
	    var description = arguments.length < 1 || arguments[0] === undefined ? undefined : toString$u(arguments[0]);
	    var result = isPrototypeOf$9(SymbolPrototype, this) ? new NativeSymbol(description)
	    // in Edge 13, String(Symbol(undefined)) === 'Symbol(undefined)'
	    : description === undefined ? NativeSymbol() : NativeSymbol(description);
	    if (description === '') EmptyStringDescriptionStore[result] = true;
	    return result;
	  };
	  copyConstructorProperties$3(SymbolWrapper, NativeSymbol);
	  SymbolWrapper.prototype = SymbolPrototype;
	  SymbolPrototype.constructor = SymbolWrapper;
	  var NATIVE_SYMBOL = String(NativeSymbol('test')) == 'Symbol(test)';
	  var thisSymbolValue = uncurryThis$12(SymbolPrototype.valueOf);
	  var symbolDescriptiveString = uncurryThis$12(SymbolPrototype.toString);
	  var regexp = /^Symbol\((.*)\)[^)]+$/;
	  var replace$b = uncurryThis$12(''.replace);
	  var stringSlice$g = uncurryThis$12(''.slice);
	  defineBuiltInAccessor$f(SymbolPrototype, 'description', {
	    configurable: true,
	    get: function description() {
	      var symbol = thisSymbolValue(this);
	      if (hasOwn$k(EmptyStringDescriptionStore, symbol)) return '';
	      var string = symbolDescriptiveString(symbol);
	      var desc = NATIVE_SYMBOL ? stringSlice$g(string, 7, -1) : replace$b(string, regexp, '$1');
	      return desc === '' ? undefined : desc;
	    }
	  });
	  $$2S({
	    global: true,
	    constructor: true,
	    forced: true
	  }, {
	    Symbol: SymbolWrapper
	  });
	}

	var es_symbol_asyncIterator = {};

	var defineWellKnownSymbol$c = wellKnownSymbolDefine;

	// `Symbol.asyncIterator` well-known symbol
	// https://tc39.es/ecma262/#sec-symbol.asynciterator
	defineWellKnownSymbol$c('asyncIterator');

	var es_symbol_hasInstance = {};

	var defineWellKnownSymbol$b = wellKnownSymbolDefine;

	// `Symbol.hasInstance` well-known symbol
	// https://tc39.es/ecma262/#sec-symbol.hasinstance
	defineWellKnownSymbol$b('hasInstance');

	var es_symbol_isConcatSpreadable = {};

	var defineWellKnownSymbol$a = wellKnownSymbolDefine;

	// `Symbol.isConcatSpreadable` well-known symbol
	// https://tc39.es/ecma262/#sec-symbol.isconcatspreadable
	defineWellKnownSymbol$a('isConcatSpreadable');

	var es_symbol_iterator = {};

	var defineWellKnownSymbol$9 = wellKnownSymbolDefine;

	// `Symbol.iterator` well-known symbol
	// https://tc39.es/ecma262/#sec-symbol.iterator
	defineWellKnownSymbol$9('iterator');

	var es_symbol_match = {};

	var defineWellKnownSymbol$8 = wellKnownSymbolDefine;

	// `Symbol.match` well-known symbol
	// https://tc39.es/ecma262/#sec-symbol.match
	defineWellKnownSymbol$8('match');

	var es_symbol_matchAll = {};

	var defineWellKnownSymbol$7 = wellKnownSymbolDefine;

	// `Symbol.matchAll` well-known symbol
	// https://tc39.es/ecma262/#sec-symbol.matchall
	defineWellKnownSymbol$7('matchAll');

	var es_symbol_replace = {};

	var defineWellKnownSymbol$6 = wellKnownSymbolDefine;

	// `Symbol.replace` well-known symbol
	// https://tc39.es/ecma262/#sec-symbol.replace
	defineWellKnownSymbol$6('replace');

	var es_symbol_search = {};

	var defineWellKnownSymbol$5 = wellKnownSymbolDefine;

	// `Symbol.search` well-known symbol
	// https://tc39.es/ecma262/#sec-symbol.search
	defineWellKnownSymbol$5('search');

	var es_symbol_species = {};

	var defineWellKnownSymbol$4 = wellKnownSymbolDefine;

	// `Symbol.species` well-known symbol
	// https://tc39.es/ecma262/#sec-symbol.species
	defineWellKnownSymbol$4('species');

	var es_symbol_split = {};

	var defineWellKnownSymbol$3 = wellKnownSymbolDefine;

	// `Symbol.split` well-known symbol
	// https://tc39.es/ecma262/#sec-symbol.split
	defineWellKnownSymbol$3('split');

	var es_symbol_toPrimitive = {};

	var defineWellKnownSymbol$2 = wellKnownSymbolDefine;
	var defineSymbolToPrimitive = symbolDefineToPrimitive;

	// `Symbol.toPrimitive` well-known symbol
	// https://tc39.es/ecma262/#sec-symbol.toprimitive
	defineWellKnownSymbol$2('toPrimitive');

	// `Symbol.prototype[@@toPrimitive]` method
	// https://tc39.es/ecma262/#sec-symbol.prototype-@@toprimitive
	defineSymbolToPrimitive();

	var es_symbol_toStringTag = {};

	var getBuiltIn$e = getBuiltIn$m;
	var defineWellKnownSymbol$1 = wellKnownSymbolDefine;
	var setToStringTag$b = setToStringTag$d;

	// `Symbol.toStringTag` well-known symbol
	// https://tc39.es/ecma262/#sec-symbol.tostringtag
	defineWellKnownSymbol$1('toStringTag');

	// `Symbol.prototype[@@toStringTag]` property
	// https://tc39.es/ecma262/#sec-symbol.prototype-@@tostringtag
	setToStringTag$b(getBuiltIn$e('Symbol'), 'Symbol');

	var es_symbol_unscopables = {};

	var defineWellKnownSymbol = wellKnownSymbolDefine;

	// `Symbol.unscopables` well-known symbol
	// https://tc39.es/ecma262/#sec-symbol.unscopables
	defineWellKnownSymbol('unscopables');

	var es_error_cause = {};

	var uncurryThis$11 = functionUncurryThis;
	var aCallable$i = aCallable$l;
	var functionUncurryThisAccessor = function functionUncurryThisAccessor(object, key, method) {
	  try {
	    // eslint-disable-next-line es/no-object-getownpropertydescriptor -- safe
	    return uncurryThis$11(aCallable$i(Object.getOwnPropertyDescriptor(object, key)[method]));
	  } catch (error) {/* empty */}
	};
	var functionUncurryThisAccessor$1 = /*@__PURE__*/getDefaultExportFromCjs(functionUncurryThisAccessor);

	var isCallable$j = isCallable$z;
	var $String$2 = String;
	var $TypeError$j = TypeError;
	var aPossiblePrototype$2 = function aPossiblePrototype(argument) {
	  if (_typeof(argument) == 'object' || isCallable$j(argument)) return argument;
	  throw $TypeError$j("Can't set " + $String$2(argument) + ' as a prototype');
	};
	var aPossiblePrototype$3 = /*@__PURE__*/getDefaultExportFromCjs(aPossiblePrototype$2);

	/* eslint-disable no-proto -- safe */
	var uncurryThisAccessor = functionUncurryThisAccessor;
	var anObject$x = anObject$D;
	var aPossiblePrototype$1 = aPossiblePrototype$2;

	// `Object.setPrototypeOf` method
	// https://tc39.es/ecma262/#sec-object.setprototypeof
	// Works with __proto__ only. Old v8 can't work with null proto objects.
	// eslint-disable-next-line es/no-object-setprototypeof -- safe
	var objectSetPrototypeOf$1 = Object.setPrototypeOf || ('__proto__' in {} ? function () {
	  var CORRECT_SETTER = false;
	  var test = {};
	  var setter;
	  try {
	    setter = uncurryThisAccessor(Object.prototype, '__proto__', 'set');
	    setter(test, []);
	    CORRECT_SETTER = test instanceof Array;
	  } catch (error) {/* empty */}
	  return function setPrototypeOf(O, proto) {
	    anObject$x(O);
	    aPossiblePrototype$1(proto);
	    if (CORRECT_SETTER) setter(O, proto);else O.__proto__ = proto;
	    return O;
	  };
	}() : undefined);
	var objectSetPrototypeOf$2 = /*@__PURE__*/getDefaultExportFromCjs(objectSetPrototypeOf$1);

	var defineProperty$9 = objectDefineProperty.f;
	var proxyAccessor$2 = function proxyAccessor(Target, Source, key) {
	  key in Target || defineProperty$9(Target, key, {
	    configurable: true,
	    get: function get() {
	      return Source[key];
	    },
	    set: function set(it) {
	      Source[key] = it;
	    }
	  });
	};
	var proxyAccessor$3 = /*@__PURE__*/getDefaultExportFromCjs(proxyAccessor$2);

	var isCallable$i = isCallable$z;
	var isObject$s = isObject$z;
	var setPrototypeOf$9 = objectSetPrototypeOf$1;

	// makes subclassing work correct for wrapped built-ins
	var inheritIfRequired$6 = function inheritIfRequired($this, dummy, Wrapper) {
	  var NewTarget, NewTargetPrototype;
	  if (
	  // it can work only with native `setPrototypeOf`
	  setPrototypeOf$9 &&
	  // we haven't completely correct pre-ES6 way for getting `new.target`, so use this
	  isCallable$i(NewTarget = dummy.constructor) && NewTarget !== Wrapper && isObject$s(NewTargetPrototype = NewTarget.prototype) && NewTargetPrototype !== Wrapper.prototype) setPrototypeOf$9($this, NewTargetPrototype);
	  return $this;
	};
	var inheritIfRequired$7 = /*@__PURE__*/getDefaultExportFromCjs(inheritIfRequired$6);

	var toString$t = toString$x;
	var normalizeStringArgument$5 = function normalizeStringArgument(argument, $default) {
	  return argument === undefined ? arguments.length < 2 ? '' : $default : toString$t(argument);
	};
	var normalizeStringArgument$6 = /*@__PURE__*/getDefaultExportFromCjs(normalizeStringArgument$5);

	var isObject$r = isObject$z;
	var createNonEnumerableProperty$c = createNonEnumerableProperty$f;

	// `InstallErrorCause` abstract operation
	// https://tc39.es/proposal-error-cause/#sec-errorobjects-install-error-cause
	var installErrorCause$2 = function installErrorCause(O, options) {
	  if (isObject$r(options) && 'cause' in options) {
	    createNonEnumerableProperty$c(O, 'cause', options.cause);
	  }
	};
	var installErrorCause$3 = /*@__PURE__*/getDefaultExportFromCjs(installErrorCause$2);

	var uncurryThis$10 = functionUncurryThis;
	var $Error$1 = Error;
	var replace$a = uncurryThis$10(''.replace);
	var TEST = function (arg) {
	  return String($Error$1(arg).stack);
	}('zxcasd');
	// eslint-disable-next-line redos/no-vulnerable -- safe
	var V8_OR_CHAKRA_STACK_ENTRY = /\n\s*at [^:]*:[^\n]*/;
	var IS_V8_OR_CHAKRA_STACK = V8_OR_CHAKRA_STACK_ENTRY.test(TEST);
	var errorStackClear = function errorStackClear(stack, dropEntries) {
	  if (IS_V8_OR_CHAKRA_STACK && typeof stack == 'string' && !$Error$1.prepareStackTrace) {
	    while (dropEntries--) stack = replace$a(stack, V8_OR_CHAKRA_STACK_ENTRY, '');
	  }
	  return stack;
	};
	var errorStackClear$1 = /*@__PURE__*/getDefaultExportFromCjs(errorStackClear);

	var fails$19 = fails$1m;
	var createPropertyDescriptor$7 = createPropertyDescriptor$c;
	var errorStackInstallable = !fails$19(function () {
	  var error = Error('a');
	  if (!('stack' in error)) return true;
	  // eslint-disable-next-line es/no-object-defineproperty -- safe
	  Object.defineProperty(error, 'stack', createPropertyDescriptor$7(1, 7));
	  return error.stack !== 7;
	});
	var errorStackInstallable$1 = /*@__PURE__*/getDefaultExportFromCjs(errorStackInstallable);

	var createNonEnumerableProperty$b = createNonEnumerableProperty$f;
	var clearErrorStack$2 = errorStackClear;
	var ERROR_STACK_INSTALLABLE$1 = errorStackInstallable;

	// non-standard V8
	var captureStackTrace = Error.captureStackTrace;
	var errorStackInstall = function errorStackInstall(error, C, stack, dropEntries) {
	  if (ERROR_STACK_INSTALLABLE$1) {
	    if (captureStackTrace) captureStackTrace(error, C);else createNonEnumerableProperty$b(error, 'stack', clearErrorStack$2(stack, dropEntries));
	  }
	};
	var errorStackInstall$1 = /*@__PURE__*/getDefaultExportFromCjs(errorStackInstall);

	'use strict';
	var getBuiltIn$d = getBuiltIn$m;
	var hasOwn$j = hasOwnProperty_1;
	var createNonEnumerableProperty$a = createNonEnumerableProperty$f;
	var isPrototypeOf$8 = objectIsPrototypeOf;
	var setPrototypeOf$8 = objectSetPrototypeOf$1;
	var copyConstructorProperties$2 = copyConstructorProperties$5;
	var proxyAccessor$1 = proxyAccessor$2;
	var inheritIfRequired$5 = inheritIfRequired$6;
	var normalizeStringArgument$4 = normalizeStringArgument$5;
	var installErrorCause$1 = installErrorCause$2;
	var installErrorStack$1 = errorStackInstall;
	var DESCRIPTORS$z = descriptors;
	var IS_PURE$i = isPure;
	var wrapErrorConstructorWithCause$2 = function wrapErrorConstructorWithCause(FULL_NAME, wrapper, FORCED, IS_AGGREGATE_ERROR) {
	  var STACK_TRACE_LIMIT = 'stackTraceLimit';
	  var OPTIONS_POSITION = IS_AGGREGATE_ERROR ? 2 : 1;
	  var path = FULL_NAME.split('.');
	  var ERROR_NAME = path[path.length - 1];
	  var OriginalError = getBuiltIn$d.apply(null, path);
	  if (!OriginalError) return;
	  var OriginalErrorPrototype = OriginalError.prototype;

	  // V8 9.3- bug https://bugs.chromium.org/p/v8/issues/detail?id=12006
	  if (!IS_PURE$i && hasOwn$j(OriginalErrorPrototype, 'cause')) delete OriginalErrorPrototype.cause;
	  if (!FORCED) return OriginalError;
	  var BaseError = getBuiltIn$d('Error');
	  var WrappedError = wrapper(function (a, b) {
	    var message = normalizeStringArgument$4(IS_AGGREGATE_ERROR ? b : a, undefined);
	    var result = IS_AGGREGATE_ERROR ? new OriginalError(a) : new OriginalError();
	    if (message !== undefined) createNonEnumerableProperty$a(result, 'message', message);
	    installErrorStack$1(result, WrappedError, result.stack, 2);
	    if (this && isPrototypeOf$8(OriginalErrorPrototype, this)) inheritIfRequired$5(result, this, WrappedError);
	    if (arguments.length > OPTIONS_POSITION) installErrorCause$1(result, arguments[OPTIONS_POSITION]);
	    return result;
	  });
	  WrappedError.prototype = OriginalErrorPrototype;
	  if (ERROR_NAME !== 'Error') {
	    if (setPrototypeOf$8) setPrototypeOf$8(WrappedError, BaseError);else copyConstructorProperties$2(WrappedError, BaseError, {
	      name: true
	    });
	  } else if (DESCRIPTORS$z && STACK_TRACE_LIMIT in OriginalError) {
	    proxyAccessor$1(WrappedError, OriginalError, STACK_TRACE_LIMIT);
	    proxyAccessor$1(WrappedError, OriginalError, 'prepareStackTrace');
	  }
	  copyConstructorProperties$2(WrappedError, OriginalError);
	  if (!IS_PURE$i) try {
	    // Safari 13- bug: WebAssembly errors does not have a proper `.name`
	    if (OriginalErrorPrototype.name !== ERROR_NAME) {
	      createNonEnumerableProperty$a(OriginalErrorPrototype, 'name', ERROR_NAME);
	    }
	    OriginalErrorPrototype.constructor = WrappedError;
	  } catch (error) {/* empty */}
	  return WrappedError;
	};
	var wrapErrorConstructorWithCause$3 = /*@__PURE__*/getDefaultExportFromCjs(wrapErrorConstructorWithCause$2);

	/* eslint-disable no-unused-vars -- required for functions `.length` */
	var $$2R = _export;
	var global$M = global$Z;
	var apply$9 = functionApply$1;
	var wrapErrorConstructorWithCause$1 = wrapErrorConstructorWithCause$2;
	var WEB_ASSEMBLY = 'WebAssembly';
	var WebAssembly$2 = global$M[WEB_ASSEMBLY];
	var FORCED$C = Error('e', {
	  cause: 7
	}).cause !== 7;
	var exportGlobalErrorCauseWrapper = function exportGlobalErrorCauseWrapper(ERROR_NAME, wrapper) {
	  var O = {};
	  O[ERROR_NAME] = wrapErrorConstructorWithCause$1(ERROR_NAME, wrapper, FORCED$C);
	  $$2R({
	    global: true,
	    constructor: true,
	    arity: 1,
	    forced: FORCED$C
	  }, O);
	};
	var exportWebAssemblyErrorCauseWrapper = function exportWebAssemblyErrorCauseWrapper(ERROR_NAME, wrapper) {
	  if (WebAssembly$2 && WebAssembly$2[ERROR_NAME]) {
	    var O = {};
	    O[ERROR_NAME] = wrapErrorConstructorWithCause$1(WEB_ASSEMBLY + '.' + ERROR_NAME, wrapper, FORCED$C);
	    $$2R({
	      target: WEB_ASSEMBLY,
	      stat: true,
	      constructor: true,
	      arity: 1,
	      forced: FORCED$C
	    }, O);
	  }
	};

	// https://tc39.es/ecma262/#sec-nativeerror
	// https://github.com/tc39/proposal-error-cause
	exportGlobalErrorCauseWrapper('Error', function (init) {
	  return function Error(message) {
	    return apply$9(init, this, arguments);
	  };
	});
	exportGlobalErrorCauseWrapper('EvalError', function (init) {
	  return function EvalError(message) {
	    return apply$9(init, this, arguments);
	  };
	});
	exportGlobalErrorCauseWrapper('RangeError', function (init) {
	  return function RangeError(message) {
	    return apply$9(init, this, arguments);
	  };
	});
	exportGlobalErrorCauseWrapper('ReferenceError', function (init) {
	  return function ReferenceError(message) {
	    return apply$9(init, this, arguments);
	  };
	});
	exportGlobalErrorCauseWrapper('SyntaxError', function (init) {
	  return function SyntaxError(message) {
	    return apply$9(init, this, arguments);
	  };
	});
	exportGlobalErrorCauseWrapper('TypeError', function (init) {
	  return function TypeError(message) {
	    return apply$9(init, this, arguments);
	  };
	});
	exportGlobalErrorCauseWrapper('URIError', function (init) {
	  return function URIError(message) {
	    return apply$9(init, this, arguments);
	  };
	});
	exportWebAssemblyErrorCauseWrapper('CompileError', function (init) {
	  return function CompileError(message) {
	    return apply$9(init, this, arguments);
	  };
	});
	exportWebAssemblyErrorCauseWrapper('LinkError', function (init) {
	  return function LinkError(message) {
	    return apply$9(init, this, arguments);
	  };
	});
	exportWebAssemblyErrorCauseWrapper('RuntimeError', function (init) {
	  return function RuntimeError(message) {
	    return apply$9(init, this, arguments);
	  };
	});

	var es_error_toString = {};

	'use strict';
	var DESCRIPTORS$y = descriptors;
	var fails$18 = fails$1m;
	var anObject$w = anObject$D;
	var create$b = objectCreate;
	var normalizeStringArgument$3 = normalizeStringArgument$5;
	var nativeErrorToString = Error.prototype.toString;
	var INCORRECT_TO_STRING$1 = fails$18(function () {
	  if (DESCRIPTORS$y) {
	    // Chrome 32- incorrectly call accessor
	    // eslint-disable-next-line es/no-object-defineproperty -- safe
	    var object = create$b(Object.defineProperty({}, 'name', {
	      get: function get() {
	        return this === object;
	      }
	    }));
	    if (nativeErrorToString.call(object) !== 'true') return true;
	  }
	  // FF10- does not properly handle non-strings
	  return nativeErrorToString.call({
	    message: 1,
	    name: 2
	  }) !== '2: 1'
	  // IE8 does not properly handle defaults
	  || nativeErrorToString.call({}) !== 'Error';
	});
	var errorToString$2 = INCORRECT_TO_STRING$1 ? function toString() {
	  var O = anObject$w(this);
	  var name = normalizeStringArgument$3(O.name, 'Error');
	  var message = normalizeStringArgument$3(O.message);
	  return !name ? message : !message ? name : name + ': ' + message;
	} : nativeErrorToString;
	var errorToString$3 = /*@__PURE__*/getDefaultExportFromCjs(errorToString$2);

	var defineBuiltIn$i = defineBuiltIn$m;
	var errorToString$1 = errorToString$2;
	var ErrorPrototype$1 = Error.prototype;

	// `Error.prototype.toString` method fix
	// https://tc39.es/ecma262/#sec-error.prototype.tostring
	if (ErrorPrototype$1.toString !== errorToString$1) {
	  defineBuiltIn$i(ErrorPrototype$1, 'toString', errorToString$1);
	}

	var es_aggregateError = {};

	var es_aggregateError_constructor = {};

	var fails$17 = fails$1m;
	var correctPrototypeGetter = !fails$17(function () {
	  function F() {/* empty */}
	  F.prototype.constructor = null;
	  // eslint-disable-next-line es/no-object-getprototypeof -- required for testing
	  return Object.getPrototypeOf(new F()) !== F.prototype;
	});
	var correctPrototypeGetter$1 = /*@__PURE__*/getDefaultExportFromCjs(correctPrototypeGetter);

	var hasOwn$i = hasOwnProperty_1;
	var isCallable$h = isCallable$z;
	var toObject$p = toObject$t;
	var sharedKey = sharedKey$4;
	var CORRECT_PROTOTYPE_GETTER$2 = correctPrototypeGetter;
	var IE_PROTO = sharedKey('IE_PROTO');
	var $Object$1 = Object;
	var ObjectPrototype$4 = $Object$1.prototype;

	// `Object.getPrototypeOf` method
	// https://tc39.es/ecma262/#sec-object.getprototypeof
	// eslint-disable-next-line es/no-object-getprototypeof -- safe
	var objectGetPrototypeOf$1 = CORRECT_PROTOTYPE_GETTER$2 ? $Object$1.getPrototypeOf : function (O) {
	  var object = toObject$p(O);
	  if (hasOwn$i(object, IE_PROTO)) return object[IE_PROTO];
	  var constructor = object.constructor;
	  if (isCallable$h(constructor) && object instanceof constructor) {
	    return constructor.prototype;
	  }
	  return object instanceof $Object$1 ? ObjectPrototype$4 : null;
	};
	var objectGetPrototypeOf$2 = /*@__PURE__*/getDefaultExportFromCjs(objectGetPrototypeOf$1);

	var iterators = {};
	var iterators$1 = /*@__PURE__*/getDefaultExportFromCjs(iterators);

	var wellKnownSymbol$q = wellKnownSymbol$z;
	var Iterators$4 = iterators;
	var ITERATOR$a = wellKnownSymbol$q('iterator');
	var ArrayPrototype$1 = Array.prototype;

	// check on default Array iterator
	var isArrayIteratorMethod$3 = function isArrayIteratorMethod(it) {
	  return it !== undefined && (Iterators$4.Array === it || ArrayPrototype$1[ITERATOR$a] === it);
	};
	var isArrayIteratorMethod$4 = /*@__PURE__*/getDefaultExportFromCjs(isArrayIteratorMethod$3);

	var classof$g = classof$m;
	var getMethod$7 = getMethod$9;
	var isNullOrUndefined$b = isNullOrUndefined$e;
	var Iterators$3 = iterators;
	var wellKnownSymbol$p = wellKnownSymbol$z;
	var ITERATOR$9 = wellKnownSymbol$p('iterator');
	var getIteratorMethod$5 = function getIteratorMethod(it) {
	  if (!isNullOrUndefined$b(it)) return getMethod$7(it, ITERATOR$9) || getMethod$7(it, '@@iterator') || Iterators$3[classof$g(it)];
	};
	var getIteratorMethod$6 = /*@__PURE__*/getDefaultExportFromCjs(getIteratorMethod$5);

	var call$v = functionCall;
	var aCallable$h = aCallable$l;
	var anObject$v = anObject$D;
	var tryToString$4 = tryToString$7;
	var getIteratorMethod$4 = getIteratorMethod$5;
	var $TypeError$i = TypeError;
	var getIterator$4 = function getIterator(argument, usingIterator) {
	  var iteratorMethod = arguments.length < 2 ? getIteratorMethod$4(argument) : usingIterator;
	  if (aCallable$h(iteratorMethod)) return anObject$v(call$v(iteratorMethod, argument));
	  throw $TypeError$i(tryToString$4(argument) + ' is not iterable');
	};
	var getIterator$5 = /*@__PURE__*/getDefaultExportFromCjs(getIterator$4);

	var call$u = functionCall;
	var anObject$u = anObject$D;
	var getMethod$6 = getMethod$9;
	var iteratorClose$2 = function iteratorClose(iterator, kind, value) {
	  var innerResult, innerError;
	  anObject$u(iterator);
	  try {
	    innerResult = getMethod$6(iterator, 'return');
	    if (!innerResult) {
	      if (kind === 'throw') throw value;
	      return value;
	    }
	    innerResult = call$u(innerResult, iterator);
	  } catch (error) {
	    innerError = true;
	    innerResult = error;
	  }
	  if (kind === 'throw') throw value;
	  if (innerError) throw innerResult;
	  anObject$u(innerResult);
	  return value;
	};
	var iteratorClose$3 = /*@__PURE__*/getDefaultExportFromCjs(iteratorClose$2);

	var bind$c = functionBindContext;
	var call$t = functionCall;
	var anObject$t = anObject$D;
	var tryToString$3 = tryToString$7;
	var isArrayIteratorMethod$2 = isArrayIteratorMethod$3;
	var lengthOfArrayLike$p = lengthOfArrayLike$t;
	var isPrototypeOf$7 = objectIsPrototypeOf;
	var getIterator$3 = getIterator$4;
	var getIteratorMethod$3 = getIteratorMethod$5;
	var iteratorClose$1 = iteratorClose$2;
	var $TypeError$h = TypeError;
	var Result = function Result(stopped, result) {
	  this.stopped = stopped;
	  this.result = result;
	};
	var ResultPrototype = Result.prototype;
	var iterate$a = function iterate(iterable, unboundFunction, options) {
	  var that = options && options.that;
	  var AS_ENTRIES = !!(options && options.AS_ENTRIES);
	  var IS_RECORD = !!(options && options.IS_RECORD);
	  var IS_ITERATOR = !!(options && options.IS_ITERATOR);
	  var INTERRUPTED = !!(options && options.INTERRUPTED);
	  var fn = bind$c(unboundFunction, that);
	  var iterator, iterFn, index, length, result, next, step;
	  var stop = function stop(condition) {
	    if (iterator) iteratorClose$1(iterator, 'normal', condition);
	    return new Result(true, condition);
	  };
	  var callFn = function callFn(value) {
	    if (AS_ENTRIES) {
	      anObject$t(value);
	      return INTERRUPTED ? fn(value[0], value[1], stop) : fn(value[0], value[1]);
	    }
	    return INTERRUPTED ? fn(value, stop) : fn(value);
	  };
	  if (IS_RECORD) {
	    iterator = iterable.iterator;
	  } else if (IS_ITERATOR) {
	    iterator = iterable;
	  } else {
	    iterFn = getIteratorMethod$3(iterable);
	    if (!iterFn) throw $TypeError$h(tryToString$3(iterable) + ' is not iterable');
	    // optimisation for array iterators
	    if (isArrayIteratorMethod$2(iterFn)) {
	      for (index = 0, length = lengthOfArrayLike$p(iterable); length > index; index++) {
	        result = callFn(iterable[index]);
	        if (result && isPrototypeOf$7(ResultPrototype, result)) return result;
	      }
	      return new Result(false);
	    }
	    iterator = getIterator$3(iterable, iterFn);
	  }
	  next = IS_RECORD ? iterable.next : iterator.next;
	  while (!(step = call$t(next, iterator)).done) {
	    try {
	      result = callFn(step.value);
	    } catch (error) {
	      iteratorClose$1(iterator, 'throw', error);
	    }
	    if (_typeof(result) == 'object' && result && isPrototypeOf$7(ResultPrototype, result)) return result;
	  }
	  return new Result(false);
	};
	var iterate$b = /*@__PURE__*/getDefaultExportFromCjs(iterate$a);

	'use strict';
	var $$2Q = _export;
	var isPrototypeOf$6 = objectIsPrototypeOf;
	var getPrototypeOf$a = objectGetPrototypeOf$1;
	var setPrototypeOf$7 = objectSetPrototypeOf$1;
	var copyConstructorProperties$1 = copyConstructorProperties$5;
	var create$a = objectCreate;
	var createNonEnumerableProperty$9 = createNonEnumerableProperty$f;
	var createPropertyDescriptor$6 = createPropertyDescriptor$c;
	var installErrorCause = installErrorCause$2;
	var installErrorStack = errorStackInstall;
	var iterate$9 = iterate$a;
	var normalizeStringArgument$2 = normalizeStringArgument$5;
	var wellKnownSymbol$o = wellKnownSymbol$z;
	var TO_STRING_TAG$2 = wellKnownSymbol$o('toStringTag');
	var $Error = Error;
	var push$a = [].push;
	var $AggregateError$1 = function AggregateError(errors, message /* , options */) {
	  var isInstance = isPrototypeOf$6(AggregateErrorPrototype, this);
	  var that;
	  if (setPrototypeOf$7) {
	    that = setPrototypeOf$7($Error(), isInstance ? getPrototypeOf$a(this) : AggregateErrorPrototype);
	  } else {
	    that = isInstance ? this : create$a(AggregateErrorPrototype);
	    createNonEnumerableProperty$9(that, TO_STRING_TAG$2, 'Error');
	  }
	  if (message !== undefined) createNonEnumerableProperty$9(that, 'message', normalizeStringArgument$2(message));
	  installErrorStack(that, $AggregateError$1, that.stack, 1);
	  if (arguments.length > 2) installErrorCause(that, arguments[2]);
	  var errorsArray = [];
	  iterate$9(errors, push$a, {
	    that: errorsArray
	  });
	  createNonEnumerableProperty$9(that, 'errors', errorsArray);
	  return that;
	};
	if (setPrototypeOf$7) setPrototypeOf$7($AggregateError$1, $Error);else copyConstructorProperties$1($AggregateError$1, $Error, {
	  name: true
	});
	var AggregateErrorPrototype = $AggregateError$1.prototype = create$a($Error.prototype, {
	  constructor: createPropertyDescriptor$6(1, $AggregateError$1),
	  message: createPropertyDescriptor$6(1, ''),
	  name: createPropertyDescriptor$6(1, 'AggregateError')
	});

	// `AggregateError` constructor
	// https://tc39.es/ecma262/#sec-aggregate-error-constructor
	$$2Q({
	  global: true,
	  constructor: true,
	  arity: 2
	}, {
	  AggregateError: $AggregateError$1
	});

	var es_aggregateError_cause = {};

	var $$2P = _export;
	var getBuiltIn$c = getBuiltIn$m;
	var apply$8 = functionApply$1;
	var fails$16 = fails$1m;
	var wrapErrorConstructorWithCause = wrapErrorConstructorWithCause$2;
	var AGGREGATE_ERROR = 'AggregateError';
	var $AggregateError = getBuiltIn$c(AGGREGATE_ERROR);
	var FORCED$B = !fails$16(function () {
	  return $AggregateError([1]).errors[0] !== 1;
	}) && fails$16(function () {
	  return $AggregateError([1], AGGREGATE_ERROR, {
	    cause: 7
	  }).cause !== 7;
	});

	// https://github.com/tc39/proposal-error-cause
	$$2P({
	  global: true,
	  constructor: true,
	  arity: 2,
	  forced: FORCED$B
	}, {
	  AggregateError: wrapErrorConstructorWithCause(AGGREGATE_ERROR, function (init) {
	    // eslint-disable-next-line no-unused-vars -- required for functions `.length`
	    return function AggregateError(errors, message) {
	      return apply$8(init, this, arguments);
	    };
	  }, FORCED$B, true)
	});

	var es_array_at = {};

	var wellKnownSymbol$n = wellKnownSymbol$z;
	var create$9 = objectCreate;
	var defineProperty$8 = objectDefineProperty.f;
	var UNSCOPABLES = wellKnownSymbol$n('unscopables');
	var ArrayPrototype = Array.prototype;

	// Array.prototype[@@unscopables]
	// https://tc39.es/ecma262/#sec-array.prototype-@@unscopables
	if (ArrayPrototype[UNSCOPABLES] == undefined) {
	  defineProperty$8(ArrayPrototype, UNSCOPABLES, {
	    configurable: true,
	    value: create$9(null)
	  });
	}

	// add a key to Array.prototype[@@unscopables]
	var addToUnscopables$e = function addToUnscopables(key) {
	  ArrayPrototype[UNSCOPABLES][key] = true;
	};
	var addToUnscopables$f = /*@__PURE__*/getDefaultExportFromCjs(addToUnscopables$e);

	'use strict';
	var $$2O = _export;
	var toObject$o = toObject$t;
	var lengthOfArrayLike$o = lengthOfArrayLike$t;
	var toIntegerOrInfinity$i = toIntegerOrInfinity$l;
	var addToUnscopables$d = addToUnscopables$e;

	// `Array.prototype.at` method
	// https://github.com/tc39/proposal-relative-indexing-method
	$$2O({
	  target: 'Array',
	  proto: true
	}, {
	  at: function at(index) {
	    var O = toObject$o(this);
	    var len = lengthOfArrayLike$o(O);
	    var relativeIndex = toIntegerOrInfinity$i(index);
	    var k = relativeIndex >= 0 ? relativeIndex : len + relativeIndex;
	    return k < 0 || k >= len ? undefined : O[k];
	  }
	});
	addToUnscopables$d('at');

	var es_array_concat = {};

	var $TypeError$g = TypeError;
	var MAX_SAFE_INTEGER = 0x1FFFFFFFFFFFFF; // 2 ** 53 - 1 == 9007199254740991

	var doesNotExceedSafeInteger$6 = function doesNotExceedSafeInteger(it) {
	  if (it > MAX_SAFE_INTEGER) throw $TypeError$g('Maximum allowed index exceeded');
	  return it;
	};
	var doesNotExceedSafeInteger$7 = /*@__PURE__*/getDefaultExportFromCjs(doesNotExceedSafeInteger$6);

	var fails$15 = fails$1m;
	var wellKnownSymbol$m = wellKnownSymbol$z;
	var V8_VERSION$2 = engineV8Version;
	var SPECIES$5 = wellKnownSymbol$m('species');
	var arrayMethodHasSpeciesSupport$5 = function arrayMethodHasSpeciesSupport(METHOD_NAME) {
	  // We can't use this feature detection in V8 since it causes
	  // deoptimization and serious performance degradation
	  // https://github.com/zloirock/core-js/issues/677
	  return V8_VERSION$2 >= 51 || !fails$15(function () {
	    var array = [];
	    var constructor = array.constructor = {};
	    constructor[SPECIES$5] = function () {
	      return {
	        foo: 1
	      };
	    };
	    return array[METHOD_NAME](Boolean).foo !== 1;
	  });
	};
	var arrayMethodHasSpeciesSupport$6 = /*@__PURE__*/getDefaultExportFromCjs(arrayMethodHasSpeciesSupport$5);

	'use strict';
	var $$2N = _export;
	var fails$14 = fails$1m;
	var isArray$6 = isArray$9;
	var isObject$q = isObject$z;
	var toObject$n = toObject$t;
	var lengthOfArrayLike$n = lengthOfArrayLike$t;
	var doesNotExceedSafeInteger$5 = doesNotExceedSafeInteger$6;
	var createProperty$7 = createProperty$9;
	var arraySpeciesCreate$3 = arraySpeciesCreate$5;
	var arrayMethodHasSpeciesSupport$4 = arrayMethodHasSpeciesSupport$5;
	var wellKnownSymbol$l = wellKnownSymbol$z;
	var V8_VERSION$1 = engineV8Version;
	var IS_CONCAT_SPREADABLE = wellKnownSymbol$l('isConcatSpreadable');

	// We can't use this feature detection in V8 since it causes
	// deoptimization and serious performance degradation
	// https://github.com/zloirock/core-js/issues/679
	var IS_CONCAT_SPREADABLE_SUPPORT = V8_VERSION$1 >= 51 || !fails$14(function () {
	  var array = [];
	  array[IS_CONCAT_SPREADABLE] = false;
	  return array.concat()[0] !== array;
	});
	var isConcatSpreadable = function isConcatSpreadable(O) {
	  if (!isObject$q(O)) return false;
	  var spreadable = O[IS_CONCAT_SPREADABLE];
	  return spreadable !== undefined ? !!spreadable : isArray$6(O);
	};
	var FORCED$A = !IS_CONCAT_SPREADABLE_SUPPORT || !arrayMethodHasSpeciesSupport$4('concat');

	// `Array.prototype.concat` method
	// https://tc39.es/ecma262/#sec-array.prototype.concat
	// with adding support of @@isConcatSpreadable and @@species
	$$2N({
	  target: 'Array',
	  proto: true,
	  arity: 1,
	  forced: FORCED$A
	}, {
	  // eslint-disable-next-line no-unused-vars -- required for `.length`
	  concat: function concat(arg) {
	    var O = toObject$n(this);
	    var A = arraySpeciesCreate$3(O, 0);
	    var n = 0;
	    var i, k, length, len, E;
	    for (i = -1, length = arguments.length; i < length; i++) {
	      E = i === -1 ? O : arguments[i];
	      if (isConcatSpreadable(E)) {
	        len = lengthOfArrayLike$n(E);
	        doesNotExceedSafeInteger$5(n + len);
	        for (k = 0; k < len; k++, n++) if (k in E) createProperty$7(A, n, E[k]);
	      } else {
	        doesNotExceedSafeInteger$5(n + 1);
	        createProperty$7(A, n++, E);
	      }
	    }
	    A.length = n;
	    return A;
	  }
	});

	var es_array_copyWithin = {};

	'use strict';
	var tryToString$2 = tryToString$7;
	var $TypeError$f = TypeError;
	var deletePropertyOrThrow$4 = function deletePropertyOrThrow(O, P) {
	  if (!delete O[P]) throw $TypeError$f('Cannot delete property ' + tryToString$2(P) + ' of ' + tryToString$2(O));
	};
	var deletePropertyOrThrow$5 = /*@__PURE__*/getDefaultExportFromCjs(deletePropertyOrThrow$4);

	'use strict';
	var toObject$m = toObject$t;
	var toAbsoluteIndex$7 = toAbsoluteIndex$a;
	var lengthOfArrayLike$m = lengthOfArrayLike$t;
	var deletePropertyOrThrow$3 = deletePropertyOrThrow$4;
	var min$c = Math.min;

	// `Array.prototype.copyWithin` method implementation
	// https://tc39.es/ecma262/#sec-array.prototype.copywithin
	// eslint-disable-next-line es/no-array-prototype-copywithin -- safe
	var arrayCopyWithin = [].copyWithin || function copyWithin(target /* = 0 */, start /* = 0, end = @length */) {
	  var O = toObject$m(this);
	  var len = lengthOfArrayLike$m(O);
	  var to = toAbsoluteIndex$7(target, len);
	  var from = toAbsoluteIndex$7(start, len);
	  var end = arguments.length > 2 ? arguments[2] : undefined;
	  var count = min$c((end === undefined ? len : toAbsoluteIndex$7(end, len)) - from, len - to);
	  var inc = 1;
	  if (from < to && to < from + count) {
	    inc = -1;
	    from += count - 1;
	    to += count - 1;
	  }
	  while (count-- > 0) {
	    if (from in O) O[to] = O[from];else deletePropertyOrThrow$3(O, to);
	    to += inc;
	    from += inc;
	  }
	  return O;
	};
	var arrayCopyWithin$1 = /*@__PURE__*/getDefaultExportFromCjs(arrayCopyWithin);

	var $$2M = _export;
	var copyWithin = arrayCopyWithin;
	var addToUnscopables$c = addToUnscopables$e;

	// `Array.prototype.copyWithin` method
	// https://tc39.es/ecma262/#sec-array.prototype.copywithin
	$$2M({
	  target: 'Array',
	  proto: true
	}, {
	  copyWithin: copyWithin
	});

	// https://tc39.es/ecma262/#sec-array.prototype-@@unscopables
	addToUnscopables$c('copyWithin');

	var es_array_every = {};

	'use strict';
	var fails$13 = fails$1m;
	var arrayMethodIsStrict$9 = function arrayMethodIsStrict(METHOD_NAME, argument) {
	  var method = [][METHOD_NAME];
	  return !!method && fails$13(function () {
	    // eslint-disable-next-line no-useless-call -- required for testing
	    method.call(null, argument || function () {
	      return 1;
	    }, 1);
	  });
	};
	var arrayMethodIsStrict$a = /*@__PURE__*/getDefaultExportFromCjs(arrayMethodIsStrict$9);

	'use strict';
	var $$2L = _export;
	var $every$1 = arrayIteration.every;
	var arrayMethodIsStrict$8 = arrayMethodIsStrict$9;
	var STRICT_METHOD$4 = arrayMethodIsStrict$8('every');

	// `Array.prototype.every` method
	// https://tc39.es/ecma262/#sec-array.prototype.every
	$$2L({
	  target: 'Array',
	  proto: true,
	  forced: !STRICT_METHOD$4
	}, {
	  every: function every(callbackfn /* , thisArg */) {
	    return $every$1(this, callbackfn, arguments.length > 1 ? arguments[1] : undefined);
	  }
	});

	var es_array_fill = {};

	'use strict';
	var toObject$l = toObject$t;
	var toAbsoluteIndex$6 = toAbsoluteIndex$a;
	var lengthOfArrayLike$l = lengthOfArrayLike$t;

	// `Array.prototype.fill` method implementation
	// https://tc39.es/ecma262/#sec-array.prototype.fill
	var arrayFill$1 = function fill(value /* , start = 0, end = @length */) {
	  var O = toObject$l(this);
	  var length = lengthOfArrayLike$l(O);
	  var argumentsLength = arguments.length;
	  var index = toAbsoluteIndex$6(argumentsLength > 1 ? arguments[1] : undefined, length);
	  var end = argumentsLength > 2 ? arguments[2] : undefined;
	  var endPos = end === undefined ? length : toAbsoluteIndex$6(end, length);
	  while (endPos > index) O[index++] = value;
	  return O;
	};
	var arrayFill$2 = /*@__PURE__*/getDefaultExportFromCjs(arrayFill$1);

	var $$2K = _export;
	var fill$4 = arrayFill$1;
	var addToUnscopables$b = addToUnscopables$e;

	// `Array.prototype.fill` method
	// https://tc39.es/ecma262/#sec-array.prototype.fill
	$$2K({
	  target: 'Array',
	  proto: true
	}, {
	  fill: fill$4
	});

	// https://tc39.es/ecma262/#sec-array.prototype-@@unscopables
	addToUnscopables$b('fill');

	var es_array_filter = {};

	'use strict';
	var $$2J = _export;
	var $filter$1 = arrayIteration.filter;
	var arrayMethodHasSpeciesSupport$3 = arrayMethodHasSpeciesSupport$5;
	var HAS_SPECIES_SUPPORT$3 = arrayMethodHasSpeciesSupport$3('filter');

	// `Array.prototype.filter` method
	// https://tc39.es/ecma262/#sec-array.prototype.filter
	// with adding support of @@species
	$$2J({
	  target: 'Array',
	  proto: true,
	  forced: !HAS_SPECIES_SUPPORT$3
	}, {
	  filter: function filter(callbackfn /* , thisArg */) {
	    return $filter$1(this, callbackfn, arguments.length > 1 ? arguments[1] : undefined);
	  }
	});

	var es_array_find = {};

	'use strict';
	var $$2I = _export;
	var $find$1 = arrayIteration.find;
	var addToUnscopables$a = addToUnscopables$e;
	var FIND = 'find';
	var SKIPS_HOLES$1 = true;

	// Shouldn't skip holes
	if (FIND in []) Array(1)[FIND](function () {
	  SKIPS_HOLES$1 = false;
	});

	// `Array.prototype.find` method
	// https://tc39.es/ecma262/#sec-array.prototype.find
	$$2I({
	  target: 'Array',
	  proto: true,
	  forced: SKIPS_HOLES$1
	}, {
	  find: function find(callbackfn /* , that = undefined */) {
	    return $find$1(this, callbackfn, arguments.length > 1 ? arguments[1] : undefined);
	  }
	});

	// https://tc39.es/ecma262/#sec-array.prototype-@@unscopables
	addToUnscopables$a(FIND);

	var es_array_findIndex = {};

	'use strict';
	var $$2H = _export;
	var $findIndex$1 = arrayIteration.findIndex;
	var addToUnscopables$9 = addToUnscopables$e;
	var FIND_INDEX = 'findIndex';
	var SKIPS_HOLES = true;

	// Shouldn't skip holes
	if (FIND_INDEX in []) Array(1)[FIND_INDEX](function () {
	  SKIPS_HOLES = false;
	});

	// `Array.prototype.findIndex` method
	// https://tc39.es/ecma262/#sec-array.prototype.findindex
	$$2H({
	  target: 'Array',
	  proto: true,
	  forced: SKIPS_HOLES
	}, {
	  findIndex: function findIndex(callbackfn /* , that = undefined */) {
	    return $findIndex$1(this, callbackfn, arguments.length > 1 ? arguments[1] : undefined);
	  }
	});

	// https://tc39.es/ecma262/#sec-array.prototype-@@unscopables
	addToUnscopables$9(FIND_INDEX);

	var es_array_findLast = {};

	var bind$b = functionBindContext;
	var IndexedObject$3 = indexedObject;
	var toObject$k = toObject$t;
	var lengthOfArrayLike$k = lengthOfArrayLike$t;

	// `Array.prototype.{ findLast, findLastIndex }` methods implementation
	var createMethod$5 = function createMethod(TYPE) {
	  var IS_FIND_LAST_INDEX = TYPE == 1;
	  return function ($this, callbackfn, that) {
	    var O = toObject$k($this);
	    var self = IndexedObject$3(O);
	    var boundFunction = bind$b(callbackfn, that);
	    var index = lengthOfArrayLike$k(self);
	    var value, result;
	    while (index-- > 0) {
	      value = self[index];
	      result = boundFunction(value, index, O);
	      if (result) switch (TYPE) {
	        case 0:
	          return value;
	        // findLast
	        case 1:
	          return index;
	        // findLastIndex
	      }
	    }

	    return IS_FIND_LAST_INDEX ? -1 : undefined;
	  };
	};
	var arrayIterationFromLast = {
	  // `Array.prototype.findLast` method
	  // https://github.com/tc39/proposal-array-find-from-last
	  findLast: createMethod$5(0),
	  // `Array.prototype.findLastIndex` method
	  // https://github.com/tc39/proposal-array-find-from-last
	  findLastIndex: createMethod$5(1)
	};
	var arrayIterationFromLast$1 = /*@__PURE__*/getDefaultExportFromCjs(arrayIterationFromLast);

	'use strict';
	var $$2G = _export;
	var $findLast$1 = arrayIterationFromLast.findLast;
	var addToUnscopables$8 = addToUnscopables$e;

	// `Array.prototype.findLast` method
	// https://github.com/tc39/proposal-array-find-from-last
	$$2G({
	  target: 'Array',
	  proto: true
	}, {
	  findLast: function findLast(callbackfn /* , that = undefined */) {
	    return $findLast$1(this, callbackfn, arguments.length > 1 ? arguments[1] : undefined);
	  }
	});
	addToUnscopables$8('findLast');

	var es_array_findLastIndex = {};

	'use strict';
	var $$2F = _export;
	var $findLastIndex$1 = arrayIterationFromLast.findLastIndex;
	var addToUnscopables$7 = addToUnscopables$e;

	// `Array.prototype.findLastIndex` method
	// https://github.com/tc39/proposal-array-find-from-last
	$$2F({
	  target: 'Array',
	  proto: true
	}, {
	  findLastIndex: function findLastIndex(callbackfn /* , that = undefined */) {
	    return $findLastIndex$1(this, callbackfn, arguments.length > 1 ? arguments[1] : undefined);
	  }
	});
	addToUnscopables$7('findLastIndex');

	var es_array_flat = {};

	'use strict';
	var isArray$5 = isArray$9;
	var lengthOfArrayLike$j = lengthOfArrayLike$t;
	var doesNotExceedSafeInteger$4 = doesNotExceedSafeInteger$6;
	var bind$a = functionBindContext;

	// `FlattenIntoArray` abstract operation
	// https://tc39.github.io/proposal-flatMap/#sec-FlattenIntoArray
	var flattenIntoArray$2 = function flattenIntoArray(target, original, source, sourceLen, start, depth, mapper, thisArg) {
	  var targetIndex = start;
	  var sourceIndex = 0;
	  var mapFn = mapper ? bind$a(mapper, thisArg) : false;
	  var element, elementLen;
	  while (sourceIndex < sourceLen) {
	    if (sourceIndex in source) {
	      element = mapFn ? mapFn(source[sourceIndex], sourceIndex, original) : source[sourceIndex];
	      if (depth > 0 && isArray$5(element)) {
	        elementLen = lengthOfArrayLike$j(element);
	        targetIndex = flattenIntoArray(target, original, element, elementLen, targetIndex, depth - 1) - 1;
	      } else {
	        doesNotExceedSafeInteger$4(targetIndex + 1);
	        target[targetIndex] = element;
	      }
	      targetIndex++;
	    }
	    sourceIndex++;
	  }
	  return targetIndex;
	};
	var flattenIntoArray_1 = flattenIntoArray$2;
	var flattenIntoArray$3 = /*@__PURE__*/getDefaultExportFromCjs(flattenIntoArray_1);

	'use strict';
	var $$2E = _export;
	var flattenIntoArray$1 = flattenIntoArray_1;
	var toObject$j = toObject$t;
	var lengthOfArrayLike$i = lengthOfArrayLike$t;
	var toIntegerOrInfinity$h = toIntegerOrInfinity$l;
	var arraySpeciesCreate$2 = arraySpeciesCreate$5;

	// `Array.prototype.flat` method
	// https://tc39.es/ecma262/#sec-array.prototype.flat
	$$2E({
	  target: 'Array',
	  proto: true
	}, {
	  flat: function flat( /* depthArg = 1 */
	  ) {
	    var depthArg = arguments.length ? arguments[0] : undefined;
	    var O = toObject$j(this);
	    var sourceLen = lengthOfArrayLike$i(O);
	    var A = arraySpeciesCreate$2(O, 0);
	    A.length = flattenIntoArray$1(A, O, O, sourceLen, 0, depthArg === undefined ? 1 : toIntegerOrInfinity$h(depthArg));
	    return A;
	  }
	});

	var es_array_flatMap = {};

	'use strict';
	var $$2D = _export;
	var flattenIntoArray = flattenIntoArray_1;
	var aCallable$g = aCallable$l;
	var toObject$i = toObject$t;
	var lengthOfArrayLike$h = lengthOfArrayLike$t;
	var arraySpeciesCreate$1 = arraySpeciesCreate$5;

	// `Array.prototype.flatMap` method
	// https://tc39.es/ecma262/#sec-array.prototype.flatmap
	$$2D({
	  target: 'Array',
	  proto: true
	}, {
	  flatMap: function flatMap(callbackfn /* , thisArg */) {
	    var O = toObject$i(this);
	    var sourceLen = lengthOfArrayLike$h(O);
	    var A;
	    aCallable$g(callbackfn);
	    A = arraySpeciesCreate$1(O, 0);
	    A.length = flattenIntoArray(A, O, O, sourceLen, 0, 1, callbackfn, arguments.length > 1 ? arguments[1] : undefined);
	    return A;
	  }
	});

	var es_array_forEach = {};

	'use strict';
	var $forEach$1 = arrayIteration.forEach;
	var arrayMethodIsStrict$7 = arrayMethodIsStrict$9;
	var STRICT_METHOD$3 = arrayMethodIsStrict$7('forEach');

	// `Array.prototype.forEach` method implementation
	// https://tc39.es/ecma262/#sec-array.prototype.foreach
	var arrayForEach = !STRICT_METHOD$3 ? function forEach(callbackfn /* , thisArg */) {
	  return $forEach$1(this, callbackfn, arguments.length > 1 ? arguments[1] : undefined);
	  // eslint-disable-next-line es/no-array-prototype-foreach -- safe
	} : [].forEach;
	var arrayForEach$1 = /*@__PURE__*/getDefaultExportFromCjs(arrayForEach);

	'use strict';
	var $$2C = _export;
	var forEach$3 = arrayForEach;

	// `Array.prototype.forEach` method
	// https://tc39.es/ecma262/#sec-array.prototype.foreach
	// eslint-disable-next-line es/no-array-prototype-foreach -- safe
	$$2C({
	  target: 'Array',
	  proto: true,
	  forced: [].forEach != forEach$3
	}, {
	  forEach: forEach$3
	});

	var es_array_from = {};

	var anObject$s = anObject$D;
	var iteratorClose = iteratorClose$2;

	// call something on iterator step with safe closing on error
	var callWithSafeIterationClosing$1 = function callWithSafeIterationClosing(iterator, fn, value, ENTRIES) {
	  try {
	    return ENTRIES ? fn(anObject$s(value)[0], value[1]) : fn(value);
	  } catch (error) {
	    iteratorClose(iterator, 'throw', error);
	  }
	};
	var callWithSafeIterationClosing$2 = /*@__PURE__*/getDefaultExportFromCjs(callWithSafeIterationClosing$1);

	'use strict';
	var bind$9 = functionBindContext;
	var call$s = functionCall;
	var toObject$h = toObject$t;
	var callWithSafeIterationClosing = callWithSafeIterationClosing$1;
	var isArrayIteratorMethod$1 = isArrayIteratorMethod$3;
	var isConstructor$4 = isConstructor$6;
	var lengthOfArrayLike$g = lengthOfArrayLike$t;
	var createProperty$6 = createProperty$9;
	var getIterator$2 = getIterator$4;
	var getIteratorMethod$2 = getIteratorMethod$5;
	var $Array$7 = Array;

	// `Array.from` method implementation
	// https://tc39.es/ecma262/#sec-array.from
	var arrayFrom$1 = function from(arrayLike /* , mapfn = undefined, thisArg = undefined */) {
	  var O = toObject$h(arrayLike);
	  var IS_CONSTRUCTOR = isConstructor$4(this);
	  var argumentsLength = arguments.length;
	  var mapfn = argumentsLength > 1 ? arguments[1] : undefined;
	  var mapping = mapfn !== undefined;
	  if (mapping) mapfn = bind$9(mapfn, argumentsLength > 2 ? arguments[2] : undefined);
	  var iteratorMethod = getIteratorMethod$2(O);
	  var index = 0;
	  var length, result, step, iterator, next, value;
	  // if the target is not iterable or it's an array with the default iterator - use a simple case
	  if (iteratorMethod && !(this === $Array$7 && isArrayIteratorMethod$1(iteratorMethod))) {
	    iterator = getIterator$2(O, iteratorMethod);
	    next = iterator.next;
	    result = IS_CONSTRUCTOR ? new this() : [];
	    for (; !(step = call$s(next, iterator)).done; index++) {
	      value = mapping ? callWithSafeIterationClosing(iterator, mapfn, [step.value, index], true) : step.value;
	      createProperty$6(result, index, value);
	    }
	  } else {
	    length = lengthOfArrayLike$g(O);
	    result = IS_CONSTRUCTOR ? new this(length) : $Array$7(length);
	    for (; length > index; index++) {
	      value = mapping ? mapfn(O[index], index) : O[index];
	      createProperty$6(result, index, value);
	    }
	  }
	  result.length = index;
	  return result;
	};
	var arrayFrom$2 = /*@__PURE__*/getDefaultExportFromCjs(arrayFrom$1);

	var wellKnownSymbol$k = wellKnownSymbol$z;
	var ITERATOR$8 = wellKnownSymbol$k('iterator');
	var SAFE_CLOSING = false;
	try {
	  var called = 0;
	  var iteratorWithReturn = {
	    next: function next() {
	      return {
	        done: !!called++
	      };
	    },
	    'return': function _return() {
	      SAFE_CLOSING = true;
	    }
	  };
	  iteratorWithReturn[ITERATOR$8] = function () {
	    return this;
	  };
	  // eslint-disable-next-line es/no-array-from, no-throw-literal -- required for testing
	  Array.from(iteratorWithReturn, function () {
	    throw 2;
	  });
	} catch (error) {/* empty */}
	var checkCorrectnessOfIteration$4 = function checkCorrectnessOfIteration(exec, SKIP_CLOSING) {
	  if (!SKIP_CLOSING && !SAFE_CLOSING) return false;
	  var ITERATION_SUPPORT = false;
	  try {
	    var object = {};
	    object[ITERATOR$8] = function () {
	      return {
	        next: function next() {
	          return {
	            done: ITERATION_SUPPORT = true
	          };
	        }
	      };
	    };
	    exec(object);
	  } catch (error) {/* empty */}
	  return ITERATION_SUPPORT;
	};
	var checkCorrectnessOfIteration$5 = /*@__PURE__*/getDefaultExportFromCjs(checkCorrectnessOfIteration$4);

	var $$2B = _export;
	var from = arrayFrom$1;
	var checkCorrectnessOfIteration$3 = checkCorrectnessOfIteration$4;
	var INCORRECT_ITERATION = !checkCorrectnessOfIteration$3(function (iterable) {
	  // eslint-disable-next-line es/no-array-from -- required for testing
	  Array.from(iterable);
	});

	// `Array.from` method
	// https://tc39.es/ecma262/#sec-array.from
	$$2B({
	  target: 'Array',
	  stat: true,
	  forced: INCORRECT_ITERATION
	}, {
	  from: from
	});

	var es_array_includes = {};

	'use strict';
	var $$2A = _export;
	var $includes$1 = arrayIncludes.includes;
	var fails$12 = fails$1m;
	var addToUnscopables$6 = addToUnscopables$e;

	// FF99+ bug
	var BROKEN_ON_SPARSE = fails$12(function () {
	  // eslint-disable-next-line es/no-array-prototype-includes -- detection
	  return !Array(1).includes();
	});

	// `Array.prototype.includes` method
	// https://tc39.es/ecma262/#sec-array.prototype.includes
	$$2A({
	  target: 'Array',
	  proto: true,
	  forced: BROKEN_ON_SPARSE
	}, {
	  includes: function includes(el /* , fromIndex = 0 */) {
	    return $includes$1(this, el, arguments.length > 1 ? arguments[1] : undefined);
	  }
	});

	// https://tc39.es/ecma262/#sec-array.prototype-@@unscopables
	addToUnscopables$6('includes');

	var es_array_indexOf = {};

	'use strict';
	/* eslint-disable es/no-array-prototype-indexof -- required for testing */
	var $$2z = _export;
	var uncurryThis$$ = functionUncurryThisClause;
	var $indexOf$1 = arrayIncludes.indexOf;
	var arrayMethodIsStrict$6 = arrayMethodIsStrict$9;
	var nativeIndexOf = uncurryThis$$([].indexOf);
	var NEGATIVE_ZERO$1 = !!nativeIndexOf && 1 / nativeIndexOf([1], 1, -0) < 0;
	var FORCED$z = NEGATIVE_ZERO$1 || !arrayMethodIsStrict$6('indexOf');

	// `Array.prototype.indexOf` method
	// https://tc39.es/ecma262/#sec-array.prototype.indexof
	$$2z({
	  target: 'Array',
	  proto: true,
	  forced: FORCED$z
	}, {
	  indexOf: function indexOf(searchElement /* , fromIndex = 0 */) {
	    var fromIndex = arguments.length > 1 ? arguments[1] : undefined;
	    return NEGATIVE_ZERO$1
	    // convert -0 to +0
	    ? nativeIndexOf(this, searchElement, fromIndex) || 0 : $indexOf$1(this, searchElement, fromIndex);
	  }
	});

	var es_array_isArray = {};

	var $$2y = _export;
	var isArray$4 = isArray$9;

	// `Array.isArray` method
	// https://tc39.es/ecma262/#sec-array.isarray
	$$2y({
	  target: 'Array',
	  stat: true
	}, {
	  isArray: isArray$4
	});

	'use strict';
	var fails$11 = fails$1m;
	var isCallable$g = isCallable$z;
	var isObject$p = isObject$z;
	var create$8 = objectCreate;
	var getPrototypeOf$9 = objectGetPrototypeOf$1;
	var defineBuiltIn$h = defineBuiltIn$m;
	var wellKnownSymbol$j = wellKnownSymbol$z;
	var IS_PURE$h = isPure;
	var ITERATOR$7 = wellKnownSymbol$j('iterator');
	var BUGGY_SAFARI_ITERATORS$1 = false;

	// `%IteratorPrototype%` object
	// https://tc39.es/ecma262/#sec-%iteratorprototype%-object
	var IteratorPrototype$2, PrototypeOfArrayIteratorPrototype, arrayIterator;

	/* eslint-disable es/no-array-prototype-keys -- safe */
	if ([].keys) {
	  arrayIterator = [].keys();
	  // Safari 8 has buggy iterators w/o `next`
	  if (!('next' in arrayIterator)) BUGGY_SAFARI_ITERATORS$1 = true;else {
	    PrototypeOfArrayIteratorPrototype = getPrototypeOf$9(getPrototypeOf$9(arrayIterator));
	    if (PrototypeOfArrayIteratorPrototype !== Object.prototype) IteratorPrototype$2 = PrototypeOfArrayIteratorPrototype;
	  }
	}
	var NEW_ITERATOR_PROTOTYPE = !isObject$p(IteratorPrototype$2) || fails$11(function () {
	  var test = {};
	  // FF44- legacy iterators case
	  return IteratorPrototype$2[ITERATOR$7].call(test) !== test;
	});
	if (NEW_ITERATOR_PROTOTYPE) IteratorPrototype$2 = {};else if (IS_PURE$h) IteratorPrototype$2 = create$8(IteratorPrototype$2);

	// `%IteratorPrototype%[@@iterator]()` method
	// https://tc39.es/ecma262/#sec-%iteratorprototype%-@@iterator
	if (!isCallable$g(IteratorPrototype$2[ITERATOR$7])) {
	  defineBuiltIn$h(IteratorPrototype$2, ITERATOR$7, function () {
	    return this;
	  });
	}
	var iteratorsCore = {
	  IteratorPrototype: IteratorPrototype$2,
	  BUGGY_SAFARI_ITERATORS: BUGGY_SAFARI_ITERATORS$1
	};
	var iteratorsCore$1 = /*@__PURE__*/getDefaultExportFromCjs(iteratorsCore);

	'use strict';
	var IteratorPrototype$1 = iteratorsCore.IteratorPrototype;
	var create$7 = objectCreate;
	var createPropertyDescriptor$5 = createPropertyDescriptor$c;
	var setToStringTag$a = setToStringTag$d;
	var Iterators$2 = iterators;
	var returnThis$1 = function returnThis() {
	  return this;
	};
	var iteratorCreateConstructor = function iteratorCreateConstructor(IteratorConstructor, NAME, next, ENUMERABLE_NEXT) {
	  var TO_STRING_TAG = NAME + ' Iterator';
	  IteratorConstructor.prototype = create$7(IteratorPrototype$1, {
	    next: createPropertyDescriptor$5(+!ENUMERABLE_NEXT, next)
	  });
	  setToStringTag$a(IteratorConstructor, TO_STRING_TAG, false, true);
	  Iterators$2[TO_STRING_TAG] = returnThis$1;
	  return IteratorConstructor;
	};
	var iteratorCreateConstructor$1 = /*@__PURE__*/getDefaultExportFromCjs(iteratorCreateConstructor);

	'use strict';
	var $$2x = _export;
	var call$r = functionCall;
	var IS_PURE$g = isPure;
	var FunctionName$1 = functionName;
	var isCallable$f = isCallable$z;
	var createIteratorConstructor$2 = iteratorCreateConstructor;
	var getPrototypeOf$8 = objectGetPrototypeOf$1;
	var setPrototypeOf$6 = objectSetPrototypeOf$1;
	var setToStringTag$9 = setToStringTag$d;
	var createNonEnumerableProperty$8 = createNonEnumerableProperty$f;
	var defineBuiltIn$g = defineBuiltIn$m;
	var wellKnownSymbol$i = wellKnownSymbol$z;
	var Iterators$1 = iterators;
	var IteratorsCore = iteratorsCore;
	var PROPER_FUNCTION_NAME$3 = FunctionName$1.PROPER;
	var CONFIGURABLE_FUNCTION_NAME$1 = FunctionName$1.CONFIGURABLE;
	var IteratorPrototype = IteratorsCore.IteratorPrototype;
	var BUGGY_SAFARI_ITERATORS = IteratorsCore.BUGGY_SAFARI_ITERATORS;
	var ITERATOR$6 = wellKnownSymbol$i('iterator');
	var KEYS = 'keys';
	var VALUES = 'values';
	var ENTRIES = 'entries';
	var returnThis = function returnThis() {
	  return this;
	};
	var iteratorDefine = function iteratorDefine(Iterable, NAME, IteratorConstructor, next, DEFAULT, IS_SET, FORCED) {
	  createIteratorConstructor$2(IteratorConstructor, NAME, next);
	  var getIterationMethod = function getIterationMethod(KIND) {
	    if (KIND === DEFAULT && defaultIterator) return defaultIterator;
	    if (!BUGGY_SAFARI_ITERATORS && KIND in IterablePrototype) return IterablePrototype[KIND];
	    switch (KIND) {
	      case KEYS:
	        return function keys() {
	          return new IteratorConstructor(this, KIND);
	        };
	      case VALUES:
	        return function values() {
	          return new IteratorConstructor(this, KIND);
	        };
	      case ENTRIES:
	        return function entries() {
	          return new IteratorConstructor(this, KIND);
	        };
	    }
	    return function () {
	      return new IteratorConstructor(this);
	    };
	  };
	  var TO_STRING_TAG = NAME + ' Iterator';
	  var INCORRECT_VALUES_NAME = false;
	  var IterablePrototype = Iterable.prototype;
	  var nativeIterator = IterablePrototype[ITERATOR$6] || IterablePrototype['@@iterator'] || DEFAULT && IterablePrototype[DEFAULT];
	  var defaultIterator = !BUGGY_SAFARI_ITERATORS && nativeIterator || getIterationMethod(DEFAULT);
	  var anyNativeIterator = NAME == 'Array' ? IterablePrototype.entries || nativeIterator : nativeIterator;
	  var CurrentIteratorPrototype, methods, KEY;

	  // fix native
	  if (anyNativeIterator) {
	    CurrentIteratorPrototype = getPrototypeOf$8(anyNativeIterator.call(new Iterable()));
	    if (CurrentIteratorPrototype !== Object.prototype && CurrentIteratorPrototype.next) {
	      if (!IS_PURE$g && getPrototypeOf$8(CurrentIteratorPrototype) !== IteratorPrototype) {
	        if (setPrototypeOf$6) {
	          setPrototypeOf$6(CurrentIteratorPrototype, IteratorPrototype);
	        } else if (!isCallable$f(CurrentIteratorPrototype[ITERATOR$6])) {
	          defineBuiltIn$g(CurrentIteratorPrototype, ITERATOR$6, returnThis);
	        }
	      }
	      // Set @@toStringTag to native iterators
	      setToStringTag$9(CurrentIteratorPrototype, TO_STRING_TAG, true, true);
	      if (IS_PURE$g) Iterators$1[TO_STRING_TAG] = returnThis;
	    }
	  }

	  // fix Array.prototype.{ values, @@iterator }.name in V8 / FF
	  if (PROPER_FUNCTION_NAME$3 && DEFAULT == VALUES && nativeIterator && nativeIterator.name !== VALUES) {
	    if (!IS_PURE$g && CONFIGURABLE_FUNCTION_NAME$1) {
	      createNonEnumerableProperty$8(IterablePrototype, 'name', VALUES);
	    } else {
	      INCORRECT_VALUES_NAME = true;
	      defaultIterator = function values() {
	        return call$r(nativeIterator, this);
	      };
	    }
	  }

	  // export additional methods
	  if (DEFAULT) {
	    methods = {
	      values: getIterationMethod(VALUES),
	      keys: IS_SET ? defaultIterator : getIterationMethod(KEYS),
	      entries: getIterationMethod(ENTRIES)
	    };
	    if (FORCED) for (KEY in methods) {
	      if (BUGGY_SAFARI_ITERATORS || INCORRECT_VALUES_NAME || !(KEY in IterablePrototype)) {
	        defineBuiltIn$g(IterablePrototype, KEY, methods[KEY]);
	      }
	    } else $$2x({
	      target: NAME,
	      proto: true,
	      forced: BUGGY_SAFARI_ITERATORS || INCORRECT_VALUES_NAME
	    }, methods);
	  }

	  // define iterator
	  if ((!IS_PURE$g || FORCED) && IterablePrototype[ITERATOR$6] !== defaultIterator) {
	    defineBuiltIn$g(IterablePrototype, ITERATOR$6, defaultIterator, {
	      name: DEFAULT
	    });
	  }
	  Iterators$1[NAME] = defaultIterator;
	  return methods;
	};
	var iteratorDefine$1 = /*@__PURE__*/getDefaultExportFromCjs(iteratorDefine);

	// `CreateIterResultObject` abstract operation
	// https://tc39.es/ecma262/#sec-createiterresultobject
	var createIterResultObject$4 = function createIterResultObject(value, done) {
	  return {
	    value: value,
	    done: done
	  };
	};
	var createIterResultObject$5 = /*@__PURE__*/getDefaultExportFromCjs(createIterResultObject$4);

	'use strict';
	var toIndexedObject$c = toIndexedObject$j;
	var addToUnscopables$5 = addToUnscopables$e;
	var Iterators = iterators;
	var InternalStateModule$b = internalState;
	var defineProperty$7 = objectDefineProperty.f;
	var defineIterator$2 = iteratorDefine;
	var createIterResultObject$3 = createIterResultObject$4;
	var IS_PURE$f = isPure;
	var DESCRIPTORS$x = descriptors;
	var ARRAY_ITERATOR = 'Array Iterator';
	var setInternalState$a = InternalStateModule$b.set;
	var getInternalState$8 = InternalStateModule$b.getterFor(ARRAY_ITERATOR);

	// `Array.prototype.entries` method
	// https://tc39.es/ecma262/#sec-array.prototype.entries
	// `Array.prototype.keys` method
	// https://tc39.es/ecma262/#sec-array.prototype.keys
	// `Array.prototype.values` method
	// https://tc39.es/ecma262/#sec-array.prototype.values
	// `Array.prototype[@@iterator]` method
	// https://tc39.es/ecma262/#sec-array.prototype-@@iterator
	// `CreateArrayIterator` internal method
	// https://tc39.es/ecma262/#sec-createarrayiterator
	var es_array_iterator = defineIterator$2(Array, 'Array', function (iterated, kind) {
	  setInternalState$a(this, {
	    type: ARRAY_ITERATOR,
	    target: toIndexedObject$c(iterated),
	    // target
	    index: 0,
	    // next index
	    kind: kind // kind
	  });
	  // `%ArrayIteratorPrototype%.next` method
	  // https://tc39.es/ecma262/#sec-%arrayiteratorprototype%.next
	}, function () {
	  var state = getInternalState$8(this);
	  var target = state.target;
	  var kind = state.kind;
	  var index = state.index++;
	  if (!target || index >= target.length) {
	    state.target = undefined;
	    return createIterResultObject$3(undefined, true);
	  }
	  if (kind == 'keys') return createIterResultObject$3(index, false);
	  if (kind == 'values') return createIterResultObject$3(target[index], false);
	  return createIterResultObject$3([index, target[index]], false);
	}, 'values');

	// argumentsList[@@iterator] is %ArrayProto_values%
	// https://tc39.es/ecma262/#sec-createunmappedargumentsobject
	// https://tc39.es/ecma262/#sec-createmappedargumentsobject
	var values = Iterators.Arguments = Iterators.Array;

	// https://tc39.es/ecma262/#sec-array.prototype-@@unscopables
	addToUnscopables$5('keys');
	addToUnscopables$5('values');
	addToUnscopables$5('entries');

	// V8 ~ Chrome 45- bug
	if (!IS_PURE$f && DESCRIPTORS$x && values.name !== 'values') try {
	  defineProperty$7(values, 'name', {
	    value: 'values'
	  });
	} catch (error) {/* empty */}
	var es_array_iterator$1 = /*@__PURE__*/getDefaultExportFromCjs(es_array_iterator);

	var es_array_join = {};

	'use strict';
	var $$2w = _export;
	var uncurryThis$_ = functionUncurryThis;
	var IndexedObject$2 = indexedObject;
	var toIndexedObject$b = toIndexedObject$j;
	var arrayMethodIsStrict$5 = arrayMethodIsStrict$9;
	var nativeJoin = uncurryThis$_([].join);
	var ES3_STRINGS = IndexedObject$2 != Object;
	var FORCED$y = ES3_STRINGS || !arrayMethodIsStrict$5('join', ',');

	// `Array.prototype.join` method
	// https://tc39.es/ecma262/#sec-array.prototype.join
	$$2w({
	  target: 'Array',
	  proto: true,
	  forced: FORCED$y
	}, {
	  join: function join(separator) {
	    return nativeJoin(toIndexedObject$b(this), separator === undefined ? ',' : separator);
	  }
	});

	var es_array_lastIndexOf = {};

	'use strict';
	/* eslint-disable es/no-array-prototype-lastindexof -- safe */
	var apply$7 = functionApply$1;
	var toIndexedObject$a = toIndexedObject$j;
	var toIntegerOrInfinity$g = toIntegerOrInfinity$l;
	var lengthOfArrayLike$f = lengthOfArrayLike$t;
	var arrayMethodIsStrict$4 = arrayMethodIsStrict$9;
	var min$b = Math.min;
	var $lastIndexOf$1 = [].lastIndexOf;
	var NEGATIVE_ZERO = !!$lastIndexOf$1 && 1 / [1].lastIndexOf(1, -0) < 0;
	var STRICT_METHOD$2 = arrayMethodIsStrict$4('lastIndexOf');
	var FORCED$x = NEGATIVE_ZERO || !STRICT_METHOD$2;

	// `Array.prototype.lastIndexOf` method implementation
	// https://tc39.es/ecma262/#sec-array.prototype.lastindexof
	var arrayLastIndexOf = FORCED$x ? function lastIndexOf(searchElement /* , fromIndex = @[*-1] */) {
	  // convert -0 to +0
	  if (NEGATIVE_ZERO) return apply$7($lastIndexOf$1, this, arguments) || 0;
	  var O = toIndexedObject$a(this);
	  var length = lengthOfArrayLike$f(O);
	  var index = length - 1;
	  if (arguments.length > 1) index = min$b(index, toIntegerOrInfinity$g(arguments[1]));
	  if (index < 0) index = length + index;
	  for (; index >= 0; index--) if (index in O && O[index] === searchElement) return index || 0;
	  return -1;
	} : $lastIndexOf$1;
	var arrayLastIndexOf$1 = /*@__PURE__*/getDefaultExportFromCjs(arrayLastIndexOf);

	var $$2v = _export;
	var lastIndexOf = arrayLastIndexOf;

	// `Array.prototype.lastIndexOf` method
	// https://tc39.es/ecma262/#sec-array.prototype.lastindexof
	// eslint-disable-next-line es/no-array-prototype-lastindexof -- required for testing
	$$2v({
	  target: 'Array',
	  proto: true,
	  forced: lastIndexOf !== [].lastIndexOf
	}, {
	  lastIndexOf: lastIndexOf
	});

	var es_array_map = {};

	'use strict';
	var $$2u = _export;
	var $map$1 = arrayIteration.map;
	var arrayMethodHasSpeciesSupport$2 = arrayMethodHasSpeciesSupport$5;
	var HAS_SPECIES_SUPPORT$2 = arrayMethodHasSpeciesSupport$2('map');

	// `Array.prototype.map` method
	// https://tc39.es/ecma262/#sec-array.prototype.map
	// with adding support of @@species
	$$2u({
	  target: 'Array',
	  proto: true,
	  forced: !HAS_SPECIES_SUPPORT$2
	}, {
	  map: function map(callbackfn /* , thisArg */) {
	    return $map$1(this, callbackfn, arguments.length > 1 ? arguments[1] : undefined);
	  }
	});

	var es_array_of = {};

	'use strict';
	var $$2t = _export;
	var fails$10 = fails$1m;
	var isConstructor$3 = isConstructor$6;
	var createProperty$5 = createProperty$9;
	var $Array$6 = Array;
	var ISNT_GENERIC = fails$10(function () {
	  function F() {/* empty */}
	  // eslint-disable-next-line es/no-array-of -- safe
	  return !($Array$6.of.call(F) instanceof F);
	});

	// `Array.of` method
	// https://tc39.es/ecma262/#sec-array.of
	// WebKit Array.of isn't generic
	$$2t({
	  target: 'Array',
	  stat: true,
	  forced: ISNT_GENERIC
	}, {
	  of: function of( /* ...args */
	  ) {
	    var index = 0;
	    var argumentsLength = arguments.length;
	    var result = new (isConstructor$3(this) ? this : $Array$6)(argumentsLength);
	    while (argumentsLength > index) createProperty$5(result, index, arguments[index++]);
	    result.length = argumentsLength;
	    return result;
	  }
	});

	var es_array_push = {};

	'use strict';
	var DESCRIPTORS$w = descriptors;
	var isArray$3 = isArray$9;
	var $TypeError$e = TypeError;
	// eslint-disable-next-line es/no-object-getownpropertydescriptor -- safe
	var getOwnPropertyDescriptor$8 = Object.getOwnPropertyDescriptor;

	// Safari < 13 does not throw an error in this case
	var SILENT_ON_NON_WRITABLE_LENGTH_SET = DESCRIPTORS$w && !function () {
	  // makes no sense without proper strict mode support
	  if (this !== undefined) return true;
	  try {
	    // eslint-disable-next-line es/no-object-defineproperty -- safe
	    Object.defineProperty([], 'length', {
	      writable: false
	    }).length = 1;
	  } catch (error) {
	    return error instanceof TypeError;
	  }
	}();
	var arraySetLength = SILENT_ON_NON_WRITABLE_LENGTH_SET ? function (O, length) {
	  if (isArray$3(O) && !getOwnPropertyDescriptor$8(O, 'length').writable) {
	    throw $TypeError$e('Cannot set read only .length');
	  }
	  return O.length = length;
	} : function (O, length) {
	  return O.length = length;
	};
	var arraySetLength$1 = /*@__PURE__*/getDefaultExportFromCjs(arraySetLength);

	'use strict';
	var $$2s = _export;
	var toObject$g = toObject$t;
	var lengthOfArrayLike$e = lengthOfArrayLike$t;
	var setArrayLength$2 = arraySetLength;
	var doesNotExceedSafeInteger$3 = doesNotExceedSafeInteger$6;
	var fails$$ = fails$1m;
	var INCORRECT_TO_LENGTH = fails$$(function () {
	  return [].push.call({
	    length: 0x100000000
	  }, 1) !== 4294967297;
	});

	// V8 and Safari <= 15.4, FF < 23 throws InternalError
	// https://bugs.chromium.org/p/v8/issues/detail?id=12681
	var properErrorOnNonWritableLength$1 = function properErrorOnNonWritableLength() {
	  try {
	    // eslint-disable-next-line es/no-object-defineproperty -- safe
	    Object.defineProperty([], 'length', {
	      writable: false
	    }).push();
	  } catch (error) {
	    return error instanceof TypeError;
	  }
	};
	var FORCED$w = INCORRECT_TO_LENGTH || !properErrorOnNonWritableLength$1();

	// `Array.prototype.push` method
	// https://tc39.es/ecma262/#sec-array.prototype.push
	$$2s({
	  target: 'Array',
	  proto: true,
	  arity: 1,
	  forced: FORCED$w
	}, {
	  // eslint-disable-next-line no-unused-vars -- required for `.length`
	  push: function push(item) {
	    var O = toObject$g(this);
	    var len = lengthOfArrayLike$e(O);
	    var argCount = arguments.length;
	    doesNotExceedSafeInteger$3(len + argCount);
	    for (var i = 0; i < argCount; i++) {
	      O[len] = arguments[i];
	      len++;
	    }
	    setArrayLength$2(O, len);
	    return len;
	  }
	});

	var es_array_reduce = {};

	var aCallable$f = aCallable$l;
	var toObject$f = toObject$t;
	var IndexedObject$1 = indexedObject;
	var lengthOfArrayLike$d = lengthOfArrayLike$t;
	var $TypeError$d = TypeError;

	// `Array.prototype.{ reduce, reduceRight }` methods implementation
	var createMethod$4 = function createMethod(IS_RIGHT) {
	  return function (that, callbackfn, argumentsLength, memo) {
	    aCallable$f(callbackfn);
	    var O = toObject$f(that);
	    var self = IndexedObject$1(O);
	    var length = lengthOfArrayLike$d(O);
	    var index = IS_RIGHT ? length - 1 : 0;
	    var i = IS_RIGHT ? -1 : 1;
	    if (argumentsLength < 2) while (true) {
	      if (index in self) {
	        memo = self[index];
	        index += i;
	        break;
	      }
	      index += i;
	      if (IS_RIGHT ? index < 0 : length <= index) {
	        throw $TypeError$d('Reduce of empty array with no initial value');
	      }
	    }
	    for (; IS_RIGHT ? index >= 0 : length > index; index += i) if (index in self) {
	      memo = callbackfn(memo, self[index], index, O);
	    }
	    return memo;
	  };
	};
	var arrayReduce = {
	  // `Array.prototype.reduce` method
	  // https://tc39.es/ecma262/#sec-array.prototype.reduce
	  left: createMethod$4(false),
	  // `Array.prototype.reduceRight` method
	  // https://tc39.es/ecma262/#sec-array.prototype.reduceright
	  right: createMethod$4(true)
	};
	var arrayReduce$1 = /*@__PURE__*/getDefaultExportFromCjs(arrayReduce);

	var classof$f = classofRaw$2;
	var engineIsNode = typeof process != 'undefined' && classof$f(process) == 'process';
	var engineIsNode$1 = /*@__PURE__*/getDefaultExportFromCjs(engineIsNode);

	'use strict';
	var $$2r = _export;
	var $reduce$1 = arrayReduce.left;
	var arrayMethodIsStrict$3 = arrayMethodIsStrict$9;
	var CHROME_VERSION$1 = engineV8Version;
	var IS_NODE$8 = engineIsNode;

	// Chrome 80-82 has a critical bug
	// https://bugs.chromium.org/p/chromium/issues/detail?id=1049982
	var CHROME_BUG$1 = !IS_NODE$8 && CHROME_VERSION$1 > 79 && CHROME_VERSION$1 < 83;
	var FORCED$v = CHROME_BUG$1 || !arrayMethodIsStrict$3('reduce');

	// `Array.prototype.reduce` method
	// https://tc39.es/ecma262/#sec-array.prototype.reduce
	$$2r({
	  target: 'Array',
	  proto: true,
	  forced: FORCED$v
	}, {
	  reduce: function reduce(callbackfn /* , initialValue */) {
	    var length = arguments.length;
	    return $reduce$1(this, callbackfn, length, length > 1 ? arguments[1] : undefined);
	  }
	});

	var es_array_reduceRight = {};

	'use strict';
	var $$2q = _export;
	var $reduceRight$1 = arrayReduce.right;
	var arrayMethodIsStrict$2 = arrayMethodIsStrict$9;
	var CHROME_VERSION = engineV8Version;
	var IS_NODE$7 = engineIsNode;

	// Chrome 80-82 has a critical bug
	// https://bugs.chromium.org/p/chromium/issues/detail?id=1049982
	var CHROME_BUG = !IS_NODE$7 && CHROME_VERSION > 79 && CHROME_VERSION < 83;
	var FORCED$u = CHROME_BUG || !arrayMethodIsStrict$2('reduceRight');

	// `Array.prototype.reduceRight` method
	// https://tc39.es/ecma262/#sec-array.prototype.reduceright
	$$2q({
	  target: 'Array',
	  proto: true,
	  forced: FORCED$u
	}, {
	  reduceRight: function reduceRight(callbackfn /* , initialValue */) {
	    return $reduceRight$1(this, callbackfn, arguments.length, arguments.length > 1 ? arguments[1] : undefined);
	  }
	});

	var es_array_reverse = {};

	'use strict';
	var $$2p = _export;
	var uncurryThis$Z = functionUncurryThis;
	var isArray$2 = isArray$9;
	var nativeReverse = uncurryThis$Z([].reverse);
	var test$1 = [1, 2];

	// `Array.prototype.reverse` method
	// https://tc39.es/ecma262/#sec-array.prototype.reverse
	// fix for Safari 12.0 bug
	// https://bugs.webkit.org/show_bug.cgi?id=188794
	$$2p({
	  target: 'Array',
	  proto: true,
	  forced: String(test$1) === String(test$1.reverse())
	}, {
	  reverse: function reverse() {
	    // eslint-disable-next-line no-self-assign -- dirty hack
	    if (isArray$2(this)) this.length = this.length;
	    return nativeReverse(this);
	  }
	});

	var es_array_slice = {};

	'use strict';
	var $$2o = _export;
	var isArray$1 = isArray$9;
	var isConstructor$2 = isConstructor$6;
	var isObject$o = isObject$z;
	var toAbsoluteIndex$5 = toAbsoluteIndex$a;
	var lengthOfArrayLike$c = lengthOfArrayLike$t;
	var toIndexedObject$9 = toIndexedObject$j;
	var createProperty$4 = createProperty$9;
	var wellKnownSymbol$h = wellKnownSymbol$z;
	var arrayMethodHasSpeciesSupport$1 = arrayMethodHasSpeciesSupport$5;
	var nativeSlice = arraySlice$a;
	var HAS_SPECIES_SUPPORT$1 = arrayMethodHasSpeciesSupport$1('slice');
	var SPECIES$4 = wellKnownSymbol$h('species');
	var $Array$5 = Array;
	var max$9 = Math.max;

	// `Array.prototype.slice` method
	// https://tc39.es/ecma262/#sec-array.prototype.slice
	// fallback for not array-like ES3 strings and DOM objects
	$$2o({
	  target: 'Array',
	  proto: true,
	  forced: !HAS_SPECIES_SUPPORT$1
	}, {
	  slice: function slice(start, end) {
	    var O = toIndexedObject$9(this);
	    var length = lengthOfArrayLike$c(O);
	    var k = toAbsoluteIndex$5(start, length);
	    var fin = toAbsoluteIndex$5(end === undefined ? length : end, length);
	    // inline `ArraySpeciesCreate` for usage native `Array#slice` where it's possible
	    var Constructor, result, n;
	    if (isArray$1(O)) {
	      Constructor = O.constructor;
	      // cross-realm fallback
	      if (isConstructor$2(Constructor) && (Constructor === $Array$5 || isArray$1(Constructor.prototype))) {
	        Constructor = undefined;
	      } else if (isObject$o(Constructor)) {
	        Constructor = Constructor[SPECIES$4];
	        if (Constructor === null) Constructor = undefined;
	      }
	      if (Constructor === $Array$5 || Constructor === undefined) {
	        return nativeSlice(O, k, fin);
	      }
	    }
	    result = new (Constructor === undefined ? $Array$5 : Constructor)(max$9(fin - k, 0));
	    for (n = 0; k < fin; k++, n++) if (k in O) createProperty$4(result, n, O[k]);
	    result.length = n;
	    return result;
	  }
	});

	var es_array_some = {};

	'use strict';
	var $$2n = _export;
	var $some$1 = arrayIteration.some;
	var arrayMethodIsStrict$1 = arrayMethodIsStrict$9;
	var STRICT_METHOD$1 = arrayMethodIsStrict$1('some');

	// `Array.prototype.some` method
	// https://tc39.es/ecma262/#sec-array.prototype.some
	$$2n({
	  target: 'Array',
	  proto: true,
	  forced: !STRICT_METHOD$1
	}, {
	  some: function some(callbackfn /* , thisArg */) {
	    return $some$1(this, callbackfn, arguments.length > 1 ? arguments[1] : undefined);
	  }
	});

	var es_array_sort = {};

	var arraySlice$8 = arraySliceSimple;
	var floor$c = Math.floor;
	var mergeSort = function mergeSort(array, comparefn) {
	  var length = array.length;
	  var middle = floor$c(length / 2);
	  return length < 8 ? insertionSort(array, comparefn) : merge(array, mergeSort(arraySlice$8(array, 0, middle), comparefn), mergeSort(arraySlice$8(array, middle), comparefn), comparefn);
	};
	var insertionSort = function insertionSort(array, comparefn) {
	  var length = array.length;
	  var i = 1;
	  var element, j;
	  while (i < length) {
	    j = i;
	    element = array[i];
	    while (j && comparefn(array[j - 1], element) > 0) {
	      array[j] = array[--j];
	    }
	    if (j !== i++) array[j] = element;
	  }
	  return array;
	};
	var merge = function merge(array, left, right, comparefn) {
	  var llength = left.length;
	  var rlength = right.length;
	  var lindex = 0;
	  var rindex = 0;
	  while (lindex < llength || rindex < rlength) {
	    array[lindex + rindex] = lindex < llength && rindex < rlength ? comparefn(left[lindex], right[rindex]) <= 0 ? left[lindex++] : right[rindex++] : lindex < llength ? left[lindex++] : right[rindex++];
	  }
	  return array;
	};
	var arraySort$1 = mergeSort;
	var arraySort$2 = /*@__PURE__*/getDefaultExportFromCjs(arraySort$1);

	var userAgent$5 = engineUserAgent;
	var firefox = userAgent$5.match(/firefox\/(\d+)/i);
	var engineFfVersion = !!firefox && +firefox[1];
	var engineFfVersion$1 = /*@__PURE__*/getDefaultExportFromCjs(engineFfVersion);

	var UA = engineUserAgent;
	var engineIsIeOrEdge = /MSIE|Trident/.test(UA);
	var engineIsIeOrEdge$1 = /*@__PURE__*/getDefaultExportFromCjs(engineIsIeOrEdge);

	var userAgent$4 = engineUserAgent;
	var webkit = userAgent$4.match(/AppleWebKit\/(\d+)\./);
	var engineWebkitVersion = !!webkit && +webkit[1];
	var engineWebkitVersion$1 = /*@__PURE__*/getDefaultExportFromCjs(engineWebkitVersion);

	'use strict';
	var $$2m = _export;
	var uncurryThis$Y = functionUncurryThis;
	var aCallable$e = aCallable$l;
	var toObject$e = toObject$t;
	var lengthOfArrayLike$b = lengthOfArrayLike$t;
	var deletePropertyOrThrow$2 = deletePropertyOrThrow$4;
	var toString$s = toString$x;
	var fails$_ = fails$1m;
	var internalSort$1 = arraySort$1;
	var arrayMethodIsStrict = arrayMethodIsStrict$9;
	var FF$1 = engineFfVersion;
	var IE_OR_EDGE$1 = engineIsIeOrEdge;
	var V8$2 = engineV8Version;
	var WEBKIT$2 = engineWebkitVersion;
	var test = [];
	var nativeSort$1 = uncurryThis$Y(test.sort);
	var push$9 = uncurryThis$Y(test.push);

	// IE8-
	var FAILS_ON_UNDEFINED = fails$_(function () {
	  test.sort(undefined);
	});
	// V8 bug
	var FAILS_ON_NULL = fails$_(function () {
	  test.sort(null);
	});
	// Old WebKit
	var STRICT_METHOD = arrayMethodIsStrict('sort');
	var STABLE_SORT$1 = !fails$_(function () {
	  // feature detection can be too slow, so check engines versions
	  if (V8$2) return V8$2 < 70;
	  if (FF$1 && FF$1 > 3) return;
	  if (IE_OR_EDGE$1) return true;
	  if (WEBKIT$2) return WEBKIT$2 < 603;
	  var result = '';
	  var code, chr, value, index;

	  // generate an array with more 512 elements (Chakra and old V8 fails only in this case)
	  for (code = 65; code < 76; code++) {
	    chr = String.fromCharCode(code);
	    switch (code) {
	      case 66:
	      case 69:
	      case 70:
	      case 72:
	        value = 3;
	        break;
	      case 68:
	      case 71:
	        value = 4;
	        break;
	      default:
	        value = 2;
	    }
	    for (index = 0; index < 47; index++) {
	      test.push({
	        k: chr + index,
	        v: value
	      });
	    }
	  }
	  test.sort(function (a, b) {
	    return b.v - a.v;
	  });
	  for (index = 0; index < test.length; index++) {
	    chr = test[index].k.charAt(0);
	    if (result.charAt(result.length - 1) !== chr) result += chr;
	  }
	  return result !== 'DGBEFHACIJK';
	});
	var FORCED$t = FAILS_ON_UNDEFINED || !FAILS_ON_NULL || !STRICT_METHOD || !STABLE_SORT$1;
	var getSortCompare$1 = function getSortCompare(comparefn) {
	  return function (x, y) {
	    if (y === undefined) return -1;
	    if (x === undefined) return 1;
	    if (comparefn !== undefined) return +comparefn(x, y) || 0;
	    return toString$s(x) > toString$s(y) ? 1 : -1;
	  };
	};

	// `Array.prototype.sort` method
	// https://tc39.es/ecma262/#sec-array.prototype.sort
	$$2m({
	  target: 'Array',
	  proto: true,
	  forced: FORCED$t
	}, {
	  sort: function sort(comparefn) {
	    if (comparefn !== undefined) aCallable$e(comparefn);
	    var array = toObject$e(this);
	    if (STABLE_SORT$1) return comparefn === undefined ? nativeSort$1(array) : nativeSort$1(array, comparefn);
	    var items = [];
	    var arrayLength = lengthOfArrayLike$b(array);
	    var itemsLength, index;
	    for (index = 0; index < arrayLength; index++) {
	      if (index in array) push$9(items, array[index]);
	    }
	    internalSort$1(items, getSortCompare$1(comparefn));
	    itemsLength = lengthOfArrayLike$b(items);
	    index = 0;
	    while (index < itemsLength) array[index] = items[index++];
	    while (index < arrayLength) deletePropertyOrThrow$2(array, index++);
	    return array;
	  }
	});

	var es_array_species = {};

	'use strict';
	var getBuiltIn$b = getBuiltIn$m;
	var defineBuiltInAccessor$e = defineBuiltInAccessor$h;
	var wellKnownSymbol$g = wellKnownSymbol$z;
	var DESCRIPTORS$v = descriptors;
	var SPECIES$3 = wellKnownSymbol$g('species');
	var setSpecies$6 = function setSpecies(CONSTRUCTOR_NAME) {
	  var Constructor = getBuiltIn$b(CONSTRUCTOR_NAME);
	  if (DESCRIPTORS$v && Constructor && !Constructor[SPECIES$3]) {
	    defineBuiltInAccessor$e(Constructor, SPECIES$3, {
	      configurable: true,
	      get: function get() {
	        return this;
	      }
	    });
	  }
	};
	var setSpecies$7 = /*@__PURE__*/getDefaultExportFromCjs(setSpecies$6);

	var setSpecies$5 = setSpecies$6;

	// `Array[@@species]` getter
	// https://tc39.es/ecma262/#sec-get-array-@@species
	setSpecies$5('Array');

	var es_array_splice = {};

	'use strict';
	var $$2l = _export;
	var toObject$d = toObject$t;
	var toAbsoluteIndex$4 = toAbsoluteIndex$a;
	var toIntegerOrInfinity$f = toIntegerOrInfinity$l;
	var lengthOfArrayLike$a = lengthOfArrayLike$t;
	var setArrayLength$1 = arraySetLength;
	var doesNotExceedSafeInteger$2 = doesNotExceedSafeInteger$6;
	var arraySpeciesCreate = arraySpeciesCreate$5;
	var createProperty$3 = createProperty$9;
	var deletePropertyOrThrow$1 = deletePropertyOrThrow$4;
	var arrayMethodHasSpeciesSupport = arrayMethodHasSpeciesSupport$5;
	var HAS_SPECIES_SUPPORT = arrayMethodHasSpeciesSupport('splice');
	var max$8 = Math.max;
	var min$a = Math.min;

	// `Array.prototype.splice` method
	// https://tc39.es/ecma262/#sec-array.prototype.splice
	// with adding support of @@species
	$$2l({
	  target: 'Array',
	  proto: true,
	  forced: !HAS_SPECIES_SUPPORT
	}, {
	  splice: function splice(start, deleteCount /* , ...items */) {
	    var O = toObject$d(this);
	    var len = lengthOfArrayLike$a(O);
	    var actualStart = toAbsoluteIndex$4(start, len);
	    var argumentsLength = arguments.length;
	    var insertCount, actualDeleteCount, A, k, from, to;
	    if (argumentsLength === 0) {
	      insertCount = actualDeleteCount = 0;
	    } else if (argumentsLength === 1) {
	      insertCount = 0;
	      actualDeleteCount = len - actualStart;
	    } else {
	      insertCount = argumentsLength - 2;
	      actualDeleteCount = min$a(max$8(toIntegerOrInfinity$f(deleteCount), 0), len - actualStart);
	    }
	    doesNotExceedSafeInteger$2(len + insertCount - actualDeleteCount);
	    A = arraySpeciesCreate(O, actualDeleteCount);
	    for (k = 0; k < actualDeleteCount; k++) {
	      from = actualStart + k;
	      if (from in O) createProperty$3(A, k, O[from]);
	    }
	    A.length = actualDeleteCount;
	    if (insertCount < actualDeleteCount) {
	      for (k = actualStart; k < len - actualDeleteCount; k++) {
	        from = k + actualDeleteCount;
	        to = k + insertCount;
	        if (from in O) O[to] = O[from];else deletePropertyOrThrow$1(O, to);
	      }
	      for (k = len; k > len - actualDeleteCount + insertCount; k--) deletePropertyOrThrow$1(O, k - 1);
	    } else if (insertCount > actualDeleteCount) {
	      for (k = len - actualDeleteCount; k > actualStart; k--) {
	        from = k + actualDeleteCount - 1;
	        to = k + insertCount - 1;
	        if (from in O) O[to] = O[from];else deletePropertyOrThrow$1(O, to);
	      }
	    }
	    for (k = 0; k < insertCount; k++) {
	      O[k + actualStart] = arguments[k + 2];
	    }
	    setArrayLength$1(O, len - actualDeleteCount + insertCount);
	    return A;
	  }
	});

	var es_array_toReversed = {};

	var lengthOfArrayLike$9 = lengthOfArrayLike$t;

	// https://tc39.es/proposal-change-array-by-copy/#sec-array.prototype.toReversed
	// https://tc39.es/proposal-change-array-by-copy/#sec-%typedarray%.prototype.toReversed
	var arrayToReversed$2 = function arrayToReversed(O, C) {
	  var len = lengthOfArrayLike$9(O);
	  var A = new C(len);
	  var k = 0;
	  for (; k < len; k++) A[k] = O[len - k - 1];
	  return A;
	};
	var arrayToReversed$3 = /*@__PURE__*/getDefaultExportFromCjs(arrayToReversed$2);

	'use strict';
	var $$2k = _export;
	var arrayToReversed$1 = arrayToReversed$2;
	var toIndexedObject$8 = toIndexedObject$j;
	var addToUnscopables$4 = addToUnscopables$e;
	var $Array$4 = Array;

	// `Array.prototype.toReversed` method
	// https://tc39.es/proposal-change-array-by-copy/#sec-array.prototype.toReversed
	$$2k({
	  target: 'Array',
	  proto: true
	}, {
	  toReversed: function toReversed() {
	    return arrayToReversed$1(toIndexedObject$8(this), $Array$4);
	  }
	});
	addToUnscopables$4('toReversed');

	var es_array_toSorted = {};

	var lengthOfArrayLike$8 = lengthOfArrayLike$t;
	var arrayFromConstructorAndList$3 = function arrayFromConstructorAndList(Constructor, list) {
	  var index = 0;
	  var length = lengthOfArrayLike$8(list);
	  var result = new Constructor(length);
	  while (length > index) result[index] = list[index++];
	  return result;
	};
	var arrayFromConstructorAndList$4 = /*@__PURE__*/getDefaultExportFromCjs(arrayFromConstructorAndList$3);

	var global$L = global$Z;
	var entryVirtual = function entryVirtual(CONSTRUCTOR) {
	  return global$L[CONSTRUCTOR].prototype;
	};
	var entryVirtual$1 = /*@__PURE__*/getDefaultExportFromCjs(entryVirtual);

	'use strict';
	var $$2j = _export;
	var uncurryThis$X = functionUncurryThis;
	var aCallable$d = aCallable$l;
	var toIndexedObject$7 = toIndexedObject$j;
	var arrayFromConstructorAndList$2 = arrayFromConstructorAndList$3;
	var getVirtual = entryVirtual;
	var addToUnscopables$3 = addToUnscopables$e;
	var $Array$3 = Array;
	var sort$1 = uncurryThis$X(getVirtual('Array').sort);

	// `Array.prototype.toSorted` method
	// https://tc39.es/proposal-change-array-by-copy/#sec-array.prototype.toSorted
	$$2j({
	  target: 'Array',
	  proto: true
	}, {
	  toSorted: function toSorted(compareFn) {
	    if (compareFn !== undefined) aCallable$d(compareFn);
	    var O = toIndexedObject$7(this);
	    var A = arrayFromConstructorAndList$2($Array$3, O);
	    return sort$1(A, compareFn);
	  }
	});
	addToUnscopables$3('toSorted');

	var es_array_toSpliced = {};

	'use strict';
	var $$2i = _export;
	var addToUnscopables$2 = addToUnscopables$e;
	var doesNotExceedSafeInteger$1 = doesNotExceedSafeInteger$6;
	var lengthOfArrayLike$7 = lengthOfArrayLike$t;
	var toAbsoluteIndex$3 = toAbsoluteIndex$a;
	var toIndexedObject$6 = toIndexedObject$j;
	var toIntegerOrInfinity$e = toIntegerOrInfinity$l;
	var $Array$2 = Array;
	var max$7 = Math.max;
	var min$9 = Math.min;

	// `Array.prototype.toSpliced` method
	// https://tc39.es/proposal-change-array-by-copy/#sec-array.prototype.toSpliced
	$$2i({
	  target: 'Array',
	  proto: true
	}, {
	  toSpliced: function toSpliced(start, deleteCount /* , ...items */) {
	    var O = toIndexedObject$6(this);
	    var len = lengthOfArrayLike$7(O);
	    var actualStart = toAbsoluteIndex$3(start, len);
	    var argumentsLength = arguments.length;
	    var k = 0;
	    var insertCount, actualDeleteCount, newLen, A;
	    if (argumentsLength === 0) {
	      insertCount = actualDeleteCount = 0;
	    } else if (argumentsLength === 1) {
	      insertCount = 0;
	      actualDeleteCount = len - actualStart;
	    } else {
	      insertCount = argumentsLength - 2;
	      actualDeleteCount = min$9(max$7(toIntegerOrInfinity$e(deleteCount), 0), len - actualStart);
	    }
	    newLen = doesNotExceedSafeInteger$1(len + insertCount - actualDeleteCount);
	    A = $Array$2(newLen);
	    for (; k < actualStart; k++) A[k] = O[k];
	    for (; k < actualStart + insertCount; k++) A[k] = arguments[k - actualStart + 2];
	    for (; k < newLen; k++) A[k] = O[k + actualDeleteCount - insertCount];
	    return A;
	  }
	});
	addToUnscopables$2('toSpliced');

	var es_array_unscopables_flat = {};

	// this method was added to unscopables after implementation
	// in popular engines, so it's moved to a separate module
	var addToUnscopables$1 = addToUnscopables$e;

	// https://tc39.es/ecma262/#sec-array.prototype-@@unscopables
	addToUnscopables$1('flat');

	var es_array_unscopables_flatMap = {};

	// this method was added to unscopables after implementation
	// in popular engines, so it's moved to a separate module
	var addToUnscopables = addToUnscopables$e;

	// https://tc39.es/ecma262/#sec-array.prototype-@@unscopables
	addToUnscopables('flatMap');

	var es_array_unshift = {};

	'use strict';
	var $$2h = _export;
	var toObject$c = toObject$t;
	var lengthOfArrayLike$6 = lengthOfArrayLike$t;
	var setArrayLength = arraySetLength;
	var deletePropertyOrThrow = deletePropertyOrThrow$4;
	var doesNotExceedSafeInteger = doesNotExceedSafeInteger$6;

	// IE8-
	var INCORRECT_RESULT = [].unshift(0) !== 1;

	// V8 ~ Chrome < 71 and Safari <= 15.4, FF < 23 throws InternalError
	var properErrorOnNonWritableLength = function properErrorOnNonWritableLength() {
	  try {
	    // eslint-disable-next-line es/no-object-defineproperty -- safe
	    Object.defineProperty([], 'length', {
	      writable: false
	    }).unshift();
	  } catch (error) {
	    return error instanceof TypeError;
	  }
	};
	var FORCED$s = INCORRECT_RESULT || !properErrorOnNonWritableLength();

	// `Array.prototype.unshift` method
	// https://tc39.es/ecma262/#sec-array.prototype.unshift
	$$2h({
	  target: 'Array',
	  proto: true,
	  arity: 1,
	  forced: FORCED$s
	}, {
	  // eslint-disable-next-line no-unused-vars -- required for `.length`
	  unshift: function unshift(item) {
	    var O = toObject$c(this);
	    var len = lengthOfArrayLike$6(O);
	    var argCount = arguments.length;
	    if (argCount) {
	      doesNotExceedSafeInteger(len + argCount);
	      var k = len;
	      while (k--) {
	        var to = k + argCount;
	        if (k in O) O[to] = O[k];else deletePropertyOrThrow(O, to);
	      }
	      for (var j = 0; j < argCount; j++) {
	        O[j] = arguments[j];
	      }
	    }
	    return setArrayLength(O, len + argCount);
	  }
	});

	var es_array_with = {};

	var lengthOfArrayLike$5 = lengthOfArrayLike$t;
	var toIntegerOrInfinity$d = toIntegerOrInfinity$l;
	var $RangeError$9 = RangeError;

	// https://tc39.es/proposal-change-array-by-copy/#sec-array.prototype.with
	// https://tc39.es/proposal-change-array-by-copy/#sec-%typedarray%.prototype.with
	var arrayWith$2 = function arrayWith(O, C, index, value) {
	  var len = lengthOfArrayLike$5(O);
	  var relativeIndex = toIntegerOrInfinity$d(index);
	  var actualIndex = relativeIndex < 0 ? len + relativeIndex : relativeIndex;
	  if (actualIndex >= len || actualIndex < 0) throw $RangeError$9('Incorrect index');
	  var A = new C(len);
	  var k = 0;
	  for (; k < len; k++) A[k] = k === actualIndex ? value : O[k];
	  return A;
	};
	var arrayWith$3 = /*@__PURE__*/getDefaultExportFromCjs(arrayWith$2);

	'use strict';
	var $$2g = _export;
	var arrayWith$1 = arrayWith$2;
	var toIndexedObject$5 = toIndexedObject$j;
	var $Array$1 = Array;

	// `Array.prototype.with` method
	// https://tc39.es/proposal-change-array-by-copy/#sec-array.prototype.with
	$$2g({
	  target: 'Array',
	  proto: true
	}, {
	  'with': function _with(index, value) {
	    return arrayWith$1(toIndexedObject$5(this), $Array$1, index, value);
	  }
	});

	var es_arrayBuffer_constructor = {};

	// eslint-disable-next-line es/no-typed-arrays -- safe
	var arrayBufferBasicDetection = typeof ArrayBuffer != 'undefined' && typeof DataView != 'undefined';
	var arrayBufferBasicDetection$1 = /*@__PURE__*/getDefaultExportFromCjs(arrayBufferBasicDetection);

	var defineBuiltIn$f = defineBuiltIn$m;
	var defineBuiltIns$5 = function defineBuiltIns(target, src, options) {
	  for (var key in src) defineBuiltIn$f(target, key, src[key], options);
	  return target;
	};
	var defineBuiltIns$6 = /*@__PURE__*/getDefaultExportFromCjs(defineBuiltIns$5);

	var isPrototypeOf$5 = objectIsPrototypeOf;
	var $TypeError$c = TypeError;
	var anInstance$a = function anInstance(it, Prototype) {
	  if (isPrototypeOf$5(Prototype, it)) return it;
	  throw $TypeError$c('Incorrect invocation');
	};
	var anInstance$b = /*@__PURE__*/getDefaultExportFromCjs(anInstance$a);

	var toIntegerOrInfinity$c = toIntegerOrInfinity$l;
	var toLength$b = toLength$d;
	var $RangeError$8 = RangeError;

	// `ToIndex` abstract operation
	// https://tc39.es/ecma262/#sec-toindex
	var toIndex$2 = function toIndex(it) {
	  if (it === undefined) return 0;
	  var number = toIntegerOrInfinity$c(it);
	  var length = toLength$b(number);
	  if (number !== length) throw $RangeError$8('Wrong length or index');
	  return length;
	};
	var toIndex$3 = /*@__PURE__*/getDefaultExportFromCjs(toIndex$2);

	// IEEE754 conversions based on https://github.com/feross/ieee754
	var $Array = Array;
	var abs$b = Math.abs;
	var pow$9 = Math.pow;
	var floor$b = Math.floor;
	var log$c = Math.log;
	var LN2$2 = Math.LN2;
	var pack$2 = function pack(number, mantissaLength, bytes) {
	  var buffer = $Array(bytes);
	  var exponentLength = bytes * 8 - mantissaLength - 1;
	  var eMax = (1 << exponentLength) - 1;
	  var eBias = eMax >> 1;
	  var rt = mantissaLength === 23 ? pow$9(2, -24) - pow$9(2, -77) : 0;
	  var sign = number < 0 || number === 0 && 1 / number < 0 ? 1 : 0;
	  var index = 0;
	  var exponent, mantissa, c;
	  number = abs$b(number);
	  // eslint-disable-next-line no-self-compare -- NaN check
	  if (number != number || number === Infinity) {
	    // eslint-disable-next-line no-self-compare -- NaN check
	    mantissa = number != number ? 1 : 0;
	    exponent = eMax;
	  } else {
	    exponent = floor$b(log$c(number) / LN2$2);
	    c = pow$9(2, -exponent);
	    if (number * c < 1) {
	      exponent--;
	      c *= 2;
	    }
	    if (exponent + eBias >= 1) {
	      number += rt / c;
	    } else {
	      number += rt * pow$9(2, 1 - eBias);
	    }
	    if (number * c >= 2) {
	      exponent++;
	      c /= 2;
	    }
	    if (exponent + eBias >= eMax) {
	      mantissa = 0;
	      exponent = eMax;
	    } else if (exponent + eBias >= 1) {
	      mantissa = (number * c - 1) * pow$9(2, mantissaLength);
	      exponent = exponent + eBias;
	    } else {
	      mantissa = number * pow$9(2, eBias - 1) * pow$9(2, mantissaLength);
	      exponent = 0;
	    }
	  }
	  while (mantissaLength >= 8) {
	    buffer[index++] = mantissa & 255;
	    mantissa /= 256;
	    mantissaLength -= 8;
	  }
	  exponent = exponent << mantissaLength | mantissa;
	  exponentLength += mantissaLength;
	  while (exponentLength > 0) {
	    buffer[index++] = exponent & 255;
	    exponent /= 256;
	    exponentLength -= 8;
	  }
	  buffer[--index] |= sign * 128;
	  return buffer;
	};
	var unpack$2 = function unpack(buffer, mantissaLength) {
	  var bytes = buffer.length;
	  var exponentLength = bytes * 8 - mantissaLength - 1;
	  var eMax = (1 << exponentLength) - 1;
	  var eBias = eMax >> 1;
	  var nBits = exponentLength - 7;
	  var index = bytes - 1;
	  var sign = buffer[index--];
	  var exponent = sign & 127;
	  var mantissa;
	  sign >>= 7;
	  while (nBits > 0) {
	    exponent = exponent * 256 + buffer[index--];
	    nBits -= 8;
	  }
	  mantissa = exponent & (1 << -nBits) - 1;
	  exponent >>= -nBits;
	  nBits += mantissaLength;
	  while (nBits > 0) {
	    mantissa = mantissa * 256 + buffer[index--];
	    nBits -= 8;
	  }
	  if (exponent === 0) {
	    exponent = 1 - eBias;
	  } else if (exponent === eMax) {
	    return mantissa ? NaN : sign ? -Infinity : Infinity;
	  } else {
	    mantissa = mantissa + pow$9(2, mantissaLength);
	    exponent = exponent - eBias;
	  }
	  return (sign ? -1 : 1) * mantissa * pow$9(2, exponent - mantissaLength);
	};
	var ieee754 = {
	  pack: pack$2,
	  unpack: unpack$2
	};
	var ieee754$1 = /*@__PURE__*/getDefaultExportFromCjs(ieee754);

	'use strict';
	var global$K = global$Z;
	var uncurryThis$W = functionUncurryThis;
	var DESCRIPTORS$u = descriptors;
	var NATIVE_ARRAY_BUFFER$2 = arrayBufferBasicDetection;
	var FunctionName = functionName;
	var createNonEnumerableProperty$7 = createNonEnumerableProperty$f;
	var defineBuiltInAccessor$d = defineBuiltInAccessor$h;
	var defineBuiltIns$4 = defineBuiltIns$5;
	var fails$Z = fails$1m;
	var anInstance$9 = anInstance$a;
	var toIntegerOrInfinity$b = toIntegerOrInfinity$l;
	var toLength$a = toLength$d;
	var toIndex$1 = toIndex$2;
	var IEEE754 = ieee754;
	var getPrototypeOf$7 = objectGetPrototypeOf$1;
	var setPrototypeOf$5 = objectSetPrototypeOf$1;
	var getOwnPropertyNames$4 = objectGetOwnPropertyNames.f;
	var arrayFill = arrayFill$1;
	var arraySlice$7 = arraySliceSimple;
	var setToStringTag$8 = setToStringTag$d;
	var InternalStateModule$a = internalState;
	var PROPER_FUNCTION_NAME$2 = FunctionName.PROPER;
	var CONFIGURABLE_FUNCTION_NAME = FunctionName.CONFIGURABLE;
	var ARRAY_BUFFER$1 = 'ArrayBuffer';
	var DATA_VIEW = 'DataView';
	var PROTOTYPE = 'prototype';
	var WRONG_LENGTH$1 = 'Wrong length';
	var WRONG_INDEX = 'Wrong index';
	var getInternalArrayBufferState = InternalStateModule$a.getterFor(ARRAY_BUFFER$1);
	var getInternalDataViewState = InternalStateModule$a.getterFor(DATA_VIEW);
	var setInternalState$9 = InternalStateModule$a.set;
	var NativeArrayBuffer$1 = global$K[ARRAY_BUFFER$1];
	var $ArrayBuffer = NativeArrayBuffer$1;
	var ArrayBufferPrototype$1 = $ArrayBuffer && $ArrayBuffer[PROTOTYPE];
	var $DataView = global$K[DATA_VIEW];
	var DataViewPrototype$1 = $DataView && $DataView[PROTOTYPE];
	var ObjectPrototype$3 = Object.prototype;
	var Array$2 = global$K.Array;
	var RangeError$4 = global$K.RangeError;
	var fill$3 = uncurryThis$W(arrayFill);
	var reverse$3 = uncurryThis$W([].reverse);
	var packIEEE754 = IEEE754.pack;
	var unpackIEEE754 = IEEE754.unpack;
	var packInt8 = function packInt8(number) {
	  return [number & 0xFF];
	};
	var packInt16 = function packInt16(number) {
	  return [number & 0xFF, number >> 8 & 0xFF];
	};
	var packInt32 = function packInt32(number) {
	  return [number & 0xFF, number >> 8 & 0xFF, number >> 16 & 0xFF, number >> 24 & 0xFF];
	};
	var unpackInt32 = function unpackInt32(buffer) {
	  return buffer[3] << 24 | buffer[2] << 16 | buffer[1] << 8 | buffer[0];
	};
	var packFloat32 = function packFloat32(number) {
	  return packIEEE754(number, 23, 4);
	};
	var packFloat64 = function packFloat64(number) {
	  return packIEEE754(number, 52, 8);
	};
	var addGetter$1 = function addGetter(Constructor, key, getInternalState) {
	  defineBuiltInAccessor$d(Constructor[PROTOTYPE], key, {
	    configurable: true,
	    get: function get() {
	      return getInternalState(this)[key];
	    }
	  });
	};
	var get$3 = function get(view, count, index, isLittleEndian) {
	  var intIndex = toIndex$1(index);
	  var store = getInternalDataViewState(view);
	  if (intIndex + count > store.byteLength) throw RangeError$4(WRONG_INDEX);
	  var bytes = store.bytes;
	  var start = intIndex + store.byteOffset;
	  var pack = arraySlice$7(bytes, start, start + count);
	  return isLittleEndian ? pack : reverse$3(pack);
	};
	var set$2 = function set(view, count, index, conversion, value, isLittleEndian) {
	  var intIndex = toIndex$1(index);
	  var store = getInternalDataViewState(view);
	  if (intIndex + count > store.byteLength) throw RangeError$4(WRONG_INDEX);
	  var bytes = store.bytes;
	  var start = intIndex + store.byteOffset;
	  var pack = conversion(+value);
	  for (var i = 0; i < count; i++) bytes[start + i] = pack[isLittleEndian ? i : count - i - 1];
	};
	if (!NATIVE_ARRAY_BUFFER$2) {
	  $ArrayBuffer = function ArrayBuffer(length) {
	    anInstance$9(this, ArrayBufferPrototype$1);
	    var byteLength = toIndex$1(length);
	    setInternalState$9(this, {
	      type: ARRAY_BUFFER$1,
	      bytes: fill$3(Array$2(byteLength), 0),
	      byteLength: byteLength
	    });
	    if (!DESCRIPTORS$u) {
	      this.byteLength = byteLength;
	      this.detached = false;
	    }
	  };
	  ArrayBufferPrototype$1 = $ArrayBuffer[PROTOTYPE];
	  $DataView = function DataView(buffer, byteOffset, byteLength) {
	    anInstance$9(this, DataViewPrototype$1);
	    anInstance$9(buffer, ArrayBufferPrototype$1);
	    var bufferState = getInternalArrayBufferState(buffer);
	    var bufferLength = bufferState.byteLength;
	    var offset = toIntegerOrInfinity$b(byteOffset);
	    if (offset < 0 || offset > bufferLength) throw RangeError$4('Wrong offset');
	    byteLength = byteLength === undefined ? bufferLength - offset : toLength$a(byteLength);
	    if (offset + byteLength > bufferLength) throw RangeError$4(WRONG_LENGTH$1);
	    setInternalState$9(this, {
	      type: DATA_VIEW,
	      buffer: buffer,
	      byteLength: byteLength,
	      byteOffset: offset,
	      bytes: bufferState.bytes
	    });
	    if (!DESCRIPTORS$u) {
	      this.buffer = buffer;
	      this.byteLength = byteLength;
	      this.byteOffset = offset;
	    }
	  };
	  DataViewPrototype$1 = $DataView[PROTOTYPE];
	  if (DESCRIPTORS$u) {
	    addGetter$1($ArrayBuffer, 'byteLength', getInternalArrayBufferState);
	    addGetter$1($DataView, 'buffer', getInternalDataViewState);
	    addGetter$1($DataView, 'byteLength', getInternalDataViewState);
	    addGetter$1($DataView, 'byteOffset', getInternalDataViewState);
	  }
	  defineBuiltIns$4(DataViewPrototype$1, {
	    getInt8: function getInt8(byteOffset) {
	      return get$3(this, 1, byteOffset)[0] << 24 >> 24;
	    },
	    getUint8: function getUint8(byteOffset) {
	      return get$3(this, 1, byteOffset)[0];
	    },
	    getInt16: function getInt16(byteOffset /* , littleEndian */) {
	      var bytes = get$3(this, 2, byteOffset, arguments.length > 1 ? arguments[1] : undefined);
	      return (bytes[1] << 8 | bytes[0]) << 16 >> 16;
	    },
	    getUint16: function getUint16(byteOffset /* , littleEndian */) {
	      var bytes = get$3(this, 2, byteOffset, arguments.length > 1 ? arguments[1] : undefined);
	      return bytes[1] << 8 | bytes[0];
	    },
	    getInt32: function getInt32(byteOffset /* , littleEndian */) {
	      return unpackInt32(get$3(this, 4, byteOffset, arguments.length > 1 ? arguments[1] : undefined));
	    },
	    getUint32: function getUint32(byteOffset /* , littleEndian */) {
	      return unpackInt32(get$3(this, 4, byteOffset, arguments.length > 1 ? arguments[1] : undefined)) >>> 0;
	    },
	    getFloat32: function getFloat32(byteOffset /* , littleEndian */) {
	      return unpackIEEE754(get$3(this, 4, byteOffset, arguments.length > 1 ? arguments[1] : undefined), 23);
	    },
	    getFloat64: function getFloat64(byteOffset /* , littleEndian */) {
	      return unpackIEEE754(get$3(this, 8, byteOffset, arguments.length > 1 ? arguments[1] : undefined), 52);
	    },
	    setInt8: function setInt8(byteOffset, value) {
	      set$2(this, 1, byteOffset, packInt8, value);
	    },
	    setUint8: function setUint8(byteOffset, value) {
	      set$2(this, 1, byteOffset, packInt8, value);
	    },
	    setInt16: function setInt16(byteOffset, value /* , littleEndian */) {
	      set$2(this, 2, byteOffset, packInt16, value, arguments.length > 2 ? arguments[2] : undefined);
	    },
	    setUint16: function setUint16(byteOffset, value /* , littleEndian */) {
	      set$2(this, 2, byteOffset, packInt16, value, arguments.length > 2 ? arguments[2] : undefined);
	    },
	    setInt32: function setInt32(byteOffset, value /* , littleEndian */) {
	      set$2(this, 4, byteOffset, packInt32, value, arguments.length > 2 ? arguments[2] : undefined);
	    },
	    setUint32: function setUint32(byteOffset, value /* , littleEndian */) {
	      set$2(this, 4, byteOffset, packInt32, value, arguments.length > 2 ? arguments[2] : undefined);
	    },
	    setFloat32: function setFloat32(byteOffset, value /* , littleEndian */) {
	      set$2(this, 4, byteOffset, packFloat32, value, arguments.length > 2 ? arguments[2] : undefined);
	    },
	    setFloat64: function setFloat64(byteOffset, value /* , littleEndian */) {
	      set$2(this, 8, byteOffset, packFloat64, value, arguments.length > 2 ? arguments[2] : undefined);
	    }
	  });
	} else {
	  var INCORRECT_ARRAY_BUFFER_NAME = PROPER_FUNCTION_NAME$2 && NativeArrayBuffer$1.name !== ARRAY_BUFFER$1;
	  /* eslint-disable no-new -- required for testing */
	  if (!fails$Z(function () {
	    NativeArrayBuffer$1(1);
	  }) || !fails$Z(function () {
	    new NativeArrayBuffer$1(-1);
	  }) || fails$Z(function () {
	    new NativeArrayBuffer$1();
	    new NativeArrayBuffer$1(1.5);
	    new NativeArrayBuffer$1(NaN);
	    return NativeArrayBuffer$1.length != 1 || INCORRECT_ARRAY_BUFFER_NAME && !CONFIGURABLE_FUNCTION_NAME;
	  })) {
	    /* eslint-enable no-new -- required for testing */
	    $ArrayBuffer = function ArrayBuffer(length) {
	      anInstance$9(this, ArrayBufferPrototype$1);
	      return new NativeArrayBuffer$1(toIndex$1(length));
	    };
	    $ArrayBuffer[PROTOTYPE] = ArrayBufferPrototype$1;
	    for (var keys$1 = getOwnPropertyNames$4(NativeArrayBuffer$1), j = 0, key$2; keys$1.length > j;) {
	      if (!((key$2 = keys$1[j++]) in $ArrayBuffer)) {
	        createNonEnumerableProperty$7($ArrayBuffer, key$2, NativeArrayBuffer$1[key$2]);
	      }
	    }
	    ArrayBufferPrototype$1.constructor = $ArrayBuffer;
	  } else if (INCORRECT_ARRAY_BUFFER_NAME && CONFIGURABLE_FUNCTION_NAME) {
	    createNonEnumerableProperty$7(NativeArrayBuffer$1, 'name', ARRAY_BUFFER$1);
	  }

	  // WebKit bug - the same parent prototype for typed arrays and data view
	  if (setPrototypeOf$5 && getPrototypeOf$7(DataViewPrototype$1) !== ObjectPrototype$3) {
	    setPrototypeOf$5(DataViewPrototype$1, ObjectPrototype$3);
	  }

	  // iOS Safari 7.x bug
	  var testView = new $DataView(new $ArrayBuffer(2));
	  var $setInt8 = uncurryThis$W(DataViewPrototype$1.setInt8);
	  testView.setInt8(0, 2147483648);
	  testView.setInt8(1, 2147483649);
	  if (testView.getInt8(0) || !testView.getInt8(1)) defineBuiltIns$4(DataViewPrototype$1, {
	    setInt8: function setInt8(byteOffset, value) {
	      $setInt8(this, byteOffset, value << 24 >> 24);
	    },
	    setUint8: function setUint8(byteOffset, value) {
	      $setInt8(this, byteOffset, value << 24 >> 24);
	    }
	  }, {
	    unsafe: true
	  });
	}
	setToStringTag$8($ArrayBuffer, ARRAY_BUFFER$1);
	setToStringTag$8($DataView, DATA_VIEW);
	var arrayBuffer = {
	  ArrayBuffer: $ArrayBuffer,
	  DataView: $DataView
	};
	var arrayBuffer$1 = /*@__PURE__*/getDefaultExportFromCjs(arrayBuffer);

	'use strict';
	var $$2f = _export;
	var global$J = global$Z;
	var arrayBufferModule = arrayBuffer;
	var setSpecies$4 = setSpecies$6;
	var ARRAY_BUFFER = 'ArrayBuffer';
	var ArrayBuffer$4 = arrayBufferModule[ARRAY_BUFFER];
	var NativeArrayBuffer = global$J[ARRAY_BUFFER];

	// `ArrayBuffer` constructor
	// https://tc39.es/ecma262/#sec-arraybuffer-constructor
	$$2f({
	  global: true,
	  constructor: true,
	  forced: NativeArrayBuffer !== ArrayBuffer$4
	}, {
	  ArrayBuffer: ArrayBuffer$4
	});
	setSpecies$4(ARRAY_BUFFER);

	var es_arrayBuffer_isView = {};

	'use strict';
	var NATIVE_ARRAY_BUFFER$1 = arrayBufferBasicDetection;
	var DESCRIPTORS$t = descriptors;
	var global$I = global$Z;
	var isCallable$e = isCallable$z;
	var isObject$n = isObject$z;
	var hasOwn$h = hasOwnProperty_1;
	var classof$e = classof$m;
	var tryToString$1 = tryToString$7;
	var createNonEnumerableProperty$6 = createNonEnumerableProperty$f;
	var defineBuiltIn$e = defineBuiltIn$m;
	var defineBuiltInAccessor$c = defineBuiltInAccessor$h;
	var isPrototypeOf$4 = objectIsPrototypeOf;
	var getPrototypeOf$6 = objectGetPrototypeOf$1;
	var setPrototypeOf$4 = objectSetPrototypeOf$1;
	var wellKnownSymbol$f = wellKnownSymbol$z;
	var uid$2 = uid$6;
	var InternalStateModule$9 = internalState;
	var enforceInternalState$3 = InternalStateModule$9.enforce;
	var getInternalState$7 = InternalStateModule$9.get;
	var Int8Array$4 = global$I.Int8Array;
	var Int8ArrayPrototype$1 = Int8Array$4 && Int8Array$4.prototype;
	var Uint8ClampedArray$1 = global$I.Uint8ClampedArray;
	var Uint8ClampedArrayPrototype = Uint8ClampedArray$1 && Uint8ClampedArray$1.prototype;
	var TypedArray$1 = Int8Array$4 && getPrototypeOf$6(Int8Array$4);
	var TypedArrayPrototype$2 = Int8ArrayPrototype$1 && getPrototypeOf$6(Int8ArrayPrototype$1);
	var ObjectPrototype$2 = Object.prototype;
	var TypeError$6 = global$I.TypeError;
	var TO_STRING_TAG$1 = wellKnownSymbol$f('toStringTag');
	var TYPED_ARRAY_TAG$1 = uid$2('TYPED_ARRAY_TAG');
	var TYPED_ARRAY_CONSTRUCTOR = 'TypedArrayConstructor';
	// Fixing native typed arrays in Opera Presto crashes the browser, see #595
	var NATIVE_ARRAY_BUFFER_VIEWS$3 = NATIVE_ARRAY_BUFFER$1 && !!setPrototypeOf$4 && classof$e(global$I.opera) !== 'Opera';
	var TYPED_ARRAY_TAG_REQUIRED = false;
	var NAME$1, Constructor, Prototype;
	var TypedArrayConstructorsList = {
	  Int8Array: 1,
	  Uint8Array: 1,
	  Uint8ClampedArray: 1,
	  Int16Array: 2,
	  Uint16Array: 2,
	  Int32Array: 4,
	  Uint32Array: 4,
	  Float32Array: 4,
	  Float64Array: 8
	};
	var BigIntArrayConstructorsList = {
	  BigInt64Array: 8,
	  BigUint64Array: 8
	};
	var isView = function isView(it) {
	  if (!isObject$n(it)) return false;
	  var klass = classof$e(it);
	  return klass === 'DataView' || hasOwn$h(TypedArrayConstructorsList, klass) || hasOwn$h(BigIntArrayConstructorsList, klass);
	};
	var getTypedArrayConstructor$4 = function getTypedArrayConstructor(it) {
	  var proto = getPrototypeOf$6(it);
	  if (!isObject$n(proto)) return;
	  var state = getInternalState$7(proto);
	  return state && hasOwn$h(state, TYPED_ARRAY_CONSTRUCTOR) ? state[TYPED_ARRAY_CONSTRUCTOR] : getTypedArrayConstructor(proto);
	};
	var isTypedArray$2 = function isTypedArray(it) {
	  if (!isObject$n(it)) return false;
	  var klass = classof$e(it);
	  return hasOwn$h(TypedArrayConstructorsList, klass) || hasOwn$h(BigIntArrayConstructorsList, klass);
	};
	var aTypedArray$s = function aTypedArray(it) {
	  if (isTypedArray$2(it)) return it;
	  throw TypeError$6('Target is not a typed array');
	};
	var aTypedArrayConstructor$4 = function aTypedArrayConstructor(C) {
	  if (isCallable$e(C) && (!setPrototypeOf$4 || isPrototypeOf$4(TypedArray$1, C))) return C;
	  throw TypeError$6(tryToString$1(C) + ' is not a typed array constructor');
	};
	var exportTypedArrayMethod$t = function exportTypedArrayMethod(KEY, property, forced, options) {
	  if (!DESCRIPTORS$t) return;
	  if (forced) for (var ARRAY in TypedArrayConstructorsList) {
	    var TypedArrayConstructor = global$I[ARRAY];
	    if (TypedArrayConstructor && hasOwn$h(TypedArrayConstructor.prototype, KEY)) try {
	      delete TypedArrayConstructor.prototype[KEY];
	    } catch (error) {
	      // old WebKit bug - some methods are non-configurable
	      try {
	        TypedArrayConstructor.prototype[KEY] = property;
	      } catch (error2) {/* empty */}
	    }
	  }
	  if (!TypedArrayPrototype$2[KEY] || forced) {
	    defineBuiltIn$e(TypedArrayPrototype$2, KEY, forced ? property : NATIVE_ARRAY_BUFFER_VIEWS$3 && Int8ArrayPrototype$1[KEY] || property, options);
	  }
	};
	var exportTypedArrayStaticMethod$2 = function exportTypedArrayStaticMethod(KEY, property, forced) {
	  var ARRAY, TypedArrayConstructor;
	  if (!DESCRIPTORS$t) return;
	  if (setPrototypeOf$4) {
	    if (forced) for (ARRAY in TypedArrayConstructorsList) {
	      TypedArrayConstructor = global$I[ARRAY];
	      if (TypedArrayConstructor && hasOwn$h(TypedArrayConstructor, KEY)) try {
	        delete TypedArrayConstructor[KEY];
	      } catch (error) {/* empty */}
	    }
	    if (!TypedArray$1[KEY] || forced) {
	      // V8 ~ Chrome 49-50 `%TypedArray%` methods are non-writable non-configurable
	      try {
	        return defineBuiltIn$e(TypedArray$1, KEY, forced ? property : NATIVE_ARRAY_BUFFER_VIEWS$3 && TypedArray$1[KEY] || property);
	      } catch (error) {/* empty */}
	    } else return;
	  }
	  for (ARRAY in TypedArrayConstructorsList) {
	    TypedArrayConstructor = global$I[ARRAY];
	    if (TypedArrayConstructor && (!TypedArrayConstructor[KEY] || forced)) {
	      defineBuiltIn$e(TypedArrayConstructor, KEY, property);
	    }
	  }
	};
	for (NAME$1 in TypedArrayConstructorsList) {
	  Constructor = global$I[NAME$1];
	  Prototype = Constructor && Constructor.prototype;
	  if (Prototype) enforceInternalState$3(Prototype)[TYPED_ARRAY_CONSTRUCTOR] = Constructor;else NATIVE_ARRAY_BUFFER_VIEWS$3 = false;
	}
	for (NAME$1 in BigIntArrayConstructorsList) {
	  Constructor = global$I[NAME$1];
	  Prototype = Constructor && Constructor.prototype;
	  if (Prototype) enforceInternalState$3(Prototype)[TYPED_ARRAY_CONSTRUCTOR] = Constructor;
	}

	// WebKit bug - typed arrays constructors prototype is Object.prototype
	if (!NATIVE_ARRAY_BUFFER_VIEWS$3 || !isCallable$e(TypedArray$1) || TypedArray$1 === Function.prototype) {
	  // eslint-disable-next-line no-shadow -- safe
	  TypedArray$1 = function TypedArray() {
	    throw TypeError$6('Incorrect invocation');
	  };
	  if (NATIVE_ARRAY_BUFFER_VIEWS$3) for (NAME$1 in TypedArrayConstructorsList) {
	    if (global$I[NAME$1]) setPrototypeOf$4(global$I[NAME$1], TypedArray$1);
	  }
	}
	if (!NATIVE_ARRAY_BUFFER_VIEWS$3 || !TypedArrayPrototype$2 || TypedArrayPrototype$2 === ObjectPrototype$2) {
	  TypedArrayPrototype$2 = TypedArray$1.prototype;
	  if (NATIVE_ARRAY_BUFFER_VIEWS$3) for (NAME$1 in TypedArrayConstructorsList) {
	    if (global$I[NAME$1]) setPrototypeOf$4(global$I[NAME$1].prototype, TypedArrayPrototype$2);
	  }
	}

	// WebKit bug - one more object in Uint8ClampedArray prototype chain
	if (NATIVE_ARRAY_BUFFER_VIEWS$3 && getPrototypeOf$6(Uint8ClampedArrayPrototype) !== TypedArrayPrototype$2) {
	  setPrototypeOf$4(Uint8ClampedArrayPrototype, TypedArrayPrototype$2);
	}
	if (DESCRIPTORS$t && !hasOwn$h(TypedArrayPrototype$2, TO_STRING_TAG$1)) {
	  TYPED_ARRAY_TAG_REQUIRED = true;
	  defineBuiltInAccessor$c(TypedArrayPrototype$2, TO_STRING_TAG$1, {
	    configurable: true,
	    get: function get() {
	      return isObject$n(this) ? this[TYPED_ARRAY_TAG$1] : undefined;
	    }
	  });
	  for (NAME$1 in TypedArrayConstructorsList) if (global$I[NAME$1]) {
	    createNonEnumerableProperty$6(global$I[NAME$1], TYPED_ARRAY_TAG$1, NAME$1);
	  }
	}
	var arrayBufferViewCore = {
	  NATIVE_ARRAY_BUFFER_VIEWS: NATIVE_ARRAY_BUFFER_VIEWS$3,
	  TYPED_ARRAY_TAG: TYPED_ARRAY_TAG_REQUIRED && TYPED_ARRAY_TAG$1,
	  aTypedArray: aTypedArray$s,
	  aTypedArrayConstructor: aTypedArrayConstructor$4,
	  exportTypedArrayMethod: exportTypedArrayMethod$t,
	  exportTypedArrayStaticMethod: exportTypedArrayStaticMethod$2,
	  getTypedArrayConstructor: getTypedArrayConstructor$4,
	  isView: isView,
	  isTypedArray: isTypedArray$2,
	  TypedArray: TypedArray$1,
	  TypedArrayPrototype: TypedArrayPrototype$2
	};
	var arrayBufferViewCore$1 = /*@__PURE__*/getDefaultExportFromCjs(arrayBufferViewCore);

	var $$2e = _export;
	var ArrayBufferViewCore$v = arrayBufferViewCore;
	var NATIVE_ARRAY_BUFFER_VIEWS$2 = ArrayBufferViewCore$v.NATIVE_ARRAY_BUFFER_VIEWS;

	// `ArrayBuffer.isView` method
	// https://tc39.es/ecma262/#sec-arraybuffer.isview
	$$2e({
	  target: 'ArrayBuffer',
	  stat: true,
	  forced: !NATIVE_ARRAY_BUFFER_VIEWS$2
	}, {
	  isView: ArrayBufferViewCore$v.isView
	});

	var es_arrayBuffer_slice = {};

	var isConstructor$1 = isConstructor$6;
	var tryToString = tryToString$7;
	var $TypeError$b = TypeError;

	// `Assert: IsConstructor(argument) is true`
	var aConstructor$3 = function aConstructor(argument) {
	  if (isConstructor$1(argument)) return argument;
	  throw $TypeError$b(tryToString(argument) + ' is not a constructor');
	};
	var aConstructor$4 = /*@__PURE__*/getDefaultExportFromCjs(aConstructor$3);

	var anObject$r = anObject$D;
	var aConstructor$2 = aConstructor$3;
	var isNullOrUndefined$a = isNullOrUndefined$e;
	var wellKnownSymbol$e = wellKnownSymbol$z;
	var SPECIES$2 = wellKnownSymbol$e('species');

	// `SpeciesConstructor` abstract operation
	// https://tc39.es/ecma262/#sec-speciesconstructor
	var speciesConstructor$6 = function speciesConstructor(O, defaultConstructor) {
	  var C = anObject$r(O).constructor;
	  var S;
	  return C === undefined || isNullOrUndefined$a(S = anObject$r(C)[SPECIES$2]) ? defaultConstructor : aConstructor$2(S);
	};
	var speciesConstructor$7 = /*@__PURE__*/getDefaultExportFromCjs(speciesConstructor$6);

	'use strict';
	var $$2d = _export;
	var uncurryThis$V = functionUncurryThisClause;
	var fails$Y = fails$1m;
	var ArrayBufferModule$2 = arrayBuffer;
	var anObject$q = anObject$D;
	var toAbsoluteIndex$2 = toAbsoluteIndex$a;
	var toLength$9 = toLength$d;
	var speciesConstructor$5 = speciesConstructor$6;
	var ArrayBuffer$3 = ArrayBufferModule$2.ArrayBuffer;
	var DataView$2 = ArrayBufferModule$2.DataView;
	var DataViewPrototype = DataView$2.prototype;
	var nativeArrayBufferSlice = uncurryThis$V(ArrayBuffer$3.prototype.slice);
	var getUint8 = uncurryThis$V(DataViewPrototype.getUint8);
	var setUint8 = uncurryThis$V(DataViewPrototype.setUint8);
	var INCORRECT_SLICE = fails$Y(function () {
	  return !new ArrayBuffer$3(2).slice(1, undefined).byteLength;
	});

	// `ArrayBuffer.prototype.slice` method
	// https://tc39.es/ecma262/#sec-arraybuffer.prototype.slice
	$$2d({
	  target: 'ArrayBuffer',
	  proto: true,
	  unsafe: true,
	  forced: INCORRECT_SLICE
	}, {
	  slice: function slice(start, end) {
	    if (nativeArrayBufferSlice && end === undefined) {
	      return nativeArrayBufferSlice(anObject$q(this), start); // FF fix
	    }

	    var length = anObject$q(this).byteLength;
	    var first = toAbsoluteIndex$2(start, length);
	    var fin = toAbsoluteIndex$2(end === undefined ? length : end, length);
	    var result = new (speciesConstructor$5(this, ArrayBuffer$3))(toLength$9(fin - first));
	    var viewSource = new DataView$2(this);
	    var viewTarget = new DataView$2(result);
	    var index = 0;
	    while (first < fin) {
	      setUint8(viewTarget, index++, getUint8(viewSource, first++));
	    }
	    return result;
	  }
	});

	var es_dataView = {};

	var es_dataView_constructor = {};

	var $$2c = _export;
	var ArrayBufferModule$1 = arrayBuffer;
	var NATIVE_ARRAY_BUFFER = arrayBufferBasicDetection;

	// `DataView` constructor
	// https://tc39.es/ecma262/#sec-dataview-constructor
	$$2c({
	  global: true,
	  constructor: true,
	  forced: !NATIVE_ARRAY_BUFFER
	}, {
	  DataView: ArrayBufferModule$1.DataView
	});

	var es_date_getYear = {};

	'use strict';
	var $$2b = _export;
	var uncurryThis$U = functionUncurryThis;
	var fails$X = fails$1m;

	// IE8- non-standard case
	var FORCED$r = fails$X(function () {
	  // eslint-disable-next-line es/no-date-prototype-getyear-setyear -- detection
	  return new Date(16e11).getYear() !== 120;
	});
	var getFullYear = uncurryThis$U(Date.prototype.getFullYear);

	// `Date.prototype.getYear` method
	// https://tc39.es/ecma262/#sec-date.prototype.getyear
	$$2b({
	  target: 'Date',
	  proto: true,
	  forced: FORCED$r
	}, {
	  getYear: function getYear() {
	    return getFullYear(this) - 1900;
	  }
	});

	var es_date_now = {};

	// TODO: Remove from `core-js@4`
	var $$2a = _export;
	var uncurryThis$T = functionUncurryThis;
	var $Date = Date;
	var thisTimeValue$4 = uncurryThis$T($Date.prototype.getTime);

	// `Date.now` method
	// https://tc39.es/ecma262/#sec-date.now
	$$2a({
	  target: 'Date',
	  stat: true
	}, {
	  now: function now() {
	    return thisTimeValue$4(new $Date());
	  }
	});

	var es_date_setYear = {};

	'use strict';
	var $$29 = _export;
	var uncurryThis$S = functionUncurryThis;
	var toIntegerOrInfinity$a = toIntegerOrInfinity$l;
	var DatePrototype$3 = Date.prototype;
	var thisTimeValue$3 = uncurryThis$S(DatePrototype$3.getTime);
	var setFullYear = uncurryThis$S(DatePrototype$3.setFullYear);

	// `Date.prototype.setYear` method
	// https://tc39.es/ecma262/#sec-date.prototype.setyear
	$$29({
	  target: 'Date',
	  proto: true
	}, {
	  setYear: function setYear(year) {
	    // validate
	    thisTimeValue$3(this);
	    var yi = toIntegerOrInfinity$a(year);
	    var yyyy = 0 <= yi && yi <= 99 ? yi + 1900 : yi;
	    return setFullYear(this, yyyy);
	  }
	});

	var es_date_toGmtString = {};

	var $$28 = _export;

	// `Date.prototype.toGMTString` method
	// https://tc39.es/ecma262/#sec-date.prototype.togmtstring
	$$28({
	  target: 'Date',
	  proto: true
	}, {
	  toGMTString: Date.prototype.toUTCString
	});

	var es_date_toIsoString = {};

	'use strict';
	var toIntegerOrInfinity$9 = toIntegerOrInfinity$l;
	var toString$r = toString$x;
	var requireObjectCoercible$g = requireObjectCoercible$j;
	var $RangeError$7 = RangeError;

	// `String.prototype.repeat` method implementation
	// https://tc39.es/ecma262/#sec-string.prototype.repeat
	var stringRepeat = function repeat(count) {
	  var str = toString$r(requireObjectCoercible$g(this));
	  var result = '';
	  var n = toIntegerOrInfinity$9(count);
	  if (n < 0 || n == Infinity) throw $RangeError$7('Wrong number of repetitions');
	  for (; n > 0; (n >>>= 1) && (str += str)) if (n & 1) result += str;
	  return result;
	};
	var stringRepeat$1 = /*@__PURE__*/getDefaultExportFromCjs(stringRepeat);

	// https://github.com/tc39/proposal-string-pad-start-end
	var uncurryThis$R = functionUncurryThis;
	var toLength$8 = toLength$d;
	var toString$q = toString$x;
	var $repeat$2 = stringRepeat;
	var requireObjectCoercible$f = requireObjectCoercible$j;
	var repeat$4 = uncurryThis$R($repeat$2);
	var stringSlice$f = uncurryThis$R(''.slice);
	var ceil$3 = Math.ceil;

	// `String.prototype.{ padStart, padEnd }` methods implementation
	var createMethod$3 = function createMethod(IS_END) {
	  return function ($this, maxLength, fillString) {
	    var S = toString$q(requireObjectCoercible$f($this));
	    var intMaxLength = toLength$8(maxLength);
	    var stringLength = S.length;
	    var fillStr = fillString === undefined ? ' ' : toString$q(fillString);
	    var fillLen, stringFiller;
	    if (intMaxLength <= stringLength || fillStr == '') return S;
	    fillLen = intMaxLength - stringLength;
	    stringFiller = repeat$4(fillStr, ceil$3(fillLen / fillStr.length));
	    if (stringFiller.length > fillLen) stringFiller = stringSlice$f(stringFiller, 0, fillLen);
	    return IS_END ? S + stringFiller : stringFiller + S;
	  };
	};
	var stringPad = {
	  // `String.prototype.padStart` method
	  // https://tc39.es/ecma262/#sec-string.prototype.padstart
	  start: createMethod$3(false),
	  // `String.prototype.padEnd` method
	  // https://tc39.es/ecma262/#sec-string.prototype.padend
	  end: createMethod$3(true)
	};
	var stringPad$1 = /*@__PURE__*/getDefaultExportFromCjs(stringPad);

	'use strict';
	var uncurryThis$Q = functionUncurryThis;
	var fails$W = fails$1m;
	var padStart = stringPad.start;
	var $RangeError$6 = RangeError;
	var $isFinite$1 = isFinite;
	var abs$a = Math.abs;
	var DatePrototype$2 = Date.prototype;
	var nativeDateToISOString = DatePrototype$2.toISOString;
	var thisTimeValue$2 = uncurryThis$Q(DatePrototype$2.getTime);
	var getUTCDate = uncurryThis$Q(DatePrototype$2.getUTCDate);
	var getUTCFullYear = uncurryThis$Q(DatePrototype$2.getUTCFullYear);
	var getUTCHours = uncurryThis$Q(DatePrototype$2.getUTCHours);
	var getUTCMilliseconds = uncurryThis$Q(DatePrototype$2.getUTCMilliseconds);
	var getUTCMinutes = uncurryThis$Q(DatePrototype$2.getUTCMinutes);
	var getUTCMonth = uncurryThis$Q(DatePrototype$2.getUTCMonth);
	var getUTCSeconds = uncurryThis$Q(DatePrototype$2.getUTCSeconds);

	// `Date.prototype.toISOString` method implementation
	// https://tc39.es/ecma262/#sec-date.prototype.toisostring
	// PhantomJS / old WebKit fails here:
	var dateToIsoString = fails$W(function () {
	  return nativeDateToISOString.call(new Date(-5e13 - 1)) != '0385-07-25T07:06:39.999Z';
	}) || !fails$W(function () {
	  nativeDateToISOString.call(new Date(NaN));
	}) ? function toISOString() {
	  if (!$isFinite$1(thisTimeValue$2(this))) throw $RangeError$6('Invalid time value');
	  var date = this;
	  var year = getUTCFullYear(date);
	  var milliseconds = getUTCMilliseconds(date);
	  var sign = year < 0 ? '-' : year > 9999 ? '+' : '';
	  return sign + padStart(abs$a(year), sign ? 6 : 4, 0) + '-' + padStart(getUTCMonth(date) + 1, 2, 0) + '-' + padStart(getUTCDate(date), 2, 0) + 'T' + padStart(getUTCHours(date), 2, 0) + ':' + padStart(getUTCMinutes(date), 2, 0) + ':' + padStart(getUTCSeconds(date), 2, 0) + '.' + padStart(milliseconds, 3, 0) + 'Z';
	} : nativeDateToISOString;
	var dateToIsoString$1 = /*@__PURE__*/getDefaultExportFromCjs(dateToIsoString);

	var $$27 = _export;
	var toISOString = dateToIsoString;

	// `Date.prototype.toISOString` method
	// https://tc39.es/ecma262/#sec-date.prototype.toisostring
	// PhantomJS / old WebKit has a broken implementations
	$$27({
	  target: 'Date',
	  proto: true,
	  forced: Date.prototype.toISOString !== toISOString
	}, {
	  toISOString: toISOString
	});

	var es_date_toJson = {};

	'use strict';
	var $$26 = _export;
	var fails$V = fails$1m;
	var toObject$b = toObject$t;
	var toPrimitive$2 = toPrimitive$4;
	var FORCED$q = fails$V(function () {
	  return new Date(NaN).toJSON() !== null || Date.prototype.toJSON.call({
	    toISOString: function toISOString() {
	      return 1;
	    }
	  }) !== 1;
	});

	// `Date.prototype.toJSON` method
	// https://tc39.es/ecma262/#sec-date.prototype.tojson
	$$26({
	  target: 'Date',
	  proto: true,
	  arity: 1,
	  forced: FORCED$q
	}, {
	  // eslint-disable-next-line no-unused-vars -- required for `.length`
	  toJSON: function toJSON(key) {
	    var O = toObject$b(this);
	    var pv = toPrimitive$2(O, 'number');
	    return typeof pv == 'number' && !isFinite(pv) ? null : O.toISOString();
	  }
	});

	var es_date_toPrimitive = {};

	'use strict';
	var anObject$p = anObject$D;
	var ordinaryToPrimitive = ordinaryToPrimitive$2;
	var $TypeError$a = TypeError;

	// `Date.prototype[@@toPrimitive](hint)` method implementation
	// https://tc39.es/ecma262/#sec-date.prototype-@@toprimitive
	var dateToPrimitive$1 = function dateToPrimitive(hint) {
	  anObject$p(this);
	  if (hint === 'string' || hint === 'default') hint = 'string';else if (hint !== 'number') throw $TypeError$a('Incorrect hint');
	  return ordinaryToPrimitive(this, hint);
	};
	var dateToPrimitive$2 = /*@__PURE__*/getDefaultExportFromCjs(dateToPrimitive$1);

	var hasOwn$g = hasOwnProperty_1;
	var defineBuiltIn$d = defineBuiltIn$m;
	var dateToPrimitive = dateToPrimitive$1;
	var wellKnownSymbol$d = wellKnownSymbol$z;
	var TO_PRIMITIVE = wellKnownSymbol$d('toPrimitive');
	var DatePrototype$1 = Date.prototype;

	// `Date.prototype[@@toPrimitive]` method
	// https://tc39.es/ecma262/#sec-date.prototype-@@toprimitive
	if (!hasOwn$g(DatePrototype$1, TO_PRIMITIVE)) {
	  defineBuiltIn$d(DatePrototype$1, TO_PRIMITIVE, dateToPrimitive);
	}

	var es_date_toString = {};

	// TODO: Remove from `core-js@4`
	var uncurryThis$P = functionUncurryThis;
	var defineBuiltIn$c = defineBuiltIn$m;
	var DatePrototype = Date.prototype;
	var INVALID_DATE = 'Invalid Date';
	var TO_STRING$1 = 'toString';
	var nativeDateToString = uncurryThis$P(DatePrototype[TO_STRING$1]);
	var thisTimeValue$1 = uncurryThis$P(DatePrototype.getTime);

	// `Date.prototype.toString` method
	// https://tc39.es/ecma262/#sec-date.prototype.tostring
	if (String(new Date(NaN)) != INVALID_DATE) {
	  defineBuiltIn$c(DatePrototype, TO_STRING$1, function toString() {
	    var value = thisTimeValue$1(this);
	    // eslint-disable-next-line no-self-compare -- NaN check
	    return value === value ? nativeDateToString(this) : INVALID_DATE;
	  });
	}

	var es_escape = {};

	'use strict';
	var $$25 = _export;
	var uncurryThis$O = functionUncurryThis;
	var toString$p = toString$x;
	var charAt$d = uncurryThis$O(''.charAt);
	var charCodeAt$4 = uncurryThis$O(''.charCodeAt);
	var exec$8 = uncurryThis$O(/./.exec);
	var numberToString$1 = uncurryThis$O(1.0.toString);
	var toUpperCase = uncurryThis$O(''.toUpperCase);
	var raw = /[\w*+\-./@]/;
	var hex$1 = function hex(code, length) {
	  var result = numberToString$1(code, 16);
	  while (result.length < length) result = '0' + result;
	  return result;
	};

	// `escape` method
	// https://tc39.es/ecma262/#sec-escape-string
	$$25({
	  global: true
	}, {
	  escape: function escape(string) {
	    var str = toString$p(string);
	    var result = '';
	    var length = str.length;
	    var index = 0;
	    var chr, code;
	    while (index < length) {
	      chr = charAt$d(str, index++);
	      if (exec$8(raw, chr)) {
	        result += chr;
	      } else {
	        code = charCodeAt$4(chr, 0);
	        if (code < 256) {
	          result += '%' + hex$1(code, 2);
	        } else {
	          result += '%u' + toUpperCase(hex$1(code, 4));
	        }
	      }
	    }
	    return result;
	  }
	});

	var es_function_bind = {};

	'use strict';
	var uncurryThis$N = functionUncurryThis;
	var aCallable$c = aCallable$l;
	var isObject$m = isObject$z;
	var hasOwn$f = hasOwnProperty_1;
	var arraySlice$6 = arraySlice$a;
	var NATIVE_BIND = functionBindNative;
	var $Function = Function;
	var concat$5 = uncurryThis$N([].concat);
	var join$6 = uncurryThis$N([].join);
	var factories = {};
	var construct = function construct(C, argsLength, args) {
	  if (!hasOwn$f(factories, argsLength)) {
	    for (var list = [], i = 0; i < argsLength; i++) list[i] = 'a[' + i + ']';
	    factories[argsLength] = $Function('C,a', 'return new C(' + join$6(list, ',') + ')');
	  }
	  return factories[argsLength](C, args);
	};

	// `Function.prototype.bind` method implementation
	// https://tc39.es/ecma262/#sec-function.prototype.bind
	// eslint-disable-next-line es/no-function-prototype-bind -- detection
	var functionBind = NATIVE_BIND ? $Function.bind : function bind(that /* , ...args */) {
	  var F = aCallable$c(this);
	  var Prototype = F.prototype;
	  var partArgs = arraySlice$6(arguments, 1);
	  var boundFunction = function bound( /* args... */
	  ) {
	    var args = concat$5(partArgs, arraySlice$6(arguments));
	    return this instanceof boundFunction ? construct(F, args.length, args) : F.apply(that, args);
	  };
	  if (isObject$m(Prototype)) boundFunction.prototype = Prototype;
	  return boundFunction;
	};
	var functionBind$1 = /*@__PURE__*/getDefaultExportFromCjs(functionBind);

	// TODO: Remove from `core-js@4`
	var $$24 = _export;
	var bind$8 = functionBind;

	// `Function.prototype.bind` method
	// https://tc39.es/ecma262/#sec-function.prototype.bind
	// eslint-disable-next-line es/no-function-prototype-bind -- detection
	$$24({
	  target: 'Function',
	  proto: true,
	  forced: Function.bind !== bind$8
	}, {
	  bind: bind$8
	});

	var es_function_hasInstance = {};

	'use strict';
	var isCallable$d = isCallable$z;
	var isObject$l = isObject$z;
	var definePropertyModule$5 = objectDefineProperty;
	var getPrototypeOf$5 = objectGetPrototypeOf$1;
	var wellKnownSymbol$c = wellKnownSymbol$z;
	var makeBuiltIn = makeBuiltInExports;
	var HAS_INSTANCE = wellKnownSymbol$c('hasInstance');
	var FunctionPrototype$1 = Function.prototype;

	// `Function.prototype[@@hasInstance]` method
	// https://tc39.es/ecma262/#sec-function.prototype-@@hasinstance
	if (!(HAS_INSTANCE in FunctionPrototype$1)) {
	  definePropertyModule$5.f(FunctionPrototype$1, HAS_INSTANCE, {
	    value: makeBuiltIn(function (O) {
	      if (!isCallable$d(this) || !isObject$l(O)) return false;
	      var P = this.prototype;
	      if (!isObject$l(P)) return O instanceof this;
	      // for environment w/o native `@@hasInstance` logic enough `instanceof`, but add this:
	      while (O = getPrototypeOf$5(O)) if (P === O) return true;
	      return false;
	    }, HAS_INSTANCE)
	  });
	}

	var es_function_name = {};

	var DESCRIPTORS$s = descriptors;
	var FUNCTION_NAME_EXISTS = functionName.EXISTS;
	var uncurryThis$M = functionUncurryThis;
	var defineBuiltInAccessor$b = defineBuiltInAccessor$h;
	var FunctionPrototype = Function.prototype;
	var functionToString = uncurryThis$M(FunctionPrototype.toString);
	var nameRE = /function\b(?:\s|\/\*[\S\s]*?\*\/|\/\/[^\n\r]*[\n\r]+)*([^\s(/]*)/;
	var regExpExec$4 = uncurryThis$M(nameRE.exec);
	var NAME = 'name';

	// Function instances `.name` property
	// https://tc39.es/ecma262/#sec-function-instances-name
	if (DESCRIPTORS$s && !FUNCTION_NAME_EXISTS) {
	  defineBuiltInAccessor$b(FunctionPrototype, NAME, {
	    configurable: true,
	    get: function get() {
	      try {
	        return regExpExec$4(nameRE, functionToString(this))[1];
	      } catch (error) {
	        return '';
	      }
	    }
	  });
	}

	var es_globalThis = {};

	var $$23 = _export;
	var global$H = global$Z;

	// `globalThis` object
	// https://tc39.es/ecma262/#sec-globalthis
	$$23({
	  global: true,
	  forced: global$H.globalThis !== global$H
	}, {
	  globalThis: global$H
	});

	var es_json_toStringTag = {};

	var global$G = global$Z;
	var setToStringTag$7 = setToStringTag$d;

	// JSON[@@toStringTag] property
	// https://tc39.es/ecma262/#sec-json-@@tostringtag
	setToStringTag$7(global$G.JSON, 'JSON', true);

	var es_map = {};

	var es_map_constructor = {};

	var internalMetadata$2 = {exports: {}};

	// FF26- bug: ArrayBuffers are non-extensible, but Object.isExtensible does not report it
	var fails$U = fails$1m;
	var arrayBufferNonExtensible = fails$U(function () {
	  if (typeof ArrayBuffer == 'function') {
	    var buffer = new ArrayBuffer(8);
	    // eslint-disable-next-line es/no-object-isextensible, es/no-object-defineproperty -- safe
	    if (Object.isExtensible(buffer)) Object.defineProperty(buffer, 'a', {
	      value: 8
	    });
	  }
	});
	var arrayBufferNonExtensible$1 = /*@__PURE__*/getDefaultExportFromCjs(arrayBufferNonExtensible);

	var fails$T = fails$1m;
	var isObject$k = isObject$z;
	var classof$d = classofRaw$2;
	var ARRAY_BUFFER_NON_EXTENSIBLE$2 = arrayBufferNonExtensible;

	// eslint-disable-next-line es/no-object-isextensible -- safe
	var $isExtensible$2 = Object.isExtensible;
	var FAILS_ON_PRIMITIVES$6 = fails$T(function () {
	  $isExtensible$2(1);
	});

	// `Object.isExtensible` method
	// https://tc39.es/ecma262/#sec-object.isextensible
	var objectIsExtensible = FAILS_ON_PRIMITIVES$6 || ARRAY_BUFFER_NON_EXTENSIBLE$2 ? function isExtensible(it) {
	  if (!isObject$k(it)) return false;
	  if (ARRAY_BUFFER_NON_EXTENSIBLE$2 && classof$d(it) == 'ArrayBuffer') return false;
	  return $isExtensible$2 ? $isExtensible$2(it) : true;
	} : $isExtensible$2;
	var objectIsExtensible$1 = /*@__PURE__*/getDefaultExportFromCjs(objectIsExtensible);

	var fails$S = fails$1m;
	var freezing = !fails$S(function () {
	  // eslint-disable-next-line es/no-object-isextensible, es/no-object-preventextensions -- required for testing
	  return Object.isExtensible(Object.preventExtensions({}));
	});
	var freezing$1 = /*@__PURE__*/getDefaultExportFromCjs(freezing);

	var internalMetadata = internalMetadata$2.exports;
	var $$22 = _export;
	var uncurryThis$L = functionUncurryThis;
	var hiddenKeys = hiddenKeys$6;
	var isObject$j = isObject$z;
	var hasOwn$e = hasOwnProperty_1;
	var defineProperty$6 = objectDefineProperty.f;
	var getOwnPropertyNamesModule = objectGetOwnPropertyNames;
	var getOwnPropertyNamesExternalModule = objectGetOwnPropertyNamesExternal;
	var isExtensible$1 = objectIsExtensible;
	var uid$1 = uid$6;
	var FREEZING$5 = freezing;
	var REQUIRED = false;
	var METADATA = uid$1('meta');
	var id$1 = 0;
	var setMetadata = function setMetadata(it) {
	  defineProperty$6(it, METADATA, {
	    value: {
	      objectID: 'O' + id$1++,
	      // object ID
	      weakData: {} // weak collections IDs
	    }
	  });
	};

	var fastKey$1 = function fastKey(it, create) {
	  // return a primitive with prefix
	  if (!isObject$j(it)) return _typeof(it) == 'symbol' ? it : (typeof it == 'string' ? 'S' : 'P') + it;
	  if (!hasOwn$e(it, METADATA)) {
	    // can't set metadata to uncaught frozen object
	    if (!isExtensible$1(it)) return 'F';
	    // not necessary to add metadata
	    if (!create) return 'E';
	    // add missing metadata
	    setMetadata(it);
	    // return object ID
	  }
	  return it[METADATA].objectID;
	};
	var getWeakData$1 = function getWeakData(it, create) {
	  if (!hasOwn$e(it, METADATA)) {
	    // can't set metadata to uncaught frozen object
	    if (!isExtensible$1(it)) return true;
	    // not necessary to add metadata
	    if (!create) return false;
	    // add missing metadata
	    setMetadata(it);
	    // return the store of weak collections IDs
	  }
	  return it[METADATA].weakData;
	};

	// add metadata on freeze-family methods calling
	var onFreeze$3 = function onFreeze(it) {
	  if (FREEZING$5 && REQUIRED && isExtensible$1(it) && !hasOwn$e(it, METADATA)) setMetadata(it);
	  return it;
	};
	var enable = function enable() {
	  meta.enable = function () {/* empty */};
	  REQUIRED = true;
	  var getOwnPropertyNames = getOwnPropertyNamesModule.f;
	  var splice = uncurryThis$L([].splice);
	  var test = {};
	  test[METADATA] = 1;

	  // prevent exposing of metadata key
	  if (getOwnPropertyNames(test).length) {
	    getOwnPropertyNamesModule.f = function (it) {
	      var result = getOwnPropertyNames(it);
	      for (var i = 0, length = result.length; i < length; i++) {
	        if (result[i] === METADATA) {
	          splice(result, i, 1);
	          break;
	        }
	      }
	      return result;
	    };
	    $$22({
	      target: 'Object',
	      stat: true,
	      forced: true
	    }, {
	      getOwnPropertyNames: getOwnPropertyNamesExternalModule.f
	    });
	  }
	};
	var meta = internalMetadata$2.exports = {
	  enable: enable,
	  fastKey: fastKey$1,
	  getWeakData: getWeakData$1,
	  onFreeze: onFreeze$3
	};
	hiddenKeys[METADATA] = true;
	var internalMetadataExports = internalMetadata$2.exports;
	var internalMetadata$1 = /*@__PURE__*/getDefaultExportFromCjs(internalMetadataExports);

	'use strict';
	var $$21 = _export;
	var global$F = global$Z;
	var uncurryThis$K = functionUncurryThis;
	var isForced$3 = isForced_1;
	var defineBuiltIn$b = defineBuiltIn$m;
	var InternalMetadataModule$1 = internalMetadataExports;
	var iterate$8 = iterate$a;
	var anInstance$8 = anInstance$a;
	var isCallable$c = isCallable$z;
	var isNullOrUndefined$9 = isNullOrUndefined$e;
	var isObject$i = isObject$z;
	var fails$R = fails$1m;
	var checkCorrectnessOfIteration$2 = checkCorrectnessOfIteration$4;
	var setToStringTag$6 = setToStringTag$d;
	var inheritIfRequired$4 = inheritIfRequired$6;
	var collection$4 = function collection(CONSTRUCTOR_NAME, wrapper, common) {
	  var IS_MAP = CONSTRUCTOR_NAME.indexOf('Map') !== -1;
	  var IS_WEAK = CONSTRUCTOR_NAME.indexOf('Weak') !== -1;
	  var ADDER = IS_MAP ? 'set' : 'add';
	  var NativeConstructor = global$F[CONSTRUCTOR_NAME];
	  var NativePrototype = NativeConstructor && NativeConstructor.prototype;
	  var Constructor = NativeConstructor;
	  var exported = {};
	  var fixMethod = function fixMethod(KEY) {
	    var uncurriedNativeMethod = uncurryThis$K(NativePrototype[KEY]);
	    defineBuiltIn$b(NativePrototype, KEY, KEY == 'add' ? function add(value) {
	      uncurriedNativeMethod(this, value === 0 ? 0 : value);
	      return this;
	    } : KEY == 'delete' ? function (key) {
	      return IS_WEAK && !isObject$i(key) ? false : uncurriedNativeMethod(this, key === 0 ? 0 : key);
	    } : KEY == 'get' ? function get(key) {
	      return IS_WEAK && !isObject$i(key) ? undefined : uncurriedNativeMethod(this, key === 0 ? 0 : key);
	    } : KEY == 'has' ? function has(key) {
	      return IS_WEAK && !isObject$i(key) ? false : uncurriedNativeMethod(this, key === 0 ? 0 : key);
	    } : function set(key, value) {
	      uncurriedNativeMethod(this, key === 0 ? 0 : key, value);
	      return this;
	    });
	  };
	  var REPLACE = isForced$3(CONSTRUCTOR_NAME, !isCallable$c(NativeConstructor) || !(IS_WEAK || NativePrototype.forEach && !fails$R(function () {
	    new NativeConstructor().entries().next();
	  })));
	  if (REPLACE) {
	    // create collection constructor
	    Constructor = common.getConstructor(wrapper, CONSTRUCTOR_NAME, IS_MAP, ADDER);
	    InternalMetadataModule$1.enable();
	  } else if (isForced$3(CONSTRUCTOR_NAME, true)) {
	    var instance = new Constructor();
	    // early implementations not supports chaining
	    var HASNT_CHAINING = instance[ADDER](IS_WEAK ? {} : -0, 1) != instance;
	    // V8 ~ Chromium 40- weak-collections throws on primitives, but should return false
	    var THROWS_ON_PRIMITIVES = fails$R(function () {
	      instance.has(1);
	    });
	    // most early implementations doesn't supports iterables, most modern - not close it correctly
	    // eslint-disable-next-line no-new -- required for testing
	    var ACCEPT_ITERABLES = checkCorrectnessOfIteration$2(function (iterable) {
	      new NativeConstructor(iterable);
	    });
	    // for early implementations -0 and +0 not the same
	    var BUGGY_ZERO = !IS_WEAK && fails$R(function () {
	      // V8 ~ Chromium 42- fails only with 5+ elements
	      var $instance = new NativeConstructor();
	      var index = 5;
	      while (index--) $instance[ADDER](index, index);
	      return !$instance.has(-0);
	    });
	    if (!ACCEPT_ITERABLES) {
	      Constructor = wrapper(function (dummy, iterable) {
	        anInstance$8(dummy, NativePrototype);
	        var that = inheritIfRequired$4(new NativeConstructor(), dummy, Constructor);
	        if (!isNullOrUndefined$9(iterable)) iterate$8(iterable, that[ADDER], {
	          that: that,
	          AS_ENTRIES: IS_MAP
	        });
	        return that;
	      });
	      Constructor.prototype = NativePrototype;
	      NativePrototype.constructor = Constructor;
	    }
	    if (THROWS_ON_PRIMITIVES || BUGGY_ZERO) {
	      fixMethod('delete');
	      fixMethod('has');
	      IS_MAP && fixMethod('get');
	    }
	    if (BUGGY_ZERO || HASNT_CHAINING) fixMethod(ADDER);

	    // weak collections should not contains .clear method
	    if (IS_WEAK && NativePrototype.clear) delete NativePrototype.clear;
	  }
	  exported[CONSTRUCTOR_NAME] = Constructor;
	  $$21({
	    global: true,
	    constructor: true,
	    forced: Constructor != NativeConstructor
	  }, exported);
	  setToStringTag$6(Constructor, CONSTRUCTOR_NAME);
	  if (!IS_WEAK) common.setStrong(Constructor, CONSTRUCTOR_NAME, IS_MAP);
	  return Constructor;
	};
	var collection$5 = /*@__PURE__*/getDefaultExportFromCjs(collection$4);

	'use strict';
	var create$6 = objectCreate;
	var defineBuiltInAccessor$a = defineBuiltInAccessor$h;
	var defineBuiltIns$3 = defineBuiltIns$5;
	var bind$7 = functionBindContext;
	var anInstance$7 = anInstance$a;
	var isNullOrUndefined$8 = isNullOrUndefined$e;
	var iterate$7 = iterate$a;
	var defineIterator$1 = iteratorDefine;
	var createIterResultObject$2 = createIterResultObject$4;
	var setSpecies$3 = setSpecies$6;
	var DESCRIPTORS$r = descriptors;
	var fastKey = internalMetadataExports.fastKey;
	var InternalStateModule$8 = internalState;
	var setInternalState$8 = InternalStateModule$8.set;
	var internalStateGetterFor$1 = InternalStateModule$8.getterFor;
	var collectionStrong$2 = {
	  getConstructor: function getConstructor(wrapper, CONSTRUCTOR_NAME, IS_MAP, ADDER) {
	    var Constructor = wrapper(function (that, iterable) {
	      anInstance$7(that, Prototype);
	      setInternalState$8(that, {
	        type: CONSTRUCTOR_NAME,
	        index: create$6(null),
	        first: undefined,
	        last: undefined,
	        size: 0
	      });
	      if (!DESCRIPTORS$r) that.size = 0;
	      if (!isNullOrUndefined$8(iterable)) iterate$7(iterable, that[ADDER], {
	        that: that,
	        AS_ENTRIES: IS_MAP
	      });
	    });
	    var Prototype = Constructor.prototype;
	    var getInternalState = internalStateGetterFor$1(CONSTRUCTOR_NAME);
	    var define = function define(that, key, value) {
	      var state = getInternalState(that);
	      var entry = getEntry(that, key);
	      var previous, index;
	      // change existing entry
	      if (entry) {
	        entry.value = value;
	        // create new entry
	      } else {
	        state.last = entry = {
	          index: index = fastKey(key, true),
	          key: key,
	          value: value,
	          previous: previous = state.last,
	          next: undefined,
	          removed: false
	        };
	        if (!state.first) state.first = entry;
	        if (previous) previous.next = entry;
	        if (DESCRIPTORS$r) state.size++;else that.size++;
	        // add to index
	        if (index !== 'F') state.index[index] = entry;
	      }
	      return that;
	    };
	    var getEntry = function getEntry(that, key) {
	      var state = getInternalState(that);
	      // fast case
	      var index = fastKey(key);
	      var entry;
	      if (index !== 'F') return state.index[index];
	      // frozen object case
	      for (entry = state.first; entry; entry = entry.next) {
	        if (entry.key == key) return entry;
	      }
	    };
	    defineBuiltIns$3(Prototype, {
	      // `{ Map, Set }.prototype.clear()` methods
	      // https://tc39.es/ecma262/#sec-map.prototype.clear
	      // https://tc39.es/ecma262/#sec-set.prototype.clear
	      clear: function clear() {
	        var that = this;
	        var state = getInternalState(that);
	        var data = state.index;
	        var entry = state.first;
	        while (entry) {
	          entry.removed = true;
	          if (entry.previous) entry.previous = entry.previous.next = undefined;
	          delete data[entry.index];
	          entry = entry.next;
	        }
	        state.first = state.last = undefined;
	        if (DESCRIPTORS$r) state.size = 0;else that.size = 0;
	      },
	      // `{ Map, Set }.prototype.delete(key)` methods
	      // https://tc39.es/ecma262/#sec-map.prototype.delete
	      // https://tc39.es/ecma262/#sec-set.prototype.delete
	      'delete': function _delete(key) {
	        var that = this;
	        var state = getInternalState(that);
	        var entry = getEntry(that, key);
	        if (entry) {
	          var next = entry.next;
	          var prev = entry.previous;
	          delete state.index[entry.index];
	          entry.removed = true;
	          if (prev) prev.next = next;
	          if (next) next.previous = prev;
	          if (state.first == entry) state.first = next;
	          if (state.last == entry) state.last = prev;
	          if (DESCRIPTORS$r) state.size--;else that.size--;
	        }
	        return !!entry;
	      },
	      // `{ Map, Set }.prototype.forEach(callbackfn, thisArg = undefined)` methods
	      // https://tc39.es/ecma262/#sec-map.prototype.foreach
	      // https://tc39.es/ecma262/#sec-set.prototype.foreach
	      forEach: function forEach(callbackfn /* , that = undefined */) {
	        var state = getInternalState(this);
	        var boundFunction = bind$7(callbackfn, arguments.length > 1 ? arguments[1] : undefined);
	        var entry;
	        while (entry = entry ? entry.next : state.first) {
	          boundFunction(entry.value, entry.key, this);
	          // revert to the last existing entry
	          while (entry && entry.removed) entry = entry.previous;
	        }
	      },
	      // `{ Map, Set}.prototype.has(key)` methods
	      // https://tc39.es/ecma262/#sec-map.prototype.has
	      // https://tc39.es/ecma262/#sec-set.prototype.has
	      has: function has(key) {
	        return !!getEntry(this, key);
	      }
	    });
	    defineBuiltIns$3(Prototype, IS_MAP ? {
	      // `Map.prototype.get(key)` method
	      // https://tc39.es/ecma262/#sec-map.prototype.get
	      get: function get(key) {
	        var entry = getEntry(this, key);
	        return entry && entry.value;
	      },
	      // `Map.prototype.set(key, value)` method
	      // https://tc39.es/ecma262/#sec-map.prototype.set
	      set: function set(key, value) {
	        return define(this, key === 0 ? 0 : key, value);
	      }
	    } : {
	      // `Set.prototype.add(value)` method
	      // https://tc39.es/ecma262/#sec-set.prototype.add
	      add: function add(value) {
	        return define(this, value = value === 0 ? 0 : value, value);
	      }
	    });
	    if (DESCRIPTORS$r) defineBuiltInAccessor$a(Prototype, 'size', {
	      configurable: true,
	      get: function get() {
	        return getInternalState(this).size;
	      }
	    });
	    return Constructor;
	  },
	  setStrong: function setStrong(Constructor, CONSTRUCTOR_NAME, IS_MAP) {
	    var ITERATOR_NAME = CONSTRUCTOR_NAME + ' Iterator';
	    var getInternalCollectionState = internalStateGetterFor$1(CONSTRUCTOR_NAME);
	    var getInternalIteratorState = internalStateGetterFor$1(ITERATOR_NAME);
	    // `{ Map, Set }.prototype.{ keys, values, entries, @@iterator }()` methods
	    // https://tc39.es/ecma262/#sec-map.prototype.entries
	    // https://tc39.es/ecma262/#sec-map.prototype.keys
	    // https://tc39.es/ecma262/#sec-map.prototype.values
	    // https://tc39.es/ecma262/#sec-map.prototype-@@iterator
	    // https://tc39.es/ecma262/#sec-set.prototype.entries
	    // https://tc39.es/ecma262/#sec-set.prototype.keys
	    // https://tc39.es/ecma262/#sec-set.prototype.values
	    // https://tc39.es/ecma262/#sec-set.prototype-@@iterator
	    defineIterator$1(Constructor, CONSTRUCTOR_NAME, function (iterated, kind) {
	      setInternalState$8(this, {
	        type: ITERATOR_NAME,
	        target: iterated,
	        state: getInternalCollectionState(iterated),
	        kind: kind,
	        last: undefined
	      });
	    }, function () {
	      var state = getInternalIteratorState(this);
	      var kind = state.kind;
	      var entry = state.last;
	      // revert to the last existing entry
	      while (entry && entry.removed) entry = entry.previous;
	      // get next entry
	      if (!state.target || !(state.last = entry = entry ? entry.next : state.state.first)) {
	        // or finish the iteration
	        state.target = undefined;
	        return createIterResultObject$2(undefined, true);
	      }
	      // return step by kind
	      if (kind == 'keys') return createIterResultObject$2(entry.key, false);
	      if (kind == 'values') return createIterResultObject$2(entry.value, false);
	      return createIterResultObject$2([entry.key, entry.value], false);
	    }, IS_MAP ? 'entries' : 'values', !IS_MAP, true);

	    // `{ Map, Set }.prototype[@@species]` accessors
	    // https://tc39.es/ecma262/#sec-get-map-@@species
	    // https://tc39.es/ecma262/#sec-get-set-@@species
	    setSpecies$3(CONSTRUCTOR_NAME);
	  }
	};
	var collectionStrong$3 = /*@__PURE__*/getDefaultExportFromCjs(collectionStrong$2);

	'use strict';
	var collection$3 = collection$4;
	var collectionStrong$1 = collectionStrong$2;

	// `Map` constructor
	// https://tc39.es/ecma262/#sec-map-objects
	collection$3('Map', function (init) {
	  return function Map() {
	    return init(this, arguments.length ? arguments[0] : undefined);
	  };
	}, collectionStrong$1);

	var es_math_acosh = {};

	var log$b = Math.log;

	// `Math.log1p` method implementation
	// https://tc39.es/ecma262/#sec-math.log1p
	// eslint-disable-next-line es/no-math-log1p -- safe
	var mathLog1p = Math.log1p || function log1p(x) {
	  var n = +x;
	  return n > -1e-8 && n < 1e-8 ? n - n * n / 2 : log$b(1 + n);
	};
	var mathLog1p$1 = /*@__PURE__*/getDefaultExportFromCjs(mathLog1p);

	var $$20 = _export;
	var log1p$4 = mathLog1p;

	// eslint-disable-next-line es/no-math-acosh -- required for testing
	var $acosh = Math.acosh;
	var log$a = Math.log;
	var sqrt$5 = Math.sqrt;
	var LN2$1 = Math.LN2;
	var FORCED$p = !$acosh
	// V8 bug: https://code.google.com/p/v8/issues/detail?id=3509
	|| Math.floor($acosh(Number.MAX_VALUE)) != 710
	// Tor Browser bug: Math.acosh(Infinity) -> NaN
	|| $acosh(Infinity) != Infinity;

	// `Math.acosh` method
	// https://tc39.es/ecma262/#sec-math.acosh
	$$20({
	  target: 'Math',
	  stat: true,
	  forced: FORCED$p
	}, {
	  acosh: function acosh(x) {
	    var n = +x;
	    return n < 1 ? NaN : n > 94906265.62425156 ? log$a(n) + LN2$1 : log1p$4(n - 1 + sqrt$5(n - 1) * sqrt$5(n + 1));
	  }
	});

	var es_math_asinh = {};

	var $$1$ = _export;

	// eslint-disable-next-line es/no-math-asinh -- required for testing
	var $asinh = Math.asinh;
	var log$9 = Math.log;
	var sqrt$4 = Math.sqrt;
	function asinh$3(x) {
	  var n = +x;
	  return !isFinite(n) || n == 0 ? n : n < 0 ? -asinh$3(-n) : log$9(n + sqrt$4(n * n + 1));
	}
	var FORCED$o = !($asinh && 1 / $asinh(0) > 0);

	// `Math.asinh` method
	// https://tc39.es/ecma262/#sec-math.asinh
	// Tor Browser bug: Math.asinh(0) -> -0
	$$1$({
	  target: 'Math',
	  stat: true,
	  forced: FORCED$o
	}, {
	  asinh: asinh$3
	});

	var es_math_atanh = {};

	var $$1_ = _export;

	// eslint-disable-next-line es/no-math-atanh -- required for testing
	var $atanh = Math.atanh;
	var log$8 = Math.log;
	var FORCED$n = !($atanh && 1 / $atanh(-0) < 0);

	// `Math.atanh` method
	// https://tc39.es/ecma262/#sec-math.atanh
	// Tor Browser bug: Math.atanh(-0) -> 0
	$$1_({
	  target: 'Math',
	  stat: true,
	  forced: FORCED$n
	}, {
	  atanh: function atanh(x) {
	    var n = +x;
	    return n == 0 ? n : log$8((1 + n) / (1 - n)) / 2;
	  }
	});

	var es_math_cbrt = {};

	// `Math.sign` method implementation
	// https://tc39.es/ecma262/#sec-math.sign
	// eslint-disable-next-line es/no-math-sign -- safe
	var mathSign = Math.sign || function sign(x) {
	  var n = +x;
	  // eslint-disable-next-line no-self-compare -- NaN check
	  return n == 0 || n != n ? n : n < 0 ? -1 : 1;
	};
	var mathSign$1 = /*@__PURE__*/getDefaultExportFromCjs(mathSign);

	var $$1Z = _export;
	var sign$6 = mathSign;
	var abs$9 = Math.abs;
	var pow$8 = Math.pow;

	// `Math.cbrt` method
	// https://tc39.es/ecma262/#sec-math.cbrt
	$$1Z({
	  target: 'Math',
	  stat: true
	}, {
	  cbrt: function cbrt(x) {
	    var n = +x;
	    return sign$6(n) * pow$8(abs$9(n), 1 / 3);
	  }
	});

	var es_math_clz32 = {};

	var $$1Y = _export;
	var floor$a = Math.floor;
	var log$7 = Math.log;
	var LOG2E = Math.LOG2E;

	// `Math.clz32` method
	// https://tc39.es/ecma262/#sec-math.clz32
	$$1Y({
	  target: 'Math',
	  stat: true
	}, {
	  clz32: function clz32(x) {
	    var n = x >>> 0;
	    return n ? 31 - floor$a(log$7(n + 0.5) * LOG2E) : 32;
	  }
	});

	var es_math_cosh = {};

	// eslint-disable-next-line es/no-math-expm1 -- safe
	var $expm1 = Math.expm1;
	var exp$5 = Math.exp;

	// `Math.expm1` method implementation
	// https://tc39.es/ecma262/#sec-math.expm1
	var mathExpm1 = !$expm1
	// Old FF bug
	|| $expm1(10) > 22025.465794806719 || $expm1(10) < 22025.4657948067165168
	// Tor Browser bug
	|| $expm1(-2e-17) != -2e-17 ? function expm1(x) {
	  var n = +x;
	  return n == 0 ? n : n > -1e-6 && n < 1e-6 ? n + n * n / 2 : exp$5(n) - 1;
	} : $expm1;
	var mathExpm1$1 = /*@__PURE__*/getDefaultExportFromCjs(mathExpm1);

	var $$1X = _export;
	var expm1$6 = mathExpm1;

	// eslint-disable-next-line es/no-math-cosh -- required for testing
	var $cosh = Math.cosh;
	var abs$8 = Math.abs;
	var E$1 = Math.E;
	var FORCED$m = !$cosh || $cosh(710) === Infinity;

	// `Math.cosh` method
	// https://tc39.es/ecma262/#sec-math.cosh
	$$1X({
	  target: 'Math',
	  stat: true,
	  forced: FORCED$m
	}, {
	  cosh: function cosh(x) {
	    var t = expm1$6(abs$8(x) - 1) + 1;
	    return (t + 1 / (t * E$1 * E$1)) * (E$1 / 2);
	  }
	});

	var es_math_expm1 = {};

	var $$1W = _export;
	var expm1$5 = mathExpm1;

	// `Math.expm1` method
	// https://tc39.es/ecma262/#sec-math.expm1
	// eslint-disable-next-line es/no-math-expm1 -- required for testing
	$$1W({
	  target: 'Math',
	  stat: true,
	  forced: expm1$5 != Math.expm1
	}, {
	  expm1: expm1$5
	});

	var es_math_fround = {};

	var sign$5 = mathSign;
	var abs$7 = Math.abs;
	var pow$7 = Math.pow;
	var EPSILON = pow$7(2, -52);
	var EPSILON32 = pow$7(2, -23);
	var MAX32 = pow$7(2, 127) * (2 - EPSILON32);
	var MIN32 = pow$7(2, -126);
	var roundTiesToEven = function roundTiesToEven(n) {
	  return n + 1 / EPSILON - 1 / EPSILON;
	};

	// `Math.fround` method implementation
	// https://tc39.es/ecma262/#sec-math.fround
	// eslint-disable-next-line es/no-math-fround -- safe
	var mathFround = Math.fround || function fround(x) {
	  var n = +x;
	  var $abs = abs$7(n);
	  var $sign = sign$5(n);
	  var a, result;
	  if ($abs < MIN32) return $sign * roundTiesToEven($abs / MIN32 / EPSILON32) * MIN32 * EPSILON32;
	  a = (1 + EPSILON32 / EPSILON) * $abs;
	  result = a - (a - $abs);
	  // eslint-disable-next-line no-self-compare -- NaN check
	  if (result > MAX32 || result != result) return $sign * Infinity;
	  return $sign * result;
	};
	var mathFround$1 = /*@__PURE__*/getDefaultExportFromCjs(mathFround);

	var $$1V = _export;
	var fround = mathFround;

	// `Math.fround` method
	// https://tc39.es/ecma262/#sec-math.fround
	$$1V({
	  target: 'Math',
	  stat: true
	}, {
	  fround: fround
	});

	var es_math_hypot = {};

	var $$1U = _export;

	// eslint-disable-next-line es/no-math-hypot -- required for testing
	var $hypot = Math.hypot;
	var abs$6 = Math.abs;
	var sqrt$3 = Math.sqrt;

	// Chrome 77 bug
	// https://bugs.chromium.org/p/v8/issues/detail?id=9546
	var FORCED$l = !!$hypot && $hypot(Infinity, NaN) !== Infinity;

	// `Math.hypot` method
	// https://tc39.es/ecma262/#sec-math.hypot
	$$1U({
	  target: 'Math',
	  stat: true,
	  arity: 2,
	  forced: FORCED$l
	}, {
	  // eslint-disable-next-line no-unused-vars -- required for `.length`
	  hypot: function hypot(value1, value2) {
	    var sum = 0;
	    var i = 0;
	    var aLen = arguments.length;
	    var larg = 0;
	    var arg, div;
	    while (i < aLen) {
	      arg = abs$6(arguments[i++]);
	      if (larg < arg) {
	        div = larg / arg;
	        sum = sum * div * div + 1;
	        larg = arg;
	      } else if (arg > 0) {
	        div = arg / larg;
	        sum += div * div;
	      } else sum += arg;
	    }
	    return larg === Infinity ? Infinity : larg * sqrt$3(sum);
	  }
	});

	var es_math_imul = {};

	var $$1T = _export;
	var fails$Q = fails$1m;

	// eslint-disable-next-line es/no-math-imul -- required for testing
	var $imul = Math.imul;
	var FORCED$k = fails$Q(function () {
	  return $imul(0xFFFFFFFF, 5) != -5 || $imul.length != 2;
	});

	// `Math.imul` method
	// https://tc39.es/ecma262/#sec-math.imul
	// some WebKit versions fails with big numbers, some has wrong arity
	$$1T({
	  target: 'Math',
	  stat: true,
	  forced: FORCED$k
	}, {
	  imul: function imul(x, y) {
	    var UINT16 = 0xFFFF;
	    var xn = +x;
	    var yn = +y;
	    var xl = UINT16 & xn;
	    var yl = UINT16 & yn;
	    return 0 | xl * yl + ((UINT16 & xn >>> 16) * yl + xl * (UINT16 & yn >>> 16) << 16 >>> 0);
	  }
	});

	var es_math_log10 = {};

	var log$6 = Math.log;
	var LOG10E = Math.LOG10E;

	// eslint-disable-next-line es/no-math-log10 -- safe
	var mathLog10 = Math.log10 || function log10(x) {
	  return log$6(x) * LOG10E;
	};
	var mathLog10$1 = /*@__PURE__*/getDefaultExportFromCjs(mathLog10);

	var $$1S = _export;
	var log10$1 = mathLog10;

	// `Math.log10` method
	// https://tc39.es/ecma262/#sec-math.log10
	$$1S({
	  target: 'Math',
	  stat: true
	}, {
	  log10: log10$1
	});

	var es_math_log1p = {};

	var $$1R = _export;
	var log1p$3 = mathLog1p;

	// `Math.log1p` method
	// https://tc39.es/ecma262/#sec-math.log1p
	$$1R({
	  target: 'Math',
	  stat: true
	}, {
	  log1p: log1p$3
	});

	var es_math_log2 = {};

	var $$1Q = _export;
	var log$5 = Math.log;
	var LN2 = Math.LN2;

	// `Math.log2` method
	// https://tc39.es/ecma262/#sec-math.log2
	$$1Q({
	  target: 'Math',
	  stat: true
	}, {
	  log2: function log2(x) {
	    return log$5(x) / LN2;
	  }
	});

	var es_math_sign = {};

	var $$1P = _export;
	var sign$4 = mathSign;

	// `Math.sign` method
	// https://tc39.es/ecma262/#sec-math.sign
	$$1P({
	  target: 'Math',
	  stat: true
	}, {
	  sign: sign$4
	});

	var es_math_sinh = {};

	var $$1O = _export;
	var fails$P = fails$1m;
	var expm1$4 = mathExpm1;
	var abs$5 = Math.abs;
	var exp$4 = Math.exp;
	var E = Math.E;
	var FORCED$j = fails$P(function () {
	  // eslint-disable-next-line es/no-math-sinh -- required for testing
	  return Math.sinh(-2e-17) != -2e-17;
	});

	// `Math.sinh` method
	// https://tc39.es/ecma262/#sec-math.sinh
	// V8 near Chromium 38 has a problem with very small numbers
	$$1O({
	  target: 'Math',
	  stat: true,
	  forced: FORCED$j
	}, {
	  sinh: function sinh(x) {
	    var n = +x;
	    return abs$5(n) < 1 ? (expm1$4(n) - expm1$4(-n)) / 2 : (exp$4(n - 1) - exp$4(-n - 1)) * (E / 2);
	  }
	});

	var es_math_tanh = {};

	var $$1N = _export;
	var expm1$3 = mathExpm1;
	var exp$3 = Math.exp;

	// `Math.tanh` method
	// https://tc39.es/ecma262/#sec-math.tanh
	$$1N({
	  target: 'Math',
	  stat: true
	}, {
	  tanh: function tanh(x) {
	    var n = +x;
	    var a = expm1$3(n);
	    var b = expm1$3(-n);
	    return a == Infinity ? 1 : b == Infinity ? -1 : (a - b) / (exp$3(n) + exp$3(-n));
	  }
	});

	var es_math_toStringTag = {};

	var setToStringTag$5 = setToStringTag$d;

	// Math[@@toStringTag] property
	// https://tc39.es/ecma262/#sec-math-@@tostringtag
	setToStringTag$5(Math, 'Math', true);

	var es_math_trunc = {};

	var $$1M = _export;
	var trunc = mathTrunc;

	// `Math.trunc` method
	// https://tc39.es/ecma262/#sec-math.trunc
	$$1M({
	  target: 'Math',
	  stat: true
	}, {
	  trunc: trunc
	});

	var es_number_constructor = {};

	var uncurryThis$J = functionUncurryThis;

	// `thisNumberValue` abstract operation
	// https://tc39.es/ecma262/#sec-thisnumbervalue
	var thisNumberValue$5 = uncurryThis$J(1.0.valueOf);
	var thisNumberValue$6 = /*@__PURE__*/getDefaultExportFromCjs(thisNumberValue$5);

	// a string of all valid unicode whitespaces
	var whitespaces$5 = "\t\n\x0B\f\r \xA0\u1680\u2000\u2001\u2002" + "\u2003\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028\u2029\uFEFF";
	var whitespaces$6 = /*@__PURE__*/getDefaultExportFromCjs(whitespaces$5);

	var uncurryThis$I = functionUncurryThis;
	var requireObjectCoercible$e = requireObjectCoercible$j;
	var toString$o = toString$x;
	var whitespaces$4 = whitespaces$5;
	var replace$9 = uncurryThis$I(''.replace);
	var ltrim = RegExp('^[' + whitespaces$4 + ']+');
	var rtrim = RegExp('(^|[^' + whitespaces$4 + '])[' + whitespaces$4 + ']+$');

	// `String.prototype.{ trim, trimStart, trimEnd, trimLeft, trimRight }` methods implementation
	var createMethod$2 = function createMethod(TYPE) {
	  return function ($this) {
	    var string = toString$o(requireObjectCoercible$e($this));
	    if (TYPE & 1) string = replace$9(string, ltrim, '');
	    if (TYPE & 2) string = replace$9(string, rtrim, '$1');
	    return string;
	  };
	};
	var stringTrim = {
	  // `String.prototype.{ trimLeft, trimStart }` methods
	  // https://tc39.es/ecma262/#sec-string.prototype.trimstart
	  start: createMethod$2(1),
	  // `String.prototype.{ trimRight, trimEnd }` methods
	  // https://tc39.es/ecma262/#sec-string.prototype.trimend
	  end: createMethod$2(2),
	  // `String.prototype.trim` method
	  // https://tc39.es/ecma262/#sec-string.prototype.trim
	  trim: createMethod$2(3)
	};
	var stringTrim$1 = /*@__PURE__*/getDefaultExportFromCjs(stringTrim);

	'use strict';
	var $$1L = _export;
	var IS_PURE$e = isPure;
	var DESCRIPTORS$q = descriptors;
	var global$E = global$Z;
	var path = path$2;
	var uncurryThis$H = functionUncurryThis;
	var isForced$2 = isForced_1;
	var hasOwn$d = hasOwnProperty_1;
	var inheritIfRequired$3 = inheritIfRequired$6;
	var isPrototypeOf$3 = objectIsPrototypeOf;
	var isSymbol$2 = isSymbol$7;
	var toPrimitive$1 = toPrimitive$4;
	var fails$O = fails$1m;
	var getOwnPropertyNames$3 = objectGetOwnPropertyNames.f;
	var getOwnPropertyDescriptor$7 = objectGetOwnPropertyDescriptor.f;
	var defineProperty$5 = objectDefineProperty.f;
	var thisNumberValue$4 = thisNumberValue$5;
	var trim$2 = stringTrim.trim;
	var NUMBER = 'Number';
	var NativeNumber = global$E[NUMBER];
	var PureNumberNamespace = path[NUMBER];
	var NumberPrototype = NativeNumber.prototype;
	var TypeError$5 = global$E.TypeError;
	var stringSlice$e = uncurryThis$H(''.slice);
	var charCodeAt$3 = uncurryThis$H(''.charCodeAt);

	// `ToNumeric` abstract operation
	// https://tc39.es/ecma262/#sec-tonumeric
	var toNumeric = function toNumeric(value) {
	  var primValue = toPrimitive$1(value, 'number');
	  return typeof primValue == 'bigint' ? primValue : toNumber(primValue);
	};

	// `ToNumber` abstract operation
	// https://tc39.es/ecma262/#sec-tonumber
	var toNumber = function toNumber(argument) {
	  var it = toPrimitive$1(argument, 'number');
	  var first, third, radix, maxCode, digits, length, index, code;
	  if (isSymbol$2(it)) throw TypeError$5('Cannot convert a Symbol value to a number');
	  if (typeof it == 'string' && it.length > 2) {
	    it = trim$2(it);
	    first = charCodeAt$3(it, 0);
	    if (first === 43 || first === 45) {
	      third = charCodeAt$3(it, 2);
	      if (third === 88 || third === 120) return NaN; // Number('+0x1') should be NaN, old V8 fix
	    } else if (first === 48) {
	      switch (charCodeAt$3(it, 1)) {
	        case 66:
	        case 98:
	          radix = 2;
	          maxCode = 49;
	          break;
	        // fast equal of /^0b[01]+$/i
	        case 79:
	        case 111:
	          radix = 8;
	          maxCode = 55;
	          break;
	        // fast equal of /^0o[0-7]+$/i
	        default:
	          return +it;
	      }
	      digits = stringSlice$e(it, 2);
	      length = digits.length;
	      for (index = 0; index < length; index++) {
	        code = charCodeAt$3(digits, index);
	        // parseInt parses a string to a first unavailable symbol
	        // but ToNumber should return NaN if a string contains unavailable symbols
	        if (code < 48 || code > maxCode) return NaN;
	      }
	      return parseInt(digits, radix);
	    }
	  }
	  return +it;
	};
	var FORCED$i = isForced$2(NUMBER, !NativeNumber(' 0o1') || !NativeNumber('0b1') || NativeNumber('+0x1'));
	var calledWithNew = function calledWithNew(dummy) {
	  // includes check on 1..constructor(foo) case
	  return isPrototypeOf$3(NumberPrototype, dummy) && fails$O(function () {
	    thisNumberValue$4(dummy);
	  });
	};

	// `Number` constructor
	// https://tc39.es/ecma262/#sec-number-constructor
	var NumberWrapper = function Number(value) {
	  var n = arguments.length < 1 ? 0 : NativeNumber(toNumeric(value));
	  return calledWithNew(this) ? inheritIfRequired$3(Object(n), this, NumberWrapper) : n;
	};
	NumberWrapper.prototype = NumberPrototype;
	if (FORCED$i && !IS_PURE$e) NumberPrototype.constructor = NumberWrapper;
	$$1L({
	  global: true,
	  constructor: true,
	  wrap: true,
	  forced: FORCED$i
	}, {
	  Number: NumberWrapper
	});

	// Use `internal/copy-constructor-properties` helper in `core-js@4`
	var copyConstructorProperties = function copyConstructorProperties(target, source) {
	  for (var keys = DESCRIPTORS$q ? getOwnPropertyNames$3(source) : (
	    // ES3:
	    'MAX_VALUE,MIN_VALUE,NaN,NEGATIVE_INFINITY,POSITIVE_INFINITY,' +
	    // ES2015 (in case, if modules with ES2015 Number statics required before):
	    'EPSILON,MAX_SAFE_INTEGER,MIN_SAFE_INTEGER,isFinite,isInteger,isNaN,isSafeInteger,parseFloat,parseInt,' +
	    // ESNext
	    'fromString,range').split(','), j = 0, key; keys.length > j; j++) {
	    if (hasOwn$d(source, key = keys[j]) && !hasOwn$d(target, key)) {
	      defineProperty$5(target, key, getOwnPropertyDescriptor$7(source, key));
	    }
	  }
	};
	if (IS_PURE$e && PureNumberNamespace) copyConstructorProperties(path[NUMBER], PureNumberNamespace);
	if (FORCED$i || IS_PURE$e) copyConstructorProperties(path[NUMBER], NativeNumber);

	var es_number_epsilon = {};

	var $$1K = _export;

	// `Number.EPSILON` constant
	// https://tc39.es/ecma262/#sec-number.epsilon
	$$1K({
	  target: 'Number',
	  stat: true,
	  nonConfigurable: true,
	  nonWritable: true
	}, {
	  EPSILON: Math.pow(2, -52)
	});

	var es_number_isFinite = {};

	var global$D = global$Z;
	var globalIsFinite = global$D.isFinite;

	// `Number.isFinite` method
	// https://tc39.es/ecma262/#sec-number.isfinite
	// eslint-disable-next-line es/no-number-isfinite -- safe
	var numberIsFinite$1 = Number.isFinite || function isFinite(it) {
	  return typeof it == 'number' && globalIsFinite(it);
	};
	var numberIsFinite$2 = /*@__PURE__*/getDefaultExportFromCjs(numberIsFinite$1);

	var $$1J = _export;
	var numberIsFinite = numberIsFinite$1;

	// `Number.isFinite` method
	// https://tc39.es/ecma262/#sec-number.isfinite
	$$1J({
	  target: 'Number',
	  stat: true
	}, {
	  isFinite: numberIsFinite
	});

	var es_number_isInteger = {};

	var isObject$h = isObject$z;
	var floor$9 = Math.floor;

	// `IsIntegralNumber` abstract operation
	// https://tc39.es/ecma262/#sec-isintegralnumber
	// eslint-disable-next-line es/no-number-isinteger -- safe
	var isIntegralNumber$3 = Number.isInteger || function isInteger(it) {
	  return !isObject$h(it) && isFinite(it) && floor$9(it) === it;
	};
	var isIntegralNumber$4 = /*@__PURE__*/getDefaultExportFromCjs(isIntegralNumber$3);

	var $$1I = _export;
	var isIntegralNumber$2 = isIntegralNumber$3;

	// `Number.isInteger` method
	// https://tc39.es/ecma262/#sec-number.isinteger
	$$1I({
	  target: 'Number',
	  stat: true
	}, {
	  isInteger: isIntegralNumber$2
	});

	var es_number_isNan = {};

	var $$1H = _export;

	// `Number.isNaN` method
	// https://tc39.es/ecma262/#sec-number.isnan
	$$1H({
	  target: 'Number',
	  stat: true
	}, {
	  isNaN: function isNaN(number) {
	    // eslint-disable-next-line no-self-compare -- NaN check
	    return number != number;
	  }
	});

	var es_number_isSafeInteger = {};

	var $$1G = _export;
	var isIntegralNumber$1 = isIntegralNumber$3;
	var abs$4 = Math.abs;

	// `Number.isSafeInteger` method
	// https://tc39.es/ecma262/#sec-number.issafeinteger
	$$1G({
	  target: 'Number',
	  stat: true
	}, {
	  isSafeInteger: function isSafeInteger(number) {
	    return isIntegralNumber$1(number) && abs$4(number) <= 0x1FFFFFFFFFFFFF;
	  }
	});

	var es_number_maxSafeInteger = {};

	var $$1F = _export;

	// `Number.MAX_SAFE_INTEGER` constant
	// https://tc39.es/ecma262/#sec-number.max_safe_integer
	$$1F({
	  target: 'Number',
	  stat: true,
	  nonConfigurable: true,
	  nonWritable: true
	}, {
	  MAX_SAFE_INTEGER: 0x1FFFFFFFFFFFFF
	});

	var es_number_minSafeInteger = {};

	var $$1E = _export;

	// `Number.MIN_SAFE_INTEGER` constant
	// https://tc39.es/ecma262/#sec-number.min_safe_integer
	$$1E({
	  target: 'Number',
	  stat: true,
	  nonConfigurable: true,
	  nonWritable: true
	}, {
	  MIN_SAFE_INTEGER: -0x1FFFFFFFFFFFFF
	});

	var es_number_parseFloat = {};

	var global$C = global$Z;
	var fails$N = fails$1m;
	var uncurryThis$G = functionUncurryThis;
	var toString$n = toString$x;
	var trim$1 = stringTrim.trim;
	var whitespaces$3 = whitespaces$5;
	var charAt$c = uncurryThis$G(''.charAt);
	var $parseFloat$1 = global$C.parseFloat;
	var _Symbol$1 = global$C.Symbol;
	var ITERATOR$5 = _Symbol$1 && _Symbol$1.iterator;
	var FORCED$h = 1 / $parseFloat$1(whitespaces$3 + '-0') !== -Infinity
	// MS Edge 18- broken with boxed symbols
	|| ITERATOR$5 && !fails$N(function () {
	  $parseFloat$1(Object(ITERATOR$5));
	});

	// `parseFloat` method
	// https://tc39.es/ecma262/#sec-parsefloat-string
	var numberParseFloat = FORCED$h ? function parseFloat(string) {
	  var trimmedString = trim$1(toString$n(string));
	  var result = $parseFloat$1(trimmedString);
	  return result === 0 && charAt$c(trimmedString, 0) == '-' ? -0 : result;
	} : $parseFloat$1;
	var numberParseFloat$1 = /*@__PURE__*/getDefaultExportFromCjs(numberParseFloat);

	var $$1D = _export;
	var parseFloat$1 = numberParseFloat;

	// `Number.parseFloat` method
	// https://tc39.es/ecma262/#sec-number.parseFloat
	// eslint-disable-next-line es/no-number-parsefloat -- required for testing
	$$1D({
	  target: 'Number',
	  stat: true,
	  forced: Number.parseFloat != parseFloat$1
	}, {
	  parseFloat: parseFloat$1
	});

	var es_number_parseInt = {};

	var global$B = global$Z;
	var fails$M = fails$1m;
	var uncurryThis$F = functionUncurryThis;
	var toString$m = toString$x;
	var trim = stringTrim.trim;
	var whitespaces$2 = whitespaces$5;
	var $parseInt$1 = global$B.parseInt;
	var _Symbol = global$B.Symbol;
	var ITERATOR$4 = _Symbol && _Symbol.iterator;
	var hex = /^[+-]?0x/i;
	var exec$7 = uncurryThis$F(hex.exec);
	var FORCED$g = $parseInt$1(whitespaces$2 + '08') !== 8 || $parseInt$1(whitespaces$2 + '0x16') !== 22
	// MS Edge 18- broken with boxed symbols
	|| ITERATOR$4 && !fails$M(function () {
	  $parseInt$1(Object(ITERATOR$4));
	});

	// `parseInt` method
	// https://tc39.es/ecma262/#sec-parseint-string-radix
	var numberParseInt = FORCED$g ? function parseInt(string, radix) {
	  var S = trim(toString$m(string));
	  return $parseInt$1(S, radix >>> 0 || (exec$7(hex, S) ? 16 : 10));
	} : $parseInt$1;
	var numberParseInt$1 = /*@__PURE__*/getDefaultExportFromCjs(numberParseInt);

	var $$1C = _export;
	var parseInt$2 = numberParseInt;

	// `Number.parseInt` method
	// https://tc39.es/ecma262/#sec-number.parseint
	// eslint-disable-next-line es/no-number-parseint -- required for testing
	$$1C({
	  target: 'Number',
	  stat: true,
	  forced: Number.parseInt != parseInt$2
	}, {
	  parseInt: parseInt$2
	});

	var es_number_toExponential = {};

	'use strict';
	var $$1B = _export;
	var uncurryThis$E = functionUncurryThis;
	var toIntegerOrInfinity$8 = toIntegerOrInfinity$l;
	var thisNumberValue$3 = thisNumberValue$5;
	var $repeat$1 = stringRepeat;
	var log10 = mathLog10;
	var fails$L = fails$1m;
	var $RangeError$5 = RangeError;
	var $String$1 = String;
	var $isFinite = isFinite;
	var abs$3 = Math.abs;
	var floor$8 = Math.floor;
	var pow$6 = Math.pow;
	var round$5 = Math.round;
	var nativeToExponential = uncurryThis$E(1.0.toExponential);
	var repeat$3 = uncurryThis$E($repeat$1);
	var stringSlice$d = uncurryThis$E(''.slice);

	// Edge 17-
	var ROUNDS_PROPERLY = nativeToExponential(-6.9e-11, 4) === '-6.9000e-11'
	// IE11- && Edge 14-
	&& nativeToExponential(1.255, 2) === '1.25e+0'
	// FF86-, V8 ~ Chrome 49-50
	&& nativeToExponential(12345, 3) === '1.235e+4'
	// FF86-, V8 ~ Chrome 49-50
	&& nativeToExponential(25, 0) === '3e+1';

	// IE8-
	var throwsOnInfinityFraction = function throwsOnInfinityFraction() {
	  return fails$L(function () {
	    nativeToExponential(1, Infinity);
	  }) && fails$L(function () {
	    nativeToExponential(1, -Infinity);
	  });
	};

	// Safari <11 && FF <50
	var properNonFiniteThisCheck = function properNonFiniteThisCheck() {
	  return !fails$L(function () {
	    nativeToExponential(Infinity, Infinity);
	    nativeToExponential(NaN, Infinity);
	  });
	};
	var FORCED$f = !ROUNDS_PROPERLY || !throwsOnInfinityFraction() || !properNonFiniteThisCheck();

	// `Number.prototype.toExponential` method
	// https://tc39.es/ecma262/#sec-number.prototype.toexponential
	$$1B({
	  target: 'Number',
	  proto: true,
	  forced: FORCED$f
	}, {
	  toExponential: function toExponential(fractionDigits) {
	    var x = thisNumberValue$3(this);
	    if (fractionDigits === undefined) return nativeToExponential(x);
	    var f = toIntegerOrInfinity$8(fractionDigits);
	    if (!$isFinite(x)) return String(x);
	    // TODO: ES2018 increased the maximum number of fraction digits to 100, need to improve the implementation
	    if (f < 0 || f > 20) throw $RangeError$5('Incorrect fraction digits');
	    if (ROUNDS_PROPERLY) return nativeToExponential(x, f);
	    var s = '';
	    var m = '';
	    var e = 0;
	    var c = '';
	    var d = '';
	    if (x < 0) {
	      s = '-';
	      x = -x;
	    }
	    if (x === 0) {
	      e = 0;
	      m = repeat$3('0', f + 1);
	    } else {
	      // this block is based on https://gist.github.com/SheetJSDev/1100ad56b9f856c95299ed0e068eea08
	      // TODO: improve accuracy with big fraction digits
	      var l = log10(x);
	      e = floor$8(l);
	      var n = 0;
	      var w = pow$6(10, e - f);
	      n = round$5(x / w);
	      if (2 * x >= (2 * n + 1) * w) {
	        n += 1;
	      }
	      if (n >= pow$6(10, f + 1)) {
	        n /= 10;
	        e += 1;
	      }
	      m = $String$1(n);
	    }
	    if (f !== 0) {
	      m = stringSlice$d(m, 0, 1) + '.' + stringSlice$d(m, 1);
	    }
	    if (e === 0) {
	      c = '+';
	      d = '0';
	    } else {
	      c = e > 0 ? '+' : '-';
	      d = $String$1(abs$3(e));
	    }
	    m += 'e' + c + d;
	    return s + m;
	  }
	});

	var es_number_toFixed = {};

	'use strict';
	var $$1A = _export;
	var uncurryThis$D = functionUncurryThis;
	var toIntegerOrInfinity$7 = toIntegerOrInfinity$l;
	var thisNumberValue$2 = thisNumberValue$5;
	var $repeat = stringRepeat;
	var fails$K = fails$1m;
	var $RangeError$4 = RangeError;
	var $String = String;
	var floor$7 = Math.floor;
	var repeat$2 = uncurryThis$D($repeat);
	var stringSlice$c = uncurryThis$D(''.slice);
	var nativeToFixed = uncurryThis$D(1.0.toFixed);
	var pow$5 = function pow(x, n, acc) {
	  return n === 0 ? acc : n % 2 === 1 ? pow(x, n - 1, acc * x) : pow(x * x, n / 2, acc);
	};
	var log$4 = function log(x) {
	  var n = 0;
	  var x2 = x;
	  while (x2 >= 4096) {
	    n += 12;
	    x2 /= 4096;
	  }
	  while (x2 >= 2) {
	    n += 1;
	    x2 /= 2;
	  }
	  return n;
	};
	var multiply$4 = function multiply(data, n, c) {
	  var index = -1;
	  var c2 = c;
	  while (++index < 6) {
	    c2 += n * data[index];
	    data[index] = c2 % 1e7;
	    c2 = floor$7(c2 / 1e7);
	  }
	};
	var divide = function divide(data, n) {
	  var index = 6;
	  var c = 0;
	  while (--index >= 0) {
	    c += data[index];
	    data[index] = floor$7(c / n);
	    c = c % n * 1e7;
	  }
	};
	var dataToString = function dataToString(data) {
	  var index = 6;
	  var s = '';
	  while (--index >= 0) {
	    if (s !== '' || index === 0 || data[index] !== 0) {
	      var t = $String(data[index]);
	      s = s === '' ? t : s + repeat$2('0', 7 - t.length) + t;
	    }
	  }
	  return s;
	};
	var FORCED$e = fails$K(function () {
	  return nativeToFixed(0.00008, 3) !== '0.000' || nativeToFixed(0.9, 0) !== '1' || nativeToFixed(1.255, 2) !== '1.25' || nativeToFixed(1000000000000000128.0, 0) !== '1000000000000000128';
	}) || !fails$K(function () {
	  // V8 ~ Android 4.3-
	  nativeToFixed({});
	});

	// `Number.prototype.toFixed` method
	// https://tc39.es/ecma262/#sec-number.prototype.tofixed
	$$1A({
	  target: 'Number',
	  proto: true,
	  forced: FORCED$e
	}, {
	  toFixed: function toFixed(fractionDigits) {
	    var number = thisNumberValue$2(this);
	    var fractDigits = toIntegerOrInfinity$7(fractionDigits);
	    var data = [0, 0, 0, 0, 0, 0];
	    var sign = '';
	    var result = '0';
	    var e, z, j, k;

	    // TODO: ES2018 increased the maximum number of fraction digits to 100, need to improve the implementation
	    if (fractDigits < 0 || fractDigits > 20) throw $RangeError$4('Incorrect fraction digits');
	    // eslint-disable-next-line no-self-compare -- NaN check
	    if (number != number) return 'NaN';
	    if (number <= -1e21 || number >= 1e21) return $String(number);
	    if (number < 0) {
	      sign = '-';
	      number = -number;
	    }
	    if (number > 1e-21) {
	      e = log$4(number * pow$5(2, 69, 1)) - 69;
	      z = e < 0 ? number * pow$5(2, -e, 1) : number / pow$5(2, e, 1);
	      z *= 0x10000000000000;
	      e = 52 - e;
	      if (e > 0) {
	        multiply$4(data, 0, z);
	        j = fractDigits;
	        while (j >= 7) {
	          multiply$4(data, 1e7, 0);
	          j -= 7;
	        }
	        multiply$4(data, pow$5(10, j, 1), 0);
	        j = e - 1;
	        while (j >= 23) {
	          divide(data, 1 << 23);
	          j -= 23;
	        }
	        divide(data, 1 << j);
	        multiply$4(data, 1, 1);
	        divide(data, 2);
	        result = dataToString(data);
	      } else {
	        multiply$4(data, 0, z);
	        multiply$4(data, 1 << -e, 0);
	        result = dataToString(data) + repeat$2('0', fractDigits);
	      }
	    }
	    if (fractDigits > 0) {
	      k = result.length;
	      result = sign + (k <= fractDigits ? '0.' + repeat$2('0', fractDigits - k) + result : stringSlice$c(result, 0, k - fractDigits) + '.' + stringSlice$c(result, k - fractDigits));
	    } else {
	      result = sign + result;
	    }
	    return result;
	  }
	});

	var es_number_toPrecision = {};

	'use strict';
	var $$1z = _export;
	var uncurryThis$C = functionUncurryThis;
	var fails$J = fails$1m;
	var thisNumberValue$1 = thisNumberValue$5;
	var nativeToPrecision = uncurryThis$C(1.0.toPrecision);
	var FORCED$d = fails$J(function () {
	  // IE7-
	  return nativeToPrecision(1, undefined) !== '1';
	}) || !fails$J(function () {
	  // V8 ~ Android 4.3-
	  nativeToPrecision({});
	});

	// `Number.prototype.toPrecision` method
	// https://tc39.es/ecma262/#sec-number.prototype.toprecision
	$$1z({
	  target: 'Number',
	  proto: true,
	  forced: FORCED$d
	}, {
	  toPrecision: function toPrecision(precision) {
	    return precision === undefined ? nativeToPrecision(thisNumberValue$1(this)) : nativeToPrecision(thisNumberValue$1(this), precision);
	  }
	});

	var es_object_assign = {};

	'use strict';
	var DESCRIPTORS$p = descriptors;
	var uncurryThis$B = functionUncurryThis;
	var call$q = functionCall;
	var fails$I = fails$1m;
	var objectKeys$2 = objectKeys$5;
	var getOwnPropertySymbolsModule = objectGetOwnPropertySymbols;
	var propertyIsEnumerableModule = objectPropertyIsEnumerable;
	var toObject$a = toObject$t;
	var IndexedObject = indexedObject;

	// eslint-disable-next-line es/no-object-assign -- safe
	var $assign = Object.assign;
	// eslint-disable-next-line es/no-object-defineproperty -- required for testing
	var defineProperty$4 = Object.defineProperty;
	var concat$4 = uncurryThis$B([].concat);

	// `Object.assign` method
	// https://tc39.es/ecma262/#sec-object.assign
	var objectAssign = !$assign || fails$I(function () {
	  // should have correct order of operations (Edge bug)
	  if (DESCRIPTORS$p && $assign({
	    b: 1
	  }, $assign(defineProperty$4({}, 'a', {
	    enumerable: true,
	    get: function get() {
	      defineProperty$4(this, 'b', {
	        value: 3,
	        enumerable: false
	      });
	    }
	  }), {
	    b: 2
	  })).b !== 1) return true;
	  // should work with symbols and should have deterministic property order (V8 bug)
	  var A = {};
	  var B = {};
	  // eslint-disable-next-line es/no-symbol -- safe
	  var symbol = Symbol();
	  var alphabet = 'abcdefghijklmnopqrst';
	  A[symbol] = 7;
	  alphabet.split('').forEach(function (chr) {
	    B[chr] = chr;
	  });
	  return $assign({}, A)[symbol] != 7 || objectKeys$2($assign({}, B)).join('') != alphabet;
	}) ? function assign(target, source) {
	  // eslint-disable-line no-unused-vars -- required for `.length`
	  var T = toObject$a(target);
	  var argumentsLength = arguments.length;
	  var index = 1;
	  var getOwnPropertySymbols = getOwnPropertySymbolsModule.f;
	  var propertyIsEnumerable = propertyIsEnumerableModule.f;
	  while (argumentsLength > index) {
	    var S = IndexedObject(arguments[index++]);
	    var keys = getOwnPropertySymbols ? concat$4(objectKeys$2(S), getOwnPropertySymbols(S)) : objectKeys$2(S);
	    var length = keys.length;
	    var j = 0;
	    var key;
	    while (length > j) {
	      key = keys[j++];
	      if (!DESCRIPTORS$p || call$q(propertyIsEnumerable, S, key)) T[key] = S[key];
	    }
	  }
	  return T;
	} : $assign;
	var objectAssign$1 = /*@__PURE__*/getDefaultExportFromCjs(objectAssign);

	var $$1y = _export;
	var assign$1 = objectAssign;

	// `Object.assign` method
	// https://tc39.es/ecma262/#sec-object.assign
	// eslint-disable-next-line es/no-object-assign -- required for testing
	$$1y({
	  target: 'Object',
	  stat: true,
	  arity: 2,
	  forced: Object.assign !== assign$1
	}, {
	  assign: assign$1
	});

	var es_object_create = {};

	// TODO: Remove from `core-js@4`
	var $$1x = _export;
	var DESCRIPTORS$o = descriptors;
	var create$5 = objectCreate;

	// `Object.create` method
	// https://tc39.es/ecma262/#sec-object.create
	$$1x({
	  target: 'Object',
	  stat: true,
	  sham: !DESCRIPTORS$o
	}, {
	  create: create$5
	});

	var es_object_defineGetter = {};

	'use strict';
	var IS_PURE$d = isPure;
	var global$A = global$Z;
	var fails$H = fails$1m;
	var WEBKIT$1 = engineWebkitVersion;

	// Forced replacement object prototype accessors methods
	var objectPrototypeAccessorsForced = IS_PURE$d || !fails$H(function () {
	  // This feature detection crashes old WebKit
	  // https://github.com/zloirock/core-js/issues/232
	  if (WEBKIT$1 && WEBKIT$1 < 535) return;
	  var key = Math.random();
	  // In FF throws only define methods
	  // eslint-disable-next-line no-undef, no-useless-call, es/no-legacy-object-prototype-accessor-methods -- required for testing
	  __defineSetter__.call(null, key, function () {/* empty */});
	  delete global$A[key];
	});
	var objectPrototypeAccessorsForced$1 = /*@__PURE__*/getDefaultExportFromCjs(objectPrototypeAccessorsForced);

	'use strict';
	var $$1w = _export;
	var DESCRIPTORS$n = descriptors;
	var FORCED$c = objectPrototypeAccessorsForced;
	var aCallable$b = aCallable$l;
	var toObject$9 = toObject$t;
	var definePropertyModule$4 = objectDefineProperty;

	// `Object.prototype.__defineGetter__` method
	// https://tc39.es/ecma262/#sec-object.prototype.__defineGetter__
	if (DESCRIPTORS$n) {
	  $$1w({
	    target: 'Object',
	    proto: true,
	    forced: FORCED$c
	  }, {
	    __defineGetter__: function __defineGetter__(P, getter) {
	      definePropertyModule$4.f(toObject$9(this), P, {
	        get: aCallable$b(getter),
	        enumerable: true,
	        configurable: true
	      });
	    }
	  });
	}

	var es_object_defineProperties = {};

	var $$1v = _export;
	var DESCRIPTORS$m = descriptors;
	var defineProperties = objectDefineProperties.f;

	// `Object.defineProperties` method
	// https://tc39.es/ecma262/#sec-object.defineproperties
	// eslint-disable-next-line es/no-object-defineproperties -- safe
	$$1v({
	  target: 'Object',
	  stat: true,
	  forced: Object.defineProperties !== defineProperties,
	  sham: !DESCRIPTORS$m
	}, {
	  defineProperties: defineProperties
	});

	var es_object_defineProperty = {};

	var $$1u = _export;
	var DESCRIPTORS$l = descriptors;
	var defineProperty$3 = objectDefineProperty.f;

	// `Object.defineProperty` method
	// https://tc39.es/ecma262/#sec-object.defineproperty
	// eslint-disable-next-line es/no-object-defineproperty -- safe
	$$1u({
	  target: 'Object',
	  stat: true,
	  forced: Object.defineProperty !== defineProperty$3,
	  sham: !DESCRIPTORS$l
	}, {
	  defineProperty: defineProperty$3
	});

	var es_object_defineSetter = {};

	'use strict';
	var $$1t = _export;
	var DESCRIPTORS$k = descriptors;
	var FORCED$b = objectPrototypeAccessorsForced;
	var aCallable$a = aCallable$l;
	var toObject$8 = toObject$t;
	var definePropertyModule$3 = objectDefineProperty;

	// `Object.prototype.__defineSetter__` method
	// https://tc39.es/ecma262/#sec-object.prototype.__defineSetter__
	if (DESCRIPTORS$k) {
	  $$1t({
	    target: 'Object',
	    proto: true,
	    forced: FORCED$b
	  }, {
	    __defineSetter__: function __defineSetter__(P, setter) {
	      definePropertyModule$3.f(toObject$8(this), P, {
	        set: aCallable$a(setter),
	        enumerable: true,
	        configurable: true
	      });
	    }
	  });
	}

	var es_object_entries = {};

	var DESCRIPTORS$j = descriptors;
	var uncurryThis$A = functionUncurryThis;
	var objectKeys$1 = objectKeys$5;
	var toIndexedObject$4 = toIndexedObject$j;
	var $propertyIsEnumerable = objectPropertyIsEnumerable.f;
	var propertyIsEnumerable = uncurryThis$A($propertyIsEnumerable);
	var push$8 = uncurryThis$A([].push);

	// `Object.{ entries, values }` methods implementation
	var createMethod$1 = function createMethod(TO_ENTRIES) {
	  return function (it) {
	    var O = toIndexedObject$4(it);
	    var keys = objectKeys$1(O);
	    var length = keys.length;
	    var i = 0;
	    var result = [];
	    var key;
	    while (length > i) {
	      key = keys[i++];
	      if (!DESCRIPTORS$j || propertyIsEnumerable(O, key)) {
	        push$8(result, TO_ENTRIES ? [key, O[key]] : O[key]);
	      }
	    }
	    return result;
	  };
	};
	var objectToArray = {
	  // `Object.entries` method
	  // https://tc39.es/ecma262/#sec-object.entries
	  entries: createMethod$1(true),
	  // `Object.values` method
	  // https://tc39.es/ecma262/#sec-object.values
	  values: createMethod$1(false)
	};
	var objectToArray$1 = /*@__PURE__*/getDefaultExportFromCjs(objectToArray);

	var $$1s = _export;
	var $entries = objectToArray.entries;

	// `Object.entries` method
	// https://tc39.es/ecma262/#sec-object.entries
	$$1s({
	  target: 'Object',
	  stat: true
	}, {
	  entries: function entries(O) {
	    return $entries(O);
	  }
	});

	var es_object_freeze = {};

	var $$1r = _export;
	var FREEZING$4 = freezing;
	var fails$G = fails$1m;
	var isObject$g = isObject$z;
	var onFreeze$2 = internalMetadataExports.onFreeze;

	// eslint-disable-next-line es/no-object-freeze -- safe
	var $freeze = Object.freeze;
	var FAILS_ON_PRIMITIVES$5 = fails$G(function () {
	  $freeze(1);
	});

	// `Object.freeze` method
	// https://tc39.es/ecma262/#sec-object.freeze
	$$1r({
	  target: 'Object',
	  stat: true,
	  forced: FAILS_ON_PRIMITIVES$5,
	  sham: !FREEZING$4
	}, {
	  freeze: function freeze(it) {
	    return $freeze && isObject$g(it) ? $freeze(onFreeze$2(it)) : it;
	  }
	});

	var es_object_fromEntries = {};

	var $$1q = _export;
	var iterate$6 = iterate$a;
	var createProperty$2 = createProperty$9;

	// `Object.fromEntries` method
	// https://github.com/tc39/proposal-object-from-entries
	$$1q({
	  target: 'Object',
	  stat: true
	}, {
	  fromEntries: function fromEntries(iterable) {
	    var obj = {};
	    iterate$6(iterable, function (k, v) {
	      createProperty$2(obj, k, v);
	    }, {
	      AS_ENTRIES: true
	    });
	    return obj;
	  }
	});

	var es_object_getOwnPropertyDescriptor = {};

	var $$1p = _export;
	var fails$F = fails$1m;
	var toIndexedObject$3 = toIndexedObject$j;
	var nativeGetOwnPropertyDescriptor$1 = objectGetOwnPropertyDescriptor.f;
	var DESCRIPTORS$i = descriptors;
	var FORCED$a = !DESCRIPTORS$i || fails$F(function () {
	  nativeGetOwnPropertyDescriptor$1(1);
	});

	// `Object.getOwnPropertyDescriptor` method
	// https://tc39.es/ecma262/#sec-object.getownpropertydescriptor
	$$1p({
	  target: 'Object',
	  stat: true,
	  forced: FORCED$a,
	  sham: !DESCRIPTORS$i
	}, {
	  getOwnPropertyDescriptor: function getOwnPropertyDescriptor(it, key) {
	    return nativeGetOwnPropertyDescriptor$1(toIndexedObject$3(it), key);
	  }
	});

	var es_object_getOwnPropertyDescriptors = {};

	var $$1o = _export;
	var DESCRIPTORS$h = descriptors;
	var ownKeys$1 = ownKeys$3;
	var toIndexedObject$2 = toIndexedObject$j;
	var getOwnPropertyDescriptorModule$4 = objectGetOwnPropertyDescriptor;
	var createProperty$1 = createProperty$9;

	// `Object.getOwnPropertyDescriptors` method
	// https://tc39.es/ecma262/#sec-object.getownpropertydescriptors
	$$1o({
	  target: 'Object',
	  stat: true,
	  sham: !DESCRIPTORS$h
	}, {
	  getOwnPropertyDescriptors: function getOwnPropertyDescriptors(object) {
	    var O = toIndexedObject$2(object);
	    var getOwnPropertyDescriptor = getOwnPropertyDescriptorModule$4.f;
	    var keys = ownKeys$1(O);
	    var result = {};
	    var index = 0;
	    var key, descriptor;
	    while (keys.length > index) {
	      descriptor = getOwnPropertyDescriptor(O, key = keys[index++]);
	      if (descriptor !== undefined) createProperty$1(result, key, descriptor);
	    }
	    return result;
	  }
	});

	var es_object_getOwnPropertyNames = {};

	var $$1n = _export;
	var fails$E = fails$1m;
	var getOwnPropertyNames$2 = objectGetOwnPropertyNamesExternal.f;

	// eslint-disable-next-line es/no-object-getownpropertynames -- required for testing
	var FAILS_ON_PRIMITIVES$4 = fails$E(function () {
	  return !Object.getOwnPropertyNames(1);
	});

	// `Object.getOwnPropertyNames` method
	// https://tc39.es/ecma262/#sec-object.getownpropertynames
	$$1n({
	  target: 'Object',
	  stat: true,
	  forced: FAILS_ON_PRIMITIVES$4
	}, {
	  getOwnPropertyNames: getOwnPropertyNames$2
	});

	var es_object_getPrototypeOf = {};

	var $$1m = _export;
	var fails$D = fails$1m;
	var toObject$7 = toObject$t;
	var nativeGetPrototypeOf = objectGetPrototypeOf$1;
	var CORRECT_PROTOTYPE_GETTER$1 = correctPrototypeGetter;
	var FAILS_ON_PRIMITIVES$3 = fails$D(function () {
	  nativeGetPrototypeOf(1);
	});

	// `Object.getPrototypeOf` method
	// https://tc39.es/ecma262/#sec-object.getprototypeof
	$$1m({
	  target: 'Object',
	  stat: true,
	  forced: FAILS_ON_PRIMITIVES$3,
	  sham: !CORRECT_PROTOTYPE_GETTER$1
	}, {
	  getPrototypeOf: function getPrototypeOf(it) {
	    return nativeGetPrototypeOf(toObject$7(it));
	  }
	});

	var es_object_hasOwn = {};

	var $$1l = _export;
	var hasOwn$c = hasOwnProperty_1;

	// `Object.hasOwn` method
	// https://github.com/tc39/proposal-accessible-object-hasownproperty
	$$1l({
	  target: 'Object',
	  stat: true
	}, {
	  hasOwn: hasOwn$c
	});

	var es_object_is = {};

	// `SameValue` abstract operation
	// https://tc39.es/ecma262/#sec-samevalue
	// eslint-disable-next-line es/no-object-is -- safe
	var sameValue$1 = Object.is || function is(x, y) {
	  // eslint-disable-next-line no-self-compare -- NaN check
	  return x === y ? x !== 0 || 1 / x === 1 / y : x != x && y != y;
	};
	var sameValue$2 = /*@__PURE__*/getDefaultExportFromCjs(sameValue$1);

	var $$1k = _export;
	var is = sameValue$1;

	// `Object.is` method
	// https://tc39.es/ecma262/#sec-object.is
	$$1k({
	  target: 'Object',
	  stat: true
	}, {
	  is: is
	});

	var es_object_isExtensible = {};

	var $$1j = _export;
	var $isExtensible$1 = objectIsExtensible;

	// `Object.isExtensible` method
	// https://tc39.es/ecma262/#sec-object.isextensible
	// eslint-disable-next-line es/no-object-isextensible -- safe
	$$1j({
	  target: 'Object',
	  stat: true,
	  forced: Object.isExtensible !== $isExtensible$1
	}, {
	  isExtensible: $isExtensible$1
	});

	var es_object_isFrozen = {};

	var $$1i = _export;
	var fails$C = fails$1m;
	var isObject$f = isObject$z;
	var classof$c = classofRaw$2;
	var ARRAY_BUFFER_NON_EXTENSIBLE$1 = arrayBufferNonExtensible;

	// eslint-disable-next-line es/no-object-isfrozen -- safe
	var $isFrozen = Object.isFrozen;
	var FORCED$9 = ARRAY_BUFFER_NON_EXTENSIBLE$1 || fails$C(function () {
	  $isFrozen(1);
	});

	// `Object.isFrozen` method
	// https://tc39.es/ecma262/#sec-object.isfrozen
	$$1i({
	  target: 'Object',
	  stat: true,
	  forced: FORCED$9
	}, {
	  isFrozen: function isFrozen(it) {
	    if (!isObject$f(it)) return true;
	    if (ARRAY_BUFFER_NON_EXTENSIBLE$1 && classof$c(it) == 'ArrayBuffer') return true;
	    return $isFrozen ? $isFrozen(it) : false;
	  }
	});

	var es_object_isSealed = {};

	var $$1h = _export;
	var fails$B = fails$1m;
	var isObject$e = isObject$z;
	var classof$b = classofRaw$2;
	var ARRAY_BUFFER_NON_EXTENSIBLE = arrayBufferNonExtensible;

	// eslint-disable-next-line es/no-object-issealed -- safe
	var $isSealed = Object.isSealed;
	var FORCED$8 = ARRAY_BUFFER_NON_EXTENSIBLE || fails$B(function () {
	  $isSealed(1);
	});

	// `Object.isSealed` method
	// https://tc39.es/ecma262/#sec-object.issealed
	$$1h({
	  target: 'Object',
	  stat: true,
	  forced: FORCED$8
	}, {
	  isSealed: function isSealed(it) {
	    if (!isObject$e(it)) return true;
	    if (ARRAY_BUFFER_NON_EXTENSIBLE && classof$b(it) == 'ArrayBuffer') return true;
	    return $isSealed ? $isSealed(it) : false;
	  }
	});

	var es_object_keys = {};

	var $$1g = _export;
	var toObject$6 = toObject$t;
	var nativeKeys = objectKeys$5;
	var fails$A = fails$1m;
	var FAILS_ON_PRIMITIVES$2 = fails$A(function () {
	  nativeKeys(1);
	});

	// `Object.keys` method
	// https://tc39.es/ecma262/#sec-object.keys
	$$1g({
	  target: 'Object',
	  stat: true,
	  forced: FAILS_ON_PRIMITIVES$2
	}, {
	  keys: function keys(it) {
	    return nativeKeys(toObject$6(it));
	  }
	});

	var es_object_lookupGetter = {};

	'use strict';
	var $$1f = _export;
	var DESCRIPTORS$g = descriptors;
	var FORCED$7 = objectPrototypeAccessorsForced;
	var toObject$5 = toObject$t;
	var toPropertyKey$3 = toPropertyKey$8;
	var getPrototypeOf$4 = objectGetPrototypeOf$1;
	var getOwnPropertyDescriptor$6 = objectGetOwnPropertyDescriptor.f;

	// `Object.prototype.__lookupGetter__` method
	// https://tc39.es/ecma262/#sec-object.prototype.__lookupGetter__
	if (DESCRIPTORS$g) {
	  $$1f({
	    target: 'Object',
	    proto: true,
	    forced: FORCED$7
	  }, {
	    __lookupGetter__: function __lookupGetter__(P) {
	      var O = toObject$5(this);
	      var key = toPropertyKey$3(P);
	      var desc;
	      do {
	        if (desc = getOwnPropertyDescriptor$6(O, key)) return desc.get;
	      } while (O = getPrototypeOf$4(O));
	    }
	  });
	}

	var es_object_lookupSetter = {};

	'use strict';
	var $$1e = _export;
	var DESCRIPTORS$f = descriptors;
	var FORCED$6 = objectPrototypeAccessorsForced;
	var toObject$4 = toObject$t;
	var toPropertyKey$2 = toPropertyKey$8;
	var getPrototypeOf$3 = objectGetPrototypeOf$1;
	var getOwnPropertyDescriptor$5 = objectGetOwnPropertyDescriptor.f;

	// `Object.prototype.__lookupSetter__` method
	// https://tc39.es/ecma262/#sec-object.prototype.__lookupSetter__
	if (DESCRIPTORS$f) {
	  $$1e({
	    target: 'Object',
	    proto: true,
	    forced: FORCED$6
	  }, {
	    __lookupSetter__: function __lookupSetter__(P) {
	      var O = toObject$4(this);
	      var key = toPropertyKey$2(P);
	      var desc;
	      do {
	        if (desc = getOwnPropertyDescriptor$5(O, key)) return desc.set;
	      } while (O = getPrototypeOf$3(O));
	    }
	  });
	}

	var es_object_preventExtensions = {};

	var $$1d = _export;
	var isObject$d = isObject$z;
	var onFreeze$1 = internalMetadataExports.onFreeze;
	var FREEZING$3 = freezing;
	var fails$z = fails$1m;

	// eslint-disable-next-line es/no-object-preventextensions -- safe
	var $preventExtensions = Object.preventExtensions;
	var FAILS_ON_PRIMITIVES$1 = fails$z(function () {
	  $preventExtensions(1);
	});

	// `Object.preventExtensions` method
	// https://tc39.es/ecma262/#sec-object.preventextensions
	$$1d({
	  target: 'Object',
	  stat: true,
	  forced: FAILS_ON_PRIMITIVES$1,
	  sham: !FREEZING$3
	}, {
	  preventExtensions: function preventExtensions(it) {
	    return $preventExtensions && isObject$d(it) ? $preventExtensions(onFreeze$1(it)) : it;
	  }
	});

	var es_object_proto = {};

	'use strict';
	var DESCRIPTORS$e = descriptors;
	var defineBuiltInAccessor$9 = defineBuiltInAccessor$h;
	var isObject$c = isObject$z;
	var toObject$3 = toObject$t;
	var requireObjectCoercible$d = requireObjectCoercible$j;

	// eslint-disable-next-line es/no-object-getprototypeof -- safe
	var getPrototypeOf$2 = Object.getPrototypeOf;
	// eslint-disable-next-line es/no-object-setprototypeof -- safe
	var setPrototypeOf$3 = Object.setPrototypeOf;
	var ObjectPrototype$1 = Object.prototype;
	var PROTO = '__proto__';

	// `Object.prototype.__proto__` accessor
	// https://tc39.es/ecma262/#sec-object.prototype.__proto__
	if (DESCRIPTORS$e && getPrototypeOf$2 && setPrototypeOf$3 && !(PROTO in ObjectPrototype$1)) try {
	  defineBuiltInAccessor$9(ObjectPrototype$1, PROTO, {
	    configurable: true,
	    get: function __proto__() {
	      return getPrototypeOf$2(toObject$3(this));
	    },
	    set: function __proto__(proto) {
	      var O = requireObjectCoercible$d(this);
	      if (!isObject$c(proto) && proto !== null || !isObject$c(O)) return;
	      setPrototypeOf$3(O, proto);
	    }
	  });
	} catch (error) {/* empty */}

	var es_object_seal = {};

	var $$1c = _export;
	var isObject$b = isObject$z;
	var onFreeze = internalMetadataExports.onFreeze;
	var FREEZING$2 = freezing;
	var fails$y = fails$1m;

	// eslint-disable-next-line es/no-object-seal -- safe
	var $seal = Object.seal;
	var FAILS_ON_PRIMITIVES = fails$y(function () {
	  $seal(1);
	});

	// `Object.seal` method
	// https://tc39.es/ecma262/#sec-object.seal
	$$1c({
	  target: 'Object',
	  stat: true,
	  forced: FAILS_ON_PRIMITIVES,
	  sham: !FREEZING$2
	}, {
	  seal: function seal(it) {
	    return $seal && isObject$b(it) ? $seal(onFreeze(it)) : it;
	  }
	});

	var es_object_setPrototypeOf = {};

	var $$1b = _export;
	var setPrototypeOf$2 = objectSetPrototypeOf$1;

	// `Object.setPrototypeOf` method
	// https://tc39.es/ecma262/#sec-object.setprototypeof
	$$1b({
	  target: 'Object',
	  stat: true
	}, {
	  setPrototypeOf: setPrototypeOf$2
	});

	var es_object_toString = {};

	'use strict';
	var TO_STRING_TAG_SUPPORT$1 = toStringTagSupport;
	var classof$a = classof$m;

	// `Object.prototype.toString` method implementation
	// https://tc39.es/ecma262/#sec-object.prototype.tostring
	var objectToString = TO_STRING_TAG_SUPPORT$1 ? {}.toString : function toString() {
	  return '[object ' + classof$a(this) + ']';
	};
	var objectToString$1 = /*@__PURE__*/getDefaultExportFromCjs(objectToString);

	var TO_STRING_TAG_SUPPORT = toStringTagSupport;
	var defineBuiltIn$a = defineBuiltIn$m;
	var toString$l = objectToString;

	// `Object.prototype.toString` method
	// https://tc39.es/ecma262/#sec-object.prototype.tostring
	if (!TO_STRING_TAG_SUPPORT) {
	  defineBuiltIn$a(Object.prototype, 'toString', toString$l, {
	    unsafe: true
	  });
	}

	var es_object_values = {};

	var $$1a = _export;
	var $values = objectToArray.values;

	// `Object.values` method
	// https://tc39.es/ecma262/#sec-object.values
	$$1a({
	  target: 'Object',
	  stat: true
	}, {
	  values: function values(O) {
	    return $values(O);
	  }
	});

	var es_parseFloat = {};

	var $$19 = _export;
	var $parseFloat = numberParseFloat;

	// `parseFloat` method
	// https://tc39.es/ecma262/#sec-parsefloat-string
	$$19({
	  global: true,
	  forced: parseFloat != $parseFloat
	}, {
	  parseFloat: $parseFloat
	});

	var es_parseInt = {};

	var $$18 = _export;
	var $parseInt = numberParseInt;

	// `parseInt` method
	// https://tc39.es/ecma262/#sec-parseint-string-radix
	$$18({
	  global: true,
	  forced: parseInt != $parseInt
	}, {
	  parseInt: $parseInt
	});

	var es_promise = {};

	var es_promise_constructor = {};

	var $TypeError$9 = TypeError;
	var validateArgumentsLength$8 = function validateArgumentsLength(passed, required) {
	  if (passed < required) throw $TypeError$9('Not enough arguments');
	  return passed;
	};
	var validateArgumentsLength$9 = /*@__PURE__*/getDefaultExportFromCjs(validateArgumentsLength$8);

	var userAgent$3 = engineUserAgent;

	// eslint-disable-next-line redos/no-vulnerable -- safe
	var engineIsIos = /(?:ipad|iphone|ipod).*applewebkit/i.test(userAgent$3);
	var engineIsIos$1 = /*@__PURE__*/getDefaultExportFromCjs(engineIsIos);

	var global$z = global$Z;
	var apply$6 = functionApply$1;
	var bind$6 = functionBindContext;
	var isCallable$b = isCallable$z;
	var hasOwn$b = hasOwnProperty_1;
	var fails$x = fails$1m;
	var html = html$2;
	var arraySlice$5 = arraySlice$a;
	var createElement = documentCreateElement$2;
	var validateArgumentsLength$7 = validateArgumentsLength$8;
	var IS_IOS$1 = engineIsIos;
	var IS_NODE$6 = engineIsNode;
	var set$1 = global$z.setImmediate;
	var clear = global$z.clearImmediate;
	var process$4 = global$z.process;
	var Dispatch = global$z.Dispatch;
	var Function$2 = global$z.Function;
	var MessageChannel = global$z.MessageChannel;
	var String$1 = global$z.String;
	var counter = 0;
	var queue$3 = {};
	var ONREADYSTATECHANGE = 'onreadystatechange';
	var $location, defer$1, channel, port;
	fails$x(function () {
	  // Deno throws a ReferenceError on `location` access without `--location` flag
	  $location = global$z.location;
	});
	var run = function run(id) {
	  if (hasOwn$b(queue$3, id)) {
	    var fn = queue$3[id];
	    delete queue$3[id];
	    fn();
	  }
	};
	var runner = function runner(id) {
	  return function () {
	    run(id);
	  };
	};
	var eventListener = function eventListener(event) {
	  run(event.data);
	};
	var globalPostMessageDefer = function globalPostMessageDefer(id) {
	  // old engines have not location.origin
	  global$z.postMessage(String$1(id), $location.protocol + '//' + $location.host);
	};

	// Node.js 0.9+ & IE10+ has setImmediate, otherwise:
	if (!set$1 || !clear) {
	  set$1 = function setImmediate(handler) {
	    validateArgumentsLength$7(arguments.length, 1);
	    var fn = isCallable$b(handler) ? handler : Function$2(handler);
	    var args = arraySlice$5(arguments, 1);
	    queue$3[++counter] = function () {
	      apply$6(fn, undefined, args);
	    };
	    defer$1(counter);
	    return counter;
	  };
	  clear = function clearImmediate(id) {
	    delete queue$3[id];
	  };
	  // Node.js 0.8-
	  if (IS_NODE$6) {
	    defer$1 = function defer(id) {
	      process$4.nextTick(runner(id));
	    };
	    // Sphere (JS game engine) Dispatch API
	  } else if (Dispatch && Dispatch.now) {
	    defer$1 = function defer(id) {
	      Dispatch.now(runner(id));
	    };
	    // Browsers with MessageChannel, includes WebWorkers
	    // except iOS - https://github.com/zloirock/core-js/issues/624
	  } else if (MessageChannel && !IS_IOS$1) {
	    channel = new MessageChannel();
	    port = channel.port2;
	    channel.port1.onmessage = eventListener;
	    defer$1 = bind$6(port.postMessage, port);
	    // Browsers with postMessage, skip WebWorkers
	    // IE8 has postMessage, but it's sync & typeof its postMessage is 'object'
	  } else if (global$z.addEventListener && isCallable$b(global$z.postMessage) && !global$z.importScripts && $location && $location.protocol !== 'file:' && !fails$x(globalPostMessageDefer)) {
	    defer$1 = globalPostMessageDefer;
	    global$z.addEventListener('message', eventListener, false);
	    // IE8-
	  } else if (ONREADYSTATECHANGE in createElement('script')) {
	    defer$1 = function defer(id) {
	      html.appendChild(createElement('script'))[ONREADYSTATECHANGE] = function () {
	        html.removeChild(this);
	        run(id);
	      };
	    };
	    // Rest old browsers
	  } else {
	    defer$1 = function defer(id) {
	      setTimeout(runner(id), 0);
	    };
	  }
	}
	var task$1 = {
	  set: set$1,
	  clear: clear
	};
	var task$2 = /*@__PURE__*/getDefaultExportFromCjs(task$1);

	var Queue$2 = function Queue() {
	  this.head = null;
	  this.tail = null;
	};
	Queue$2.prototype = {
	  add: function add(item) {
	    var entry = {
	      item: item,
	      next: null
	    };
	    var tail = this.tail;
	    if (tail) tail.next = entry;else this.head = entry;
	    this.tail = entry;
	  },
	  get: function get() {
	    var entry = this.head;
	    if (entry) {
	      var next = this.head = entry.next;
	      if (next === null) this.tail = null;
	      return entry.item;
	    }
	  }
	};
	var queue$1 = Queue$2;
	var queue$2 = /*@__PURE__*/getDefaultExportFromCjs(queue$1);

	var userAgent$2 = engineUserAgent;
	var engineIsIosPebble = /ipad|iphone|ipod/i.test(userAgent$2) && typeof Pebble != 'undefined';
	var engineIsIosPebble$1 = /*@__PURE__*/getDefaultExportFromCjs(engineIsIosPebble);

	var userAgent$1 = engineUserAgent;
	var engineIsWebosWebkit = /web0s(?!.*chrome)/i.test(userAgent$1);
	var engineIsWebosWebkit$1 = /*@__PURE__*/getDefaultExportFromCjs(engineIsWebosWebkit);

	var global$y = global$Z;
	var bind$5 = functionBindContext;
	var getOwnPropertyDescriptor$4 = objectGetOwnPropertyDescriptor.f;
	var macrotask = task$1.set;
	var Queue$1 = queue$1;
	var IS_IOS = engineIsIos;
	var IS_IOS_PEBBLE = engineIsIosPebble;
	var IS_WEBOS_WEBKIT = engineIsWebosWebkit;
	var IS_NODE$5 = engineIsNode;
	var MutationObserver = global$y.MutationObserver || global$y.WebKitMutationObserver;
	var document$2 = global$y.document;
	var process$3 = global$y.process;
	var Promise$1 = global$y.Promise;
	// Node.js 11 shows ExperimentalWarning on getting `queueMicrotask`
	var queueMicrotaskDescriptor = getOwnPropertyDescriptor$4(global$y, 'queueMicrotask');
	var microtask$2 = queueMicrotaskDescriptor && queueMicrotaskDescriptor.value;
	var notify$1, toggle, node, promise, then;

	// modern engines have queueMicrotask method
	if (!microtask$2) {
	  var queue = new Queue$1();
	  var flush = function flush() {
	    var parent, fn;
	    if (IS_NODE$5 && (parent = process$3.domain)) parent.exit();
	    while (fn = queue.get()) try {
	      fn();
	    } catch (error) {
	      if (queue.head) notify$1();
	      throw error;
	    }
	    if (parent) parent.enter();
	  };

	  // browsers with MutationObserver, except iOS - https://github.com/zloirock/core-js/issues/339
	  // also except WebOS Webkit https://github.com/zloirock/core-js/issues/898
	  if (!IS_IOS && !IS_NODE$5 && !IS_WEBOS_WEBKIT && MutationObserver && document$2) {
	    toggle = true;
	    node = document$2.createTextNode('');
	    new MutationObserver(flush).observe(node, {
	      characterData: true
	    });
	    notify$1 = function notify() {
	      node.data = toggle = !toggle;
	    };
	    // environments with maybe non-completely correct, but existent Promise
	  } else if (!IS_IOS_PEBBLE && Promise$1 && Promise$1.resolve) {
	    // Promise.resolve without an argument throws an error in LG WebOS 2
	    promise = Promise$1.resolve(undefined);
	    // workaround of WebKit ~ iOS Safari 10.1 bug
	    promise.constructor = Promise$1;
	    then = bind$5(promise.then, promise);
	    notify$1 = function notify() {
	      then(flush);
	    };
	    // Node.js without promises
	  } else if (IS_NODE$5) {
	    notify$1 = function notify() {
	      process$3.nextTick(flush);
	    };
	    // for other environments - macrotask based on:
	    // - setImmediate
	    // - MessageChannel
	    // - window.postMessage
	    // - onreadystatechange
	    // - setTimeout
	  } else {
	    // `webpack` dev server bug on IE global methods - use bind(fn, global)
	    macrotask = bind$5(macrotask, global$y);
	    notify$1 = function notify() {
	      macrotask(flush);
	    };
	  }
	  microtask$2 = function microtask(fn) {
	    if (!queue.head) notify$1();
	    queue.add(fn);
	  };
	}
	var microtask_1 = microtask$2;
	var microtask$3 = /*@__PURE__*/getDefaultExportFromCjs(microtask_1);

	var hostReportErrors$1 = function hostReportErrors(a, b) {
	  try {
	    // eslint-disable-next-line no-console -- safe
	    arguments.length == 1 ? console.error(a) : console.error(a, b);
	  } catch (error) {/* empty */}
	};
	var hostReportErrors$2 = /*@__PURE__*/getDefaultExportFromCjs(hostReportErrors$1);

	var perform$5 = function perform(exec) {
	  try {
	    return {
	      error: false,
	      value: exec()
	    };
	  } catch (error) {
	    return {
	      error: true,
	      value: error
	    };
	  }
	};
	var perform$6 = /*@__PURE__*/getDefaultExportFromCjs(perform$5);

	var global$x = global$Z;
	var promiseNativeConstructor = global$x.Promise;
	var promiseNativeConstructor$1 = /*@__PURE__*/getDefaultExportFromCjs(promiseNativeConstructor);

	var engineIsDeno = (typeof Deno === "undefined" ? "undefined" : _typeof(Deno)) == 'object' && Deno && _typeof(Deno.version) == 'object';
	var engineIsDeno$1 = /*@__PURE__*/getDefaultExportFromCjs(engineIsDeno);

	var IS_DENO$2 = engineIsDeno;
	var IS_NODE$4 = engineIsNode;
	var engineIsBrowser = !IS_DENO$2 && !IS_NODE$4 && (typeof window === "undefined" ? "undefined" : _typeof(window)) == 'object' && (typeof document === "undefined" ? "undefined" : _typeof(document)) == 'object';
	var engineIsBrowser$1 = /*@__PURE__*/getDefaultExportFromCjs(engineIsBrowser);

	var global$w = global$Z;
	var NativePromiseConstructor$5 = promiseNativeConstructor;
	var isCallable$a = isCallable$z;
	var isForced$1 = isForced_1;
	var inspectSource = inspectSource$3;
	var wellKnownSymbol$b = wellKnownSymbol$z;
	var IS_BROWSER$1 = engineIsBrowser;
	var IS_DENO$1 = engineIsDeno;
	var IS_PURE$c = isPure;
	var V8_VERSION = engineV8Version;
	var NativePromisePrototype$3 = NativePromiseConstructor$5 && NativePromiseConstructor$5.prototype;
	var SPECIES$1 = wellKnownSymbol$b('species');
	var SUBCLASSING = false;
	var NATIVE_PROMISE_REJECTION_EVENT$1 = isCallable$a(global$w.PromiseRejectionEvent);
	var FORCED_PROMISE_CONSTRUCTOR$5 = isForced$1('Promise', function () {
	  var PROMISE_CONSTRUCTOR_SOURCE = inspectSource(NativePromiseConstructor$5);
	  var GLOBAL_CORE_JS_PROMISE = PROMISE_CONSTRUCTOR_SOURCE !== String(NativePromiseConstructor$5);
	  // V8 6.6 (Node 10 and Chrome 66) have a bug with resolving custom thenables
	  // https://bugs.chromium.org/p/chromium/issues/detail?id=830565
	  // We can't detect it synchronously, so just check versions
	  if (!GLOBAL_CORE_JS_PROMISE && V8_VERSION === 66) return true;
	  // We need Promise#{ catch, finally } in the pure version for preventing prototype pollution
	  if (IS_PURE$c && !(NativePromisePrototype$3['catch'] && NativePromisePrototype$3['finally'])) return true;
	  // We can't use @@species feature detection in V8 since it causes
	  // deoptimization and performance degradation
	  // https://github.com/zloirock/core-js/issues/679
	  if (!V8_VERSION || V8_VERSION < 51 || !/native code/.test(PROMISE_CONSTRUCTOR_SOURCE)) {
	    // Detect correctness of subclassing with @@species support
	    var promise = new NativePromiseConstructor$5(function (resolve) {
	      resolve(1);
	    });
	    var FakePromise = function FakePromise(exec) {
	      exec(function () {/* empty */}, function () {/* empty */});
	    };
	    var constructor = promise.constructor = {};
	    constructor[SPECIES$1] = FakePromise;
	    SUBCLASSING = promise.then(function () {/* empty */}) instanceof FakePromise;
	    if (!SUBCLASSING) return true;
	    // Unhandled rejections tracking support, NodeJS Promise without it fails @@species test
	  }
	  return !GLOBAL_CORE_JS_PROMISE && (IS_BROWSER$1 || IS_DENO$1) && !NATIVE_PROMISE_REJECTION_EVENT$1;
	});
	var promiseConstructorDetection = {
	  CONSTRUCTOR: FORCED_PROMISE_CONSTRUCTOR$5,
	  REJECTION_EVENT: NATIVE_PROMISE_REJECTION_EVENT$1,
	  SUBCLASSING: SUBCLASSING
	};
	var promiseConstructorDetection$1 = /*@__PURE__*/getDefaultExportFromCjs(promiseConstructorDetection);

	var newPromiseCapability$2 = {};

	'use strict';
	var aCallable$9 = aCallable$l;
	var $TypeError$8 = TypeError;
	var PromiseCapability = function PromiseCapability(C) {
	  var resolve, reject;
	  this.promise = new C(function ($$resolve, $$reject) {
	    if (resolve !== undefined || reject !== undefined) throw $TypeError$8('Bad Promise constructor');
	    resolve = $$resolve;
	    reject = $$reject;
	  });
	  this.resolve = aCallable$9(resolve);
	  this.reject = aCallable$9(reject);
	};

	// `NewPromiseCapability` abstract operation
	// https://tc39.es/ecma262/#sec-newpromisecapability
	var f = newPromiseCapability$2.f = function (C) {
	  return new PromiseCapability(C);
	};

	'use strict';
	var $$17 = _export;
	var IS_PURE$b = isPure;
	var IS_NODE$3 = engineIsNode;
	var global$v = global$Z;
	var call$p = functionCall;
	var defineBuiltIn$9 = defineBuiltIn$m;
	var setPrototypeOf$1 = objectSetPrototypeOf$1;
	var setToStringTag$4 = setToStringTag$d;
	var setSpecies$2 = setSpecies$6;
	var aCallable$8 = aCallable$l;
	var isCallable$9 = isCallable$z;
	var isObject$a = isObject$z;
	var anInstance$6 = anInstance$a;
	var speciesConstructor$4 = speciesConstructor$6;
	var task = task$1.set;
	var microtask$1 = microtask_1;
	var hostReportErrors = hostReportErrors$1;
	var perform$4 = perform$5;
	var Queue = queue$1;
	var InternalStateModule$7 = internalState;
	var NativePromiseConstructor$4 = promiseNativeConstructor;
	var PromiseConstructorDetection = promiseConstructorDetection;
	var newPromiseCapabilityModule$5 = newPromiseCapability$2;
	var PROMISE = 'Promise';
	var FORCED_PROMISE_CONSTRUCTOR$4 = PromiseConstructorDetection.CONSTRUCTOR;
	var NATIVE_PROMISE_REJECTION_EVENT = PromiseConstructorDetection.REJECTION_EVENT;
	var NATIVE_PROMISE_SUBCLASSING = PromiseConstructorDetection.SUBCLASSING;
	var getInternalPromiseState = InternalStateModule$7.getterFor(PROMISE);
	var setInternalState$7 = InternalStateModule$7.set;
	var NativePromisePrototype$2 = NativePromiseConstructor$4 && NativePromiseConstructor$4.prototype;
	var PromiseConstructor = NativePromiseConstructor$4;
	var PromisePrototype = NativePromisePrototype$2;
	var TypeError$4 = global$v.TypeError;
	var document$1 = global$v.document;
	var process$2 = global$v.process;
	var newPromiseCapability$1 = newPromiseCapabilityModule$5.f;
	var newGenericPromiseCapability = newPromiseCapability$1;
	var DISPATCH_EVENT = !!(document$1 && document$1.createEvent && global$v.dispatchEvent);
	var UNHANDLED_REJECTION = 'unhandledrejection';
	var REJECTION_HANDLED = 'rejectionhandled';
	var PENDING = 0;
	var FULFILLED = 1;
	var REJECTED = 2;
	var HANDLED = 1;
	var UNHANDLED = 2;
	var Internal, OwnPromiseCapability, PromiseWrapper, nativeThen;

	// helpers
	var isThenable = function isThenable(it) {
	  var then;
	  return isObject$a(it) && isCallable$9(then = it.then) ? then : false;
	};
	var callReaction = function callReaction(reaction, state) {
	  var value = state.value;
	  var ok = state.state == FULFILLED;
	  var handler = ok ? reaction.ok : reaction.fail;
	  var resolve = reaction.resolve;
	  var reject = reaction.reject;
	  var domain = reaction.domain;
	  var result, then, exited;
	  try {
	    if (handler) {
	      if (!ok) {
	        if (state.rejection === UNHANDLED) onHandleUnhandled(state);
	        state.rejection = HANDLED;
	      }
	      if (handler === true) result = value;else {
	        if (domain) domain.enter();
	        result = handler(value); // can throw
	        if (domain) {
	          domain.exit();
	          exited = true;
	        }
	      }
	      if (result === reaction.promise) {
	        reject(TypeError$4('Promise-chain cycle'));
	      } else if (then = isThenable(result)) {
	        call$p(then, result, resolve, reject);
	      } else resolve(result);
	    } else reject(value);
	  } catch (error) {
	    if (domain && !exited) domain.exit();
	    reject(error);
	  }
	};
	var notify = function notify(state, isReject) {
	  if (state.notified) return;
	  state.notified = true;
	  microtask$1(function () {
	    var reactions = state.reactions;
	    var reaction;
	    while (reaction = reactions.get()) {
	      callReaction(reaction, state);
	    }
	    state.notified = false;
	    if (isReject && !state.rejection) onUnhandled(state);
	  });
	};
	var dispatchEvent = function dispatchEvent(name, promise, reason) {
	  var event, handler;
	  if (DISPATCH_EVENT) {
	    event = document$1.createEvent('Event');
	    event.promise = promise;
	    event.reason = reason;
	    event.initEvent(name, false, true);
	    global$v.dispatchEvent(event);
	  } else event = {
	    promise: promise,
	    reason: reason
	  };
	  if (!NATIVE_PROMISE_REJECTION_EVENT && (handler = global$v['on' + name])) handler(event);else if (name === UNHANDLED_REJECTION) hostReportErrors('Unhandled promise rejection', reason);
	};
	var onUnhandled = function onUnhandled(state) {
	  call$p(task, global$v, function () {
	    var promise = state.facade;
	    var value = state.value;
	    var IS_UNHANDLED = isUnhandled(state);
	    var result;
	    if (IS_UNHANDLED) {
	      result = perform$4(function () {
	        if (IS_NODE$3) {
	          process$2.emit('unhandledRejection', value, promise);
	        } else dispatchEvent(UNHANDLED_REJECTION, promise, value);
	      });
	      // Browsers should not trigger `rejectionHandled` event if it was handled here, NodeJS - should
	      state.rejection = IS_NODE$3 || isUnhandled(state) ? UNHANDLED : HANDLED;
	      if (result.error) throw result.value;
	    }
	  });
	};
	var isUnhandled = function isUnhandled(state) {
	  return state.rejection !== HANDLED && !state.parent;
	};
	var onHandleUnhandled = function onHandleUnhandled(state) {
	  call$p(task, global$v, function () {
	    var promise = state.facade;
	    if (IS_NODE$3) {
	      process$2.emit('rejectionHandled', promise);
	    } else dispatchEvent(REJECTION_HANDLED, promise, state.value);
	  });
	};
	var bind$4 = function bind(fn, state, unwrap) {
	  return function (value) {
	    fn(state, value, unwrap);
	  };
	};
	var internalReject = function internalReject(state, value, unwrap) {
	  if (state.done) return;
	  state.done = true;
	  if (unwrap) state = unwrap;
	  state.value = value;
	  state.state = REJECTED;
	  notify(state, true);
	};
	var internalResolve = function internalResolve(state, value, unwrap) {
	  if (state.done) return;
	  state.done = true;
	  if (unwrap) state = unwrap;
	  try {
	    if (state.facade === value) throw TypeError$4("Promise can't be resolved itself");
	    var then = isThenable(value);
	    if (then) {
	      microtask$1(function () {
	        var wrapper = {
	          done: false
	        };
	        try {
	          call$p(then, value, bind$4(internalResolve, wrapper, state), bind$4(internalReject, wrapper, state));
	        } catch (error) {
	          internalReject(wrapper, error, state);
	        }
	      });
	    } else {
	      state.value = value;
	      state.state = FULFILLED;
	      notify(state, false);
	    }
	  } catch (error) {
	    internalReject({
	      done: false
	    }, error, state);
	  }
	};

	// constructor polyfill
	if (FORCED_PROMISE_CONSTRUCTOR$4) {
	  // 25.4.3.1 Promise(executor)
	  PromiseConstructor = function Promise(executor) {
	    anInstance$6(this, PromisePrototype);
	    aCallable$8(executor);
	    call$p(Internal, this);
	    var state = getInternalPromiseState(this);
	    try {
	      executor(bind$4(internalResolve, state), bind$4(internalReject, state));
	    } catch (error) {
	      internalReject(state, error);
	    }
	  };
	  PromisePrototype = PromiseConstructor.prototype;

	  // eslint-disable-next-line no-unused-vars -- required for `.length`
	  Internal = function Promise(executor) {
	    setInternalState$7(this, {
	      type: PROMISE,
	      done: false,
	      notified: false,
	      parent: false,
	      reactions: new Queue(),
	      rejection: false,
	      state: PENDING,
	      value: undefined
	    });
	  };

	  // `Promise.prototype.then` method
	  // https://tc39.es/ecma262/#sec-promise.prototype.then
	  Internal.prototype = defineBuiltIn$9(PromisePrototype, 'then', function then(onFulfilled, onRejected) {
	    var state = getInternalPromiseState(this);
	    var reaction = newPromiseCapability$1(speciesConstructor$4(this, PromiseConstructor));
	    state.parent = true;
	    reaction.ok = isCallable$9(onFulfilled) ? onFulfilled : true;
	    reaction.fail = isCallable$9(onRejected) && onRejected;
	    reaction.domain = IS_NODE$3 ? process$2.domain : undefined;
	    if (state.state == PENDING) state.reactions.add(reaction);else microtask$1(function () {
	      callReaction(reaction, state);
	    });
	    return reaction.promise;
	  });
	  OwnPromiseCapability = function OwnPromiseCapability() {
	    var promise = new Internal();
	    var state = getInternalPromiseState(promise);
	    this.promise = promise;
	    this.resolve = bind$4(internalResolve, state);
	    this.reject = bind$4(internalReject, state);
	  };
	  newPromiseCapabilityModule$5.f = newPromiseCapability$1 = function newPromiseCapability(C) {
	    return C === PromiseConstructor || C === PromiseWrapper ? new OwnPromiseCapability(C) : newGenericPromiseCapability(C);
	  };
	  if (!IS_PURE$b && isCallable$9(NativePromiseConstructor$4) && NativePromisePrototype$2 !== Object.prototype) {
	    nativeThen = NativePromisePrototype$2.then;
	    if (!NATIVE_PROMISE_SUBCLASSING) {
	      // make `Promise#then` return a polyfilled `Promise` for native promise-based APIs
	      defineBuiltIn$9(NativePromisePrototype$2, 'then', function then(onFulfilled, onRejected) {
	        var that = this;
	        return new PromiseConstructor(function (resolve, reject) {
	          call$p(nativeThen, that, resolve, reject);
	        }).then(onFulfilled, onRejected);
	        // https://github.com/zloirock/core-js/issues/640
	      }, {
	        unsafe: true
	      });
	    }

	    // make `.constructor === Promise` work for native promise-based APIs
	    try {
	      delete NativePromisePrototype$2.constructor;
	    } catch (error) {/* empty */}

	    // make `instanceof Promise` work for native promise-based APIs
	    if (setPrototypeOf$1) {
	      setPrototypeOf$1(NativePromisePrototype$2, PromisePrototype);
	    }
	  }
	}
	$$17({
	  global: true,
	  constructor: true,
	  wrap: true,
	  forced: FORCED_PROMISE_CONSTRUCTOR$4
	}, {
	  Promise: PromiseConstructor
	});
	setToStringTag$4(PromiseConstructor, PROMISE, false, true);
	setSpecies$2(PROMISE);

	var es_promise_all = {};

	var NativePromiseConstructor$3 = promiseNativeConstructor;
	var checkCorrectnessOfIteration$1 = checkCorrectnessOfIteration$4;
	var FORCED_PROMISE_CONSTRUCTOR$3 = promiseConstructorDetection.CONSTRUCTOR;
	var promiseStaticsIncorrectIteration = FORCED_PROMISE_CONSTRUCTOR$3 || !checkCorrectnessOfIteration$1(function (iterable) {
	  NativePromiseConstructor$3.all(iterable).then(undefined, function () {/* empty */});
	});
	var promiseStaticsIncorrectIteration$1 = /*@__PURE__*/getDefaultExportFromCjs(promiseStaticsIncorrectIteration);

	'use strict';
	var $$16 = _export;
	var call$o = functionCall;
	var aCallable$7 = aCallable$l;
	var newPromiseCapabilityModule$4 = newPromiseCapability$2;
	var perform$3 = perform$5;
	var iterate$5 = iterate$a;
	var PROMISE_STATICS_INCORRECT_ITERATION$3 = promiseStaticsIncorrectIteration;

	// `Promise.all` method
	// https://tc39.es/ecma262/#sec-promise.all
	$$16({
	  target: 'Promise',
	  stat: true,
	  forced: PROMISE_STATICS_INCORRECT_ITERATION$3
	}, {
	  all: function all(iterable) {
	    var C = this;
	    var capability = newPromiseCapabilityModule$4.f(C);
	    var resolve = capability.resolve;
	    var reject = capability.reject;
	    var result = perform$3(function () {
	      var $promiseResolve = aCallable$7(C.resolve);
	      var values = [];
	      var counter = 0;
	      var remaining = 1;
	      iterate$5(iterable, function (promise) {
	        var index = counter++;
	        var alreadyCalled = false;
	        remaining++;
	        call$o($promiseResolve, C, promise).then(function (value) {
	          if (alreadyCalled) return;
	          alreadyCalled = true;
	          values[index] = value;
	          --remaining || resolve(values);
	        }, reject);
	      });
	      --remaining || resolve(values);
	    });
	    if (result.error) reject(result.value);
	    return capability.promise;
	  }
	});

	var es_promise_catch = {};

	'use strict';
	var $$15 = _export;
	var IS_PURE$a = isPure;
	var FORCED_PROMISE_CONSTRUCTOR$2 = promiseConstructorDetection.CONSTRUCTOR;
	var NativePromiseConstructor$2 = promiseNativeConstructor;
	var getBuiltIn$a = getBuiltIn$m;
	var isCallable$8 = isCallable$z;
	var defineBuiltIn$8 = defineBuiltIn$m;
	var NativePromisePrototype$1 = NativePromiseConstructor$2 && NativePromiseConstructor$2.prototype;

	// `Promise.prototype.catch` method
	// https://tc39.es/ecma262/#sec-promise.prototype.catch
	$$15({
	  target: 'Promise',
	  proto: true,
	  forced: FORCED_PROMISE_CONSTRUCTOR$2,
	  real: true
	}, {
	  'catch': function _catch(onRejected) {
	    return this.then(undefined, onRejected);
	  }
	});

	// makes sure that native promise-based APIs `Promise#catch` properly works with patched `Promise#then`
	if (!IS_PURE$a && isCallable$8(NativePromiseConstructor$2)) {
	  var method$1 = getBuiltIn$a('Promise').prototype['catch'];
	  if (NativePromisePrototype$1['catch'] !== method$1) {
	    defineBuiltIn$8(NativePromisePrototype$1, 'catch', method$1, {
	      unsafe: true
	    });
	  }
	}

	var es_promise_race = {};

	'use strict';
	var $$14 = _export;
	var call$n = functionCall;
	var aCallable$6 = aCallable$l;
	var newPromiseCapabilityModule$3 = newPromiseCapability$2;
	var perform$2 = perform$5;
	var iterate$4 = iterate$a;
	var PROMISE_STATICS_INCORRECT_ITERATION$2 = promiseStaticsIncorrectIteration;

	// `Promise.race` method
	// https://tc39.es/ecma262/#sec-promise.race
	$$14({
	  target: 'Promise',
	  stat: true,
	  forced: PROMISE_STATICS_INCORRECT_ITERATION$2
	}, {
	  race: function race(iterable) {
	    var C = this;
	    var capability = newPromiseCapabilityModule$3.f(C);
	    var reject = capability.reject;
	    var result = perform$2(function () {
	      var $promiseResolve = aCallable$6(C.resolve);
	      iterate$4(iterable, function (promise) {
	        call$n($promiseResolve, C, promise).then(capability.resolve, reject);
	      });
	    });
	    if (result.error) reject(result.value);
	    return capability.promise;
	  }
	});

	var es_promise_reject = {};

	'use strict';
	var $$13 = _export;
	var call$m = functionCall;
	var newPromiseCapabilityModule$2 = newPromiseCapability$2;
	var FORCED_PROMISE_CONSTRUCTOR$1 = promiseConstructorDetection.CONSTRUCTOR;

	// `Promise.reject` method
	// https://tc39.es/ecma262/#sec-promise.reject
	$$13({
	  target: 'Promise',
	  stat: true,
	  forced: FORCED_PROMISE_CONSTRUCTOR$1
	}, {
	  reject: function reject(r) {
	    var capability = newPromiseCapabilityModule$2.f(this);
	    call$m(capability.reject, undefined, r);
	    return capability.promise;
	  }
	});

	var es_promise_resolve = {};

	var anObject$o = anObject$D;
	var isObject$9 = isObject$z;
	var newPromiseCapability = newPromiseCapability$2;
	var promiseResolve$2 = function promiseResolve(C, x) {
	  anObject$o(C);
	  if (isObject$9(x) && x.constructor === C) return x;
	  var promiseCapability = newPromiseCapability.f(C);
	  var resolve = promiseCapability.resolve;
	  resolve(x);
	  return promiseCapability.promise;
	};
	var promiseResolve$3 = /*@__PURE__*/getDefaultExportFromCjs(promiseResolve$2);

	'use strict';
	var $$12 = _export;
	var getBuiltIn$9 = getBuiltIn$m;
	var IS_PURE$9 = isPure;
	var NativePromiseConstructor$1 = promiseNativeConstructor;
	var FORCED_PROMISE_CONSTRUCTOR = promiseConstructorDetection.CONSTRUCTOR;
	var promiseResolve$1 = promiseResolve$2;
	var PromiseConstructorWrapper = getBuiltIn$9('Promise');
	var CHECK_WRAPPER = IS_PURE$9 && !FORCED_PROMISE_CONSTRUCTOR;

	// `Promise.resolve` method
	// https://tc39.es/ecma262/#sec-promise.resolve
	$$12({
	  target: 'Promise',
	  stat: true,
	  forced: IS_PURE$9 || FORCED_PROMISE_CONSTRUCTOR
	}, {
	  resolve: function resolve(x) {
	    return promiseResolve$1(CHECK_WRAPPER && this === PromiseConstructorWrapper ? NativePromiseConstructor$1 : this, x);
	  }
	});

	var es_promise_allSettled = {};

	'use strict';
	var $$11 = _export;
	var call$l = functionCall;
	var aCallable$5 = aCallable$l;
	var newPromiseCapabilityModule$1 = newPromiseCapability$2;
	var perform$1 = perform$5;
	var iterate$3 = iterate$a;
	var PROMISE_STATICS_INCORRECT_ITERATION$1 = promiseStaticsIncorrectIteration;

	// `Promise.allSettled` method
	// https://tc39.es/ecma262/#sec-promise.allsettled
	$$11({
	  target: 'Promise',
	  stat: true,
	  forced: PROMISE_STATICS_INCORRECT_ITERATION$1
	}, {
	  allSettled: function allSettled(iterable) {
	    var C = this;
	    var capability = newPromiseCapabilityModule$1.f(C);
	    var resolve = capability.resolve;
	    var reject = capability.reject;
	    var result = perform$1(function () {
	      var promiseResolve = aCallable$5(C.resolve);
	      var values = [];
	      var counter = 0;
	      var remaining = 1;
	      iterate$3(iterable, function (promise) {
	        var index = counter++;
	        var alreadyCalled = false;
	        remaining++;
	        call$l(promiseResolve, C, promise).then(function (value) {
	          if (alreadyCalled) return;
	          alreadyCalled = true;
	          values[index] = {
	            status: 'fulfilled',
	            value: value
	          };
	          --remaining || resolve(values);
	        }, function (error) {
	          if (alreadyCalled) return;
	          alreadyCalled = true;
	          values[index] = {
	            status: 'rejected',
	            reason: error
	          };
	          --remaining || resolve(values);
	        });
	      });
	      --remaining || resolve(values);
	    });
	    if (result.error) reject(result.value);
	    return capability.promise;
	  }
	});

	var es_promise_any = {};

	'use strict';
	var $$10 = _export;
	var call$k = functionCall;
	var aCallable$4 = aCallable$l;
	var getBuiltIn$8 = getBuiltIn$m;
	var newPromiseCapabilityModule = newPromiseCapability$2;
	var perform = perform$5;
	var iterate$2 = iterate$a;
	var PROMISE_STATICS_INCORRECT_ITERATION = promiseStaticsIncorrectIteration;
	var PROMISE_ANY_ERROR = 'No one promise resolved';

	// `Promise.any` method
	// https://tc39.es/ecma262/#sec-promise.any
	$$10({
	  target: 'Promise',
	  stat: true,
	  forced: PROMISE_STATICS_INCORRECT_ITERATION
	}, {
	  any: function any(iterable) {
	    var C = this;
	    var AggregateError = getBuiltIn$8('AggregateError');
	    var capability = newPromiseCapabilityModule.f(C);
	    var resolve = capability.resolve;
	    var reject = capability.reject;
	    var result = perform(function () {
	      var promiseResolve = aCallable$4(C.resolve);
	      var errors = [];
	      var counter = 0;
	      var remaining = 1;
	      var alreadyResolved = false;
	      iterate$2(iterable, function (promise) {
	        var index = counter++;
	        var alreadyRejected = false;
	        remaining++;
	        call$k(promiseResolve, C, promise).then(function (value) {
	          if (alreadyRejected || alreadyResolved) return;
	          alreadyResolved = true;
	          resolve(value);
	        }, function (error) {
	          if (alreadyRejected || alreadyResolved) return;
	          alreadyRejected = true;
	          errors[index] = error;
	          --remaining || reject(new AggregateError(errors, PROMISE_ANY_ERROR));
	        });
	      });
	      --remaining || reject(new AggregateError(errors, PROMISE_ANY_ERROR));
	    });
	    if (result.error) reject(result.value);
	    return capability.promise;
	  }
	});

	var es_promise_finally = {};

	'use strict';
	var $$$ = _export;
	var IS_PURE$8 = isPure;
	var NativePromiseConstructor = promiseNativeConstructor;
	var fails$w = fails$1m;
	var getBuiltIn$7 = getBuiltIn$m;
	var isCallable$7 = isCallable$z;
	var speciesConstructor$3 = speciesConstructor$6;
	var promiseResolve = promiseResolve$2;
	var defineBuiltIn$7 = defineBuiltIn$m;
	var NativePromisePrototype = NativePromiseConstructor && NativePromiseConstructor.prototype;

	// Safari bug https://bugs.webkit.org/show_bug.cgi?id=200829
	var NON_GENERIC = !!NativePromiseConstructor && fails$w(function () {
	  // eslint-disable-next-line unicorn/no-thenable -- required for testing
	  NativePromisePrototype['finally'].call({
	    then: function then() {/* empty */}
	  }, function () {/* empty */});
	});

	// `Promise.prototype.finally` method
	// https://tc39.es/ecma262/#sec-promise.prototype.finally
	$$$({
	  target: 'Promise',
	  proto: true,
	  real: true,
	  forced: NON_GENERIC
	}, {
	  'finally': function _finally(onFinally) {
	    var C = speciesConstructor$3(this, getBuiltIn$7('Promise'));
	    var isFunction = isCallable$7(onFinally);
	    return this.then(isFunction ? function (x) {
	      return promiseResolve(C, onFinally()).then(function () {
	        return x;
	      });
	    } : onFinally, isFunction ? function (e) {
	      return promiseResolve(C, onFinally()).then(function () {
	        throw e;
	      });
	    } : onFinally);
	  }
	});

	// makes sure that native promise-based APIs `Promise#finally` properly works with patched `Promise#then`
	if (!IS_PURE$8 && isCallable$7(NativePromiseConstructor)) {
	  var method = getBuiltIn$7('Promise').prototype['finally'];
	  if (NativePromisePrototype['finally'] !== method) {
	    defineBuiltIn$7(NativePromisePrototype, 'finally', method, {
	      unsafe: true
	    });
	  }
	}

	var es_reflect_apply = {};

	var $$_ = _export;
	var functionApply = functionApply$1;
	var aCallable$3 = aCallable$l;
	var anObject$n = anObject$D;
	var fails$v = fails$1m;

	// MS Edge argumentsList argument is optional
	var OPTIONAL_ARGUMENTS_LIST = !fails$v(function () {
	  // eslint-disable-next-line es/no-reflect -- required for testing
	  Reflect.apply(function () {/* empty */});
	});

	// `Reflect.apply` method
	// https://tc39.es/ecma262/#sec-reflect.apply
	$$_({
	  target: 'Reflect',
	  stat: true,
	  forced: OPTIONAL_ARGUMENTS_LIST
	}, {
	  apply: function apply(target, thisArgument, argumentsList) {
	    return functionApply(aCallable$3(target), thisArgument, anObject$n(argumentsList));
	  }
	});

	var es_reflect_construct = {};

	var $$Z = _export;
	var getBuiltIn$6 = getBuiltIn$m;
	var apply$5 = functionApply$1;
	var bind$3 = functionBind;
	var aConstructor$1 = aConstructor$3;
	var anObject$m = anObject$D;
	var isObject$8 = isObject$z;
	var create$4 = objectCreate;
	var fails$u = fails$1m;
	var nativeConstruct = getBuiltIn$6('Reflect', 'construct');
	var ObjectPrototype = Object.prototype;
	var push$7 = [].push;

	// `Reflect.construct` method
	// https://tc39.es/ecma262/#sec-reflect.construct
	// MS Edge supports only 2 arguments and argumentsList argument is optional
	// FF Nightly sets third argument as `new.target`, but does not create `this` from it
	var NEW_TARGET_BUG = fails$u(function () {
	  function F() {/* empty */}
	  return !(nativeConstruct(function () {/* empty */}, [], F) instanceof F);
	});
	var ARGS_BUG = !fails$u(function () {
	  nativeConstruct(function () {/* empty */});
	});
	var FORCED$5 = NEW_TARGET_BUG || ARGS_BUG;
	$$Z({
	  target: 'Reflect',
	  stat: true,
	  forced: FORCED$5,
	  sham: FORCED$5
	}, {
	  construct: function construct(Target, args /* , newTarget */) {
	    aConstructor$1(Target);
	    anObject$m(args);
	    var newTarget = arguments.length < 3 ? Target : aConstructor$1(arguments[2]);
	    if (ARGS_BUG && !NEW_TARGET_BUG) return nativeConstruct(Target, args, newTarget);
	    if (Target == newTarget) {
	      // w/o altered newTarget, optimization for 0-4 arguments
	      switch (args.length) {
	        case 0:
	          return new Target();
	        case 1:
	          return new Target(args[0]);
	        case 2:
	          return new Target(args[0], args[1]);
	        case 3:
	          return new Target(args[0], args[1], args[2]);
	        case 4:
	          return new Target(args[0], args[1], args[2], args[3]);
	      }
	      // w/o altered newTarget, lot of arguments case
	      var $args = [null];
	      apply$5(push$7, $args, args);
	      return new (apply$5(bind$3, Target, $args))();
	    }
	    // with altered newTarget, not support built-in constructors
	    var proto = newTarget.prototype;
	    var instance = create$4(isObject$8(proto) ? proto : ObjectPrototype);
	    var result = apply$5(Target, instance, args);
	    return isObject$8(result) ? result : instance;
	  }
	});

	var es_reflect_defineProperty = {};

	var $$Y = _export;
	var DESCRIPTORS$d = descriptors;
	var anObject$l = anObject$D;
	var toPropertyKey$1 = toPropertyKey$8;
	var definePropertyModule$2 = objectDefineProperty;
	var fails$t = fails$1m;

	// MS Edge has broken Reflect.defineProperty - throwing instead of returning false
	var ERROR_INSTEAD_OF_FALSE = fails$t(function () {
	  // eslint-disable-next-line es/no-reflect -- required for testing
	  Reflect.defineProperty(definePropertyModule$2.f({}, 1, {
	    value: 1
	  }), 1, {
	    value: 2
	  });
	});

	// `Reflect.defineProperty` method
	// https://tc39.es/ecma262/#sec-reflect.defineproperty
	$$Y({
	  target: 'Reflect',
	  stat: true,
	  forced: ERROR_INSTEAD_OF_FALSE,
	  sham: !DESCRIPTORS$d
	}, {
	  defineProperty: function defineProperty(target, propertyKey, attributes) {
	    anObject$l(target);
	    var key = toPropertyKey$1(propertyKey);
	    anObject$l(attributes);
	    try {
	      definePropertyModule$2.f(target, key, attributes);
	      return true;
	    } catch (error) {
	      return false;
	    }
	  }
	});

	var es_reflect_deleteProperty = {};

	var $$X = _export;
	var anObject$k = anObject$D;
	var getOwnPropertyDescriptor$3 = objectGetOwnPropertyDescriptor.f;

	// `Reflect.deleteProperty` method
	// https://tc39.es/ecma262/#sec-reflect.deleteproperty
	$$X({
	  target: 'Reflect',
	  stat: true
	}, {
	  deleteProperty: function deleteProperty(target, propertyKey) {
	    var descriptor = getOwnPropertyDescriptor$3(anObject$k(target), propertyKey);
	    return descriptor && !descriptor.configurable ? false : delete target[propertyKey];
	  }
	});

	var es_reflect_get = {};

	var hasOwn$a = hasOwnProperty_1;
	var isDataDescriptor$2 = function isDataDescriptor(descriptor) {
	  return descriptor !== undefined && (hasOwn$a(descriptor, 'value') || hasOwn$a(descriptor, 'writable'));
	};
	var isDataDescriptor$3 = /*@__PURE__*/getDefaultExportFromCjs(isDataDescriptor$2);

	var $$W = _export;
	var call$j = functionCall;
	var isObject$7 = isObject$z;
	var anObject$j = anObject$D;
	var isDataDescriptor$1 = isDataDescriptor$2;
	var getOwnPropertyDescriptorModule$3 = objectGetOwnPropertyDescriptor;
	var getPrototypeOf$1 = objectGetPrototypeOf$1;

	// `Reflect.get` method
	// https://tc39.es/ecma262/#sec-reflect.get
	function get$2(target, propertyKey /* , receiver */) {
	  var receiver = arguments.length < 3 ? target : arguments[2];
	  var descriptor, prototype;
	  if (anObject$j(target) === receiver) return target[propertyKey];
	  descriptor = getOwnPropertyDescriptorModule$3.f(target, propertyKey);
	  if (descriptor) return isDataDescriptor$1(descriptor) ? descriptor.value : descriptor.get === undefined ? undefined : call$j(descriptor.get, receiver);
	  if (isObject$7(prototype = getPrototypeOf$1(target))) return get$2(prototype, propertyKey, receiver);
	}
	$$W({
	  target: 'Reflect',
	  stat: true
	}, {
	  get: get$2
	});

	var es_reflect_getOwnPropertyDescriptor = {};

	var $$V = _export;
	var DESCRIPTORS$c = descriptors;
	var anObject$i = anObject$D;
	var getOwnPropertyDescriptorModule$2 = objectGetOwnPropertyDescriptor;

	// `Reflect.getOwnPropertyDescriptor` method
	// https://tc39.es/ecma262/#sec-reflect.getownpropertydescriptor
	$$V({
	  target: 'Reflect',
	  stat: true,
	  sham: !DESCRIPTORS$c
	}, {
	  getOwnPropertyDescriptor: function getOwnPropertyDescriptor(target, propertyKey) {
	    return getOwnPropertyDescriptorModule$2.f(anObject$i(target), propertyKey);
	  }
	});

	var es_reflect_getPrototypeOf = {};

	var $$U = _export;
	var anObject$h = anObject$D;
	var objectGetPrototypeOf = objectGetPrototypeOf$1;
	var CORRECT_PROTOTYPE_GETTER = correctPrototypeGetter;

	// `Reflect.getPrototypeOf` method
	// https://tc39.es/ecma262/#sec-reflect.getprototypeof
	$$U({
	  target: 'Reflect',
	  stat: true,
	  sham: !CORRECT_PROTOTYPE_GETTER
	}, {
	  getPrototypeOf: function getPrototypeOf(target) {
	    return objectGetPrototypeOf(anObject$h(target));
	  }
	});

	var es_reflect_has = {};

	var $$T = _export;

	// `Reflect.has` method
	// https://tc39.es/ecma262/#sec-reflect.has
	$$T({
	  target: 'Reflect',
	  stat: true
	}, {
	  has: function has(target, propertyKey) {
	    return propertyKey in target;
	  }
	});

	var es_reflect_isExtensible = {};

	var $$S = _export;
	var anObject$g = anObject$D;
	var $isExtensible = objectIsExtensible;

	// `Reflect.isExtensible` method
	// https://tc39.es/ecma262/#sec-reflect.isextensible
	$$S({
	  target: 'Reflect',
	  stat: true
	}, {
	  isExtensible: function isExtensible(target) {
	    anObject$g(target);
	    return $isExtensible(target);
	  }
	});

	var es_reflect_ownKeys = {};

	var $$R = _export;
	var ownKeys = ownKeys$3;

	// `Reflect.ownKeys` method
	// https://tc39.es/ecma262/#sec-reflect.ownkeys
	$$R({
	  target: 'Reflect',
	  stat: true
	}, {
	  ownKeys: ownKeys
	});

	var es_reflect_preventExtensions = {};

	var $$Q = _export;
	var getBuiltIn$5 = getBuiltIn$m;
	var anObject$f = anObject$D;
	var FREEZING$1 = freezing;

	// `Reflect.preventExtensions` method
	// https://tc39.es/ecma262/#sec-reflect.preventextensions
	$$Q({
	  target: 'Reflect',
	  stat: true,
	  sham: !FREEZING$1
	}, {
	  preventExtensions: function preventExtensions(target) {
	    anObject$f(target);
	    try {
	      var objectPreventExtensions = getBuiltIn$5('Object', 'preventExtensions');
	      if (objectPreventExtensions) objectPreventExtensions(target);
	      return true;
	    } catch (error) {
	      return false;
	    }
	  }
	});

	var es_reflect_set = {};

	var $$P = _export;
	var call$i = functionCall;
	var anObject$e = anObject$D;
	var isObject$6 = isObject$z;
	var isDataDescriptor = isDataDescriptor$2;
	var fails$s = fails$1m;
	var definePropertyModule$1 = objectDefineProperty;
	var getOwnPropertyDescriptorModule$1 = objectGetOwnPropertyDescriptor;
	var getPrototypeOf = objectGetPrototypeOf$1;
	var createPropertyDescriptor$4 = createPropertyDescriptor$c;

	// `Reflect.set` method
	// https://tc39.es/ecma262/#sec-reflect.set
	function set(target, propertyKey, V /* , receiver */) {
	  var receiver = arguments.length < 4 ? target : arguments[3];
	  var ownDescriptor = getOwnPropertyDescriptorModule$1.f(anObject$e(target), propertyKey);
	  var existingDescriptor, prototype, setter;
	  if (!ownDescriptor) {
	    if (isObject$6(prototype = getPrototypeOf(target))) {
	      return set(prototype, propertyKey, V, receiver);
	    }
	    ownDescriptor = createPropertyDescriptor$4(0);
	  }
	  if (isDataDescriptor(ownDescriptor)) {
	    if (ownDescriptor.writable === false || !isObject$6(receiver)) return false;
	    if (existingDescriptor = getOwnPropertyDescriptorModule$1.f(receiver, propertyKey)) {
	      if (existingDescriptor.get || existingDescriptor.set || existingDescriptor.writable === false) return false;
	      existingDescriptor.value = V;
	      definePropertyModule$1.f(receiver, propertyKey, existingDescriptor);
	    } else definePropertyModule$1.f(receiver, propertyKey, createPropertyDescriptor$4(0, V));
	  } else {
	    setter = ownDescriptor.set;
	    if (setter === undefined) return false;
	    call$i(setter, receiver, V);
	  }
	  return true;
	}

	// MS Edge 17-18 Reflect.set allows setting the property to object
	// with non-writable property on the prototype
	var MS_EDGE_BUG = fails$s(function () {
	  var Constructor = function Constructor() {/* empty */};
	  var object = definePropertyModule$1.f(new Constructor(), 'a', {
	    configurable: true
	  });
	  // eslint-disable-next-line es/no-reflect -- required for testing
	  return Reflect.set(Constructor.prototype, 'a', 1, object) !== false;
	});
	$$P({
	  target: 'Reflect',
	  stat: true,
	  forced: MS_EDGE_BUG
	}, {
	  set: set
	});

	var es_reflect_setPrototypeOf = {};

	var $$O = _export;
	var anObject$d = anObject$D;
	var aPossiblePrototype = aPossiblePrototype$2;
	var objectSetPrototypeOf = objectSetPrototypeOf$1;

	// `Reflect.setPrototypeOf` method
	// https://tc39.es/ecma262/#sec-reflect.setprototypeof
	if (objectSetPrototypeOf) $$O({
	  target: 'Reflect',
	  stat: true
	}, {
	  setPrototypeOf: function setPrototypeOf(target, proto) {
	    anObject$d(target);
	    aPossiblePrototype(proto);
	    try {
	      objectSetPrototypeOf(target, proto);
	      return true;
	    } catch (error) {
	      return false;
	    }
	  }
	});

	var es_reflect_toStringTag = {};

	var $$N = _export;
	var global$u = global$Z;
	var setToStringTag$3 = setToStringTag$d;
	$$N({
	  global: true
	}, {
	  Reflect: {}
	});

	// Reflect[@@toStringTag] property
	// https://tc39.es/ecma262/#sec-reflect-@@tostringtag
	setToStringTag$3(global$u.Reflect, 'Reflect', true);

	var es_regexp_constructor = {};

	var isObject$5 = isObject$z;
	var classof$9 = classofRaw$2;
	var wellKnownSymbol$a = wellKnownSymbol$z;
	var MATCH$2 = wellKnownSymbol$a('match');

	// `IsRegExp` abstract operation
	// https://tc39.es/ecma262/#sec-isregexp
	var isRegexp = function isRegexp(it) {
	  var isRegExp;
	  return isObject$5(it) && ((isRegExp = it[MATCH$2]) !== undefined ? !!isRegExp : classof$9(it) == 'RegExp');
	};
	var isRegexp$1 = /*@__PURE__*/getDefaultExportFromCjs(isRegexp);

	'use strict';
	var anObject$c = anObject$D;

	// `RegExp.prototype.flags` getter implementation
	// https://tc39.es/ecma262/#sec-get-regexp.prototype.flags
	var regexpFlags$1 = function regexpFlags() {
	  var that = anObject$c(this);
	  var result = '';
	  if (that.hasIndices) result += 'd';
	  if (that.global) result += 'g';
	  if (that.ignoreCase) result += 'i';
	  if (that.multiline) result += 'm';
	  if (that.dotAll) result += 's';
	  if (that.unicode) result += 'u';
	  if (that.unicodeSets) result += 'v';
	  if (that.sticky) result += 'y';
	  return result;
	};
	var regexpFlags$2 = /*@__PURE__*/getDefaultExportFromCjs(regexpFlags$1);

	var call$h = functionCall;
	var hasOwn$9 = hasOwnProperty_1;
	var isPrototypeOf$2 = objectIsPrototypeOf;
	var regExpFlags$1 = regexpFlags$1;
	var RegExpPrototype$7 = RegExp.prototype;
	var regexpGetFlags = function regexpGetFlags(R) {
	  var flags = R.flags;
	  return flags === undefined && !('flags' in RegExpPrototype$7) && !hasOwn$9(R, 'flags') && isPrototypeOf$2(RegExpPrototype$7, R) ? call$h(regExpFlags$1, R) : flags;
	};
	var regexpGetFlags$1 = /*@__PURE__*/getDefaultExportFromCjs(regexpGetFlags);

	var fails$r = fails$1m;
	var global$t = global$Z;

	// babel-minify and Closure Compiler transpiles RegExp('a', 'y') -> /a/y and it causes SyntaxError
	var $RegExp$2 = global$t.RegExp;
	var UNSUPPORTED_Y$3 = fails$r(function () {
	  var re = $RegExp$2('a', 'y');
	  re.lastIndex = 2;
	  return re.exec('abcd') != null;
	});

	// UC Browser bug
	// https://github.com/zloirock/core-js/issues/1008
	var MISSED_STICKY$2 = UNSUPPORTED_Y$3 || fails$r(function () {
	  return !$RegExp$2('a', 'y').sticky;
	});
	var BROKEN_CARET = UNSUPPORTED_Y$3 || fails$r(function () {
	  // https://bugzilla.mozilla.org/show_bug.cgi?id=773687
	  var re = $RegExp$2('^r', 'gy');
	  re.lastIndex = 2;
	  return re.exec('str') != null;
	});
	var regexpStickyHelpers = {
	  BROKEN_CARET: BROKEN_CARET,
	  MISSED_STICKY: MISSED_STICKY$2,
	  UNSUPPORTED_Y: UNSUPPORTED_Y$3
	};
	var regexpStickyHelpers$1 = /*@__PURE__*/getDefaultExportFromCjs(regexpStickyHelpers);

	var fails$q = fails$1m;
	var global$s = global$Z;

	// babel-minify and Closure Compiler transpiles RegExp('.', 's') -> /./s and it causes SyntaxError
	var $RegExp$1 = global$s.RegExp;
	var regexpUnsupportedDotAll = fails$q(function () {
	  var re = $RegExp$1('.', 's');
	  return !(re.dotAll && re.exec('\n') && re.flags === 's');
	});
	var regexpUnsupportedDotAll$1 = /*@__PURE__*/getDefaultExportFromCjs(regexpUnsupportedDotAll);

	var fails$p = fails$1m;
	var global$r = global$Z;

	// babel-minify and Closure Compiler transpiles RegExp('(?<a>b)', 'g') -> /(?<a>b)/g and it causes SyntaxError
	var $RegExp = global$r.RegExp;
	var regexpUnsupportedNcg = fails$p(function () {
	  var re = $RegExp('(?<a>b)', 'g');
	  return re.exec('b').groups.a !== 'b' || 'b'.replace(re, '$<a>c') !== 'bc';
	});
	var regexpUnsupportedNcg$1 = /*@__PURE__*/getDefaultExportFromCjs(regexpUnsupportedNcg);

	var DESCRIPTORS$b = descriptors;
	var global$q = global$Z;
	var uncurryThis$z = functionUncurryThis;
	var isForced = isForced_1;
	var inheritIfRequired$2 = inheritIfRequired$6;
	var createNonEnumerableProperty$5 = createNonEnumerableProperty$f;
	var getOwnPropertyNames$1 = objectGetOwnPropertyNames.f;
	var isPrototypeOf$1 = objectIsPrototypeOf;
	var isRegExp$4 = isRegexp;
	var toString$k = toString$x;
	var getRegExpFlags$4 = regexpGetFlags;
	var stickyHelpers$2 = regexpStickyHelpers;
	var proxyAccessor = proxyAccessor$2;
	var defineBuiltIn$6 = defineBuiltIn$m;
	var fails$o = fails$1m;
	var hasOwn$8 = hasOwnProperty_1;
	var enforceInternalState$2 = internalState.enforce;
	var setSpecies$1 = setSpecies$6;
	var wellKnownSymbol$9 = wellKnownSymbol$z;
	var UNSUPPORTED_DOT_ALL$2 = regexpUnsupportedDotAll;
	var UNSUPPORTED_NCG$1 = regexpUnsupportedNcg;
	var MATCH$1 = wellKnownSymbol$9('match');
	var NativeRegExp = global$q.RegExp;
	var RegExpPrototype$6 = NativeRegExp.prototype;
	var SyntaxError$1 = global$q.SyntaxError;
	var exec$6 = uncurryThis$z(RegExpPrototype$6.exec);
	var charAt$b = uncurryThis$z(''.charAt);
	var replace$8 = uncurryThis$z(''.replace);
	var stringIndexOf$4 = uncurryThis$z(''.indexOf);
	var stringSlice$b = uncurryThis$z(''.slice);
	// TODO: Use only proper RegExpIdentifierName
	var IS_NCG = /^\?<[^\s\d!#%&*+<=>@^][^\s!#%&*+<=>@^]*>/;
	var re1 = /a/g;
	var re2 = /a/g;

	// "new" should create a new object, old webkit bug
	var CORRECT_NEW = new NativeRegExp(re1) !== re1;
	var MISSED_STICKY$1 = stickyHelpers$2.MISSED_STICKY;
	var UNSUPPORTED_Y$2 = stickyHelpers$2.UNSUPPORTED_Y;
	var BASE_FORCED = DESCRIPTORS$b && (!CORRECT_NEW || MISSED_STICKY$1 || UNSUPPORTED_DOT_ALL$2 || UNSUPPORTED_NCG$1 || fails$o(function () {
	  re2[MATCH$1] = false;
	  // RegExp constructor can alter flags and IsRegExp works correct with @@match
	  return NativeRegExp(re1) != re1 || NativeRegExp(re2) == re2 || NativeRegExp(re1, 'i') != '/a/i';
	}));
	var handleDotAll = function handleDotAll(string) {
	  var length = string.length;
	  var index = 0;
	  var result = '';
	  var brackets = false;
	  var chr;
	  for (; index <= length; index++) {
	    chr = charAt$b(string, index);
	    if (chr === '\\') {
	      result += chr + charAt$b(string, ++index);
	      continue;
	    }
	    if (!brackets && chr === '.') {
	      result += '[\\s\\S]';
	    } else {
	      if (chr === '[') {
	        brackets = true;
	      } else if (chr === ']') {
	        brackets = false;
	      }
	      result += chr;
	    }
	  }
	  return result;
	};
	var handleNCG = function handleNCG(string) {
	  var length = string.length;
	  var index = 0;
	  var result = '';
	  var named = [];
	  var names = {};
	  var brackets = false;
	  var ncg = false;
	  var groupid = 0;
	  var groupname = '';
	  var chr;
	  for (; index <= length; index++) {
	    chr = charAt$b(string, index);
	    if (chr === '\\') {
	      chr = chr + charAt$b(string, ++index);
	    } else if (chr === ']') {
	      brackets = false;
	    } else if (!brackets) switch (true) {
	      case chr === '[':
	        brackets = true;
	        break;
	      case chr === '(':
	        if (exec$6(IS_NCG, stringSlice$b(string, index + 1))) {
	          index += 2;
	          ncg = true;
	        }
	        result += chr;
	        groupid++;
	        continue;
	      case chr === '>' && ncg:
	        if (groupname === '' || hasOwn$8(names, groupname)) {
	          throw new SyntaxError$1('Invalid capture group name');
	        }
	        names[groupname] = true;
	        named[named.length] = [groupname, groupid];
	        ncg = false;
	        groupname = '';
	        continue;
	    }
	    if (ncg) groupname += chr;else result += chr;
	  }
	  return [result, named];
	};

	// `RegExp` constructor
	// https://tc39.es/ecma262/#sec-regexp-constructor
	if (isForced('RegExp', BASE_FORCED)) {
	  var RegExpWrapper = function RegExp(pattern, flags) {
	    var thisIsRegExp = isPrototypeOf$1(RegExpPrototype$6, this);
	    var patternIsRegExp = isRegExp$4(pattern);
	    var flagsAreUndefined = flags === undefined;
	    var groups = [];
	    var rawPattern = pattern;
	    var rawFlags, dotAll, sticky, handled, result, state;
	    if (!thisIsRegExp && patternIsRegExp && flagsAreUndefined && pattern.constructor === RegExpWrapper) {
	      return pattern;
	    }
	    if (patternIsRegExp || isPrototypeOf$1(RegExpPrototype$6, pattern)) {
	      pattern = pattern.source;
	      if (flagsAreUndefined) flags = getRegExpFlags$4(rawPattern);
	    }
	    pattern = pattern === undefined ? '' : toString$k(pattern);
	    flags = flags === undefined ? '' : toString$k(flags);
	    rawPattern = pattern;
	    if (UNSUPPORTED_DOT_ALL$2 && 'dotAll' in re1) {
	      dotAll = !!flags && stringIndexOf$4(flags, 's') > -1;
	      if (dotAll) flags = replace$8(flags, /s/g, '');
	    }
	    rawFlags = flags;
	    if (MISSED_STICKY$1 && 'sticky' in re1) {
	      sticky = !!flags && stringIndexOf$4(flags, 'y') > -1;
	      if (sticky && UNSUPPORTED_Y$2) flags = replace$8(flags, /y/g, '');
	    }
	    if (UNSUPPORTED_NCG$1) {
	      handled = handleNCG(pattern);
	      pattern = handled[0];
	      groups = handled[1];
	    }
	    result = inheritIfRequired$2(NativeRegExp(pattern, flags), thisIsRegExp ? this : RegExpPrototype$6, RegExpWrapper);
	    if (dotAll || sticky || groups.length) {
	      state = enforceInternalState$2(result);
	      if (dotAll) {
	        state.dotAll = true;
	        state.raw = RegExpWrapper(handleDotAll(pattern), rawFlags);
	      }
	      if (sticky) state.sticky = true;
	      if (groups.length) state.groups = groups;
	    }
	    if (pattern !== rawPattern) try {
	      // fails in old engines, but we have no alternatives for unsupported regex syntax
	      createNonEnumerableProperty$5(result, 'source', rawPattern === '' ? '(?:)' : rawPattern);
	    } catch (error) {/* empty */}
	    return result;
	  };
	  for (var keys = getOwnPropertyNames$1(NativeRegExp), index$4 = 0; keys.length > index$4;) {
	    proxyAccessor(RegExpWrapper, NativeRegExp, keys[index$4++]);
	  }
	  RegExpPrototype$6.constructor = RegExpWrapper;
	  RegExpWrapper.prototype = RegExpPrototype$6;
	  defineBuiltIn$6(global$q, 'RegExp', RegExpWrapper, {
	    constructor: true
	  });
	}

	// https://tc39.es/ecma262/#sec-get-regexp-@@species
	setSpecies$1('RegExp');

	var es_regexp_dotAll = {};

	var DESCRIPTORS$a = descriptors;
	var UNSUPPORTED_DOT_ALL$1 = regexpUnsupportedDotAll;
	var classof$8 = classofRaw$2;
	var defineBuiltInAccessor$8 = defineBuiltInAccessor$h;
	var getInternalState$6 = internalState.get;
	var RegExpPrototype$5 = RegExp.prototype;
	var $TypeError$7 = TypeError;

	// `RegExp.prototype.dotAll` getter
	// https://tc39.es/ecma262/#sec-get-regexp.prototype.dotall
	if (DESCRIPTORS$a && UNSUPPORTED_DOT_ALL$1) {
	  defineBuiltInAccessor$8(RegExpPrototype$5, 'dotAll', {
	    configurable: true,
	    get: function dotAll() {
	      if (this === RegExpPrototype$5) return undefined;
	      // We can't use InternalStateModule.getterFor because
	      // we don't add metadata for regexps created by a literal.
	      if (classof$8(this) === 'RegExp') {
	        return !!getInternalState$6(this).dotAll;
	      }
	      throw $TypeError$7('Incompatible receiver, RegExp required');
	    }
	  });
	}

	var es_regexp_exec = {};

	'use strict';
	/* eslint-disable regexp/no-empty-capturing-group, regexp/no-empty-group, regexp/no-lazy-ends -- testing */
	/* eslint-disable regexp/no-useless-quantifier -- testing */
	var call$g = functionCall;
	var uncurryThis$y = functionUncurryThis;
	var toString$j = toString$x;
	var regexpFlags = regexpFlags$1;
	var stickyHelpers$1 = regexpStickyHelpers;
	var shared$1 = sharedExports;
	var create$3 = objectCreate;
	var getInternalState$5 = internalState.get;
	var UNSUPPORTED_DOT_ALL = regexpUnsupportedDotAll;
	var UNSUPPORTED_NCG = regexpUnsupportedNcg;
	var nativeReplace = shared$1('native-string-replace', String.prototype.replace);
	var nativeExec = RegExp.prototype.exec;
	var patchedExec = nativeExec;
	var charAt$a = uncurryThis$y(''.charAt);
	var indexOf$1 = uncurryThis$y(''.indexOf);
	var replace$7 = uncurryThis$y(''.replace);
	var stringSlice$a = uncurryThis$y(''.slice);
	var UPDATES_LAST_INDEX_WRONG = function () {
	  var re1 = /a/;
	  var re2 = /b*/g;
	  call$g(nativeExec, re1, 'a');
	  call$g(nativeExec, re2, 'a');
	  return re1.lastIndex !== 0 || re2.lastIndex !== 0;
	}();
	var UNSUPPORTED_Y$1 = stickyHelpers$1.BROKEN_CARET;

	// nonparticipating capturing group, copied from es5-shim's String#split patch.
	var NPCG_INCLUDED = /()??/.exec('')[1] !== undefined;
	var PATCH = UPDATES_LAST_INDEX_WRONG || NPCG_INCLUDED || UNSUPPORTED_Y$1 || UNSUPPORTED_DOT_ALL || UNSUPPORTED_NCG;
	if (PATCH) {
	  patchedExec = function exec(string) {
	    var re = this;
	    var state = getInternalState$5(re);
	    var str = toString$j(string);
	    var raw = state.raw;
	    var result, reCopy, lastIndex, match, i, object, group;
	    if (raw) {
	      raw.lastIndex = re.lastIndex;
	      result = call$g(patchedExec, raw, str);
	      re.lastIndex = raw.lastIndex;
	      return result;
	    }
	    var groups = state.groups;
	    var sticky = UNSUPPORTED_Y$1 && re.sticky;
	    var flags = call$g(regexpFlags, re);
	    var source = re.source;
	    var charsAdded = 0;
	    var strCopy = str;
	    if (sticky) {
	      flags = replace$7(flags, 'y', '');
	      if (indexOf$1(flags, 'g') === -1) {
	        flags += 'g';
	      }
	      strCopy = stringSlice$a(str, re.lastIndex);
	      // Support anchored sticky behavior.
	      if (re.lastIndex > 0 && (!re.multiline || re.multiline && charAt$a(str, re.lastIndex - 1) !== '\n')) {
	        source = '(?: ' + source + ')';
	        strCopy = ' ' + strCopy;
	        charsAdded++;
	      }
	      // ^(? + rx + ) is needed, in combination with some str slicing, to
	      // simulate the 'y' flag.
	      reCopy = new RegExp('^(?:' + source + ')', flags);
	    }
	    if (NPCG_INCLUDED) {
	      reCopy = new RegExp('^' + source + '$(?!\\s)', flags);
	    }
	    if (UPDATES_LAST_INDEX_WRONG) lastIndex = re.lastIndex;
	    match = call$g(nativeExec, sticky ? reCopy : re, strCopy);
	    if (sticky) {
	      if (match) {
	        match.input = stringSlice$a(match.input, charsAdded);
	        match[0] = stringSlice$a(match[0], charsAdded);
	        match.index = re.lastIndex;
	        re.lastIndex += match[0].length;
	      } else re.lastIndex = 0;
	    } else if (UPDATES_LAST_INDEX_WRONG && match) {
	      re.lastIndex = re.global ? match.index + match[0].length : lastIndex;
	    }
	    if (NPCG_INCLUDED && match && match.length > 1) {
	      // Fix browsers whose `exec` methods don't consistently return `undefined`
	      // for NPCG, like IE8. NOTE: This doesn't work for /(.?)?/
	      call$g(nativeReplace, match[0], reCopy, function () {
	        for (i = 1; i < arguments.length - 2; i++) {
	          if (arguments[i] === undefined) match[i] = undefined;
	        }
	      });
	    }
	    if (match && groups) {
	      match.groups = object = create$3(null);
	      for (i = 0; i < groups.length; i++) {
	        group = groups[i];
	        object[group[0]] = match[group[1]];
	      }
	    }
	    return match;
	  };
	}
	var regexpExec$3 = patchedExec;
	var regexpExec$4 = /*@__PURE__*/getDefaultExportFromCjs(regexpExec$3);

	'use strict';
	var $$M = _export;
	var exec$5 = regexpExec$3;

	// `RegExp.prototype.exec` method
	// https://tc39.es/ecma262/#sec-regexp.prototype.exec
	$$M({
	  target: 'RegExp',
	  proto: true,
	  forced: /./.exec !== exec$5
	}, {
	  exec: exec$5
	});

	var es_regexp_flags = {};

	var global$p = global$Z;
	var DESCRIPTORS$9 = descriptors;
	var defineBuiltInAccessor$7 = defineBuiltInAccessor$h;
	var regExpFlags = regexpFlags$1;
	var fails$n = fails$1m;

	// babel-minify and Closure Compiler transpiles RegExp('.', 'd') -> /./d and it causes SyntaxError
	var RegExp$2 = global$p.RegExp;
	var RegExpPrototype$4 = RegExp$2.prototype;
	var FORCED$4 = DESCRIPTORS$9 && fails$n(function () {
	  var INDICES_SUPPORT = true;
	  try {
	    RegExp$2('.', 'd');
	  } catch (error) {
	    INDICES_SUPPORT = false;
	  }
	  var O = {};
	  // modern V8 bug
	  var calls = '';
	  var expected = INDICES_SUPPORT ? 'dgimsy' : 'gimsy';
	  var addGetter = function addGetter(key, chr) {
	    // eslint-disable-next-line es/no-object-defineproperty -- safe
	    Object.defineProperty(O, key, {
	      get: function get() {
	        calls += chr;
	        return true;
	      }
	    });
	  };
	  var pairs = {
	    dotAll: 's',
	    global: 'g',
	    ignoreCase: 'i',
	    multiline: 'm',
	    sticky: 'y'
	  };
	  if (INDICES_SUPPORT) pairs.hasIndices = 'd';
	  for (var key in pairs) addGetter(key, pairs[key]);

	  // eslint-disable-next-line es/no-object-getownpropertydescriptor -- safe
	  var result = Object.getOwnPropertyDescriptor(RegExpPrototype$4, 'flags').get.call(O);
	  return result !== expected || calls !== expected;
	});

	// `RegExp.prototype.flags` getter
	// https://tc39.es/ecma262/#sec-get-regexp.prototype.flags
	if (FORCED$4) defineBuiltInAccessor$7(RegExpPrototype$4, 'flags', {
	  configurable: true,
	  get: regExpFlags
	});

	var es_regexp_sticky = {};

	var DESCRIPTORS$8 = descriptors;
	var MISSED_STICKY = regexpStickyHelpers.MISSED_STICKY;
	var classof$7 = classofRaw$2;
	var defineBuiltInAccessor$6 = defineBuiltInAccessor$h;
	var getInternalState$4 = internalState.get;
	var RegExpPrototype$3 = RegExp.prototype;
	var $TypeError$6 = TypeError;

	// `RegExp.prototype.sticky` getter
	// https://tc39.es/ecma262/#sec-get-regexp.prototype.sticky
	if (DESCRIPTORS$8 && MISSED_STICKY) {
	  defineBuiltInAccessor$6(RegExpPrototype$3, 'sticky', {
	    configurable: true,
	    get: function sticky() {
	      if (this === RegExpPrototype$3) return;
	      // We can't use InternalStateModule.getterFor because
	      // we don't add metadata for regexps created by a literal.
	      if (classof$7(this) === 'RegExp') {
	        return !!getInternalState$4(this).sticky;
	      }
	      throw $TypeError$6('Incompatible receiver, RegExp required');
	    }
	  });
	}

	var es_regexp_test = {};

	'use strict';
	// TODO: Remove from `core-js@4` since it's moved to entry points

	var $$L = _export;
	var call$f = functionCall;
	var isCallable$6 = isCallable$z;
	var anObject$b = anObject$D;
	var toString$i = toString$x;
	var DELEGATES_TO_EXEC = function () {
	  var execCalled = false;
	  var re = /[ac]/;
	  re.exec = function () {
	    execCalled = true;
	    return /./.exec.apply(this, arguments);
	  };
	  return re.test('abc') === true && execCalled;
	}();
	var nativeTest = /./.test;

	// `RegExp.prototype.test` method
	// https://tc39.es/ecma262/#sec-regexp.prototype.test
	$$L({
	  target: 'RegExp',
	  proto: true,
	  forced: !DELEGATES_TO_EXEC
	}, {
	  test: function test(S) {
	    var R = anObject$b(this);
	    var string = toString$i(S);
	    var exec = R.exec;
	    if (!isCallable$6(exec)) return call$f(nativeTest, R, string);
	    var result = call$f(exec, R, string);
	    if (result === null) return false;
	    anObject$b(result);
	    return true;
	  }
	});

	var es_regexp_toString = {};

	'use strict';
	var PROPER_FUNCTION_NAME$1 = functionName.PROPER;
	var defineBuiltIn$5 = defineBuiltIn$m;
	var anObject$a = anObject$D;
	var $toString$2 = toString$x;
	var fails$m = fails$1m;
	var getRegExpFlags$3 = regexpGetFlags;
	var TO_STRING = 'toString';
	var RegExpPrototype$2 = RegExp.prototype;
	var nativeToString = RegExpPrototype$2[TO_STRING];
	var NOT_GENERIC = fails$m(function () {
	  return nativeToString.call({
	    source: 'a',
	    flags: 'b'
	  }) != '/a/b';
	});
	// FF44- RegExp#toString has a wrong name
	var INCORRECT_NAME = PROPER_FUNCTION_NAME$1 && nativeToString.name != TO_STRING;

	// `RegExp.prototype.toString` method
	// https://tc39.es/ecma262/#sec-regexp.prototype.tostring
	if (NOT_GENERIC || INCORRECT_NAME) {
	  defineBuiltIn$5(RegExp.prototype, TO_STRING, function toString() {
	    var R = anObject$a(this);
	    var pattern = $toString$2(R.source);
	    var flags = $toString$2(getRegExpFlags$3(R));
	    return '/' + pattern + '/' + flags;
	  }, {
	    unsafe: true
	  });
	}

	var es_set = {};

	var es_set_constructor = {};

	'use strict';
	var collection$2 = collection$4;
	var collectionStrong = collectionStrong$2;

	// `Set` constructor
	// https://tc39.es/ecma262/#sec-set-objects
	collection$2('Set', function (init) {
	  return function Set() {
	    return init(this, arguments.length ? arguments[0] : undefined);
	  };
	}, collectionStrong);

	var es_string_atAlternative = {};

	'use strict';
	var $$K = _export;
	var uncurryThis$x = functionUncurryThis;
	var requireObjectCoercible$c = requireObjectCoercible$j;
	var toIntegerOrInfinity$6 = toIntegerOrInfinity$l;
	var toString$h = toString$x;
	var fails$l = fails$1m;
	var charAt$9 = uncurryThis$x(''.charAt);
	var FORCED$3 = fails$l(function () {
	  // eslint-disable-next-line es/no-array-string-prototype-at -- safe
	  return '𠮷'.at(-2) !== "\uD842";
	});

	// `String.prototype.at` method
	// https://github.com/tc39/proposal-relative-indexing-method
	$$K({
	  target: 'String',
	  proto: true,
	  forced: FORCED$3
	}, {
	  at: function at(index) {
	    var S = toString$h(requireObjectCoercible$c(this));
	    var len = S.length;
	    var relativeIndex = toIntegerOrInfinity$6(index);
	    var k = relativeIndex >= 0 ? relativeIndex : len + relativeIndex;
	    return k < 0 || k >= len ? undefined : charAt$9(S, k);
	  }
	});

	var es_string_codePointAt = {};

	var uncurryThis$w = functionUncurryThis;
	var toIntegerOrInfinity$5 = toIntegerOrInfinity$l;
	var toString$g = toString$x;
	var requireObjectCoercible$b = requireObjectCoercible$j;
	var charAt$8 = uncurryThis$w(''.charAt);
	var charCodeAt$2 = uncurryThis$w(''.charCodeAt);
	var stringSlice$9 = uncurryThis$w(''.slice);
	var createMethod = function createMethod(CONVERT_TO_STRING) {
	  return function ($this, pos) {
	    var S = toString$g(requireObjectCoercible$b($this));
	    var position = toIntegerOrInfinity$5(pos);
	    var size = S.length;
	    var first, second;
	    if (position < 0 || position >= size) return CONVERT_TO_STRING ? '' : undefined;
	    first = charCodeAt$2(S, position);
	    return first < 0xD800 || first > 0xDBFF || position + 1 === size || (second = charCodeAt$2(S, position + 1)) < 0xDC00 || second > 0xDFFF ? CONVERT_TO_STRING ? charAt$8(S, position) : first : CONVERT_TO_STRING ? stringSlice$9(S, position, position + 2) : (first - 0xD800 << 10) + (second - 0xDC00) + 0x10000;
	  };
	};
	var stringMultibyte = {
	  // `String.prototype.codePointAt` method
	  // https://tc39.es/ecma262/#sec-string.prototype.codepointat
	  codeAt: createMethod(false),
	  // `String.prototype.at` method
	  // https://github.com/mathiasbynens/String.prototype.at
	  charAt: createMethod(true)
	};
	var stringMultibyte$1 = /*@__PURE__*/getDefaultExportFromCjs(stringMultibyte);

	'use strict';
	var $$J = _export;
	var codeAt$1 = stringMultibyte.codeAt;

	// `String.prototype.codePointAt` method
	// https://tc39.es/ecma262/#sec-string.prototype.codepointat
	$$J({
	  target: 'String',
	  proto: true
	}, {
	  codePointAt: function codePointAt(pos) {
	    return codeAt$1(this, pos);
	  }
	});

	var es_string_endsWith = {};

	var isRegExp$3 = isRegexp;
	var $TypeError$5 = TypeError;
	var notARegexp = function notARegexp(it) {
	  if (isRegExp$3(it)) {
	    throw $TypeError$5("The method doesn't accept regular expressions");
	  }
	  return it;
	};
	var notARegexp$1 = /*@__PURE__*/getDefaultExportFromCjs(notARegexp);

	var wellKnownSymbol$8 = wellKnownSymbol$z;
	var MATCH = wellKnownSymbol$8('match');
	var correctIsRegexpLogic = function correctIsRegexpLogic(METHOD_NAME) {
	  var regexp = /./;
	  try {
	    '/./'[METHOD_NAME](regexp);
	  } catch (error1) {
	    try {
	      regexp[MATCH] = false;
	      return '/./'[METHOD_NAME](regexp);
	    } catch (error2) {/* empty */}
	  }
	  return false;
	};
	var correctIsRegexpLogic$1 = /*@__PURE__*/getDefaultExportFromCjs(correctIsRegexpLogic);

	'use strict';
	var $$I = _export;
	var uncurryThis$v = functionUncurryThisClause;
	var getOwnPropertyDescriptor$2 = objectGetOwnPropertyDescriptor.f;
	var toLength$7 = toLength$d;
	var toString$f = toString$x;
	var notARegExp$2 = notARegexp;
	var requireObjectCoercible$a = requireObjectCoercible$j;
	var correctIsRegExpLogic$2 = correctIsRegexpLogic;
	var IS_PURE$7 = isPure;

	// eslint-disable-next-line es/no-string-prototype-endswith -- safe
	var nativeEndsWith = uncurryThis$v(''.endsWith);
	var slice$4 = uncurryThis$v(''.slice);
	var min$8 = Math.min;
	var CORRECT_IS_REGEXP_LOGIC$1 = correctIsRegExpLogic$2('endsWith');
	// https://github.com/zloirock/core-js/pull/702
	var MDN_POLYFILL_BUG$1 = !IS_PURE$7 && !CORRECT_IS_REGEXP_LOGIC$1 && !!function () {
	  var descriptor = getOwnPropertyDescriptor$2(String.prototype, 'endsWith');
	  return descriptor && !descriptor.writable;
	}();

	// `String.prototype.endsWith` method
	// https://tc39.es/ecma262/#sec-string.prototype.endswith
	$$I({
	  target: 'String',
	  proto: true,
	  forced: !MDN_POLYFILL_BUG$1 && !CORRECT_IS_REGEXP_LOGIC$1
	}, {
	  endsWith: function endsWith(searchString /* , endPosition = @length */) {
	    var that = toString$f(requireObjectCoercible$a(this));
	    notARegExp$2(searchString);
	    var endPosition = arguments.length > 1 ? arguments[1] : undefined;
	    var len = that.length;
	    var end = endPosition === undefined ? len : min$8(toLength$7(endPosition), len);
	    var search = toString$f(searchString);
	    return nativeEndsWith ? nativeEndsWith(that, search, end) : slice$4(that, end - search.length, end) === search;
	  }
	});

	var es_string_fromCodePoint = {};

	var $$H = _export;
	var uncurryThis$u = functionUncurryThis;
	var toAbsoluteIndex$1 = toAbsoluteIndex$a;
	var $RangeError$3 = RangeError;
	var fromCharCode$3 = String.fromCharCode;
	// eslint-disable-next-line es/no-string-fromcodepoint -- required for testing
	var $fromCodePoint = String.fromCodePoint;
	var join$5 = uncurryThis$u([].join);

	// length should be 1, old FF problem
	var INCORRECT_LENGTH = !!$fromCodePoint && $fromCodePoint.length != 1;

	// `String.fromCodePoint` method
	// https://tc39.es/ecma262/#sec-string.fromcodepoint
	$$H({
	  target: 'String',
	  stat: true,
	  arity: 1,
	  forced: INCORRECT_LENGTH
	}, {
	  // eslint-disable-next-line no-unused-vars -- required for `.length`
	  fromCodePoint: function fromCodePoint(x) {
	    var elements = [];
	    var length = arguments.length;
	    var i = 0;
	    var code;
	    while (length > i) {
	      code = +arguments[i++];
	      if (toAbsoluteIndex$1(code, 0x10FFFF) !== code) throw $RangeError$3(code + ' is not a valid code point');
	      elements[i] = code < 0x10000 ? fromCharCode$3(code) : fromCharCode$3(((code -= 0x10000) >> 10) + 0xD800, code % 0x400 + 0xDC00);
	    }
	    return join$5(elements, '');
	  }
	});

	var es_string_includes = {};

	'use strict';
	var $$G = _export;
	var uncurryThis$t = functionUncurryThis;
	var notARegExp$1 = notARegexp;
	var requireObjectCoercible$9 = requireObjectCoercible$j;
	var toString$e = toString$x;
	var correctIsRegExpLogic$1 = correctIsRegexpLogic;
	var stringIndexOf$3 = uncurryThis$t(''.indexOf);

	// `String.prototype.includes` method
	// https://tc39.es/ecma262/#sec-string.prototype.includes
	$$G({
	  target: 'String',
	  proto: true,
	  forced: !correctIsRegExpLogic$1('includes')
	}, {
	  includes: function includes(searchString /* , position = 0 */) {
	    return !!~stringIndexOf$3(toString$e(requireObjectCoercible$9(this)), toString$e(notARegExp$1(searchString)), arguments.length > 1 ? arguments[1] : undefined);
	  }
	});

	var es_string_iterator = {};

	'use strict';
	var charAt$7 = stringMultibyte.charAt;
	var toString$d = toString$x;
	var InternalStateModule$6 = internalState;
	var defineIterator = iteratorDefine;
	var createIterResultObject$1 = createIterResultObject$4;
	var STRING_ITERATOR = 'String Iterator';
	var setInternalState$6 = InternalStateModule$6.set;
	var getInternalState$3 = InternalStateModule$6.getterFor(STRING_ITERATOR);

	// `String.prototype[@@iterator]` method
	// https://tc39.es/ecma262/#sec-string.prototype-@@iterator
	defineIterator(String, 'String', function (iterated) {
	  setInternalState$6(this, {
	    type: STRING_ITERATOR,
	    string: toString$d(iterated),
	    index: 0
	  });
	  // `%StringIteratorPrototype%.next` method
	  // https://tc39.es/ecma262/#sec-%stringiteratorprototype%.next
	}, function next() {
	  var state = getInternalState$3(this);
	  var string = state.string;
	  var index = state.index;
	  var point;
	  if (index >= string.length) return createIterResultObject$1(undefined, true);
	  point = charAt$7(string, index);
	  state.index += point.length;
	  return createIterResultObject$1(point, false);
	});

	var es_string_match = {};

	'use strict';
	// TODO: Remove from `core-js@4` since it's moved to entry points

	var uncurryThis$s = functionUncurryThisClause;
	var defineBuiltIn$4 = defineBuiltIn$m;
	var regexpExec$2 = regexpExec$3;
	var fails$k = fails$1m;
	var wellKnownSymbol$7 = wellKnownSymbol$z;
	var createNonEnumerableProperty$4 = createNonEnumerableProperty$f;
	var SPECIES = wellKnownSymbol$7('species');
	var RegExpPrototype$1 = RegExp.prototype;
	var fixRegexpWellKnownSymbolLogic = function fixRegexpWellKnownSymbolLogic(KEY, exec, FORCED, SHAM) {
	  var SYMBOL = wellKnownSymbol$7(KEY);
	  var DELEGATES_TO_SYMBOL = !fails$k(function () {
	    // String methods call symbol-named RegEp methods
	    var O = {};
	    O[SYMBOL] = function () {
	      return 7;
	    };
	    return ''[KEY](O) != 7;
	  });
	  var DELEGATES_TO_EXEC = DELEGATES_TO_SYMBOL && !fails$k(function () {
	    // Symbol-named RegExp methods call .exec
	    var execCalled = false;
	    var re = /a/;
	    if (KEY === 'split') {
	      // We can't use real regex here since it causes deoptimization
	      // and serious performance degradation in V8
	      // https://github.com/zloirock/core-js/issues/306
	      re = {};
	      // RegExp[@@split] doesn't call the regex's exec method, but first creates
	      // a new one. We need to return the patched regex when creating the new one.
	      re.constructor = {};
	      re.constructor[SPECIES] = function () {
	        return re;
	      };
	      re.flags = '';
	      re[SYMBOL] = /./[SYMBOL];
	    }
	    re.exec = function () {
	      execCalled = true;
	      return null;
	    };
	    re[SYMBOL]('');
	    return !execCalled;
	  });
	  if (!DELEGATES_TO_SYMBOL || !DELEGATES_TO_EXEC || FORCED) {
	    var uncurriedNativeRegExpMethod = uncurryThis$s(/./[SYMBOL]);
	    var methods = exec(SYMBOL, ''[KEY], function (nativeMethod, regexp, str, arg2, forceStringMethod) {
	      var uncurriedNativeMethod = uncurryThis$s(nativeMethod);
	      var $exec = regexp.exec;
	      if ($exec === regexpExec$2 || $exec === RegExpPrototype$1.exec) {
	        if (DELEGATES_TO_SYMBOL && !forceStringMethod) {
	          // The native String method already delegates to @@method (this
	          // polyfilled function), leasing to infinite recursion.
	          // We avoid it by directly calling the native @@method method.
	          return {
	            done: true,
	            value: uncurriedNativeRegExpMethod(regexp, str, arg2)
	          };
	        }
	        return {
	          done: true,
	          value: uncurriedNativeMethod(str, regexp, arg2)
	        };
	      }
	      return {
	        done: false
	      };
	    });
	    defineBuiltIn$4(String.prototype, KEY, methods[0]);
	    defineBuiltIn$4(RegExpPrototype$1, SYMBOL, methods[1]);
	  }
	  if (SHAM) createNonEnumerableProperty$4(RegExpPrototype$1[SYMBOL], 'sham', true);
	};
	var fixRegexpWellKnownSymbolLogic$1 = /*@__PURE__*/getDefaultExportFromCjs(fixRegexpWellKnownSymbolLogic);

	'use strict';
	var charAt$6 = stringMultibyte.charAt;

	// `AdvanceStringIndex` abstract operation
	// https://tc39.es/ecma262/#sec-advancestringindex
	var advanceStringIndex$4 = function advanceStringIndex(S, index, unicode) {
	  return index + (unicode ? charAt$6(S, index).length : 1);
	};
	var advanceStringIndex$5 = /*@__PURE__*/getDefaultExportFromCjs(advanceStringIndex$4);

	var call$e = functionCall;
	var anObject$9 = anObject$D;
	var isCallable$5 = isCallable$z;
	var classof$6 = classofRaw$2;
	var regexpExec$1 = regexpExec$3;
	var $TypeError$4 = TypeError;

	// `RegExpExec` abstract operation
	// https://tc39.es/ecma262/#sec-regexpexec
	var regexpExecAbstract = function regexpExecAbstract(R, S) {
	  var exec = R.exec;
	  if (isCallable$5(exec)) {
	    var result = call$e(exec, R, S);
	    if (result !== null) anObject$9(result);
	    return result;
	  }
	  if (classof$6(R) === 'RegExp') return call$e(regexpExec$1, R, S);
	  throw $TypeError$4('RegExp#exec called on incompatible receiver');
	};
	var regexpExecAbstract$1 = /*@__PURE__*/getDefaultExportFromCjs(regexpExecAbstract);

	'use strict';
	var call$d = functionCall;
	var fixRegExpWellKnownSymbolLogic$3 = fixRegexpWellKnownSymbolLogic;
	var anObject$8 = anObject$D;
	var isNullOrUndefined$7 = isNullOrUndefined$e;
	var toLength$6 = toLength$d;
	var toString$c = toString$x;
	var requireObjectCoercible$8 = requireObjectCoercible$j;
	var getMethod$5 = getMethod$9;
	var advanceStringIndex$3 = advanceStringIndex$4;
	var regExpExec$3 = regexpExecAbstract;

	// @@match logic
	fixRegExpWellKnownSymbolLogic$3('match', function (MATCH, nativeMatch, maybeCallNative) {
	  return [
	  // `String.prototype.match` method
	  // https://tc39.es/ecma262/#sec-string.prototype.match
	  function match(regexp) {
	    var O = requireObjectCoercible$8(this);
	    var matcher = isNullOrUndefined$7(regexp) ? undefined : getMethod$5(regexp, MATCH);
	    return matcher ? call$d(matcher, regexp, O) : new RegExp(regexp)[MATCH](toString$c(O));
	  },
	  // `RegExp.prototype[@@match]` method
	  // https://tc39.es/ecma262/#sec-regexp.prototype-@@match
	  function (string) {
	    var rx = anObject$8(this);
	    var S = toString$c(string);
	    var res = maybeCallNative(nativeMatch, rx, S);
	    if (res.done) return res.value;
	    if (!rx.global) return regExpExec$3(rx, S);
	    var fullUnicode = rx.unicode;
	    rx.lastIndex = 0;
	    var A = [];
	    var n = 0;
	    var result;
	    while ((result = regExpExec$3(rx, S)) !== null) {
	      var matchStr = toString$c(result[0]);
	      A[n] = matchStr;
	      if (matchStr === '') rx.lastIndex = advanceStringIndex$3(S, toLength$6(rx.lastIndex), fullUnicode);
	      n++;
	    }
	    return n === 0 ? null : A;
	  }];
	});

	var es_string_matchAll = {};

	'use strict';
	/* eslint-disable es/no-string-prototype-matchall -- safe */
	var $$F = _export;
	var call$c = functionCall;
	var uncurryThis$r = functionUncurryThisClause;
	var createIteratorConstructor$1 = iteratorCreateConstructor;
	var createIterResultObject = createIterResultObject$4;
	var requireObjectCoercible$7 = requireObjectCoercible$j;
	var toLength$5 = toLength$d;
	var toString$b = toString$x;
	var anObject$7 = anObject$D;
	var isNullOrUndefined$6 = isNullOrUndefined$e;
	var classof$5 = classofRaw$2;
	var isRegExp$2 = isRegexp;
	var getRegExpFlags$2 = regexpGetFlags;
	var getMethod$4 = getMethod$9;
	var defineBuiltIn$3 = defineBuiltIn$m;
	var fails$j = fails$1m;
	var wellKnownSymbol$6 = wellKnownSymbol$z;
	var speciesConstructor$2 = speciesConstructor$6;
	var advanceStringIndex$2 = advanceStringIndex$4;
	var regExpExec$2 = regexpExecAbstract;
	var InternalStateModule$5 = internalState;
	var IS_PURE$6 = isPure;
	var MATCH_ALL = wellKnownSymbol$6('matchAll');
	var REGEXP_STRING = 'RegExp String';
	var REGEXP_STRING_ITERATOR = REGEXP_STRING + ' Iterator';
	var setInternalState$5 = InternalStateModule$5.set;
	var getInternalState$2 = InternalStateModule$5.getterFor(REGEXP_STRING_ITERATOR);
	var RegExpPrototype = RegExp.prototype;
	var $TypeError$3 = TypeError;
	var stringIndexOf$2 = uncurryThis$r(''.indexOf);
	var nativeMatchAll = uncurryThis$r(''.matchAll);
	var WORKS_WITH_NON_GLOBAL_REGEX = !!nativeMatchAll && !fails$j(function () {
	  nativeMatchAll('a', /./);
	});
	var $RegExpStringIterator = createIteratorConstructor$1(function RegExpStringIterator(regexp, string, $global, fullUnicode) {
	  setInternalState$5(this, {
	    type: REGEXP_STRING_ITERATOR,
	    regexp: regexp,
	    string: string,
	    global: $global,
	    unicode: fullUnicode,
	    done: false
	  });
	}, REGEXP_STRING, function next() {
	  var state = getInternalState$2(this);
	  if (state.done) return createIterResultObject(undefined, true);
	  var R = state.regexp;
	  var S = state.string;
	  var match = regExpExec$2(R, S);
	  if (match === null) {
	    state.done = true;
	    return createIterResultObject(undefined, true);
	  }
	  if (state.global) {
	    if (toString$b(match[0]) === '') R.lastIndex = advanceStringIndex$2(S, toLength$5(R.lastIndex), state.unicode);
	    return createIterResultObject(match, false);
	  }
	  state.done = true;
	  return createIterResultObject(match, false);
	});
	var $matchAll = function $matchAll(string) {
	  var R = anObject$7(this);
	  var S = toString$b(string);
	  var C = speciesConstructor$2(R, RegExp);
	  var flags = toString$b(getRegExpFlags$2(R));
	  var matcher, $global, fullUnicode;
	  matcher = new C(C === RegExp ? R.source : R, flags);
	  $global = !!~stringIndexOf$2(flags, 'g');
	  fullUnicode = !!~stringIndexOf$2(flags, 'u');
	  matcher.lastIndex = toLength$5(R.lastIndex);
	  return new $RegExpStringIterator(matcher, S, $global, fullUnicode);
	};

	// `String.prototype.matchAll` method
	// https://tc39.es/ecma262/#sec-string.prototype.matchall
	$$F({
	  target: 'String',
	  proto: true,
	  forced: WORKS_WITH_NON_GLOBAL_REGEX
	}, {
	  matchAll: function matchAll(regexp) {
	    var O = requireObjectCoercible$7(this);
	    var flags, S, matcher, rx;
	    if (!isNullOrUndefined$6(regexp)) {
	      if (isRegExp$2(regexp)) {
	        flags = toString$b(requireObjectCoercible$7(getRegExpFlags$2(regexp)));
	        if (!~stringIndexOf$2(flags, 'g')) throw $TypeError$3('`.matchAll` does not allow non-global regexes');
	      }
	      if (WORKS_WITH_NON_GLOBAL_REGEX) return nativeMatchAll(O, regexp);
	      matcher = getMethod$4(regexp, MATCH_ALL);
	      if (matcher === undefined && IS_PURE$6 && classof$5(regexp) == 'RegExp') matcher = $matchAll;
	      if (matcher) return call$c(matcher, regexp, O);
	    } else if (WORKS_WITH_NON_GLOBAL_REGEX) return nativeMatchAll(O, regexp);
	    S = toString$b(O);
	    rx = new RegExp(regexp, 'g');
	    return IS_PURE$6 ? call$c($matchAll, rx, S) : rx[MATCH_ALL](S);
	  }
	});
	IS_PURE$6 || MATCH_ALL in RegExpPrototype || defineBuiltIn$3(RegExpPrototype, MATCH_ALL, $matchAll);

	var es_string_padEnd = {};

	// https://github.com/zloirock/core-js/issues/280
	var userAgent = engineUserAgent;
	var stringPadWebkitBug = /Version\/10(?:\.\d+){1,2}(?: [\w./]+)?(?: Mobile\/\w+)? Safari\//.test(userAgent);
	var stringPadWebkitBug$1 = /*@__PURE__*/getDefaultExportFromCjs(stringPadWebkitBug);

	'use strict';
	var $$E = _export;
	var $padEnd = stringPad.end;
	var WEBKIT_BUG$1 = stringPadWebkitBug;

	// `String.prototype.padEnd` method
	// https://tc39.es/ecma262/#sec-string.prototype.padend
	$$E({
	  target: 'String',
	  proto: true,
	  forced: WEBKIT_BUG$1
	}, {
	  padEnd: function padEnd(maxLength /* , fillString = ' ' */) {
	    return $padEnd(this, maxLength, arguments.length > 1 ? arguments[1] : undefined);
	  }
	});

	var es_string_padStart = {};

	'use strict';
	var $$D = _export;
	var $padStart = stringPad.start;
	var WEBKIT_BUG = stringPadWebkitBug;

	// `String.prototype.padStart` method
	// https://tc39.es/ecma262/#sec-string.prototype.padstart
	$$D({
	  target: 'String',
	  proto: true,
	  forced: WEBKIT_BUG
	}, {
	  padStart: function padStart(maxLength /* , fillString = ' ' */) {
	    return $padStart(this, maxLength, arguments.length > 1 ? arguments[1] : undefined);
	  }
	});

	var es_string_raw = {};

	var $$C = _export;
	var uncurryThis$q = functionUncurryThis;
	var toIndexedObject$1 = toIndexedObject$j;
	var toObject$2 = toObject$t;
	var toString$a = toString$x;
	var lengthOfArrayLike$4 = lengthOfArrayLike$t;
	var push$6 = uncurryThis$q([].push);
	var join$4 = uncurryThis$q([].join);

	// `String.raw` method
	// https://tc39.es/ecma262/#sec-string.raw
	$$C({
	  target: 'String',
	  stat: true
	}, {
	  raw: function raw(template) {
	    var rawTemplate = toIndexedObject$1(toObject$2(template).raw);
	    var literalSegments = lengthOfArrayLike$4(rawTemplate);
	    if (!literalSegments) return '';
	    var argumentsLength = arguments.length;
	    var elements = [];
	    var i = 0;
	    while (true) {
	      push$6(elements, toString$a(rawTemplate[i++]));
	      if (i === literalSegments) return join$4(elements, '');
	      if (i < argumentsLength) push$6(elements, toString$a(arguments[i]));
	    }
	  }
	});

	var es_string_repeat = {};

	var $$B = _export;
	var repeat$1 = stringRepeat;

	// `String.prototype.repeat` method
	// https://tc39.es/ecma262/#sec-string.prototype.repeat
	$$B({
	  target: 'String',
	  proto: true
	}, {
	  repeat: repeat$1
	});

	var es_string_replace = {};

	var uncurryThis$p = functionUncurryThis;
	var toObject$1 = toObject$t;
	var floor$6 = Math.floor;
	var charAt$5 = uncurryThis$p(''.charAt);
	var replace$6 = uncurryThis$p(''.replace);
	var stringSlice$8 = uncurryThis$p(''.slice);
	// eslint-disable-next-line redos/no-vulnerable -- safe
	var SUBSTITUTION_SYMBOLS = /\$([$&'`]|\d{1,2}|<[^>]*>)/g;
	var SUBSTITUTION_SYMBOLS_NO_NAMED = /\$([$&'`]|\d{1,2})/g;

	// `GetSubstitution` abstract operation
	// https://tc39.es/ecma262/#sec-getsubstitution
	var getSubstitution$2 = function getSubstitution(matched, str, position, captures, namedCaptures, replacement) {
	  var tailPos = position + matched.length;
	  var m = captures.length;
	  var symbols = SUBSTITUTION_SYMBOLS_NO_NAMED;
	  if (namedCaptures !== undefined) {
	    namedCaptures = toObject$1(namedCaptures);
	    symbols = SUBSTITUTION_SYMBOLS;
	  }
	  return replace$6(replacement, symbols, function (match, ch) {
	    var capture;
	    switch (charAt$5(ch, 0)) {
	      case '$':
	        return '$';
	      case '&':
	        return matched;
	      case '`':
	        return stringSlice$8(str, 0, position);
	      case "'":
	        return stringSlice$8(str, tailPos);
	      case '<':
	        capture = namedCaptures[stringSlice$8(ch, 1, -1)];
	        break;
	      default:
	        // \d\d?
	        var n = +ch;
	        if (n === 0) return match;
	        if (n > m) {
	          var f = floor$6(n / 10);
	          if (f === 0) return match;
	          if (f <= m) return captures[f - 1] === undefined ? charAt$5(ch, 1) : captures[f - 1] + charAt$5(ch, 1);
	          return match;
	        }
	        capture = captures[n - 1];
	    }
	    return capture === undefined ? '' : capture;
	  });
	};
	var getSubstitution$3 = /*@__PURE__*/getDefaultExportFromCjs(getSubstitution$2);

	'use strict';
	var apply$4 = functionApply$1;
	var call$b = functionCall;
	var uncurryThis$o = functionUncurryThis;
	var fixRegExpWellKnownSymbolLogic$2 = fixRegexpWellKnownSymbolLogic;
	var fails$i = fails$1m;
	var anObject$6 = anObject$D;
	var isCallable$4 = isCallable$z;
	var isNullOrUndefined$5 = isNullOrUndefined$e;
	var toIntegerOrInfinity$4 = toIntegerOrInfinity$l;
	var toLength$4 = toLength$d;
	var toString$9 = toString$x;
	var requireObjectCoercible$6 = requireObjectCoercible$j;
	var advanceStringIndex$1 = advanceStringIndex$4;
	var getMethod$3 = getMethod$9;
	var getSubstitution$1 = getSubstitution$2;
	var regExpExec$1 = regexpExecAbstract;
	var wellKnownSymbol$5 = wellKnownSymbol$z;
	var REPLACE$1 = wellKnownSymbol$5('replace');
	var max$6 = Math.max;
	var min$7 = Math.min;
	var concat$3 = uncurryThis$o([].concat);
	var push$5 = uncurryThis$o([].push);
	var stringIndexOf$1 = uncurryThis$o(''.indexOf);
	var stringSlice$7 = uncurryThis$o(''.slice);
	var maybeToString = function maybeToString(it) {
	  return it === undefined ? it : String(it);
	};

	// IE <= 11 replaces $0 with the whole match, as if it was $&
	// https://stackoverflow.com/questions/6024666/getting-ie-to-replace-a-regex-with-the-literal-string-0
	var REPLACE_KEEPS_$0 = function () {
	  // eslint-disable-next-line regexp/prefer-escape-replacement-dollar-char -- required for testing
	  return 'a'.replace(/./, '$0') === '$0';
	}();

	// Safari <= 13.0.3(?) substitutes nth capture where n>m with an empty string
	var REGEXP_REPLACE_SUBSTITUTES_UNDEFINED_CAPTURE = function () {
	  if (/./[REPLACE$1]) {
	    return /./[REPLACE$1]('a', '$0') === '';
	  }
	  return false;
	}();
	var REPLACE_SUPPORTS_NAMED_GROUPS = !fails$i(function () {
	  var re = /./;
	  re.exec = function () {
	    var result = [];
	    result.groups = {
	      a: '7'
	    };
	    return result;
	  };
	  // eslint-disable-next-line regexp/no-useless-dollar-replacements -- false positive
	  return ''.replace(re, '$<a>') !== '7';
	});

	// @@replace logic
	fixRegExpWellKnownSymbolLogic$2('replace', function (_, nativeReplace, maybeCallNative) {
	  var UNSAFE_SUBSTITUTE = REGEXP_REPLACE_SUBSTITUTES_UNDEFINED_CAPTURE ? '$' : '$0';
	  return [
	  // `String.prototype.replace` method
	  // https://tc39.es/ecma262/#sec-string.prototype.replace
	  function replace(searchValue, replaceValue) {
	    var O = requireObjectCoercible$6(this);
	    var replacer = isNullOrUndefined$5(searchValue) ? undefined : getMethod$3(searchValue, REPLACE$1);
	    return replacer ? call$b(replacer, searchValue, O, replaceValue) : call$b(nativeReplace, toString$9(O), searchValue, replaceValue);
	  },
	  // `RegExp.prototype[@@replace]` method
	  // https://tc39.es/ecma262/#sec-regexp.prototype-@@replace
	  function (string, replaceValue) {
	    var rx = anObject$6(this);
	    var S = toString$9(string);
	    if (typeof replaceValue == 'string' && stringIndexOf$1(replaceValue, UNSAFE_SUBSTITUTE) === -1 && stringIndexOf$1(replaceValue, '$<') === -1) {
	      var res = maybeCallNative(nativeReplace, rx, S, replaceValue);
	      if (res.done) return res.value;
	    }
	    var functionalReplace = isCallable$4(replaceValue);
	    if (!functionalReplace) replaceValue = toString$9(replaceValue);
	    var global = rx.global;
	    if (global) {
	      var fullUnicode = rx.unicode;
	      rx.lastIndex = 0;
	    }
	    var results = [];
	    while (true) {
	      var result = regExpExec$1(rx, S);
	      if (result === null) break;
	      push$5(results, result);
	      if (!global) break;
	      var matchStr = toString$9(result[0]);
	      if (matchStr === '') rx.lastIndex = advanceStringIndex$1(S, toLength$4(rx.lastIndex), fullUnicode);
	    }
	    var accumulatedResult = '';
	    var nextSourcePosition = 0;
	    for (var i = 0; i < results.length; i++) {
	      result = results[i];
	      var matched = toString$9(result[0]);
	      var position = max$6(min$7(toIntegerOrInfinity$4(result.index), S.length), 0);
	      var captures = [];
	      // NOTE: This is equivalent to
	      //   captures = result.slice(1).map(maybeToString)
	      // but for some reason `nativeSlice.call(result, 1, result.length)` (called in
	      // the slice polyfill when slicing native arrays) "doesn't work" in safari 9 and
	      // causes a crash (https://pastebin.com/N21QzeQA) when trying to debug it.
	      for (var j = 1; j < result.length; j++) push$5(captures, maybeToString(result[j]));
	      var namedCaptures = result.groups;
	      if (functionalReplace) {
	        var replacerArgs = concat$3([matched], captures, position, S);
	        if (namedCaptures !== undefined) push$5(replacerArgs, namedCaptures);
	        var replacement = toString$9(apply$4(replaceValue, undefined, replacerArgs));
	      } else {
	        replacement = getSubstitution$1(matched, S, position, captures, namedCaptures, replaceValue);
	      }
	      if (position >= nextSourcePosition) {
	        accumulatedResult += stringSlice$7(S, nextSourcePosition, position) + replacement;
	        nextSourcePosition = position + matched.length;
	      }
	    }
	    return accumulatedResult + stringSlice$7(S, nextSourcePosition);
	  }];
	}, !REPLACE_SUPPORTS_NAMED_GROUPS || !REPLACE_KEEPS_$0 || REGEXP_REPLACE_SUBSTITUTES_UNDEFINED_CAPTURE);

	var es_string_replaceAll = {};

	'use strict';
	var $$A = _export;
	var call$a = functionCall;
	var uncurryThis$n = functionUncurryThis;
	var requireObjectCoercible$5 = requireObjectCoercible$j;
	var isCallable$3 = isCallable$z;
	var isNullOrUndefined$4 = isNullOrUndefined$e;
	var isRegExp$1 = isRegexp;
	var toString$8 = toString$x;
	var getMethod$2 = getMethod$9;
	var getRegExpFlags$1 = regexpGetFlags;
	var getSubstitution = getSubstitution$2;
	var wellKnownSymbol$4 = wellKnownSymbol$z;
	var IS_PURE$5 = isPure;
	var REPLACE = wellKnownSymbol$4('replace');
	var $TypeError$2 = TypeError;
	var indexOf = uncurryThis$n(''.indexOf);
	var replace$5 = uncurryThis$n(''.replace);
	var stringSlice$6 = uncurryThis$n(''.slice);
	var max$5 = Math.max;
	var stringIndexOf = function stringIndexOf(string, searchValue, fromIndex) {
	  if (fromIndex > string.length) return -1;
	  if (searchValue === '') return fromIndex;
	  return indexOf(string, searchValue, fromIndex);
	};

	// `String.prototype.replaceAll` method
	// https://tc39.es/ecma262/#sec-string.prototype.replaceall
	$$A({
	  target: 'String',
	  proto: true
	}, {
	  replaceAll: function replaceAll(searchValue, replaceValue) {
	    var O = requireObjectCoercible$5(this);
	    var IS_REG_EXP, flags, replacer, string, searchString, functionalReplace, searchLength, advanceBy, replacement;
	    var position = 0;
	    var endOfLastMatch = 0;
	    var result = '';
	    if (!isNullOrUndefined$4(searchValue)) {
	      IS_REG_EXP = isRegExp$1(searchValue);
	      if (IS_REG_EXP) {
	        flags = toString$8(requireObjectCoercible$5(getRegExpFlags$1(searchValue)));
	        if (!~indexOf(flags, 'g')) throw $TypeError$2('`.replaceAll` does not allow non-global regexes');
	      }
	      replacer = getMethod$2(searchValue, REPLACE);
	      if (replacer) {
	        return call$a(replacer, searchValue, O, replaceValue);
	      } else if (IS_PURE$5 && IS_REG_EXP) {
	        return replace$5(toString$8(O), searchValue, replaceValue);
	      }
	    }
	    string = toString$8(O);
	    searchString = toString$8(searchValue);
	    functionalReplace = isCallable$3(replaceValue);
	    if (!functionalReplace) replaceValue = toString$8(replaceValue);
	    searchLength = searchString.length;
	    advanceBy = max$5(1, searchLength);
	    position = stringIndexOf(string, searchString, 0);
	    while (position !== -1) {
	      replacement = functionalReplace ? toString$8(replaceValue(searchString, position, string)) : getSubstitution(searchString, string, position, [], undefined, replaceValue);
	      result += stringSlice$6(string, endOfLastMatch, position) + replacement;
	      endOfLastMatch = position + searchLength;
	      position = stringIndexOf(string, searchString, position + advanceBy);
	    }
	    if (endOfLastMatch < string.length) {
	      result += stringSlice$6(string, endOfLastMatch);
	    }
	    return result;
	  }
	});

	var es_string_search = {};

	'use strict';
	var call$9 = functionCall;
	var fixRegExpWellKnownSymbolLogic$1 = fixRegexpWellKnownSymbolLogic;
	var anObject$5 = anObject$D;
	var isNullOrUndefined$3 = isNullOrUndefined$e;
	var requireObjectCoercible$4 = requireObjectCoercible$j;
	var sameValue = sameValue$1;
	var toString$7 = toString$x;
	var getMethod$1 = getMethod$9;
	var regExpExec = regexpExecAbstract;

	// @@search logic
	fixRegExpWellKnownSymbolLogic$1('search', function (SEARCH, nativeSearch, maybeCallNative) {
	  return [
	  // `String.prototype.search` method
	  // https://tc39.es/ecma262/#sec-string.prototype.search
	  function search(regexp) {
	    var O = requireObjectCoercible$4(this);
	    var searcher = isNullOrUndefined$3(regexp) ? undefined : getMethod$1(regexp, SEARCH);
	    return searcher ? call$9(searcher, regexp, O) : new RegExp(regexp)[SEARCH](toString$7(O));
	  },
	  // `RegExp.prototype[@@search]` method
	  // https://tc39.es/ecma262/#sec-regexp.prototype-@@search
	  function (string) {
	    var rx = anObject$5(this);
	    var S = toString$7(string);
	    var res = maybeCallNative(nativeSearch, rx, S);
	    if (res.done) return res.value;
	    var previousLastIndex = rx.lastIndex;
	    if (!sameValue(previousLastIndex, 0)) rx.lastIndex = 0;
	    var result = regExpExec(rx, S);
	    if (!sameValue(rx.lastIndex, previousLastIndex)) rx.lastIndex = previousLastIndex;
	    return result === null ? -1 : result.index;
	  }];
	});

	var es_string_split = {};

	'use strict';
	var apply$3 = functionApply$1;
	var call$8 = functionCall;
	var uncurryThis$m = functionUncurryThis;
	var fixRegExpWellKnownSymbolLogic = fixRegexpWellKnownSymbolLogic;
	var anObject$4 = anObject$D;
	var isNullOrUndefined$2 = isNullOrUndefined$e;
	var isRegExp = isRegexp;
	var requireObjectCoercible$3 = requireObjectCoercible$j;
	var speciesConstructor$1 = speciesConstructor$6;
	var advanceStringIndex = advanceStringIndex$4;
	var toLength$3 = toLength$d;
	var toString$6 = toString$x;
	var getMethod = getMethod$9;
	var arraySlice$4 = arraySliceSimple;
	var callRegExpExec = regexpExecAbstract;
	var regexpExec = regexpExec$3;
	var stickyHelpers = regexpStickyHelpers;
	var fails$h = fails$1m;
	var UNSUPPORTED_Y = stickyHelpers.UNSUPPORTED_Y;
	var MAX_UINT32 = 0xFFFFFFFF;
	var min$6 = Math.min;
	var $push = [].push;
	var exec$4 = uncurryThis$m(/./.exec);
	var push$4 = uncurryThis$m($push);
	var stringSlice$5 = uncurryThis$m(''.slice);

	// Chrome 51 has a buggy "split" implementation when RegExp#exec !== nativeExec
	// Weex JS has frozen built-in prototypes, so use try / catch wrapper
	var SPLIT_WORKS_WITH_OVERWRITTEN_EXEC = !fails$h(function () {
	  // eslint-disable-next-line regexp/no-empty-group -- required for testing
	  var re = /(?:)/;
	  var originalExec = re.exec;
	  re.exec = function () {
	    return originalExec.apply(this, arguments);
	  };
	  var result = 'ab'.split(re);
	  return result.length !== 2 || result[0] !== 'a' || result[1] !== 'b';
	});

	// @@split logic
	fixRegExpWellKnownSymbolLogic('split', function (SPLIT, nativeSplit, maybeCallNative) {
	  var internalSplit;
	  if ('abbc'.split(/(b)*/)[1] == 'c' ||
	  // eslint-disable-next-line regexp/no-empty-group -- required for testing
	  'test'.split(/(?:)/, -1).length != 4 || 'ab'.split(/(?:ab)*/).length != 2 || '.'.split(/(.?)(.?)/).length != 4 ||
	  // eslint-disable-next-line regexp/no-empty-capturing-group, regexp/no-empty-group -- required for testing
	  '.'.split(/()()/).length > 1 || ''.split(/.?/).length) {
	    // based on es5-shim implementation, need to rework it
	    internalSplit = function internalSplit(separator, limit) {
	      var string = toString$6(requireObjectCoercible$3(this));
	      var lim = limit === undefined ? MAX_UINT32 : limit >>> 0;
	      if (lim === 0) return [];
	      if (separator === undefined) return [string];
	      // If `separator` is not a regex, use native split
	      if (!isRegExp(separator)) {
	        return call$8(nativeSplit, string, separator, lim);
	      }
	      var output = [];
	      var flags = (separator.ignoreCase ? 'i' : '') + (separator.multiline ? 'm' : '') + (separator.unicode ? 'u' : '') + (separator.sticky ? 'y' : '');
	      var lastLastIndex = 0;
	      // Make `global` and avoid `lastIndex` issues by working with a copy
	      var separatorCopy = new RegExp(separator.source, flags + 'g');
	      var match, lastIndex, lastLength;
	      while (match = call$8(regexpExec, separatorCopy, string)) {
	        lastIndex = separatorCopy.lastIndex;
	        if (lastIndex > lastLastIndex) {
	          push$4(output, stringSlice$5(string, lastLastIndex, match.index));
	          if (match.length > 1 && match.index < string.length) apply$3($push, output, arraySlice$4(match, 1));
	          lastLength = match[0].length;
	          lastLastIndex = lastIndex;
	          if (output.length >= lim) break;
	        }
	        if (separatorCopy.lastIndex === match.index) separatorCopy.lastIndex++; // Avoid an infinite loop
	      }

	      if (lastLastIndex === string.length) {
	        if (lastLength || !exec$4(separatorCopy, '')) push$4(output, '');
	      } else push$4(output, stringSlice$5(string, lastLastIndex));
	      return output.length > lim ? arraySlice$4(output, 0, lim) : output;
	    };
	    // Chakra, V8
	  } else if ('0'.split(undefined, 0).length) {
	    internalSplit = function internalSplit(separator, limit) {
	      return separator === undefined && limit === 0 ? [] : call$8(nativeSplit, this, separator, limit);
	    };
	  } else internalSplit = nativeSplit;
	  return [
	  // `String.prototype.split` method
	  // https://tc39.es/ecma262/#sec-string.prototype.split
	  function split(separator, limit) {
	    var O = requireObjectCoercible$3(this);
	    var splitter = isNullOrUndefined$2(separator) ? undefined : getMethod(separator, SPLIT);
	    return splitter ? call$8(splitter, separator, O, limit) : call$8(internalSplit, toString$6(O), separator, limit);
	  },
	  // `RegExp.prototype[@@split]` method
	  // https://tc39.es/ecma262/#sec-regexp.prototype-@@split
	  //
	  // NOTE: This cannot be properly polyfilled in engines that don't support
	  // the 'y' flag.
	  function (string, limit) {
	    var rx = anObject$4(this);
	    var S = toString$6(string);
	    var res = maybeCallNative(internalSplit, rx, S, limit, internalSplit !== nativeSplit);
	    if (res.done) return res.value;
	    var C = speciesConstructor$1(rx, RegExp);
	    var unicodeMatching = rx.unicode;
	    var flags = (rx.ignoreCase ? 'i' : '') + (rx.multiline ? 'm' : '') + (rx.unicode ? 'u' : '') + (UNSUPPORTED_Y ? 'g' : 'y');

	    // ^(? + rx + ) is needed, in combination with some S slicing, to
	    // simulate the 'y' flag.
	    var splitter = new C(UNSUPPORTED_Y ? '^(?:' + rx.source + ')' : rx, flags);
	    var lim = limit === undefined ? MAX_UINT32 : limit >>> 0;
	    if (lim === 0) return [];
	    if (S.length === 0) return callRegExpExec(splitter, S) === null ? [S] : [];
	    var p = 0;
	    var q = 0;
	    var A = [];
	    while (q < S.length) {
	      splitter.lastIndex = UNSUPPORTED_Y ? 0 : q;
	      var z = callRegExpExec(splitter, UNSUPPORTED_Y ? stringSlice$5(S, q) : S);
	      var e;
	      if (z === null || (e = min$6(toLength$3(splitter.lastIndex + (UNSUPPORTED_Y ? q : 0)), S.length)) === p) {
	        q = advanceStringIndex(S, q, unicodeMatching);
	      } else {
	        push$4(A, stringSlice$5(S, p, q));
	        if (A.length === lim) return A;
	        for (var i = 1; i <= z.length - 1; i++) {
	          push$4(A, z[i]);
	          if (A.length === lim) return A;
	        }
	        q = p = e;
	      }
	    }
	    push$4(A, stringSlice$5(S, p));
	    return A;
	  }];
	}, !SPLIT_WORKS_WITH_OVERWRITTEN_EXEC, UNSUPPORTED_Y);

	var es_string_startsWith = {};

	'use strict';
	var $$z = _export;
	var uncurryThis$l = functionUncurryThisClause;
	var getOwnPropertyDescriptor$1 = objectGetOwnPropertyDescriptor.f;
	var toLength$2 = toLength$d;
	var toString$5 = toString$x;
	var notARegExp = notARegexp;
	var requireObjectCoercible$2 = requireObjectCoercible$j;
	var correctIsRegExpLogic = correctIsRegexpLogic;
	var IS_PURE$4 = isPure;

	// eslint-disable-next-line es/no-string-prototype-startswith -- safe
	var nativeStartsWith = uncurryThis$l(''.startsWith);
	var stringSlice$4 = uncurryThis$l(''.slice);
	var min$5 = Math.min;
	var CORRECT_IS_REGEXP_LOGIC = correctIsRegExpLogic('startsWith');
	// https://github.com/zloirock/core-js/pull/702
	var MDN_POLYFILL_BUG = !IS_PURE$4 && !CORRECT_IS_REGEXP_LOGIC && !!function () {
	  var descriptor = getOwnPropertyDescriptor$1(String.prototype, 'startsWith');
	  return descriptor && !descriptor.writable;
	}();

	// `String.prototype.startsWith` method
	// https://tc39.es/ecma262/#sec-string.prototype.startswith
	$$z({
	  target: 'String',
	  proto: true,
	  forced: !MDN_POLYFILL_BUG && !CORRECT_IS_REGEXP_LOGIC
	}, {
	  startsWith: function startsWith(searchString /* , position = 0 */) {
	    var that = toString$5(requireObjectCoercible$2(this));
	    notARegExp(searchString);
	    var index = toLength$2(min$5(arguments.length > 1 ? arguments[1] : undefined, that.length));
	    var search = toString$5(searchString);
	    return nativeStartsWith ? nativeStartsWith(that, search, index) : stringSlice$4(that, index, index + search.length) === search;
	  }
	});

	var es_string_substr = {};

	'use strict';
	var $$y = _export;
	var uncurryThis$k = functionUncurryThis;
	var requireObjectCoercible$1 = requireObjectCoercible$j;
	var toIntegerOrInfinity$3 = toIntegerOrInfinity$l;
	var toString$4 = toString$x;
	var stringSlice$3 = uncurryThis$k(''.slice);
	var max$4 = Math.max;
	var min$4 = Math.min;

	// eslint-disable-next-line unicorn/prefer-string-slice -- required for testing
	var FORCED$2 = !''.substr || 'ab'.substr(-1) !== 'b';

	// `String.prototype.substr` method
	// https://tc39.es/ecma262/#sec-string.prototype.substr
	$$y({
	  target: 'String',
	  proto: true,
	  forced: FORCED$2
	}, {
	  substr: function substr(start, length) {
	    var that = toString$4(requireObjectCoercible$1(this));
	    var size = that.length;
	    var intStart = toIntegerOrInfinity$3(start);
	    var intLength, intEnd;
	    if (intStart === Infinity) intStart = 0;
	    if (intStart < 0) intStart = max$4(size + intStart, 0);
	    intLength = length === undefined ? size : toIntegerOrInfinity$3(length);
	    if (intLength <= 0 || intLength === Infinity) return '';
	    intEnd = min$4(intStart + intLength, size);
	    return intStart >= intEnd ? '' : stringSlice$3(that, intStart, intEnd);
	  }
	});

	var es_string_trim = {};

	var PROPER_FUNCTION_NAME = functionName.PROPER;
	var fails$g = fails$1m;
	var whitespaces$1 = whitespaces$5;
	var non = "\u200B\x85\u180E";

	// check that a method works with the correct list
	// of whitespaces and has a correct name
	var stringTrimForced = function stringTrimForced(METHOD_NAME) {
	  return fails$g(function () {
	    return !!whitespaces$1[METHOD_NAME]() || non[METHOD_NAME]() !== non || PROPER_FUNCTION_NAME && whitespaces$1[METHOD_NAME].name !== METHOD_NAME;
	  });
	};
	var stringTrimForced$1 = /*@__PURE__*/getDefaultExportFromCjs(stringTrimForced);

	'use strict';
	var $$x = _export;
	var $trim = stringTrim.trim;
	var forcedStringTrimMethod$2 = stringTrimForced;

	// `String.prototype.trim` method
	// https://tc39.es/ecma262/#sec-string.prototype.trim
	$$x({
	  target: 'String',
	  proto: true,
	  forced: forcedStringTrimMethod$2('trim')
	}, {
	  trim: function trim() {
	    return $trim(this);
	  }
	});

	var es_string_trimEnd = {};

	var es_string_trimRight = {};

	'use strict';
	var $trimEnd = stringTrim.end;
	var forcedStringTrimMethod$1 = stringTrimForced;

	// `String.prototype.{ trimEnd, trimRight }` method
	// https://tc39.es/ecma262/#sec-string.prototype.trimend
	// https://tc39.es/ecma262/#String.prototype.trimright
	var stringTrimEnd = forcedStringTrimMethod$1('trimEnd') ? function trimEnd() {
	  return $trimEnd(this);
	  // eslint-disable-next-line es/no-string-prototype-trimstart-trimend -- safe
	} : ''.trimEnd;
	var stringTrimEnd$1 = /*@__PURE__*/getDefaultExportFromCjs(stringTrimEnd);

	var $$w = _export;
	var trimEnd$1 = stringTrimEnd;

	// `String.prototype.trimRight` method
	// https://tc39.es/ecma262/#sec-string.prototype.trimend
	// eslint-disable-next-line es/no-string-prototype-trimleft-trimright -- safe
	$$w({
	  target: 'String',
	  proto: true,
	  name: 'trimEnd',
	  forced: ''.trimRight !== trimEnd$1
	}, {
	  trimRight: trimEnd$1
	});

	// TODO: Remove this line from `core-js@4`

	var $$v = _export;
	var trimEnd = stringTrimEnd;

	// `String.prototype.trimEnd` method
	// https://tc39.es/ecma262/#sec-string.prototype.trimend
	// eslint-disable-next-line es/no-string-prototype-trimstart-trimend -- safe
	$$v({
	  target: 'String',
	  proto: true,
	  name: 'trimEnd',
	  forced: ''.trimEnd !== trimEnd
	}, {
	  trimEnd: trimEnd
	});

	var es_string_trimStart = {};

	var es_string_trimLeft = {};

	'use strict';
	var $trimStart = stringTrim.start;
	var forcedStringTrimMethod = stringTrimForced;

	// `String.prototype.{ trimStart, trimLeft }` method
	// https://tc39.es/ecma262/#sec-string.prototype.trimstart
	// https://tc39.es/ecma262/#String.prototype.trimleft
	var stringTrimStart = forcedStringTrimMethod('trimStart') ? function trimStart() {
	  return $trimStart(this);
	  // eslint-disable-next-line es/no-string-prototype-trimstart-trimend -- safe
	} : ''.trimStart;
	var stringTrimStart$1 = /*@__PURE__*/getDefaultExportFromCjs(stringTrimStart);

	var $$u = _export;
	var trimStart$1 = stringTrimStart;

	// `String.prototype.trimLeft` method
	// https://tc39.es/ecma262/#sec-string.prototype.trimleft
	// eslint-disable-next-line es/no-string-prototype-trimleft-trimright -- safe
	$$u({
	  target: 'String',
	  proto: true,
	  name: 'trimStart',
	  forced: ''.trimLeft !== trimStart$1
	}, {
	  trimLeft: trimStart$1
	});

	// TODO: Remove this line from `core-js@4`

	var $$t = _export;
	var trimStart = stringTrimStart;

	// `String.prototype.trimStart` method
	// https://tc39.es/ecma262/#sec-string.prototype.trimstart
	// eslint-disable-next-line es/no-string-prototype-trimstart-trimend -- safe
	$$t({
	  target: 'String',
	  proto: true,
	  name: 'trimStart',
	  forced: ''.trimStart !== trimStart
	}, {
	  trimStart: trimStart
	});

	var es_string_anchor = {};

	var uncurryThis$j = functionUncurryThis;
	var requireObjectCoercible = requireObjectCoercible$j;
	var toString$3 = toString$x;
	var quot = /"/g;
	var replace$4 = uncurryThis$j(''.replace);

	// `CreateHTML` abstract operation
	// https://tc39.es/ecma262/#sec-createhtml
	var createHtml = function createHtml(string, tag, attribute, value) {
	  var S = toString$3(requireObjectCoercible(string));
	  var p1 = '<' + tag;
	  if (attribute !== '') p1 += ' ' + attribute + '="' + replace$4(toString$3(value), quot, '&quot;') + '"';
	  return p1 + '>' + S + '</' + tag + '>';
	};
	var createHtml$1 = /*@__PURE__*/getDefaultExportFromCjs(createHtml);

	var fails$f = fails$1m;

	// check the existence of a method, lowercase
	// of a tag and escaping quotes in arguments
	var stringHtmlForced = function stringHtmlForced(METHOD_NAME) {
	  return fails$f(function () {
	    var test = ''[METHOD_NAME]('"');
	    return test !== test.toLowerCase() || test.split('"').length > 3;
	  });
	};
	var stringHtmlForced$1 = /*@__PURE__*/getDefaultExportFromCjs(stringHtmlForced);

	'use strict';
	var $$s = _export;
	var createHTML$c = createHtml;
	var forcedStringHTMLMethod$c = stringHtmlForced;

	// `String.prototype.anchor` method
	// https://tc39.es/ecma262/#sec-string.prototype.anchor
	$$s({
	  target: 'String',
	  proto: true,
	  forced: forcedStringHTMLMethod$c('anchor')
	}, {
	  anchor: function anchor(name) {
	    return createHTML$c(this, 'a', 'name', name);
	  }
	});

	var es_string_big = {};

	'use strict';
	var $$r = _export;
	var createHTML$b = createHtml;
	var forcedStringHTMLMethod$b = stringHtmlForced;

	// `String.prototype.big` method
	// https://tc39.es/ecma262/#sec-string.prototype.big
	$$r({
	  target: 'String',
	  proto: true,
	  forced: forcedStringHTMLMethod$b('big')
	}, {
	  big: function big() {
	    return createHTML$b(this, 'big', '', '');
	  }
	});

	var es_string_blink = {};

	'use strict';
	var $$q = _export;
	var createHTML$a = createHtml;
	var forcedStringHTMLMethod$a = stringHtmlForced;

	// `String.prototype.blink` method
	// https://tc39.es/ecma262/#sec-string.prototype.blink
	$$q({
	  target: 'String',
	  proto: true,
	  forced: forcedStringHTMLMethod$a('blink')
	}, {
	  blink: function blink() {
	    return createHTML$a(this, 'blink', '', '');
	  }
	});

	var es_string_bold = {};

	'use strict';
	var $$p = _export;
	var createHTML$9 = createHtml;
	var forcedStringHTMLMethod$9 = stringHtmlForced;

	// `String.prototype.bold` method
	// https://tc39.es/ecma262/#sec-string.prototype.bold
	$$p({
	  target: 'String',
	  proto: true,
	  forced: forcedStringHTMLMethod$9('bold')
	}, {
	  bold: function bold() {
	    return createHTML$9(this, 'b', '', '');
	  }
	});

	var es_string_fixed = {};

	'use strict';
	var $$o = _export;
	var createHTML$8 = createHtml;
	var forcedStringHTMLMethod$8 = stringHtmlForced;

	// `String.prototype.fixed` method
	// https://tc39.es/ecma262/#sec-string.prototype.fixed
	$$o({
	  target: 'String',
	  proto: true,
	  forced: forcedStringHTMLMethod$8('fixed')
	}, {
	  fixed: function fixed() {
	    return createHTML$8(this, 'tt', '', '');
	  }
	});

	var es_string_fontcolor = {};

	'use strict';
	var $$n = _export;
	var createHTML$7 = createHtml;
	var forcedStringHTMLMethod$7 = stringHtmlForced;

	// `String.prototype.fontcolor` method
	// https://tc39.es/ecma262/#sec-string.prototype.fontcolor
	$$n({
	  target: 'String',
	  proto: true,
	  forced: forcedStringHTMLMethod$7('fontcolor')
	}, {
	  fontcolor: function fontcolor(color) {
	    return createHTML$7(this, 'font', 'color', color);
	  }
	});

	var es_string_fontsize = {};

	'use strict';
	var $$m = _export;
	var createHTML$6 = createHtml;
	var forcedStringHTMLMethod$6 = stringHtmlForced;

	// `String.prototype.fontsize` method
	// https://tc39.es/ecma262/#sec-string.prototype.fontsize
	$$m({
	  target: 'String',
	  proto: true,
	  forced: forcedStringHTMLMethod$6('fontsize')
	}, {
	  fontsize: function fontsize(size) {
	    return createHTML$6(this, 'font', 'size', size);
	  }
	});

	var es_string_italics = {};

	'use strict';
	var $$l = _export;
	var createHTML$5 = createHtml;
	var forcedStringHTMLMethod$5 = stringHtmlForced;

	// `String.prototype.italics` method
	// https://tc39.es/ecma262/#sec-string.prototype.italics
	$$l({
	  target: 'String',
	  proto: true,
	  forced: forcedStringHTMLMethod$5('italics')
	}, {
	  italics: function italics() {
	    return createHTML$5(this, 'i', '', '');
	  }
	});

	var es_string_link = {};

	'use strict';
	var $$k = _export;
	var createHTML$4 = createHtml;
	var forcedStringHTMLMethod$4 = stringHtmlForced;

	// `String.prototype.link` method
	// https://tc39.es/ecma262/#sec-string.prototype.link
	$$k({
	  target: 'String',
	  proto: true,
	  forced: forcedStringHTMLMethod$4('link')
	}, {
	  link: function link(url) {
	    return createHTML$4(this, 'a', 'href', url);
	  }
	});

	var es_string_small = {};

	'use strict';
	var $$j = _export;
	var createHTML$3 = createHtml;
	var forcedStringHTMLMethod$3 = stringHtmlForced;

	// `String.prototype.small` method
	// https://tc39.es/ecma262/#sec-string.prototype.small
	$$j({
	  target: 'String',
	  proto: true,
	  forced: forcedStringHTMLMethod$3('small')
	}, {
	  small: function small() {
	    return createHTML$3(this, 'small', '', '');
	  }
	});

	var es_string_strike = {};

	'use strict';
	var $$i = _export;
	var createHTML$2 = createHtml;
	var forcedStringHTMLMethod$2 = stringHtmlForced;

	// `String.prototype.strike` method
	// https://tc39.es/ecma262/#sec-string.prototype.strike
	$$i({
	  target: 'String',
	  proto: true,
	  forced: forcedStringHTMLMethod$2('strike')
	}, {
	  strike: function strike() {
	    return createHTML$2(this, 'strike', '', '');
	  }
	});

	var es_string_sub = {};

	'use strict';
	var $$h = _export;
	var createHTML$1 = createHtml;
	var forcedStringHTMLMethod$1 = stringHtmlForced;

	// `String.prototype.sub` method
	// https://tc39.es/ecma262/#sec-string.prototype.sub
	$$h({
	  target: 'String',
	  proto: true,
	  forced: forcedStringHTMLMethod$1('sub')
	}, {
	  sub: function sub() {
	    return createHTML$1(this, 'sub', '', '');
	  }
	});

	var es_string_sup = {};

	'use strict';
	var $$g = _export;
	var createHTML = createHtml;
	var forcedStringHTMLMethod = stringHtmlForced;

	// `String.prototype.sup` method
	// https://tc39.es/ecma262/#sec-string.prototype.sup
	$$g({
	  target: 'String',
	  proto: true,
	  forced: forcedStringHTMLMethod('sup')
	}, {
	  sup: function sup() {
	    return createHTML(this, 'sup', '', '');
	  }
	});

	var es_typedArray_float32Array = {};

	var typedArrayConstructor$2 = {exports: {}};

	/* eslint-disable no-new -- required for testing */
	var global$o = global$Z;
	var fails$e = fails$1m;
	var checkCorrectnessOfIteration = checkCorrectnessOfIteration$4;
	var NATIVE_ARRAY_BUFFER_VIEWS$1 = arrayBufferViewCore.NATIVE_ARRAY_BUFFER_VIEWS;
	var ArrayBuffer$2 = global$o.ArrayBuffer;
	var Int8Array$3 = global$o.Int8Array;
	var typedArrayConstructorsRequireWrappers = !NATIVE_ARRAY_BUFFER_VIEWS$1 || !fails$e(function () {
	  Int8Array$3(1);
	}) || !fails$e(function () {
	  new Int8Array$3(-1);
	}) || !checkCorrectnessOfIteration(function (iterable) {
	  new Int8Array$3();
	  new Int8Array$3(null);
	  new Int8Array$3(1.5);
	  new Int8Array$3(iterable);
	}, true) || fails$e(function () {
	  // Safari (11+) bug - a reason why even Safari 13 should load a typed array polyfill
	  return new Int8Array$3(new ArrayBuffer$2(2), 1, undefined).length !== 1;
	});
	var typedArrayConstructorsRequireWrappers$1 = /*@__PURE__*/getDefaultExportFromCjs(typedArrayConstructorsRequireWrappers);

	var toIntegerOrInfinity$2 = toIntegerOrInfinity$l;
	var $RangeError$2 = RangeError;
	var toPositiveInteger$1 = function toPositiveInteger(it) {
	  var result = toIntegerOrInfinity$2(it);
	  if (result < 0) throw $RangeError$2("The argument can't be less than 0");
	  return result;
	};
	var toPositiveInteger$2 = /*@__PURE__*/getDefaultExportFromCjs(toPositiveInteger$1);

	var toPositiveInteger = toPositiveInteger$1;
	var $RangeError$1 = RangeError;
	var toOffset$2 = function toOffset(it, BYTES) {
	  var offset = toPositiveInteger(it);
	  if (offset % BYTES) throw $RangeError$1('Wrong offset');
	  return offset;
	};
	var toOffset$3 = /*@__PURE__*/getDefaultExportFromCjs(toOffset$2);

	var classof$4 = classof$m;
	var isBigIntArray$2 = function isBigIntArray(it) {
	  var klass = classof$4(it);
	  return klass == 'BigInt64Array' || klass == 'BigUint64Array';
	};
	var isBigIntArray$3 = /*@__PURE__*/getDefaultExportFromCjs(isBigIntArray$2);

	var toPrimitive = toPrimitive$4;
	var $TypeError$1 = TypeError;

	// `ToBigInt` abstract operation
	// https://tc39.es/ecma262/#sec-tobigint
	var toBigInt$3 = function toBigInt(argument) {
	  var prim = toPrimitive(argument, 'number');
	  if (typeof prim == 'number') throw $TypeError$1("Can't convert number to bigint");
	  // eslint-disable-next-line es/no-bigint -- safe
	  return BigInt(prim);
	};
	var toBigInt$4 = /*@__PURE__*/getDefaultExportFromCjs(toBigInt$3);

	var bind$2 = functionBindContext;
	var call$7 = functionCall;
	var aConstructor = aConstructor$3;
	var toObject = toObject$t;
	var lengthOfArrayLike$3 = lengthOfArrayLike$t;
	var getIterator$1 = getIterator$4;
	var getIteratorMethod$1 = getIteratorMethod$5;
	var isArrayIteratorMethod = isArrayIteratorMethod$3;
	var isBigIntArray$1 = isBigIntArray$2;
	var aTypedArrayConstructor$3 = arrayBufferViewCore.aTypedArrayConstructor;
	var toBigInt$2 = toBigInt$3;
	var typedArrayFrom$2 = function from(source /* , mapfn, thisArg */) {
	  var C = aConstructor(this);
	  var O = toObject(source);
	  var argumentsLength = arguments.length;
	  var mapfn = argumentsLength > 1 ? arguments[1] : undefined;
	  var mapping = mapfn !== undefined;
	  var iteratorMethod = getIteratorMethod$1(O);
	  var i, length, result, thisIsBigIntArray, value, step, iterator, next;
	  if (iteratorMethod && !isArrayIteratorMethod(iteratorMethod)) {
	    iterator = getIterator$1(O, iteratorMethod);
	    next = iterator.next;
	    O = [];
	    while (!(step = call$7(next, iterator)).done) {
	      O.push(step.value);
	    }
	  }
	  if (mapping && argumentsLength > 2) {
	    mapfn = bind$2(mapfn, arguments[2]);
	  }
	  length = lengthOfArrayLike$3(O);
	  result = new (aTypedArrayConstructor$3(C))(length);
	  thisIsBigIntArray = isBigIntArray$1(result);
	  for (i = 0; length > i; i++) {
	    value = mapping ? mapfn(O[i], i) : O[i];
	    // FF30- typed arrays doesn't properly convert objects to typed array values
	    result[i] = thisIsBigIntArray ? toBigInt$2(value) : +value;
	  }
	  return result;
	};
	var typedArrayFrom$3 = /*@__PURE__*/getDefaultExportFromCjs(typedArrayFrom$2);

	var typedArrayConstructor = typedArrayConstructor$2.exports;
	'use strict';
	var $$f = _export;
	var global$n = global$Z;
	var call$6 = functionCall;
	var DESCRIPTORS$7 = descriptors;
	var TYPED_ARRAYS_CONSTRUCTORS_REQUIRES_WRAPPERS$2 = typedArrayConstructorsRequireWrappers;
	var ArrayBufferViewCore$u = arrayBufferViewCore;
	var ArrayBufferModule = arrayBuffer;
	var anInstance$5 = anInstance$a;
	var createPropertyDescriptor$3 = createPropertyDescriptor$c;
	var createNonEnumerableProperty$3 = createNonEnumerableProperty$f;
	var isIntegralNumber = isIntegralNumber$3;
	var toLength$1 = toLength$d;
	var toIndex = toIndex$2;
	var toOffset$1 = toOffset$2;
	var toPropertyKey = toPropertyKey$8;
	var hasOwn$7 = hasOwnProperty_1;
	var classof$3 = classof$m;
	var isObject$4 = isObject$z;
	var isSymbol$1 = isSymbol$7;
	var create$2 = objectCreate;
	var isPrototypeOf = objectIsPrototypeOf;
	var setPrototypeOf = objectSetPrototypeOf$1;
	var getOwnPropertyNames = objectGetOwnPropertyNames.f;
	var typedArrayFrom$1 = typedArrayFrom$2;
	var forEach$2 = arrayIteration.forEach;
	var setSpecies = setSpecies$6;
	var defineBuiltInAccessor$5 = defineBuiltInAccessor$h;
	var definePropertyModule = objectDefineProperty;
	var getOwnPropertyDescriptorModule = objectGetOwnPropertyDescriptor;
	var InternalStateModule$4 = internalState;
	var inheritIfRequired$1 = inheritIfRequired$6;
	var getInternalState$1 = InternalStateModule$4.get;
	var setInternalState$4 = InternalStateModule$4.set;
	var enforceInternalState$1 = InternalStateModule$4.enforce;
	var nativeDefineProperty = definePropertyModule.f;
	var nativeGetOwnPropertyDescriptor = getOwnPropertyDescriptorModule.f;
	var round$4 = Math.round;
	var RangeError$3 = global$n.RangeError;
	var ArrayBuffer$1 = ArrayBufferModule.ArrayBuffer;
	var ArrayBufferPrototype = ArrayBuffer$1.prototype;
	var DataView$1 = ArrayBufferModule.DataView;
	var NATIVE_ARRAY_BUFFER_VIEWS = ArrayBufferViewCore$u.NATIVE_ARRAY_BUFFER_VIEWS;
	var TYPED_ARRAY_TAG = ArrayBufferViewCore$u.TYPED_ARRAY_TAG;
	var TypedArray = ArrayBufferViewCore$u.TypedArray;
	var TypedArrayPrototype$1 = ArrayBufferViewCore$u.TypedArrayPrototype;
	var aTypedArrayConstructor$2 = ArrayBufferViewCore$u.aTypedArrayConstructor;
	var isTypedArray$1 = ArrayBufferViewCore$u.isTypedArray;
	var BYTES_PER_ELEMENT = 'BYTES_PER_ELEMENT';
	var WRONG_LENGTH = 'Wrong length';
	var fromList = function fromList(C, list) {
	  aTypedArrayConstructor$2(C);
	  var index = 0;
	  var length = list.length;
	  var result = new C(length);
	  while (length > index) result[index] = list[index++];
	  return result;
	};
	var addGetter = function addGetter(it, key) {
	  defineBuiltInAccessor$5(it, key, {
	    configurable: true,
	    get: function get() {
	      return getInternalState$1(this)[key];
	    }
	  });
	};
	var isArrayBuffer = function isArrayBuffer(it) {
	  var klass;
	  return isPrototypeOf(ArrayBufferPrototype, it) || (klass = classof$3(it)) == 'ArrayBuffer' || klass == 'SharedArrayBuffer';
	};
	var isTypedArrayIndex = function isTypedArrayIndex(target, key) {
	  return isTypedArray$1(target) && !isSymbol$1(key) && key in target && isIntegralNumber(+key) && key >= 0;
	};
	var wrappedGetOwnPropertyDescriptor = function getOwnPropertyDescriptor(target, key) {
	  key = toPropertyKey(key);
	  return isTypedArrayIndex(target, key) ? createPropertyDescriptor$3(2, target[key]) : nativeGetOwnPropertyDescriptor(target, key);
	};
	var wrappedDefineProperty = function defineProperty(target, key, descriptor) {
	  key = toPropertyKey(key);
	  if (isTypedArrayIndex(target, key) && isObject$4(descriptor) && hasOwn$7(descriptor, 'value') && !hasOwn$7(descriptor, 'get') && !hasOwn$7(descriptor, 'set')
	  // TODO: add validation descriptor w/o calling accessors
	  && !descriptor.configurable && (!hasOwn$7(descriptor, 'writable') || descriptor.writable) && (!hasOwn$7(descriptor, 'enumerable') || descriptor.enumerable)) {
	    target[key] = descriptor.value;
	    return target;
	  }
	  return nativeDefineProperty(target, key, descriptor);
	};
	if (DESCRIPTORS$7) {
	  if (!NATIVE_ARRAY_BUFFER_VIEWS) {
	    getOwnPropertyDescriptorModule.f = wrappedGetOwnPropertyDescriptor;
	    definePropertyModule.f = wrappedDefineProperty;
	    addGetter(TypedArrayPrototype$1, 'buffer');
	    addGetter(TypedArrayPrototype$1, 'byteOffset');
	    addGetter(TypedArrayPrototype$1, 'byteLength');
	    addGetter(TypedArrayPrototype$1, 'length');
	  }
	  $$f({
	    target: 'Object',
	    stat: true,
	    forced: !NATIVE_ARRAY_BUFFER_VIEWS
	  }, {
	    getOwnPropertyDescriptor: wrappedGetOwnPropertyDescriptor,
	    defineProperty: wrappedDefineProperty
	  });
	  typedArrayConstructor$2.exports = function (TYPE, wrapper, CLAMPED) {
	    var BYTES = TYPE.match(/\d+/)[0] / 8;
	    var CONSTRUCTOR_NAME = TYPE + (CLAMPED ? 'Clamped' : '') + 'Array';
	    var GETTER = 'get' + TYPE;
	    var SETTER = 'set' + TYPE;
	    var NativeTypedArrayConstructor = global$n[CONSTRUCTOR_NAME];
	    var TypedArrayConstructor = NativeTypedArrayConstructor;
	    var TypedArrayConstructorPrototype = TypedArrayConstructor && TypedArrayConstructor.prototype;
	    var exported = {};
	    var getter = function getter(that, index) {
	      var data = getInternalState$1(that);
	      return data.view[GETTER](index * BYTES + data.byteOffset, true);
	    };
	    var setter = function setter(that, index, value) {
	      var data = getInternalState$1(that);
	      if (CLAMPED) value = (value = round$4(value)) < 0 ? 0 : value > 0xFF ? 0xFF : value & 0xFF;
	      data.view[SETTER](index * BYTES + data.byteOffset, value, true);
	    };
	    var addElement = function addElement(that, index) {
	      nativeDefineProperty(that, index, {
	        get: function get() {
	          return getter(this, index);
	        },
	        set: function set(value) {
	          return setter(this, index, value);
	        },
	        enumerable: true
	      });
	    };
	    if (!NATIVE_ARRAY_BUFFER_VIEWS) {
	      TypedArrayConstructor = wrapper(function (that, data, offset, $length) {
	        anInstance$5(that, TypedArrayConstructorPrototype);
	        var index = 0;
	        var byteOffset = 0;
	        var buffer, byteLength, length;
	        if (!isObject$4(data)) {
	          length = toIndex(data);
	          byteLength = length * BYTES;
	          buffer = new ArrayBuffer$1(byteLength);
	        } else if (isArrayBuffer(data)) {
	          buffer = data;
	          byteOffset = toOffset$1(offset, BYTES);
	          var $len = data.byteLength;
	          if ($length === undefined) {
	            if ($len % BYTES) throw RangeError$3(WRONG_LENGTH);
	            byteLength = $len - byteOffset;
	            if (byteLength < 0) throw RangeError$3(WRONG_LENGTH);
	          } else {
	            byteLength = toLength$1($length) * BYTES;
	            if (byteLength + byteOffset > $len) throw RangeError$3(WRONG_LENGTH);
	          }
	          length = byteLength / BYTES;
	        } else if (isTypedArray$1(data)) {
	          return fromList(TypedArrayConstructor, data);
	        } else {
	          return call$6(typedArrayFrom$1, TypedArrayConstructor, data);
	        }
	        setInternalState$4(that, {
	          buffer: buffer,
	          byteOffset: byteOffset,
	          byteLength: byteLength,
	          length: length,
	          view: new DataView$1(buffer)
	        });
	        while (index < length) addElement(that, index++);
	      });
	      if (setPrototypeOf) setPrototypeOf(TypedArrayConstructor, TypedArray);
	      TypedArrayConstructorPrototype = TypedArrayConstructor.prototype = create$2(TypedArrayPrototype$1);
	    } else if (TYPED_ARRAYS_CONSTRUCTORS_REQUIRES_WRAPPERS$2) {
	      TypedArrayConstructor = wrapper(function (dummy, data, typedArrayOffset, $length) {
	        anInstance$5(dummy, TypedArrayConstructorPrototype);
	        return inheritIfRequired$1(function () {
	          if (!isObject$4(data)) return new NativeTypedArrayConstructor(toIndex(data));
	          if (isArrayBuffer(data)) return $length !== undefined ? new NativeTypedArrayConstructor(data, toOffset$1(typedArrayOffset, BYTES), $length) : typedArrayOffset !== undefined ? new NativeTypedArrayConstructor(data, toOffset$1(typedArrayOffset, BYTES)) : new NativeTypedArrayConstructor(data);
	          if (isTypedArray$1(data)) return fromList(TypedArrayConstructor, data);
	          return call$6(typedArrayFrom$1, TypedArrayConstructor, data);
	        }(), dummy, TypedArrayConstructor);
	      });
	      if (setPrototypeOf) setPrototypeOf(TypedArrayConstructor, TypedArray);
	      forEach$2(getOwnPropertyNames(NativeTypedArrayConstructor), function (key) {
	        if (!(key in TypedArrayConstructor)) {
	          createNonEnumerableProperty$3(TypedArrayConstructor, key, NativeTypedArrayConstructor[key]);
	        }
	      });
	      TypedArrayConstructor.prototype = TypedArrayConstructorPrototype;
	    }
	    if (TypedArrayConstructorPrototype.constructor !== TypedArrayConstructor) {
	      createNonEnumerableProperty$3(TypedArrayConstructorPrototype, 'constructor', TypedArrayConstructor);
	    }
	    enforceInternalState$1(TypedArrayConstructorPrototype).TypedArrayConstructor = TypedArrayConstructor;
	    if (TYPED_ARRAY_TAG) {
	      createNonEnumerableProperty$3(TypedArrayConstructorPrototype, TYPED_ARRAY_TAG, CONSTRUCTOR_NAME);
	    }
	    var FORCED = TypedArrayConstructor != NativeTypedArrayConstructor;
	    exported[CONSTRUCTOR_NAME] = TypedArrayConstructor;
	    $$f({
	      global: true,
	      constructor: true,
	      forced: FORCED,
	      sham: !NATIVE_ARRAY_BUFFER_VIEWS
	    }, exported);
	    if (!(BYTES_PER_ELEMENT in TypedArrayConstructor)) {
	      createNonEnumerableProperty$3(TypedArrayConstructor, BYTES_PER_ELEMENT, BYTES);
	    }
	    if (!(BYTES_PER_ELEMENT in TypedArrayConstructorPrototype)) {
	      createNonEnumerableProperty$3(TypedArrayConstructorPrototype, BYTES_PER_ELEMENT, BYTES);
	    }
	    setSpecies(CONSTRUCTOR_NAME);
	  };
	} else typedArrayConstructor$2.exports = function () {/* empty */};
	var typedArrayConstructorExports = typedArrayConstructor$2.exports;
	var typedArrayConstructor$1 = /*@__PURE__*/getDefaultExportFromCjs(typedArrayConstructorExports);

	var createTypedArrayConstructor$8 = typedArrayConstructorExports;

	// `Float32Array` constructor
	// https://tc39.es/ecma262/#sec-typedarray-objects
	createTypedArrayConstructor$8('Float32', function (init) {
	  return function Float32Array(data, byteOffset, length) {
	    return init(this, data, byteOffset, length);
	  };
	});

	var es_typedArray_float64Array = {};

	var createTypedArrayConstructor$7 = typedArrayConstructorExports;

	// `Float64Array` constructor
	// https://tc39.es/ecma262/#sec-typedarray-objects
	createTypedArrayConstructor$7('Float64', function (init) {
	  return function Float64Array(data, byteOffset, length) {
	    return init(this, data, byteOffset, length);
	  };
	});

	var es_typedArray_int8Array = {};

	var createTypedArrayConstructor$6 = typedArrayConstructorExports;

	// `Int8Array` constructor
	// https://tc39.es/ecma262/#sec-typedarray-objects
	createTypedArrayConstructor$6('Int8', function (init) {
	  return function Int8Array(data, byteOffset, length) {
	    return init(this, data, byteOffset, length);
	  };
	});

	var es_typedArray_int16Array = {};

	var createTypedArrayConstructor$5 = typedArrayConstructorExports;

	// `Int16Array` constructor
	// https://tc39.es/ecma262/#sec-typedarray-objects
	createTypedArrayConstructor$5('Int16', function (init) {
	  return function Int16Array(data, byteOffset, length) {
	    return init(this, data, byteOffset, length);
	  };
	});

	var es_typedArray_int32Array = {};

	var createTypedArrayConstructor$4 = typedArrayConstructorExports;

	// `Int32Array` constructor
	// https://tc39.es/ecma262/#sec-typedarray-objects
	createTypedArrayConstructor$4('Int32', function (init) {
	  return function Int32Array(data, byteOffset, length) {
	    return init(this, data, byteOffset, length);
	  };
	});

	var es_typedArray_uint8Array = {};

	var createTypedArrayConstructor$3 = typedArrayConstructorExports;

	// `Uint8Array` constructor
	// https://tc39.es/ecma262/#sec-typedarray-objects
	createTypedArrayConstructor$3('Uint8', function (init) {
	  return function Uint8Array(data, byteOffset, length) {
	    return init(this, data, byteOffset, length);
	  };
	});

	var es_typedArray_uint8ClampedArray = {};

	var createTypedArrayConstructor$2 = typedArrayConstructorExports;

	// `Uint8ClampedArray` constructor
	// https://tc39.es/ecma262/#sec-typedarray-objects
	createTypedArrayConstructor$2('Uint8', function (init) {
	  return function Uint8ClampedArray(data, byteOffset, length) {
	    return init(this, data, byteOffset, length);
	  };
	}, true);

	var es_typedArray_uint16Array = {};

	var createTypedArrayConstructor$1 = typedArrayConstructorExports;

	// `Uint16Array` constructor
	// https://tc39.es/ecma262/#sec-typedarray-objects
	createTypedArrayConstructor$1('Uint16', function (init) {
	  return function Uint16Array(data, byteOffset, length) {
	    return init(this, data, byteOffset, length);
	  };
	});

	var es_typedArray_uint32Array = {};

	var createTypedArrayConstructor = typedArrayConstructorExports;

	// `Uint32Array` constructor
	// https://tc39.es/ecma262/#sec-typedarray-objects
	createTypedArrayConstructor('Uint32', function (init) {
	  return function Uint32Array(data, byteOffset, length) {
	    return init(this, data, byteOffset, length);
	  };
	});

	var es_typedArray_at = {};

	'use strict';
	var ArrayBufferViewCore$t = arrayBufferViewCore;
	var lengthOfArrayLike$2 = lengthOfArrayLike$t;
	var toIntegerOrInfinity$1 = toIntegerOrInfinity$l;
	var aTypedArray$r = ArrayBufferViewCore$t.aTypedArray;
	var exportTypedArrayMethod$s = ArrayBufferViewCore$t.exportTypedArrayMethod;

	// `%TypedArray%.prototype.at` method
	// https://github.com/tc39/proposal-relative-indexing-method
	exportTypedArrayMethod$s('at', function at(index) {
	  var O = aTypedArray$r(this);
	  var len = lengthOfArrayLike$2(O);
	  var relativeIndex = toIntegerOrInfinity$1(index);
	  var k = relativeIndex >= 0 ? relativeIndex : len + relativeIndex;
	  return k < 0 || k >= len ? undefined : O[k];
	});

	var es_typedArray_copyWithin = {};

	'use strict';
	var uncurryThis$i = functionUncurryThis;
	var ArrayBufferViewCore$s = arrayBufferViewCore;
	var $ArrayCopyWithin = arrayCopyWithin;
	var u$ArrayCopyWithin = uncurryThis$i($ArrayCopyWithin);
	var aTypedArray$q = ArrayBufferViewCore$s.aTypedArray;
	var exportTypedArrayMethod$r = ArrayBufferViewCore$s.exportTypedArrayMethod;

	// `%TypedArray%.prototype.copyWithin` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.copywithin
	exportTypedArrayMethod$r('copyWithin', function copyWithin(target, start /* , end */) {
	  return u$ArrayCopyWithin(aTypedArray$q(this), target, start, arguments.length > 2 ? arguments[2] : undefined);
	});

	var es_typedArray_every = {};

	'use strict';
	var ArrayBufferViewCore$r = arrayBufferViewCore;
	var $every = arrayIteration.every;
	var aTypedArray$p = ArrayBufferViewCore$r.aTypedArray;
	var exportTypedArrayMethod$q = ArrayBufferViewCore$r.exportTypedArrayMethod;

	// `%TypedArray%.prototype.every` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.every
	exportTypedArrayMethod$q('every', function every(callbackfn /* , thisArg */) {
	  return $every(aTypedArray$p(this), callbackfn, arguments.length > 1 ? arguments[1] : undefined);
	});

	var es_typedArray_fill = {};

	'use strict';
	var ArrayBufferViewCore$q = arrayBufferViewCore;
	var $fill = arrayFill$1;
	var toBigInt$1 = toBigInt$3;
	var classof$2 = classof$m;
	var call$5 = functionCall;
	var uncurryThis$h = functionUncurryThis;
	var fails$d = fails$1m;
	var aTypedArray$o = ArrayBufferViewCore$q.aTypedArray;
	var exportTypedArrayMethod$p = ArrayBufferViewCore$q.exportTypedArrayMethod;
	var slice$3 = uncurryThis$h(''.slice);

	// V8 ~ Chrome < 59, Safari < 14.1, FF < 55, Edge <=18
	var CONVERSION_BUG = fails$d(function () {
	  var count = 0;
	  // eslint-disable-next-line es/no-typed-arrays -- safe
	  new Int8Array(2).fill({
	    valueOf: function valueOf() {
	      return count++;
	    }
	  });
	  return count !== 1;
	});

	// `%TypedArray%.prototype.fill` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.fill
	exportTypedArrayMethod$p('fill', function fill(value /* , start, end */) {
	  var length = arguments.length;
	  aTypedArray$o(this);
	  var actualValue = slice$3(classof$2(this), 0, 3) === 'Big' ? toBigInt$1(value) : +value;
	  return call$5($fill, this, actualValue, length > 1 ? arguments[1] : undefined, length > 2 ? arguments[2] : undefined);
	}, CONVERSION_BUG);

	var es_typedArray_filter = {};

	var ArrayBufferViewCore$p = arrayBufferViewCore;
	var speciesConstructor = speciesConstructor$6;
	var aTypedArrayConstructor$1 = ArrayBufferViewCore$p.aTypedArrayConstructor;
	var getTypedArrayConstructor$3 = ArrayBufferViewCore$p.getTypedArrayConstructor;

	// a part of `TypedArraySpeciesCreate` abstract operation
	// https://tc39.es/ecma262/#typedarray-species-create
	var typedArraySpeciesConstructor$4 = function typedArraySpeciesConstructor(originalArray) {
	  return aTypedArrayConstructor$1(speciesConstructor(originalArray, getTypedArrayConstructor$3(originalArray)));
	};
	var typedArraySpeciesConstructor$5 = /*@__PURE__*/getDefaultExportFromCjs(typedArraySpeciesConstructor$4);

	var arrayFromConstructorAndList$1 = arrayFromConstructorAndList$3;
	var typedArraySpeciesConstructor$3 = typedArraySpeciesConstructor$4;
	var typedArrayFromSpeciesAndList = function typedArrayFromSpeciesAndList(instance, list) {
	  return arrayFromConstructorAndList$1(typedArraySpeciesConstructor$3(instance), list);
	};
	var typedArrayFromSpeciesAndList$1 = /*@__PURE__*/getDefaultExportFromCjs(typedArrayFromSpeciesAndList);

	'use strict';
	var ArrayBufferViewCore$o = arrayBufferViewCore;
	var $filter = arrayIteration.filter;
	var fromSpeciesAndList = typedArrayFromSpeciesAndList;
	var aTypedArray$n = ArrayBufferViewCore$o.aTypedArray;
	var exportTypedArrayMethod$o = ArrayBufferViewCore$o.exportTypedArrayMethod;

	// `%TypedArray%.prototype.filter` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.filter
	exportTypedArrayMethod$o('filter', function filter(callbackfn /* , thisArg */) {
	  var list = $filter(aTypedArray$n(this), callbackfn, arguments.length > 1 ? arguments[1] : undefined);
	  return fromSpeciesAndList(this, list);
	});

	var es_typedArray_find = {};

	'use strict';
	var ArrayBufferViewCore$n = arrayBufferViewCore;
	var $find = arrayIteration.find;
	var aTypedArray$m = ArrayBufferViewCore$n.aTypedArray;
	var exportTypedArrayMethod$n = ArrayBufferViewCore$n.exportTypedArrayMethod;

	// `%TypedArray%.prototype.find` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.find
	exportTypedArrayMethod$n('find', function find(predicate /* , thisArg */) {
	  return $find(aTypedArray$m(this), predicate, arguments.length > 1 ? arguments[1] : undefined);
	});

	var es_typedArray_findIndex = {};

	'use strict';
	var ArrayBufferViewCore$m = arrayBufferViewCore;
	var $findIndex = arrayIteration.findIndex;
	var aTypedArray$l = ArrayBufferViewCore$m.aTypedArray;
	var exportTypedArrayMethod$m = ArrayBufferViewCore$m.exportTypedArrayMethod;

	// `%TypedArray%.prototype.findIndex` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.findindex
	exportTypedArrayMethod$m('findIndex', function findIndex(predicate /* , thisArg */) {
	  return $findIndex(aTypedArray$l(this), predicate, arguments.length > 1 ? arguments[1] : undefined);
	});

	var es_typedArray_findLast = {};

	'use strict';
	var ArrayBufferViewCore$l = arrayBufferViewCore;
	var $findLast = arrayIterationFromLast.findLast;
	var aTypedArray$k = ArrayBufferViewCore$l.aTypedArray;
	var exportTypedArrayMethod$l = ArrayBufferViewCore$l.exportTypedArrayMethod;

	// `%TypedArray%.prototype.findLast` method
	// https://github.com/tc39/proposal-array-find-from-last
	exportTypedArrayMethod$l('findLast', function findLast(predicate /* , thisArg */) {
	  return $findLast(aTypedArray$k(this), predicate, arguments.length > 1 ? arguments[1] : undefined);
	});

	var es_typedArray_findLastIndex = {};

	'use strict';
	var ArrayBufferViewCore$k = arrayBufferViewCore;
	var $findLastIndex = arrayIterationFromLast.findLastIndex;
	var aTypedArray$j = ArrayBufferViewCore$k.aTypedArray;
	var exportTypedArrayMethod$k = ArrayBufferViewCore$k.exportTypedArrayMethod;

	// `%TypedArray%.prototype.findLastIndex` method
	// https://github.com/tc39/proposal-array-find-from-last
	exportTypedArrayMethod$k('findLastIndex', function findLastIndex(predicate /* , thisArg */) {
	  return $findLastIndex(aTypedArray$j(this), predicate, arguments.length > 1 ? arguments[1] : undefined);
	});

	var es_typedArray_forEach = {};

	'use strict';
	var ArrayBufferViewCore$j = arrayBufferViewCore;
	var $forEach = arrayIteration.forEach;
	var aTypedArray$i = ArrayBufferViewCore$j.aTypedArray;
	var exportTypedArrayMethod$j = ArrayBufferViewCore$j.exportTypedArrayMethod;

	// `%TypedArray%.prototype.forEach` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.foreach
	exportTypedArrayMethod$j('forEach', function forEach(callbackfn /* , thisArg */) {
	  $forEach(aTypedArray$i(this), callbackfn, arguments.length > 1 ? arguments[1] : undefined);
	});

	var es_typedArray_from = {};

	'use strict';
	var TYPED_ARRAYS_CONSTRUCTORS_REQUIRES_WRAPPERS$1 = typedArrayConstructorsRequireWrappers;
	var exportTypedArrayStaticMethod$1 = arrayBufferViewCore.exportTypedArrayStaticMethod;
	var typedArrayFrom = typedArrayFrom$2;

	// `%TypedArray%.from` method
	// https://tc39.es/ecma262/#sec-%typedarray%.from
	exportTypedArrayStaticMethod$1('from', typedArrayFrom, TYPED_ARRAYS_CONSTRUCTORS_REQUIRES_WRAPPERS$1);

	var es_typedArray_includes = {};

	'use strict';
	var ArrayBufferViewCore$i = arrayBufferViewCore;
	var $includes = arrayIncludes.includes;
	var aTypedArray$h = ArrayBufferViewCore$i.aTypedArray;
	var exportTypedArrayMethod$i = ArrayBufferViewCore$i.exportTypedArrayMethod;

	// `%TypedArray%.prototype.includes` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.includes
	exportTypedArrayMethod$i('includes', function includes(searchElement /* , fromIndex */) {
	  return $includes(aTypedArray$h(this), searchElement, arguments.length > 1 ? arguments[1] : undefined);
	});

	var es_typedArray_indexOf = {};

	'use strict';
	var ArrayBufferViewCore$h = arrayBufferViewCore;
	var $indexOf = arrayIncludes.indexOf;
	var aTypedArray$g = ArrayBufferViewCore$h.aTypedArray;
	var exportTypedArrayMethod$h = ArrayBufferViewCore$h.exportTypedArrayMethod;

	// `%TypedArray%.prototype.indexOf` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.indexof
	exportTypedArrayMethod$h('indexOf', function indexOf(searchElement /* , fromIndex */) {
	  return $indexOf(aTypedArray$g(this), searchElement, arguments.length > 1 ? arguments[1] : undefined);
	});

	var es_typedArray_iterator = {};

	'use strict';
	var global$m = global$Z;
	var fails$c = fails$1m;
	var uncurryThis$g = functionUncurryThis;
	var ArrayBufferViewCore$g = arrayBufferViewCore;
	var ArrayIterators = es_array_iterator;
	var wellKnownSymbol$3 = wellKnownSymbol$z;
	var ITERATOR$3 = wellKnownSymbol$3('iterator');
	var Uint8Array$2 = global$m.Uint8Array;
	var arrayValues = uncurryThis$g(ArrayIterators.values);
	var arrayKeys = uncurryThis$g(ArrayIterators.keys);
	var arrayEntries = uncurryThis$g(ArrayIterators.entries);
	var aTypedArray$f = ArrayBufferViewCore$g.aTypedArray;
	var exportTypedArrayMethod$g = ArrayBufferViewCore$g.exportTypedArrayMethod;
	var TypedArrayPrototype = Uint8Array$2 && Uint8Array$2.prototype;
	var GENERIC = !fails$c(function () {
	  TypedArrayPrototype[ITERATOR$3].call([1]);
	});
	var ITERATOR_IS_VALUES = !!TypedArrayPrototype && TypedArrayPrototype.values && TypedArrayPrototype[ITERATOR$3] === TypedArrayPrototype.values && TypedArrayPrototype.values.name === 'values';
	var typedArrayValues = function values() {
	  return arrayValues(aTypedArray$f(this));
	};

	// `%TypedArray%.prototype.entries` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.entries
	exportTypedArrayMethod$g('entries', function entries() {
	  return arrayEntries(aTypedArray$f(this));
	}, GENERIC);
	// `%TypedArray%.prototype.keys` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.keys
	exportTypedArrayMethod$g('keys', function keys() {
	  return arrayKeys(aTypedArray$f(this));
	}, GENERIC);
	// `%TypedArray%.prototype.values` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.values
	exportTypedArrayMethod$g('values', typedArrayValues, GENERIC || !ITERATOR_IS_VALUES, {
	  name: 'values'
	});
	// `%TypedArray%.prototype[@@iterator]` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype-@@iterator
	exportTypedArrayMethod$g(ITERATOR$3, typedArrayValues, GENERIC || !ITERATOR_IS_VALUES, {
	  name: 'values'
	});

	var es_typedArray_join = {};

	'use strict';
	var ArrayBufferViewCore$f = arrayBufferViewCore;
	var uncurryThis$f = functionUncurryThis;
	var aTypedArray$e = ArrayBufferViewCore$f.aTypedArray;
	var exportTypedArrayMethod$f = ArrayBufferViewCore$f.exportTypedArrayMethod;
	var $join = uncurryThis$f([].join);

	// `%TypedArray%.prototype.join` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.join
	exportTypedArrayMethod$f('join', function join(separator) {
	  return $join(aTypedArray$e(this), separator);
	});

	var es_typedArray_lastIndexOf = {};

	'use strict';
	var ArrayBufferViewCore$e = arrayBufferViewCore;
	var apply$2 = functionApply$1;
	var $lastIndexOf = arrayLastIndexOf;
	var aTypedArray$d = ArrayBufferViewCore$e.aTypedArray;
	var exportTypedArrayMethod$e = ArrayBufferViewCore$e.exportTypedArrayMethod;

	// `%TypedArray%.prototype.lastIndexOf` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.lastindexof
	exportTypedArrayMethod$e('lastIndexOf', function lastIndexOf(searchElement /* , fromIndex */) {
	  var length = arguments.length;
	  return apply$2($lastIndexOf, aTypedArray$d(this), length > 1 ? [searchElement, arguments[1]] : [searchElement]);
	});

	var es_typedArray_map = {};

	'use strict';
	var ArrayBufferViewCore$d = arrayBufferViewCore;
	var $map = arrayIteration.map;
	var typedArraySpeciesConstructor$2 = typedArraySpeciesConstructor$4;
	var aTypedArray$c = ArrayBufferViewCore$d.aTypedArray;
	var exportTypedArrayMethod$d = ArrayBufferViewCore$d.exportTypedArrayMethod;

	// `%TypedArray%.prototype.map` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.map
	exportTypedArrayMethod$d('map', function map(mapfn /* , thisArg */) {
	  return $map(aTypedArray$c(this), mapfn, arguments.length > 1 ? arguments[1] : undefined, function (O, length) {
	    return new (typedArraySpeciesConstructor$2(O))(length);
	  });
	});

	var es_typedArray_of = {};

	'use strict';
	var ArrayBufferViewCore$c = arrayBufferViewCore;
	var TYPED_ARRAYS_CONSTRUCTORS_REQUIRES_WRAPPERS = typedArrayConstructorsRequireWrappers;
	var aTypedArrayConstructor = ArrayBufferViewCore$c.aTypedArrayConstructor;
	var exportTypedArrayStaticMethod = ArrayBufferViewCore$c.exportTypedArrayStaticMethod;

	// `%TypedArray%.of` method
	// https://tc39.es/ecma262/#sec-%typedarray%.of
	exportTypedArrayStaticMethod('of', function of( /* ...items */
	) {
	  var index = 0;
	  var length = arguments.length;
	  var result = new (aTypedArrayConstructor(this))(length);
	  while (length > index) result[index] = arguments[index++];
	  return result;
	}, TYPED_ARRAYS_CONSTRUCTORS_REQUIRES_WRAPPERS);

	var es_typedArray_reduce = {};

	'use strict';
	var ArrayBufferViewCore$b = arrayBufferViewCore;
	var $reduce = arrayReduce.left;
	var aTypedArray$b = ArrayBufferViewCore$b.aTypedArray;
	var exportTypedArrayMethod$c = ArrayBufferViewCore$b.exportTypedArrayMethod;

	// `%TypedArray%.prototype.reduce` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.reduce
	exportTypedArrayMethod$c('reduce', function reduce(callbackfn /* , initialValue */) {
	  var length = arguments.length;
	  return $reduce(aTypedArray$b(this), callbackfn, length, length > 1 ? arguments[1] : undefined);
	});

	var es_typedArray_reduceRight = {};

	'use strict';
	var ArrayBufferViewCore$a = arrayBufferViewCore;
	var $reduceRight = arrayReduce.right;
	var aTypedArray$a = ArrayBufferViewCore$a.aTypedArray;
	var exportTypedArrayMethod$b = ArrayBufferViewCore$a.exportTypedArrayMethod;

	// `%TypedArray%.prototype.reduceRight` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.reduceright
	exportTypedArrayMethod$b('reduceRight', function reduceRight(callbackfn /* , initialValue */) {
	  var length = arguments.length;
	  return $reduceRight(aTypedArray$a(this), callbackfn, length, length > 1 ? arguments[1] : undefined);
	});

	var es_typedArray_reverse = {};

	'use strict';
	var ArrayBufferViewCore$9 = arrayBufferViewCore;
	var aTypedArray$9 = ArrayBufferViewCore$9.aTypedArray;
	var exportTypedArrayMethod$a = ArrayBufferViewCore$9.exportTypedArrayMethod;
	var floor$5 = Math.floor;

	// `%TypedArray%.prototype.reverse` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.reverse
	exportTypedArrayMethod$a('reverse', function reverse() {
	  var that = this;
	  var length = aTypedArray$9(that).length;
	  var middle = floor$5(length / 2);
	  var index = 0;
	  var value;
	  while (index < middle) {
	    value = that[index];
	    that[index++] = that[--length];
	    that[length] = value;
	  }
	  return that;
	});

	var es_typedArray_set = {};

	'use strict';
	var global$l = global$Z;
	var call$4 = functionCall;
	var ArrayBufferViewCore$8 = arrayBufferViewCore;
	var lengthOfArrayLike$1 = lengthOfArrayLike$t;
	var toOffset = toOffset$2;
	var toIndexedObject = toObject$t;
	var fails$b = fails$1m;
	var RangeError$2 = global$l.RangeError;
	var Int8Array$2 = global$l.Int8Array;
	var Int8ArrayPrototype = Int8Array$2 && Int8Array$2.prototype;
	var $set = Int8ArrayPrototype && Int8ArrayPrototype.set;
	var aTypedArray$8 = ArrayBufferViewCore$8.aTypedArray;
	var exportTypedArrayMethod$9 = ArrayBufferViewCore$8.exportTypedArrayMethod;
	var WORKS_WITH_OBJECTS_AND_GENERIC_ON_TYPED_ARRAYS = !fails$b(function () {
	  // eslint-disable-next-line es/no-typed-arrays -- required for testing
	  var array = new Uint8ClampedArray(2);
	  call$4($set, array, {
	    length: 1,
	    0: 3
	  }, 1);
	  return array[1] !== 3;
	});

	// https://bugs.chromium.org/p/v8/issues/detail?id=11294 and other
	var TO_OBJECT_BUG = WORKS_WITH_OBJECTS_AND_GENERIC_ON_TYPED_ARRAYS && ArrayBufferViewCore$8.NATIVE_ARRAY_BUFFER_VIEWS && fails$b(function () {
	  var array = new Int8Array$2(2);
	  array.set(1);
	  array.set('2', 1);
	  return array[0] !== 0 || array[1] !== 2;
	});

	// `%TypedArray%.prototype.set` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.set
	exportTypedArrayMethod$9('set', function set(arrayLike /* , offset */) {
	  aTypedArray$8(this);
	  var offset = toOffset(arguments.length > 1 ? arguments[1] : undefined, 1);
	  var src = toIndexedObject(arrayLike);
	  if (WORKS_WITH_OBJECTS_AND_GENERIC_ON_TYPED_ARRAYS) return call$4($set, this, src, offset);
	  var length = this.length;
	  var len = lengthOfArrayLike$1(src);
	  var index = 0;
	  if (len + offset > length) throw RangeError$2('Wrong length');
	  while (index < len) this[offset + index] = src[index++];
	}, !WORKS_WITH_OBJECTS_AND_GENERIC_ON_TYPED_ARRAYS || TO_OBJECT_BUG);

	var es_typedArray_slice = {};

	'use strict';
	var ArrayBufferViewCore$7 = arrayBufferViewCore;
	var typedArraySpeciesConstructor$1 = typedArraySpeciesConstructor$4;
	var fails$a = fails$1m;
	var arraySlice$3 = arraySlice$a;
	var aTypedArray$7 = ArrayBufferViewCore$7.aTypedArray;
	var exportTypedArrayMethod$8 = ArrayBufferViewCore$7.exportTypedArrayMethod;
	var FORCED$1 = fails$a(function () {
	  // eslint-disable-next-line es/no-typed-arrays -- required for testing
	  new Int8Array(1).slice();
	});

	// `%TypedArray%.prototype.slice` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.slice
	exportTypedArrayMethod$8('slice', function slice(start, end) {
	  var list = arraySlice$3(aTypedArray$7(this), start, end);
	  var C = typedArraySpeciesConstructor$1(this);
	  var index = 0;
	  var length = list.length;
	  var result = new C(length);
	  while (length > index) result[index] = list[index++];
	  return result;
	}, FORCED$1);

	var es_typedArray_some = {};

	'use strict';
	var ArrayBufferViewCore$6 = arrayBufferViewCore;
	var $some = arrayIteration.some;
	var aTypedArray$6 = ArrayBufferViewCore$6.aTypedArray;
	var exportTypedArrayMethod$7 = ArrayBufferViewCore$6.exportTypedArrayMethod;

	// `%TypedArray%.prototype.some` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.some
	exportTypedArrayMethod$7('some', function some(callbackfn /* , thisArg */) {
	  return $some(aTypedArray$6(this), callbackfn, arguments.length > 1 ? arguments[1] : undefined);
	});

	var es_typedArray_sort = {};

	'use strict';
	var global$k = global$Z;
	var uncurryThis$e = functionUncurryThisClause;
	var fails$9 = fails$1m;
	var aCallable$2 = aCallable$l;
	var internalSort = arraySort$1;
	var ArrayBufferViewCore$5 = arrayBufferViewCore;
	var FF = engineFfVersion;
	var IE_OR_EDGE = engineIsIeOrEdge;
	var V8$1 = engineV8Version;
	var WEBKIT = engineWebkitVersion;
	var aTypedArray$5 = ArrayBufferViewCore$5.aTypedArray;
	var exportTypedArrayMethod$6 = ArrayBufferViewCore$5.exportTypedArrayMethod;
	var Uint16Array$1 = global$k.Uint16Array;
	var nativeSort = Uint16Array$1 && uncurryThis$e(Uint16Array$1.prototype.sort);

	// WebKit
	var ACCEPT_INCORRECT_ARGUMENTS = !!nativeSort && !(fails$9(function () {
	  nativeSort(new Uint16Array$1(2), null);
	}) && fails$9(function () {
	  nativeSort(new Uint16Array$1(2), {});
	}));
	var STABLE_SORT = !!nativeSort && !fails$9(function () {
	  // feature detection can be too slow, so check engines versions
	  if (V8$1) return V8$1 < 74;
	  if (FF) return FF < 67;
	  if (IE_OR_EDGE) return true;
	  if (WEBKIT) return WEBKIT < 602;
	  var array = new Uint16Array$1(516);
	  var expected = Array(516);
	  var index, mod;
	  for (index = 0; index < 516; index++) {
	    mod = index % 4;
	    array[index] = 515 - index;
	    expected[index] = index - 2 * mod + 3;
	  }
	  nativeSort(array, function (a, b) {
	    return (a / 4 | 0) - (b / 4 | 0);
	  });
	  for (index = 0; index < 516; index++) {
	    if (array[index] !== expected[index]) return true;
	  }
	});
	var getSortCompare = function getSortCompare(comparefn) {
	  return function (x, y) {
	    if (comparefn !== undefined) return +comparefn(x, y) || 0;
	    // eslint-disable-next-line no-self-compare -- NaN check
	    if (y !== y) return -1;
	    // eslint-disable-next-line no-self-compare -- NaN check
	    if (x !== x) return 1;
	    if (x === 0 && y === 0) return 1 / x > 0 && 1 / y < 0 ? 1 : -1;
	    return x > y;
	  };
	};

	// `%TypedArray%.prototype.sort` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.sort
	exportTypedArrayMethod$6('sort', function sort(comparefn) {
	  if (comparefn !== undefined) aCallable$2(comparefn);
	  if (STABLE_SORT) return nativeSort(this, comparefn);
	  return internalSort(aTypedArray$5(this), getSortCompare(comparefn));
	}, !STABLE_SORT || ACCEPT_INCORRECT_ARGUMENTS);

	var es_typedArray_subarray = {};

	'use strict';
	var ArrayBufferViewCore$4 = arrayBufferViewCore;
	var toLength = toLength$d;
	var toAbsoluteIndex = toAbsoluteIndex$a;
	var typedArraySpeciesConstructor = typedArraySpeciesConstructor$4;
	var aTypedArray$4 = ArrayBufferViewCore$4.aTypedArray;
	var exportTypedArrayMethod$5 = ArrayBufferViewCore$4.exportTypedArrayMethod;

	// `%TypedArray%.prototype.subarray` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.subarray
	exportTypedArrayMethod$5('subarray', function subarray(begin, end) {
	  var O = aTypedArray$4(this);
	  var length = O.length;
	  var beginIndex = toAbsoluteIndex(begin, length);
	  var C = typedArraySpeciesConstructor(O);
	  return new C(O.buffer, O.byteOffset + beginIndex * O.BYTES_PER_ELEMENT, toLength((end === undefined ? length : toAbsoluteIndex(end, length)) - beginIndex));
	});

	var es_typedArray_toLocaleString = {};

	'use strict';
	var global$j = global$Z;
	var apply$1 = functionApply$1;
	var ArrayBufferViewCore$3 = arrayBufferViewCore;
	var fails$8 = fails$1m;
	var arraySlice$2 = arraySlice$a;
	var Int8Array$1 = global$j.Int8Array;
	var aTypedArray$3 = ArrayBufferViewCore$3.aTypedArray;
	var exportTypedArrayMethod$4 = ArrayBufferViewCore$3.exportTypedArrayMethod;
	var $toLocaleString = [].toLocaleString;

	// iOS Safari 6.x fails here
	var TO_LOCALE_STRING_BUG = !!Int8Array$1 && fails$8(function () {
	  $toLocaleString.call(new Int8Array$1(1));
	});
	var FORCED = fails$8(function () {
	  return [1, 2].toLocaleString() != new Int8Array$1([1, 2]).toLocaleString();
	}) || !fails$8(function () {
	  Int8Array$1.prototype.toLocaleString.call([1, 2]);
	});

	// `%TypedArray%.prototype.toLocaleString` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.tolocalestring
	exportTypedArrayMethod$4('toLocaleString', function toLocaleString() {
	  return apply$1($toLocaleString, TO_LOCALE_STRING_BUG ? arraySlice$2(aTypedArray$3(this)) : aTypedArray$3(this), arraySlice$2(arguments));
	}, FORCED);

	var es_typedArray_toReversed = {};

	'use strict';
	var arrayToReversed = arrayToReversed$2;
	var ArrayBufferViewCore$2 = arrayBufferViewCore;
	var aTypedArray$2 = ArrayBufferViewCore$2.aTypedArray;
	var exportTypedArrayMethod$3 = ArrayBufferViewCore$2.exportTypedArrayMethod;
	var getTypedArrayConstructor$2 = ArrayBufferViewCore$2.getTypedArrayConstructor;

	// `%TypedArray%.prototype.toReversed` method
	// https://tc39.es/proposal-change-array-by-copy/#sec-%typedarray%.prototype.toReversed
	exportTypedArrayMethod$3('toReversed', function toReversed() {
	  return arrayToReversed(aTypedArray$2(this), getTypedArrayConstructor$2(this));
	});

	var es_typedArray_toSorted = {};

	'use strict';
	var ArrayBufferViewCore$1 = arrayBufferViewCore;
	var uncurryThis$d = functionUncurryThis;
	var aCallable$1 = aCallable$l;
	var arrayFromConstructorAndList = arrayFromConstructorAndList$3;
	var aTypedArray$1 = ArrayBufferViewCore$1.aTypedArray;
	var getTypedArrayConstructor$1 = ArrayBufferViewCore$1.getTypedArrayConstructor;
	var exportTypedArrayMethod$2 = ArrayBufferViewCore$1.exportTypedArrayMethod;
	var sort = uncurryThis$d(ArrayBufferViewCore$1.TypedArrayPrototype.sort);

	// `%TypedArray%.prototype.toSorted` method
	// https://tc39.es/proposal-change-array-by-copy/#sec-%typedarray%.prototype.toSorted
	exportTypedArrayMethod$2('toSorted', function toSorted(compareFn) {
	  if (compareFn !== undefined) aCallable$1(compareFn);
	  var O = aTypedArray$1(this);
	  var A = arrayFromConstructorAndList(getTypedArrayConstructor$1(O), O);
	  return sort(A, compareFn);
	});

	var es_typedArray_toString = {};

	'use strict';
	var exportTypedArrayMethod$1 = arrayBufferViewCore.exportTypedArrayMethod;
	var fails$7 = fails$1m;
	var global$i = global$Z;
	var uncurryThis$c = functionUncurryThis;
	var Uint8Array$1 = global$i.Uint8Array;
	var Uint8ArrayPrototype = Uint8Array$1 && Uint8Array$1.prototype || {};
	var arrayToString = [].toString;
	var join$3 = uncurryThis$c([].join);
	if (fails$7(function () {
	  arrayToString.call({});
	})) {
	  arrayToString = function toString() {
	    return join$3(this);
	  };
	}
	var IS_NOT_ARRAY_METHOD = Uint8ArrayPrototype.toString != arrayToString;

	// `%TypedArray%.prototype.toString` method
	// https://tc39.es/ecma262/#sec-%typedarray%.prototype.tostring
	exportTypedArrayMethod$1('toString', arrayToString, IS_NOT_ARRAY_METHOD);

	var es_typedArray_with = {};

	'use strict';
	var arrayWith = arrayWith$2;
	var ArrayBufferViewCore = arrayBufferViewCore;
	var isBigIntArray = isBigIntArray$2;
	var toIntegerOrInfinity = toIntegerOrInfinity$l;
	var toBigInt = toBigInt$3;
	var aTypedArray = ArrayBufferViewCore.aTypedArray;
	var getTypedArrayConstructor = ArrayBufferViewCore.getTypedArrayConstructor;
	var exportTypedArrayMethod = ArrayBufferViewCore.exportTypedArrayMethod;
	var PROPER_ORDER = !!function () {
	  try {
	    // eslint-disable-next-line no-throw-literal, es/no-typed-arrays, es/no-array-prototype-with -- required for testing
	    new Int8Array(1)['with'](2, {
	      valueOf: function valueOf() {
	        throw 8;
	      }
	    });
	  } catch (error) {
	    // some early implementations, like WebKit, does not follow the final semantic
	    // https://github.com/tc39/proposal-change-array-by-copy/pull/86
	    return error === 8;
	  }
	}();

	// `%TypedArray%.prototype.with` method
	// https://tc39.es/proposal-change-array-by-copy/#sec-%typedarray%.prototype.with
	exportTypedArrayMethod('with', {
	  'with': function _with(index, value) {
	    var O = aTypedArray(this);
	    var relativeIndex = toIntegerOrInfinity(index);
	    var actualValue = isBigIntArray(O) ? toBigInt(value) : +value;
	    return arrayWith(O, getTypedArrayConstructor(O), relativeIndex, actualValue);
	  }
	}['with'], !PROPER_ORDER);

	var es_unescape = {};

	'use strict';
	var $$e = _export;
	var uncurryThis$b = functionUncurryThis;
	var toString$2 = toString$x;
	var fromCharCode$2 = String.fromCharCode;
	var charAt$4 = uncurryThis$b(''.charAt);
	var exec$3 = uncurryThis$b(/./.exec);
	var stringSlice$2 = uncurryThis$b(''.slice);
	var hex2 = /^[\da-f]{2}$/i;
	var hex4 = /^[\da-f]{4}$/i;

	// `unescape` method
	// https://tc39.es/ecma262/#sec-unescape-string
	$$e({
	  global: true
	}, {
	  unescape: function unescape(string) {
	    var str = toString$2(string);
	    var result = '';
	    var length = str.length;
	    var index = 0;
	    var chr, part;
	    while (index < length) {
	      chr = charAt$4(str, index++);
	      if (chr === '%') {
	        if (charAt$4(str, index) === 'u') {
	          part = stringSlice$2(str, index + 1, index + 5);
	          if (exec$3(hex4, part)) {
	            result += fromCharCode$2(parseInt(part, 16));
	            index += 5;
	            continue;
	          }
	        } else {
	          part = stringSlice$2(str, index, index + 2);
	          if (exec$3(hex2, part)) {
	            result += fromCharCode$2(parseInt(part, 16));
	            index += 2;
	            continue;
	          }
	        }
	      }
	      result += chr;
	    }
	    return result;
	  }
	});

	var es_weakMap = {};

	var es_weakMap_constructor = {};

	'use strict';
	var uncurryThis$a = functionUncurryThis;
	var defineBuiltIns$2 = defineBuiltIns$5;
	var getWeakData = internalMetadataExports.getWeakData;
	var anInstance$4 = anInstance$a;
	var anObject$3 = anObject$D;
	var isNullOrUndefined$1 = isNullOrUndefined$e;
	var isObject$3 = isObject$z;
	var iterate$1 = iterate$a;
	var ArrayIterationModule = arrayIteration;
	var hasOwn$6 = hasOwnProperty_1;
	var InternalStateModule$3 = internalState;
	var setInternalState$3 = InternalStateModule$3.set;
	var internalStateGetterFor = InternalStateModule$3.getterFor;
	var find$1 = ArrayIterationModule.find;
	var findIndex = ArrayIterationModule.findIndex;
	var splice$1 = uncurryThis$a([].splice);
	var id = 0;

	// fallback for uncaught frozen keys
	var uncaughtFrozenStore = function uncaughtFrozenStore(state) {
	  return state.frozen || (state.frozen = new UncaughtFrozenStore());
	};
	var UncaughtFrozenStore = function UncaughtFrozenStore() {
	  this.entries = [];
	};
	var findUncaughtFrozen = function findUncaughtFrozen(store, key) {
	  return find$1(store.entries, function (it) {
	    return it[0] === key;
	  });
	};
	UncaughtFrozenStore.prototype = {
	  get: function get(key) {
	    var entry = findUncaughtFrozen(this, key);
	    if (entry) return entry[1];
	  },
	  has: function has(key) {
	    return !!findUncaughtFrozen(this, key);
	  },
	  set: function set(key, value) {
	    var entry = findUncaughtFrozen(this, key);
	    if (entry) entry[1] = value;else this.entries.push([key, value]);
	  },
	  'delete': function _delete(key) {
	    var index = findIndex(this.entries, function (it) {
	      return it[0] === key;
	    });
	    if (~index) splice$1(this.entries, index, 1);
	    return !!~index;
	  }
	};
	var collectionWeak$2 = {
	  getConstructor: function getConstructor(wrapper, CONSTRUCTOR_NAME, IS_MAP, ADDER) {
	    var Constructor = wrapper(function (that, iterable) {
	      anInstance$4(that, Prototype);
	      setInternalState$3(that, {
	        type: CONSTRUCTOR_NAME,
	        id: id++,
	        frozen: undefined
	      });
	      if (!isNullOrUndefined$1(iterable)) iterate$1(iterable, that[ADDER], {
	        that: that,
	        AS_ENTRIES: IS_MAP
	      });
	    });
	    var Prototype = Constructor.prototype;
	    var getInternalState = internalStateGetterFor(CONSTRUCTOR_NAME);
	    var define = function define(that, key, value) {
	      var state = getInternalState(that);
	      var data = getWeakData(anObject$3(key), true);
	      if (data === true) uncaughtFrozenStore(state).set(key, value);else data[state.id] = value;
	      return that;
	    };
	    defineBuiltIns$2(Prototype, {
	      // `{ WeakMap, WeakSet }.prototype.delete(key)` methods
	      // https://tc39.es/ecma262/#sec-weakmap.prototype.delete
	      // https://tc39.es/ecma262/#sec-weakset.prototype.delete
	      'delete': function _delete(key) {
	        var state = getInternalState(this);
	        if (!isObject$3(key)) return false;
	        var data = getWeakData(key);
	        if (data === true) return uncaughtFrozenStore(state)['delete'](key);
	        return data && hasOwn$6(data, state.id) && delete data[state.id];
	      },
	      // `{ WeakMap, WeakSet }.prototype.has(key)` methods
	      // https://tc39.es/ecma262/#sec-weakmap.prototype.has
	      // https://tc39.es/ecma262/#sec-weakset.prototype.has
	      has: function has(key) {
	        var state = getInternalState(this);
	        if (!isObject$3(key)) return false;
	        var data = getWeakData(key);
	        if (data === true) return uncaughtFrozenStore(state).has(key);
	        return data && hasOwn$6(data, state.id);
	      }
	    });
	    defineBuiltIns$2(Prototype, IS_MAP ? {
	      // `WeakMap.prototype.get(key)` method
	      // https://tc39.es/ecma262/#sec-weakmap.prototype.get
	      get: function get(key) {
	        var state = getInternalState(this);
	        if (isObject$3(key)) {
	          var data = getWeakData(key);
	          if (data === true) return uncaughtFrozenStore(state).get(key);
	          return data ? data[state.id] : undefined;
	        }
	      },
	      // `WeakMap.prototype.set(key, value)` method
	      // https://tc39.es/ecma262/#sec-weakmap.prototype.set
	      set: function set(key, value) {
	        return define(this, key, value);
	      }
	    } : {
	      // `WeakSet.prototype.add(value)` method
	      // https://tc39.es/ecma262/#sec-weakset.prototype.add
	      add: function add(value) {
	        return define(this, value, true);
	      }
	    });
	    return Constructor;
	  }
	};
	var collectionWeak$3 = /*@__PURE__*/getDefaultExportFromCjs(collectionWeak$2);

	'use strict';
	var FREEZING = freezing;
	var global$h = global$Z;
	var uncurryThis$9 = functionUncurryThis;
	var defineBuiltIns$1 = defineBuiltIns$5;
	var InternalMetadataModule = internalMetadataExports;
	var collection$1 = collection$4;
	var collectionWeak$1 = collectionWeak$2;
	var isObject$2 = isObject$z;
	var enforceInternalState = internalState.enforce;
	var fails$6 = fails$1m;
	var NATIVE_WEAK_MAP = weakMapBasicDetection;
	var $Object = Object;
	// eslint-disable-next-line es/no-array-isarray -- safe
	var isArray = Array.isArray;
	// eslint-disable-next-line es/no-object-isextensible -- safe
	var isExtensible = $Object.isExtensible;
	// eslint-disable-next-line es/no-object-isfrozen -- safe
	var isFrozen = $Object.isFrozen;
	// eslint-disable-next-line es/no-object-issealed -- safe
	var isSealed = $Object.isSealed;
	// eslint-disable-next-line es/no-object-freeze -- safe
	var freeze = $Object.freeze;
	// eslint-disable-next-line es/no-object-seal -- safe
	var seal = $Object.seal;
	var FROZEN = {};
	var SEALED = {};
	var IS_IE11 = !global$h.ActiveXObject && 'ActiveXObject' in global$h;
	var InternalWeakMap;
	var wrapper = function wrapper(init) {
	  return function WeakMap() {
	    return init(this, arguments.length ? arguments[0] : undefined);
	  };
	};

	// `WeakMap` constructor
	// https://tc39.es/ecma262/#sec-weakmap-constructor
	var $WeakMap = collection$1('WeakMap', wrapper, collectionWeak$1);
	var WeakMapPrototype = $WeakMap.prototype;
	var nativeSet = uncurryThis$9(WeakMapPrototype.set);

	// Chakra Edge bug: adding frozen arrays to WeakMap unfreeze them
	var hasMSEdgeFreezingBug = function hasMSEdgeFreezingBug() {
	  return FREEZING && fails$6(function () {
	    var frozenArray = freeze([]);
	    nativeSet(new $WeakMap(), frozenArray, 1);
	    return !isFrozen(frozenArray);
	  });
	};

	// IE11 WeakMap frozen keys fix
	// We can't use feature detection because it crash some old IE builds
	// https://github.com/zloirock/core-js/issues/485
	if (NATIVE_WEAK_MAP) if (IS_IE11) {
	  InternalWeakMap = collectionWeak$1.getConstructor(wrapper, 'WeakMap', true);
	  InternalMetadataModule.enable();
	  var nativeDelete = uncurryThis$9(WeakMapPrototype['delete']);
	  var nativeHas = uncurryThis$9(WeakMapPrototype.has);
	  var nativeGet = uncurryThis$9(WeakMapPrototype.get);
	  defineBuiltIns$1(WeakMapPrototype, {
	    'delete': function _delete(key) {
	      if (isObject$2(key) && !isExtensible(key)) {
	        var state = enforceInternalState(this);
	        if (!state.frozen) state.frozen = new InternalWeakMap();
	        return nativeDelete(this, key) || state.frozen['delete'](key);
	      }
	      return nativeDelete(this, key);
	    },
	    has: function has(key) {
	      if (isObject$2(key) && !isExtensible(key)) {
	        var state = enforceInternalState(this);
	        if (!state.frozen) state.frozen = new InternalWeakMap();
	        return nativeHas(this, key) || state.frozen.has(key);
	      }
	      return nativeHas(this, key);
	    },
	    get: function get(key) {
	      if (isObject$2(key) && !isExtensible(key)) {
	        var state = enforceInternalState(this);
	        if (!state.frozen) state.frozen = new InternalWeakMap();
	        return nativeHas(this, key) ? nativeGet(this, key) : state.frozen.get(key);
	      }
	      return nativeGet(this, key);
	    },
	    set: function set(key, value) {
	      if (isObject$2(key) && !isExtensible(key)) {
	        var state = enforceInternalState(this);
	        if (!state.frozen) state.frozen = new InternalWeakMap();
	        nativeHas(this, key) ? nativeSet(this, key, value) : state.frozen.set(key, value);
	      } else nativeSet(this, key, value);
	      return this;
	    }
	  });
	  // Chakra Edge frozen keys fix
	} else if (hasMSEdgeFreezingBug()) {
	  defineBuiltIns$1(WeakMapPrototype, {
	    set: function set(key, value) {
	      var arrayIntegrityLevel;
	      if (isArray(key)) {
	        if (isFrozen(key)) arrayIntegrityLevel = FROZEN;else if (isSealed(key)) arrayIntegrityLevel = SEALED;
	      }
	      nativeSet(this, key, value);
	      if (arrayIntegrityLevel == FROZEN) freeze(key);
	      if (arrayIntegrityLevel == SEALED) seal(key);
	      return this;
	    }
	  });
	}

	var es_weakSet = {};

	var es_weakSet_constructor = {};

	'use strict';
	var collection = collection$4;
	var collectionWeak = collectionWeak$2;

	// `WeakSet` constructor
	// https://tc39.es/ecma262/#sec-weakset-constructor
	collection('WeakSet', function (init) {
	  return function WeakSet() {
	    return init(this, arguments.length ? arguments[0] : undefined);
	  };
	}, collectionWeak);

	var web_atob = {};

	var itoc$1 = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=';
	var ctoi$1 = {};
	for (var index$3 = 0; index$3 < 66; index$3++) ctoi$1[itoc$1.charAt(index$3)] = index$3;
	var base64Map = {
	  itoc: itoc$1,
	  ctoi: ctoi$1
	};
	var base64Map$1 = /*@__PURE__*/getDefaultExportFromCjs(base64Map);

	var $$d = _export;
	var global$g = global$Z;
	var getBuiltIn$4 = getBuiltIn$m;
	var uncurryThis$8 = functionUncurryThis;
	var call$3 = functionCall;
	var fails$5 = fails$1m;
	var toString$1 = toString$x;
	var hasOwn$5 = hasOwnProperty_1;
	var validateArgumentsLength$6 = validateArgumentsLength$8;
	var ctoi = base64Map.ctoi;
	var disallowed = /[^\d+/a-z]/i;
	var whitespaces = /[\t\n\f\r ]+/g;
	var finalEq = /[=]{1,2}$/;
	var $atob = getBuiltIn$4('atob');
	var fromCharCode$1 = String.fromCharCode;
	var charAt$3 = uncurryThis$8(''.charAt);
	var replace$3 = uncurryThis$8(''.replace);
	var exec$2 = uncurryThis$8(disallowed.exec);
	var NO_SPACES_IGNORE = fails$5(function () {
	  return $atob(' ') !== '';
	});
	var NO_ENCODING_CHECK = !fails$5(function () {
	  $atob('a');
	});
	var NO_ARG_RECEIVING_CHECK$1 = !NO_SPACES_IGNORE && !NO_ENCODING_CHECK && !fails$5(function () {
	  $atob();
	});
	var WRONG_ARITY$1 = !NO_SPACES_IGNORE && !NO_ENCODING_CHECK && $atob.length !== 1;

	// `atob` method
	// https://html.spec.whatwg.org/multipage/webappapis.html#dom-atob
	$$d({
	  global: true,
	  bind: true,
	  enumerable: true,
	  forced: NO_SPACES_IGNORE || NO_ENCODING_CHECK || NO_ARG_RECEIVING_CHECK$1 || WRONG_ARITY$1
	}, {
	  atob: function atob(data) {
	    validateArgumentsLength$6(arguments.length, 1);
	    // `webpack` dev server bug on IE global methods - use call(fn, global, ...)
	    if (NO_ARG_RECEIVING_CHECK$1 || WRONG_ARITY$1) return call$3($atob, global$g, data);
	    var string = replace$3(toString$1(data), whitespaces, '');
	    var output = '';
	    var position = 0;
	    var bc = 0;
	    var chr, bs;
	    if (string.length % 4 == 0) {
	      string = replace$3(string, finalEq, '');
	    }
	    if (string.length % 4 == 1 || exec$2(disallowed, string)) {
	      throw new (getBuiltIn$4('DOMException'))('The string is not correctly encoded', 'InvalidCharacterError');
	    }
	    while (chr = charAt$3(string, position++)) {
	      if (hasOwn$5(ctoi, chr)) {
	        bs = bc % 4 ? bs * 64 + ctoi[chr] : ctoi[chr];
	        if (bc++ % 4) output += fromCharCode$1(255 & bs >> (-2 * bc & 6));
	      }
	    }
	    return output;
	  }
	});

	var web_btoa = {};

	var $$c = _export;
	var global$f = global$Z;
	var getBuiltIn$3 = getBuiltIn$m;
	var uncurryThis$7 = functionUncurryThis;
	var call$2 = functionCall;
	var fails$4 = fails$1m;
	var toString = toString$x;
	var validateArgumentsLength$5 = validateArgumentsLength$8;
	var itoc = base64Map.itoc;
	var $btoa = getBuiltIn$3('btoa');
	var charAt$2 = uncurryThis$7(''.charAt);
	var charCodeAt$1 = uncurryThis$7(''.charCodeAt);
	var NO_ARG_RECEIVING_CHECK = !!$btoa && !fails$4(function () {
	  $btoa();
	});
	var WRONG_ARG_CONVERSION = !!$btoa && fails$4(function () {
	  return $btoa(null) !== 'bnVsbA==';
	});
	var WRONG_ARITY = !!$btoa && $btoa.length !== 1;

	// `btoa` method
	// https://html.spec.whatwg.org/multipage/webappapis.html#dom-btoa
	$$c({
	  global: true,
	  bind: true,
	  enumerable: true,
	  forced: NO_ARG_RECEIVING_CHECK || WRONG_ARG_CONVERSION || WRONG_ARITY
	}, {
	  btoa: function btoa(data) {
	    validateArgumentsLength$5(arguments.length, 1);
	    // `webpack` dev server bug on IE global methods - use call(fn, global, ...)
	    if (NO_ARG_RECEIVING_CHECK || WRONG_ARG_CONVERSION || WRONG_ARITY) return call$2($btoa, global$f, toString(data));
	    var string = toString(data);
	    var output = '';
	    var position = 0;
	    var map = itoc;
	    var block, charCode;
	    while (charAt$2(string, position) || (map = '=', position % 1)) {
	      charCode = charCodeAt$1(string, position += 3 / 4);
	      if (charCode > 0xFF) {
	        throw new (getBuiltIn$3('DOMException'))('The string contains characters outside of the Latin1 range', 'InvalidCharacterError');
	      }
	      block = block << 8 | charCode;
	      output += charAt$2(map, 63 & block >> 8 - position % 1 * 8);
	    }
	    return output;
	  }
	});

	var web_domCollections_forEach = {};

	// iterable DOM collections
	// flag - `iterable` interface - 'entries', 'keys', 'values', 'forEach' methods
	var domIterables = {
	  CSSRuleList: 0,
	  CSSStyleDeclaration: 0,
	  CSSValueList: 0,
	  ClientRectList: 0,
	  DOMRectList: 0,
	  DOMStringList: 0,
	  DOMTokenList: 1,
	  DataTransferItemList: 0,
	  FileList: 0,
	  HTMLAllCollection: 0,
	  HTMLCollection: 0,
	  HTMLFormElement: 0,
	  HTMLSelectElement: 0,
	  MediaList: 0,
	  MimeTypeArray: 0,
	  NamedNodeMap: 0,
	  NodeList: 1,
	  PaintRequestList: 0,
	  Plugin: 0,
	  PluginArray: 0,
	  SVGLengthList: 0,
	  SVGNumberList: 0,
	  SVGPathSegList: 0,
	  SVGPointList: 0,
	  SVGStringList: 0,
	  SVGTransformList: 0,
	  SourceBufferList: 0,
	  StyleSheetList: 0,
	  TextTrackCueList: 0,
	  TextTrackList: 0,
	  TouchList: 0
	};
	var domIterables$1 = /*@__PURE__*/getDefaultExportFromCjs(domIterables);

	// in old WebKit versions, `element.classList` is not an instance of global `DOMTokenList`
	var documentCreateElement = documentCreateElement$2;
	var classList = documentCreateElement('span').classList;
	var DOMTokenListPrototype$2 = classList && classList.constructor && classList.constructor.prototype;
	var domTokenListPrototype = DOMTokenListPrototype$2 === Object.prototype ? undefined : DOMTokenListPrototype$2;
	var domTokenListPrototype$1 = /*@__PURE__*/getDefaultExportFromCjs(domTokenListPrototype);

	var global$e = global$Z;
	var DOMIterables$1 = domIterables;
	var DOMTokenListPrototype$1 = domTokenListPrototype;
	var forEach$1 = arrayForEach;
	var createNonEnumerableProperty$2 = createNonEnumerableProperty$f;
	var handlePrototype$1 = function handlePrototype(CollectionPrototype) {
	  // some Chrome versions have non-configurable methods on DOMTokenList
	  if (CollectionPrototype && CollectionPrototype.forEach !== forEach$1) try {
	    createNonEnumerableProperty$2(CollectionPrototype, 'forEach', forEach$1);
	  } catch (error) {
	    CollectionPrototype.forEach = forEach$1;
	  }
	};
	for (var COLLECTION_NAME$1 in DOMIterables$1) {
	  if (DOMIterables$1[COLLECTION_NAME$1]) {
	    handlePrototype$1(global$e[COLLECTION_NAME$1] && global$e[COLLECTION_NAME$1].prototype);
	  }
	}
	handlePrototype$1(DOMTokenListPrototype$1);

	var web_domCollections_iterator = {};

	var global$d = global$Z;
	var DOMIterables = domIterables;
	var DOMTokenListPrototype = domTokenListPrototype;
	var ArrayIteratorMethods = es_array_iterator;
	var createNonEnumerableProperty$1 = createNonEnumerableProperty$f;
	var wellKnownSymbol$2 = wellKnownSymbol$z;
	var ITERATOR$2 = wellKnownSymbol$2('iterator');
	var TO_STRING_TAG = wellKnownSymbol$2('toStringTag');
	var ArrayValues = ArrayIteratorMethods.values;
	var handlePrototype = function handlePrototype(CollectionPrototype, COLLECTION_NAME) {
	  if (CollectionPrototype) {
	    // some Chrome versions have non-configurable methods on DOMTokenList
	    if (CollectionPrototype[ITERATOR$2] !== ArrayValues) try {
	      createNonEnumerableProperty$1(CollectionPrototype, ITERATOR$2, ArrayValues);
	    } catch (error) {
	      CollectionPrototype[ITERATOR$2] = ArrayValues;
	    }
	    if (!CollectionPrototype[TO_STRING_TAG]) {
	      createNonEnumerableProperty$1(CollectionPrototype, TO_STRING_TAG, COLLECTION_NAME);
	    }
	    if (DOMIterables[COLLECTION_NAME]) for (var METHOD_NAME in ArrayIteratorMethods) {
	      // some Chrome versions have non-configurable methods on DOMTokenList
	      if (CollectionPrototype[METHOD_NAME] !== ArrayIteratorMethods[METHOD_NAME]) try {
	        createNonEnumerableProperty$1(CollectionPrototype, METHOD_NAME, ArrayIteratorMethods[METHOD_NAME]);
	      } catch (error) {
	        CollectionPrototype[METHOD_NAME] = ArrayIteratorMethods[METHOD_NAME];
	      }
	    }
	  }
	};
	for (var COLLECTION_NAME in DOMIterables) {
	  handlePrototype(global$d[COLLECTION_NAME] && global$d[COLLECTION_NAME].prototype, COLLECTION_NAME);
	}
	handlePrototype(DOMTokenListPrototype, 'DOMTokenList');

	var web_domException_constructor = {};

	var IS_NODE$2 = engineIsNode;
	var tryNodeRequire$1 = function tryNodeRequire(name) {
	  try {
	    // eslint-disable-next-line no-new-func -- safe
	    if (IS_NODE$2) return Function('return require("' + name + '")')();
	  } catch (error) {/* empty */}
	};
	var tryNodeRequire$2 = /*@__PURE__*/getDefaultExportFromCjs(tryNodeRequire$1);

	var domExceptionConstants = {
	  IndexSizeError: {
	    s: 'INDEX_SIZE_ERR',
	    c: 1,
	    m: 1
	  },
	  DOMStringSizeError: {
	    s: 'DOMSTRING_SIZE_ERR',
	    c: 2,
	    m: 0
	  },
	  HierarchyRequestError: {
	    s: 'HIERARCHY_REQUEST_ERR',
	    c: 3,
	    m: 1
	  },
	  WrongDocumentError: {
	    s: 'WRONG_DOCUMENT_ERR',
	    c: 4,
	    m: 1
	  },
	  InvalidCharacterError: {
	    s: 'INVALID_CHARACTER_ERR',
	    c: 5,
	    m: 1
	  },
	  NoDataAllowedError: {
	    s: 'NO_DATA_ALLOWED_ERR',
	    c: 6,
	    m: 0
	  },
	  NoModificationAllowedError: {
	    s: 'NO_MODIFICATION_ALLOWED_ERR',
	    c: 7,
	    m: 1
	  },
	  NotFoundError: {
	    s: 'NOT_FOUND_ERR',
	    c: 8,
	    m: 1
	  },
	  NotSupportedError: {
	    s: 'NOT_SUPPORTED_ERR',
	    c: 9,
	    m: 1
	  },
	  InUseAttributeError: {
	    s: 'INUSE_ATTRIBUTE_ERR',
	    c: 10,
	    m: 1
	  },
	  InvalidStateError: {
	    s: 'INVALID_STATE_ERR',
	    c: 11,
	    m: 1
	  },
	  SyntaxError: {
	    s: 'SYNTAX_ERR',
	    c: 12,
	    m: 1
	  },
	  InvalidModificationError: {
	    s: 'INVALID_MODIFICATION_ERR',
	    c: 13,
	    m: 1
	  },
	  NamespaceError: {
	    s: 'NAMESPACE_ERR',
	    c: 14,
	    m: 1
	  },
	  InvalidAccessError: {
	    s: 'INVALID_ACCESS_ERR',
	    c: 15,
	    m: 1
	  },
	  ValidationError: {
	    s: 'VALIDATION_ERR',
	    c: 16,
	    m: 0
	  },
	  TypeMismatchError: {
	    s: 'TYPE_MISMATCH_ERR',
	    c: 17,
	    m: 1
	  },
	  SecurityError: {
	    s: 'SECURITY_ERR',
	    c: 18,
	    m: 1
	  },
	  NetworkError: {
	    s: 'NETWORK_ERR',
	    c: 19,
	    m: 1
	  },
	  AbortError: {
	    s: 'ABORT_ERR',
	    c: 20,
	    m: 1
	  },
	  URLMismatchError: {
	    s: 'URL_MISMATCH_ERR',
	    c: 21,
	    m: 1
	  },
	  QuotaExceededError: {
	    s: 'QUOTA_EXCEEDED_ERR',
	    c: 22,
	    m: 1
	  },
	  TimeoutError: {
	    s: 'TIMEOUT_ERR',
	    c: 23,
	    m: 1
	  },
	  InvalidNodeTypeError: {
	    s: 'INVALID_NODE_TYPE_ERR',
	    c: 24,
	    m: 1
	  },
	  DataCloneError: {
	    s: 'DATA_CLONE_ERR',
	    c: 25,
	    m: 1
	  }
	};
	var domExceptionConstants$1 = /*@__PURE__*/getDefaultExportFromCjs(domExceptionConstants);

	'use strict';
	var $$b = _export;
	var tryNodeRequire = tryNodeRequire$1;
	var getBuiltIn$2 = getBuiltIn$m;
	var fails$3 = fails$1m;
	var create$1 = objectCreate;
	var createPropertyDescriptor$2 = createPropertyDescriptor$c;
	var defineProperty$2 = objectDefineProperty.f;
	var defineBuiltIn$2 = defineBuiltIn$m;
	var defineBuiltInAccessor$4 = defineBuiltInAccessor$h;
	var hasOwn$4 = hasOwnProperty_1;
	var anInstance$3 = anInstance$a;
	var anObject$2 = anObject$D;
	var errorToString = errorToString$2;
	var normalizeStringArgument$1 = normalizeStringArgument$5;
	var DOMExceptionConstants$1 = domExceptionConstants;
	var clearErrorStack$1 = errorStackClear;
	var InternalStateModule$2 = internalState;
	var DESCRIPTORS$6 = descriptors;
	var IS_PURE$3 = isPure;
	var DOM_EXCEPTION$2 = 'DOMException';
	var DATA_CLONE_ERR = 'DATA_CLONE_ERR';
	var Error$3 = getBuiltIn$2('Error');
	// NodeJS < 17.0 does not expose `DOMException` to global
	var NativeDOMException$1 = getBuiltIn$2(DOM_EXCEPTION$2) || function () {
	  try {
	    // NodeJS < 15.0 does not expose `MessageChannel` to global
	    var MessageChannel = getBuiltIn$2('MessageChannel') || tryNodeRequire('worker_threads').MessageChannel;
	    // eslint-disable-next-line es/no-weak-map, unicorn/require-post-message-target-origin -- safe
	    new MessageChannel().port1.postMessage(new WeakMap());
	  } catch (error) {
	    if (error.name == DATA_CLONE_ERR && error.code == 25) return error.constructor;
	  }
	}();
	var NativeDOMExceptionPrototype = NativeDOMException$1 && NativeDOMException$1.prototype;
	var ErrorPrototype = Error$3.prototype;
	var setInternalState$2 = InternalStateModule$2.set;
	var getInternalState = InternalStateModule$2.getterFor(DOM_EXCEPTION$2);
	var HAS_STACK = ('stack' in Error$3(DOM_EXCEPTION$2));
	var codeFor = function codeFor(name) {
	  return hasOwn$4(DOMExceptionConstants$1, name) && DOMExceptionConstants$1[name].m ? DOMExceptionConstants$1[name].c : 0;
	};
	var $DOMException$1 = function DOMException() {
	  anInstance$3(this, DOMExceptionPrototype$1);
	  var argumentsLength = arguments.length;
	  var message = normalizeStringArgument$1(argumentsLength < 1 ? undefined : arguments[0]);
	  var name = normalizeStringArgument$1(argumentsLength < 2 ? undefined : arguments[1], 'Error');
	  var code = codeFor(name);
	  setInternalState$2(this, {
	    type: DOM_EXCEPTION$2,
	    name: name,
	    message: message,
	    code: code
	  });
	  if (!DESCRIPTORS$6) {
	    this.name = name;
	    this.message = message;
	    this.code = code;
	  }
	  if (HAS_STACK) {
	    var error = Error$3(message);
	    error.name = DOM_EXCEPTION$2;
	    defineProperty$2(this, 'stack', createPropertyDescriptor$2(1, clearErrorStack$1(error.stack, 1)));
	  }
	};
	var DOMExceptionPrototype$1 = $DOMException$1.prototype = create$1(ErrorPrototype);
	var createGetterDescriptor = function createGetterDescriptor(get) {
	  return {
	    enumerable: true,
	    configurable: true,
	    get: get
	  };
	};
	var getterFor = function getterFor(key) {
	  return createGetterDescriptor(function () {
	    return getInternalState(this)[key];
	  });
	};
	if (DESCRIPTORS$6) {
	  // `DOMException.prototype.code` getter
	  defineBuiltInAccessor$4(DOMExceptionPrototype$1, 'code', getterFor('code'));
	  // `DOMException.prototype.message` getter
	  defineBuiltInAccessor$4(DOMExceptionPrototype$1, 'message', getterFor('message'));
	  // `DOMException.prototype.name` getter
	  defineBuiltInAccessor$4(DOMExceptionPrototype$1, 'name', getterFor('name'));
	}
	defineProperty$2(DOMExceptionPrototype$1, 'constructor', createPropertyDescriptor$2(1, $DOMException$1));

	// FF36- DOMException is a function, but can't be constructed
	var INCORRECT_CONSTRUCTOR = fails$3(function () {
	  return !(new NativeDOMException$1() instanceof Error$3);
	});

	// Safari 10.1 / Chrome 32- / IE8- DOMException.prototype.toString bugs
	var INCORRECT_TO_STRING = INCORRECT_CONSTRUCTOR || fails$3(function () {
	  return ErrorPrototype.toString !== errorToString || String(new NativeDOMException$1(1, 2)) !== '2: 1';
	});

	// Deno 1.6.3- DOMException.prototype.code just missed
	var INCORRECT_CODE = INCORRECT_CONSTRUCTOR || fails$3(function () {
	  return new NativeDOMException$1(1, 'DataCloneError').code !== 25;
	});

	// Deno 1.6.3- DOMException constants just missed
	var MISSED_CONSTANTS = INCORRECT_CONSTRUCTOR || NativeDOMException$1[DATA_CLONE_ERR] !== 25 || NativeDOMExceptionPrototype[DATA_CLONE_ERR] !== 25;
	var FORCED_CONSTRUCTOR$1 = IS_PURE$3 ? INCORRECT_TO_STRING || INCORRECT_CODE || MISSED_CONSTANTS : INCORRECT_CONSTRUCTOR;

	// `DOMException` constructor
	// https://webidl.spec.whatwg.org/#idl-DOMException
	$$b({
	  global: true,
	  constructor: true,
	  forced: FORCED_CONSTRUCTOR$1
	}, {
	  DOMException: FORCED_CONSTRUCTOR$1 ? $DOMException$1 : NativeDOMException$1
	});
	var PolyfilledDOMException$1 = getBuiltIn$2(DOM_EXCEPTION$2);
	var PolyfilledDOMExceptionPrototype$1 = PolyfilledDOMException$1.prototype;
	if (INCORRECT_TO_STRING && (IS_PURE$3 || NativeDOMException$1 === PolyfilledDOMException$1)) {
	  defineBuiltIn$2(PolyfilledDOMExceptionPrototype$1, 'toString', errorToString);
	}
	if (INCORRECT_CODE && DESCRIPTORS$6 && NativeDOMException$1 === PolyfilledDOMException$1) {
	  defineBuiltInAccessor$4(PolyfilledDOMExceptionPrototype$1, 'code', createGetterDescriptor(function () {
	    return codeFor(anObject$2(this).name);
	  }));
	}

	// `DOMException` constants
	for (var key$1 in DOMExceptionConstants$1) if (hasOwn$4(DOMExceptionConstants$1, key$1)) {
	  var constant$2 = DOMExceptionConstants$1[key$1];
	  var constantName$1 = constant$2.s;
	  var descriptor$2 = createPropertyDescriptor$2(6, constant$2.c);
	  if (!hasOwn$4(PolyfilledDOMException$1, constantName$1)) {
	    defineProperty$2(PolyfilledDOMException$1, constantName$1, descriptor$2);
	  }
	  if (!hasOwn$4(PolyfilledDOMExceptionPrototype$1, constantName$1)) {
	    defineProperty$2(PolyfilledDOMExceptionPrototype$1, constantName$1, descriptor$2);
	  }
	}

	var web_domException_stack = {};

	'use strict';
	var $$a = _export;
	var global$c = global$Z;
	var getBuiltIn$1 = getBuiltIn$m;
	var createPropertyDescriptor$1 = createPropertyDescriptor$c;
	var defineProperty$1 = objectDefineProperty.f;
	var hasOwn$3 = hasOwnProperty_1;
	var anInstance$2 = anInstance$a;
	var inheritIfRequired = inheritIfRequired$6;
	var normalizeStringArgument = normalizeStringArgument$5;
	var DOMExceptionConstants = domExceptionConstants;
	var clearErrorStack = errorStackClear;
	var DESCRIPTORS$5 = descriptors;
	var IS_PURE$2 = isPure;
	var DOM_EXCEPTION$1 = 'DOMException';
	var Error$2 = getBuiltIn$1('Error');
	var NativeDOMException = getBuiltIn$1(DOM_EXCEPTION$1);
	var $DOMException = function DOMException() {
	  anInstance$2(this, DOMExceptionPrototype);
	  var argumentsLength = arguments.length;
	  var message = normalizeStringArgument(argumentsLength < 1 ? undefined : arguments[0]);
	  var name = normalizeStringArgument(argumentsLength < 2 ? undefined : arguments[1], 'Error');
	  var that = new NativeDOMException(message, name);
	  var error = Error$2(message);
	  error.name = DOM_EXCEPTION$1;
	  defineProperty$1(that, 'stack', createPropertyDescriptor$1(1, clearErrorStack(error.stack, 1)));
	  inheritIfRequired(that, this, $DOMException);
	  return that;
	};
	var DOMExceptionPrototype = $DOMException.prototype = NativeDOMException.prototype;
	var ERROR_HAS_STACK = ('stack' in Error$2(DOM_EXCEPTION$1));
	var DOM_EXCEPTION_HAS_STACK = ('stack' in new NativeDOMException(1, 2));

	// eslint-disable-next-line es/no-object-getownpropertydescriptor -- safe
	var descriptor$1 = NativeDOMException && DESCRIPTORS$5 && Object.getOwnPropertyDescriptor(global$c, DOM_EXCEPTION$1);

	// Bun ~ 0.1.1 DOMException have incorrect descriptor and we can't redefine it
	// https://github.com/Jarred-Sumner/bun/issues/399
	var BUGGY_DESCRIPTOR = !!descriptor$1 && !(descriptor$1.writable && descriptor$1.configurable);
	var FORCED_CONSTRUCTOR = ERROR_HAS_STACK && !BUGGY_DESCRIPTOR && !DOM_EXCEPTION_HAS_STACK;

	// `DOMException` constructor patch for `.stack` where it's required
	// https://webidl.spec.whatwg.org/#es-DOMException-specialness
	$$a({
	  global: true,
	  constructor: true,
	  forced: IS_PURE$2 || FORCED_CONSTRUCTOR
	}, {
	  // TODO: fix export logic
	  DOMException: FORCED_CONSTRUCTOR ? $DOMException : NativeDOMException
	});
	var PolyfilledDOMException = getBuiltIn$1(DOM_EXCEPTION$1);
	var PolyfilledDOMExceptionPrototype = PolyfilledDOMException.prototype;
	if (PolyfilledDOMExceptionPrototype.constructor !== PolyfilledDOMException) {
	  if (!IS_PURE$2) {
	    defineProperty$1(PolyfilledDOMExceptionPrototype, 'constructor', createPropertyDescriptor$1(1, PolyfilledDOMException));
	  }
	  for (var key in DOMExceptionConstants) if (hasOwn$3(DOMExceptionConstants, key)) {
	    var constant$1 = DOMExceptionConstants[key];
	    var constantName = constant$1.s;
	    if (!hasOwn$3(PolyfilledDOMException, constantName)) {
	      defineProperty$1(PolyfilledDOMException, constantName, createPropertyDescriptor$1(6, constant$1.c));
	    }
	  }
	}

	var web_domException_toStringTag = {};

	var getBuiltIn = getBuiltIn$m;
	var setToStringTag$2 = setToStringTag$d;
	var DOM_EXCEPTION = 'DOMException';

	// `DOMException.prototype[@@toStringTag]` property
	setToStringTag$2(getBuiltIn(DOM_EXCEPTION), DOM_EXCEPTION);

	var web_immediate = {};

	var web_clearImmediate = {};

	var $$9 = _export;
	var global$b = global$Z;
	var clearImmediate = task$1.clear;

	// `clearImmediate` method
	// http://w3c.github.io/setImmediate/#si-clearImmediate
	$$9({
	  global: true,
	  bind: true,
	  enumerable: true,
	  forced: global$b.clearImmediate !== clearImmediate
	}, {
	  clearImmediate: clearImmediate
	});

	var web_setImmediate = {};

	/* global Bun -- Deno case */
	var engineIsBun = typeof Bun == 'function' && Bun && typeof Bun.version == 'string';
	var engineIsBun$1 = /*@__PURE__*/getDefaultExportFromCjs(engineIsBun);

	'use strict';
	var global$a = global$Z;
	var apply = functionApply$1;
	var isCallable$2 = isCallable$z;
	var ENGINE_IS_BUN = engineIsBun;
	var USER_AGENT = engineUserAgent;
	var arraySlice$1 = arraySlice$a;
	var validateArgumentsLength$4 = validateArgumentsLength$8;
	var Function$1 = global$a.Function;
	// dirty IE9- and Bun 0.3.0- checks
	var WRAP = /MSIE .\./.test(USER_AGENT) || ENGINE_IS_BUN && function () {
	  var version = global$a.Bun.version.split('.');
	  return version.length < 3 || version[0] == 0 && (version[1] < 3 || version[1] == 3 && version[2] == 0);
	}();

	// IE9- / Bun 0.3.0- setTimeout / setInterval / setImmediate additional parameters fix
	// https://html.spec.whatwg.org/multipage/timers-and-user-prompts.html#timers
	// https://github.com/oven-sh/bun/issues/1633
	var schedulersFix$3 = function schedulersFix(scheduler, hasTimeArg) {
	  var firstParamIndex = hasTimeArg ? 2 : 1;
	  return WRAP ? function (handler, timeout /* , ...arguments */) {
	    var boundArgs = validateArgumentsLength$4(arguments.length, 1) > firstParamIndex;
	    var fn = isCallable$2(handler) ? handler : Function$1(handler);
	    var params = boundArgs ? arraySlice$1(arguments, firstParamIndex) : [];
	    var callback = boundArgs ? function () {
	      apply(fn, this, params);
	    } : fn;
	    return hasTimeArg ? scheduler(callback, timeout) : scheduler(callback);
	  } : scheduler;
	};
	var schedulersFix$4 = /*@__PURE__*/getDefaultExportFromCjs(schedulersFix$3);

	var $$8 = _export;
	var global$9 = global$Z;
	var setTask = task$1.set;
	var schedulersFix$2 = schedulersFix$3;

	// https://github.com/oven-sh/bun/issues/1633
	var setImmediate$1 = global$9.setImmediate ? schedulersFix$2(setTask, false) : setTask;

	// `setImmediate` method
	// http://w3c.github.io/setImmediate/#si-setImmediate
	$$8({
	  global: true,
	  bind: true,
	  enumerable: true,
	  forced: global$9.setImmediate !== setImmediate$1
	}, {
	  setImmediate: setImmediate$1
	});

	var web_queueMicrotask = {};

	var $$7 = _export;
	var global$8 = global$Z;
	var microtask = microtask_1;
	var aCallable = aCallable$l;
	var validateArgumentsLength$3 = validateArgumentsLength$8;
	var IS_NODE$1 = engineIsNode;
	var process$1 = global$8.process;

	// `queueMicrotask` method
	// https://html.spec.whatwg.org/multipage/timers-and-user-prompts.html#dom-queuemicrotask
	$$7({
	  global: true,
	  enumerable: true,
	  dontCallGetSet: true
	}, {
	  queueMicrotask: function queueMicrotask(fn) {
	    validateArgumentsLength$3(arguments.length, 1);
	    aCallable(fn);
	    var domain = IS_NODE$1 && process$1.domain;
	    microtask(domain ? domain.bind(fn) : fn);
	  }
	});

	var web_self = {};

	'use strict';
	var $$6 = _export;
	var global$7 = global$Z;
	var defineBuiltInAccessor$3 = defineBuiltInAccessor$h;
	var DESCRIPTORS$4 = descriptors;
	var $TypeError = TypeError;
	// eslint-disable-next-line es/no-object-defineproperty -- safe
	var defineProperty = Object.defineProperty;
	var INCORRECT_VALUE = global$7.self !== global$7;

	// `self` getter
	// https://html.spec.whatwg.org/multipage/window-object.html#dom-self
	try {
	  if (DESCRIPTORS$4) {
	    // eslint-disable-next-line es/no-object-getownpropertydescriptor -- safe
	    var descriptor = Object.getOwnPropertyDescriptor(global$7, 'self');
	    // some engines have `self`, but with incorrect descriptor
	    // https://github.com/denoland/deno/issues/15765
	    if (INCORRECT_VALUE || !descriptor || !descriptor.get || !descriptor.enumerable) {
	      defineBuiltInAccessor$3(global$7, 'self', {
	        get: function self() {
	          return global$7;
	        },
	        set: function self(value) {
	          if (this !== global$7) throw $TypeError('Illegal invocation');
	          defineProperty(global$7, 'self', {
	            value: value,
	            writable: true,
	            configurable: true,
	            enumerable: true
	          });
	        },
	        configurable: true,
	        enumerable: true
	      });
	    }
	  } else $$6({
	    global: true,
	    simple: true,
	    forced: INCORRECT_VALUE
	  }, {
	    self: global$7
	  });
	} catch (error) {/* empty */}

	var web_structuredClone = {};

	var uncurryThis$6 = functionUncurryThis;

	// eslint-disable-next-line es/no-map -- safe
	var MapPrototype = Map.prototype;
	var mapHelpers = {
	  // eslint-disable-next-line es/no-map -- safe
	  Map: Map,
	  set: uncurryThis$6(MapPrototype.set),
	  get: uncurryThis$6(MapPrototype.get),
	  has: uncurryThis$6(MapPrototype.has),
	  remove: uncurryThis$6(MapPrototype['delete']),
	  proto: MapPrototype
	};
	var mapHelpers$1 = /*@__PURE__*/getDefaultExportFromCjs(mapHelpers);

	var uncurryThis$5 = functionUncurryThis;

	// eslint-disable-next-line es/no-set -- safe
	var SetPrototype = Set.prototype;
	var setHelpers = {
	  // eslint-disable-next-line es/no-set -- safe
	  Set: Set,
	  add: uncurryThis$5(SetPrototype.add),
	  has: uncurryThis$5(SetPrototype.has),
	  remove: uncurryThis$5(SetPrototype['delete']),
	  proto: SetPrototype,
	  $has: SetPrototype.has,
	  $keys: SetPrototype.keys
	};
	var setHelpers$1 = /*@__PURE__*/getDefaultExportFromCjs(setHelpers);

	var global$6 = global$Z;
	var fails$2 = fails$1m;
	var V8 = engineV8Version;
	var IS_BROWSER = engineIsBrowser;
	var IS_DENO = engineIsDeno;
	var IS_NODE = engineIsNode;
	var structuredClone = global$6.structuredClone;
	var structuredCloneProperTransfer = !!structuredClone && !fails$2(function () {
	  // prevent V8 ArrayBufferDetaching protector cell invalidation and performance degradation
	  // https://github.com/zloirock/core-js/issues/679
	  if (IS_DENO && V8 > 92 || IS_NODE && V8 > 94 || IS_BROWSER && V8 > 97) return false;
	  var buffer = new ArrayBuffer(8);
	  var clone = structuredClone(buffer, {
	    transfer: [buffer]
	  });
	  return buffer.byteLength != 0 || clone.byteLength != 8;
	});
	var structuredCloneProperTransfer$1 = /*@__PURE__*/getDefaultExportFromCjs(structuredCloneProperTransfer);

	var IS_PURE$1 = isPure;
	var $$5 = _export;
	var global$5 = global$Z;
	var getBuiltin = getBuiltIn$m;
	var uncurryThis$4 = functionUncurryThis;
	var fails$1 = fails$1m;
	var uid = uid$6;
	var isCallable$1 = isCallable$z;
	var isConstructor = isConstructor$6;
	var isNullOrUndefined = isNullOrUndefined$e;
	var isObject$1 = isObject$z;
	var isSymbol = isSymbol$7;
	var iterate = iterate$a;
	var anObject$1 = anObject$D;
	var classof$1 = classof$m;
	var hasOwn$2 = hasOwnProperty_1;
	var createProperty = createProperty$9;
	var createNonEnumerableProperty = createNonEnumerableProperty$f;
	var lengthOfArrayLike = lengthOfArrayLike$t;
	var validateArgumentsLength$2 = validateArgumentsLength$8;
	var getRegExpFlags = regexpGetFlags;
	var MapHelpers = mapHelpers;
	var SetHelpers = setHelpers;
	var ERROR_STACK_INSTALLABLE = errorStackInstallable;
	var PROPER_TRANSFER = structuredCloneProperTransfer;
	var Object$1 = global$5.Object;
	var Array$1 = global$5.Array;
	var Date$1 = global$5.Date;
	var Error$1 = global$5.Error;
	var EvalError = global$5.EvalError;
	var RangeError$1 = global$5.RangeError;
	var ReferenceError$1 = global$5.ReferenceError;
	var SyntaxError = global$5.SyntaxError;
	var TypeError$3 = global$5.TypeError;
	var URIError = global$5.URIError;
	var PerformanceMark = global$5.PerformanceMark;
	var WebAssembly$1 = global$5.WebAssembly;
	var CompileError = WebAssembly$1 && WebAssembly$1.CompileError || Error$1;
	var LinkError = WebAssembly$1 && WebAssembly$1.LinkError || Error$1;
	var RuntimeError$1 = WebAssembly$1 && WebAssembly$1.RuntimeError || Error$1;
	var DOMException = getBuiltin('DOMException');
	var Map$1 = MapHelpers.Map;
	var mapHas = MapHelpers.has;
	var mapGet = MapHelpers.get;
	var mapSet = MapHelpers.set;
	var Set$1 = SetHelpers.Set;
	var setAdd = SetHelpers.add;
	var objectKeys = getBuiltin('Object', 'keys');
	var push$3 = uncurryThis$4([].push);
	var thisBooleanValue = uncurryThis$4(true.valueOf);
	var thisNumberValue = uncurryThis$4(1.0.valueOf);
	var thisStringValue = uncurryThis$4(''.valueOf);
	var thisTimeValue = uncurryThis$4(Date$1.prototype.getTime);
	var PERFORMANCE_MARK = uid('structuredClone');
	var DATA_CLONE_ERROR = 'DataCloneError';
	var TRANSFERRING = 'Transferring';
	var checkBasicSemantic = function checkBasicSemantic(structuredCloneImplementation) {
	  return !fails$1(function () {
	    var set1 = new global$5.Set([7]);
	    var set2 = structuredCloneImplementation(set1);
	    var number = structuredCloneImplementation(Object$1(7));
	    return set2 == set1 || !set2.has(7) || _typeof(number) != 'object' || number != 7;
	  }) && structuredCloneImplementation;
	};
	var checkErrorsCloning = function checkErrorsCloning(structuredCloneImplementation, $Error) {
	  return !fails$1(function () {
	    var error = new $Error();
	    var test = structuredCloneImplementation({
	      a: error,
	      b: error
	    });
	    return !(test && test.a === test.b && test.a instanceof $Error && test.a.stack === error.stack);
	  });
	};

	// https://github.com/whatwg/html/pull/5749
	var checkNewErrorsCloningSemantic = function checkNewErrorsCloningSemantic(structuredCloneImplementation) {
	  return !fails$1(function () {
	    var test = structuredCloneImplementation(new global$5.AggregateError([1], PERFORMANCE_MARK, {
	      cause: 3
	    }));
	    return test.name != 'AggregateError' || test.errors[0] != 1 || test.message != PERFORMANCE_MARK || test.cause != 3;
	  });
	};

	// FF94+, Safari 15.4+, Chrome 98+, NodeJS 17.0+, Deno 1.13+
	// FF<103 and Safari implementations can't clone errors
	// https://bugzilla.mozilla.org/show_bug.cgi?id=1556604
	// FF103 can clone errors, but `.stack` of clone is an empty string
	// https://bugzilla.mozilla.org/show_bug.cgi?id=1778762
	// FF104+ fixed it on usual errors, but not on DOMExceptions
	// https://bugzilla.mozilla.org/show_bug.cgi?id=1777321
	// Chrome <102 returns `null` if cloned object contains multiple references to one error
	// https://bugs.chromium.org/p/v8/issues/detail?id=12542
	// NodeJS implementation can't clone DOMExceptions
	// https://github.com/nodejs/node/issues/41038
	// only FF103+ supports new (html/5749) error cloning semantic
	var nativeStructuredClone = global$5.structuredClone;
	var FORCED_REPLACEMENT = IS_PURE$1 || !checkErrorsCloning(nativeStructuredClone, Error$1) || !checkErrorsCloning(nativeStructuredClone, DOMException) || !checkNewErrorsCloningSemantic(nativeStructuredClone);

	// Chrome 82+, Safari 14.1+, Deno 1.11+
	// Chrome 78-81 implementation swaps `.name` and `.message` of cloned `DOMException`
	// Chrome returns `null` if cloned object contains multiple references to one error
	// Safari 14.1 implementation doesn't clone some `RegExp` flags, so requires a workaround
	// Safari implementation can't clone errors
	// Deno 1.2-1.10 implementations too naive
	// NodeJS 16.0+ does not have `PerformanceMark` constructor
	// NodeJS <17.2 structured cloning implementation from `performance.mark` is too naive
	// and can't clone, for example, `RegExp` or some boxed primitives
	// https://github.com/nodejs/node/issues/40840
	// no one of those implementations supports new (html/5749) error cloning semantic
	var structuredCloneFromMark = !nativeStructuredClone && checkBasicSemantic(function (value) {
	  return new PerformanceMark(PERFORMANCE_MARK, {
	    detail: value
	  }).detail;
	});
	var nativeRestrictedStructuredClone = checkBasicSemantic(nativeStructuredClone) || structuredCloneFromMark;
	var throwUncloneable = function throwUncloneable(type) {
	  throw new DOMException('Uncloneable type: ' + type, DATA_CLONE_ERROR);
	};
	var throwUnpolyfillable = function throwUnpolyfillable(type, action) {
	  throw new DOMException((action || 'Cloning') + ' of ' + type + ' cannot be properly polyfilled in this engine', DATA_CLONE_ERROR);
	};
	var createDataTransfer = function createDataTransfer() {
	  var dataTransfer;
	  try {
	    dataTransfer = new global$5.DataTransfer();
	  } catch (error) {
	    try {
	      dataTransfer = new global$5.ClipboardEvent('').clipboardData;
	    } catch (error2) {/* empty */}
	  }
	  return dataTransfer && dataTransfer.items && dataTransfer.files ? dataTransfer : null;
	};
	var structuredCloneInternal = function structuredCloneInternal(value, map) {
	  if (isSymbol(value)) throwUncloneable('Symbol');
	  if (!isObject$1(value)) return value;
	  // effectively preserves circular references
	  if (map) {
	    if (mapHas(map, value)) return mapGet(map, value);
	  } else map = new Map$1();
	  var type = classof$1(value);
	  var deep = false;
	  var C, name, cloned, dataTransfer, i, length, keys, key, source, target, options;
	  switch (type) {
	    case 'Array':
	      cloned = Array$1(lengthOfArrayLike(value));
	      deep = true;
	      break;
	    case 'Object':
	      cloned = {};
	      deep = true;
	      break;
	    case 'Map':
	      cloned = new Map$1();
	      deep = true;
	      break;
	    case 'Set':
	      cloned = new Set$1();
	      deep = true;
	      break;
	    case 'RegExp':
	      // in this block because of a Safari 14.1 bug
	      // old FF does not clone regexes passed to the constructor, so get the source and flags directly
	      cloned = new RegExp(value.source, getRegExpFlags(value));
	      break;
	    case 'Error':
	      name = value.name;
	      switch (name) {
	        case 'AggregateError':
	          cloned = getBuiltin('AggregateError')([]);
	          break;
	        case 'EvalError':
	          cloned = EvalError();
	          break;
	        case 'RangeError':
	          cloned = RangeError$1();
	          break;
	        case 'ReferenceError':
	          cloned = ReferenceError$1();
	          break;
	        case 'SyntaxError':
	          cloned = SyntaxError();
	          break;
	        case 'TypeError':
	          cloned = TypeError$3();
	          break;
	        case 'URIError':
	          cloned = URIError();
	          break;
	        case 'CompileError':
	          cloned = CompileError();
	          break;
	        case 'LinkError':
	          cloned = LinkError();
	          break;
	        case 'RuntimeError':
	          cloned = RuntimeError$1();
	          break;
	        default:
	          cloned = Error$1();
	      }
	      deep = true;
	      break;
	    case 'DOMException':
	      cloned = new DOMException(value.message, value.name);
	      deep = true;
	      break;
	    case 'DataView':
	    case 'Int8Array':
	    case 'Uint8Array':
	    case 'Uint8ClampedArray':
	    case 'Int16Array':
	    case 'Uint16Array':
	    case 'Int32Array':
	    case 'Uint32Array':
	    case 'Float32Array':
	    case 'Float64Array':
	    case 'BigInt64Array':
	    case 'BigUint64Array':
	      C = global$5[type];
	      // in some old engines like Safari 9, typeof C is 'object'
	      // on Uint8ClampedArray or some other constructors
	      if (!isObject$1(C)) throwUnpolyfillable(type);
	      cloned = new C(
	      // this is safe, since arraybuffer cannot have circular references
	      structuredCloneInternal(value.buffer, map), value.byteOffset, type === 'DataView' ? value.byteLength : value.length);
	      break;
	    case 'DOMQuad':
	      try {
	        cloned = new DOMQuad(structuredCloneInternal(value.p1, map), structuredCloneInternal(value.p2, map), structuredCloneInternal(value.p3, map), structuredCloneInternal(value.p4, map));
	      } catch (error) {
	        if (nativeRestrictedStructuredClone) {
	          cloned = nativeRestrictedStructuredClone(value);
	        } else throwUnpolyfillable(type);
	      }
	      break;
	    case 'FileList':
	      dataTransfer = createDataTransfer();
	      if (dataTransfer) {
	        for (i = 0, length = lengthOfArrayLike(value); i < length; i++) {
	          dataTransfer.items.add(structuredCloneInternal(value[i], map));
	        }
	        cloned = dataTransfer.files;
	      } else if (nativeRestrictedStructuredClone) {
	        cloned = nativeRestrictedStructuredClone(value);
	      } else throwUnpolyfillable(type);
	      break;
	    case 'ImageData':
	      // Safari 9 ImageData is a constructor, but typeof ImageData is 'object'
	      try {
	        cloned = new ImageData(structuredCloneInternal(value.data, map), value.width, value.height, {
	          colorSpace: value.colorSpace
	        });
	      } catch (error) {
	        if (nativeRestrictedStructuredClone) {
	          cloned = nativeRestrictedStructuredClone(value);
	        } else throwUnpolyfillable(type);
	      }
	      break;
	    default:
	      if (nativeRestrictedStructuredClone) {
	        cloned = nativeRestrictedStructuredClone(value);
	      } else switch (type) {
	        case 'BigInt':
	          // can be a 3rd party polyfill
	          cloned = Object$1(value.valueOf());
	          break;
	        case 'Boolean':
	          cloned = Object$1(thisBooleanValue(value));
	          break;
	        case 'Number':
	          cloned = Object$1(thisNumberValue(value));
	          break;
	        case 'String':
	          cloned = Object$1(thisStringValue(value));
	          break;
	        case 'Date':
	          cloned = new Date$1(thisTimeValue(value));
	          break;
	        case 'ArrayBuffer':
	          C = global$5.DataView;
	          // `ArrayBuffer#slice` is not available in IE10
	          // `ArrayBuffer#slice` and `DataView` are not available in old FF
	          if (!C && typeof value.slice != 'function') throwUnpolyfillable(type);
	          // detached buffers throws in `DataView` and `.slice`
	          try {
	            if (typeof value.slice == 'function' && !value.resizable) {
	              cloned = value.slice(0);
	            } else {
	              length = value.byteLength;
	              options = 'maxByteLength' in value ? {
	                maxByteLength: value.maxByteLength
	              } : undefined;
	              cloned = new ArrayBuffer(length, options);
	              source = new C(value);
	              target = new C(cloned);
	              for (i = 0; i < length; i++) {
	                target.setUint8(i, source.getUint8(i));
	              }
	            }
	          } catch (error) {
	            throw new DOMException('ArrayBuffer is detached', DATA_CLONE_ERROR);
	          }
	          break;
	        case 'SharedArrayBuffer':
	          // SharedArrayBuffer should use shared memory, we can't polyfill it, so return the original
	          cloned = value;
	          break;
	        case 'Blob':
	          try {
	            cloned = value.slice(0, value.size, value.type);
	          } catch (error) {
	            throwUnpolyfillable(type);
	          }
	          break;
	        case 'DOMPoint':
	        case 'DOMPointReadOnly':
	          C = global$5[type];
	          try {
	            cloned = C.fromPoint ? C.fromPoint(value) : new C(value.x, value.y, value.z, value.w);
	          } catch (error) {
	            throwUnpolyfillable(type);
	          }
	          break;
	        case 'DOMRect':
	        case 'DOMRectReadOnly':
	          C = global$5[type];
	          try {
	            cloned = C.fromRect ? C.fromRect(value) : new C(value.x, value.y, value.width, value.height);
	          } catch (error) {
	            throwUnpolyfillable(type);
	          }
	          break;
	        case 'DOMMatrix':
	        case 'DOMMatrixReadOnly':
	          C = global$5[type];
	          try {
	            cloned = C.fromMatrix ? C.fromMatrix(value) : new C(value);
	          } catch (error) {
	            throwUnpolyfillable(type);
	          }
	          break;
	        case 'AudioData':
	        case 'VideoFrame':
	          if (!isCallable$1(value.clone)) throwUnpolyfillable(type);
	          try {
	            cloned = value.clone();
	          } catch (error) {
	            throwUncloneable(type);
	          }
	          break;
	        case 'File':
	          try {
	            cloned = new File([value], value.name, value);
	          } catch (error) {
	            throwUnpolyfillable(type);
	          }
	          break;
	        case 'CropTarget':
	        case 'CryptoKey':
	        case 'FileSystemDirectoryHandle':
	        case 'FileSystemFileHandle':
	        case 'FileSystemHandle':
	        case 'GPUCompilationInfo':
	        case 'GPUCompilationMessage':
	        case 'ImageBitmap':
	        case 'RTCCertificate':
	        case 'WebAssembly.Module':
	          throwUnpolyfillable(type);
	        // break omitted
	        default:
	          throwUncloneable(type);
	      }
	  }
	  mapSet(map, value, cloned);
	  if (deep) switch (type) {
	    case 'Array':
	    case 'Object':
	      keys = objectKeys(value);
	      for (i = 0, length = lengthOfArrayLike(keys); i < length; i++) {
	        key = keys[i];
	        createProperty(cloned, key, structuredCloneInternal(value[key], map));
	      }
	      break;
	    case 'Map':
	      value.forEach(function (v, k) {
	        mapSet(cloned, structuredCloneInternal(k, map), structuredCloneInternal(v, map));
	      });
	      break;
	    case 'Set':
	      value.forEach(function (v) {
	        setAdd(cloned, structuredCloneInternal(v, map));
	      });
	      break;
	    case 'Error':
	      createNonEnumerableProperty(cloned, 'message', structuredCloneInternal(value.message, map));
	      if (hasOwn$2(value, 'cause')) {
	        createNonEnumerableProperty(cloned, 'cause', structuredCloneInternal(value.cause, map));
	      }
	      if (name == 'AggregateError') {
	        cloned.errors = structuredCloneInternal(value.errors, map);
	      }
	    // break omitted
	    case 'DOMException':
	      if (ERROR_STACK_INSTALLABLE) {
	        createNonEnumerableProperty(cloned, 'stack', structuredCloneInternal(value.stack, map));
	      }
	  }
	  return cloned;
	};
	var tryToTransfer = function tryToTransfer(rawTransfer, map) {
	  if (!isObject$1(rawTransfer)) throw TypeError$3('Transfer option cannot be converted to a sequence');
	  var transfer = [];
	  iterate(rawTransfer, function (value) {
	    push$3(transfer, anObject$1(value));
	  });
	  var i = 0;
	  var length = lengthOfArrayLike(transfer);
	  var value, type, C, transferredArray, transferred, canvas, context;
	  if (PROPER_TRANSFER) {
	    transferredArray = nativeStructuredClone(transfer, {
	      transfer: transfer
	    });
	    while (i < length) mapSet(map, transfer[i], transferredArray[i++]);
	  } else while (i < length) {
	    value = transfer[i++];
	    if (mapHas(map, value)) throw new DOMException('Duplicate transferable', DATA_CLONE_ERROR);
	    type = classof$1(value);
	    switch (type) {
	      case 'ImageBitmap':
	        C = global$5.OffscreenCanvas;
	        if (!isConstructor(C)) throwUnpolyfillable(type, TRANSFERRING);
	        try {
	          canvas = new C(value.width, value.height);
	          context = canvas.getContext('bitmaprenderer');
	          context.transferFromImageBitmap(value);
	          transferred = canvas.transferToImageBitmap();
	        } catch (error) {/* empty */}
	        break;
	      case 'AudioData':
	      case 'VideoFrame':
	        if (!isCallable$1(value.clone) || !isCallable$1(value.close)) throwUnpolyfillable(type, TRANSFERRING);
	        try {
	          transferred = value.clone();
	          value.close();
	        } catch (error) {/* empty */}
	        break;
	      case 'ArrayBuffer':
	        if (!isCallable$1(value.transfer)) throwUnpolyfillable(type, TRANSFERRING);
	        transferred = value.transfer();
	        break;
	      case 'MediaSourceHandle':
	      case 'MessagePort':
	      case 'OffscreenCanvas':
	      case 'ReadableStream':
	      case 'TransformStream':
	      case 'WritableStream':
	        throwUnpolyfillable(type, TRANSFERRING);
	    }
	    if (transferred === undefined) throw new DOMException('This object cannot be transferred: ' + type, DATA_CLONE_ERROR);
	    mapSet(map, value, transferred);
	  }
	};

	// `structuredClone` method
	// https://html.spec.whatwg.org/multipage/structured-data.html#dom-structuredclone
	$$5({
	  global: true,
	  enumerable: true,
	  sham: !PROPER_TRANSFER,
	  forced: FORCED_REPLACEMENT
	}, {
	  structuredClone: function structuredClone(value /* , { transfer } */) {
	    var options = validateArgumentsLength$2(arguments.length, 1) > 1 && !isNullOrUndefined(arguments[1]) ? anObject$1(arguments[1]) : undefined;
	    var transfer = options ? options.transfer : undefined;
	    var map;
	    if (transfer !== undefined) {
	      map = new Map$1();
	      tryToTransfer(transfer, map);
	    }
	    return structuredCloneInternal(value, map);
	  }
	});

	var web_timers = {};

	var web_setInterval = {};

	var $$4 = _export;
	var global$4 = global$Z;
	var schedulersFix$1 = schedulersFix$3;
	var setInterval$1 = schedulersFix$1(global$4.setInterval, true);

	// Bun / IE9- setInterval additional parameters fix
	// https://html.spec.whatwg.org/multipage/timers-and-user-prompts.html#dom-setinterval
	$$4({
	  global: true,
	  bind: true,
	  forced: global$4.setInterval !== setInterval$1
	}, {
	  setInterval: setInterval$1
	});

	var web_setTimeout = {};

	var $$3 = _export;
	var global$3 = global$Z;
	var schedulersFix = schedulersFix$3;
	var setTimeout$1 = schedulersFix(global$3.setTimeout, true);

	// Bun / IE9- setTimeout additional parameters fix
	// https://html.spec.whatwg.org/multipage/timers-and-user-prompts.html#dom-settimeout
	$$3({
	  global: true,
	  bind: true,
	  forced: global$3.setTimeout !== setTimeout$1
	}, {
	  setTimeout: setTimeout$1
	});

	var web_url = {};

	var web_url_constructor = {};

	var fails = fails$1m;
	var wellKnownSymbol$1 = wellKnownSymbol$z;
	var DESCRIPTORS$3 = descriptors;
	var IS_PURE = isPure;
	var ITERATOR$1 = wellKnownSymbol$1('iterator');
	var urlConstructorDetection = !fails(function () {
	  // eslint-disable-next-line unicorn/relative-url-style -- required for testing
	  var url = new URL('b?a=1&b=2&c=3', 'http://a');
	  var searchParams = url.searchParams;
	  var result = '';
	  url.pathname = 'c%20d';
	  searchParams.forEach(function (value, key) {
	    searchParams['delete']('b');
	    result += key + value;
	  });
	  return IS_PURE && !url.toJSON || !searchParams.size && (IS_PURE || !DESCRIPTORS$3) || !searchParams.sort || url.href !== 'http://a/c%20d?a=1&c=3' || searchParams.get('c') !== '3' || String(new URLSearchParams('?a=1')) !== 'a=1' || !searchParams[ITERATOR$1]
	  // throws in Edge
	  || new URL('https://a@b').username !== 'a' || new URLSearchParams(new URLSearchParams('a=b')).get('a') !== 'b'
	  // not punycoded in Edge
	  || new URL('http://тест').host !== 'xn--e1aybc'
	  // not escaped in Chrome 62-
	  || new URL('http://a#б').hash !== '#%D0%B1'
	  // fails in Chrome 66-
	  || result !== 'a1c3'
	  // throws in Safari
	  || new URL('http://x', undefined).host !== 'x';
	});
	var urlConstructorDetection$1 = /*@__PURE__*/getDefaultExportFromCjs(urlConstructorDetection);

	// based on https://github.com/bestiejs/punycode.js/blob/master/punycode.js
	var uncurryThis$3 = functionUncurryThis;
	var maxInt = 2147483647; // aka. 0x7FFFFFFF or 2^31-1
	var base = 36;
	var tMin = 1;
	var tMax = 26;
	var skew = 38;
	var damp = 700;
	var initialBias = 72;
	var initialN = 128; // 0x80
	var delimiter = '-'; // '\x2D'
	var regexNonASCII = /[^\0-\u007E]/; // non-ASCII chars
	var regexSeparators = /[.\u3002\uFF0E\uFF61]/g; // RFC 3490 separators
	var OVERFLOW_ERROR = 'Overflow: input needs wider integers to process';
	var baseMinusTMin = base - tMin;
	var $RangeError = RangeError;
	var exec$1 = uncurryThis$3(regexSeparators.exec);
	var floor$4 = Math.floor;
	var fromCharCode = String.fromCharCode;
	var charCodeAt = uncurryThis$3(''.charCodeAt);
	var join$2 = uncurryThis$3([].join);
	var push$2 = uncurryThis$3([].push);
	var replace$2 = uncurryThis$3(''.replace);
	var split$6 = uncurryThis$3(''.split);
	var toLowerCase$1 = uncurryThis$3(''.toLowerCase);

	/**
	 * Creates an array containing the numeric code points of each Unicode
	 * character in the string. While JavaScript uses UCS-2 internally,
	 * this function will convert a pair of surrogate halves (each of which
	 * UCS-2 exposes as separate characters) into a single code point,
	 * matching UTF-16.
	 */
	var ucs2decode = function ucs2decode(string) {
	  var output = [];
	  var counter = 0;
	  var length = string.length;
	  while (counter < length) {
	    var value = charCodeAt(string, counter++);
	    if (value >= 0xD800 && value <= 0xDBFF && counter < length) {
	      // It's a high surrogate, and there is a next character.
	      var extra = charCodeAt(string, counter++);
	      if ((extra & 0xFC00) == 0xDC00) {
	        // Low surrogate.
	        push$2(output, ((value & 0x3FF) << 10) + (extra & 0x3FF) + 0x10000);
	      } else {
	        // It's an unmatched surrogate; only append this code unit, in case the
	        // next code unit is the high surrogate of a surrogate pair.
	        push$2(output, value);
	        counter--;
	      }
	    } else {
	      push$2(output, value);
	    }
	  }
	  return output;
	};

	/**
	 * Converts a digit/integer into a basic code point.
	 */
	var digitToBasic = function digitToBasic(digit) {
	  //  0..25 map to ASCII a..z or A..Z
	  // 26..35 map to ASCII 0..9
	  return digit + 22 + 75 * (digit < 26);
	};

	/**
	 * Bias adaptation function as per section 3.4 of RFC 3492.
	 * https://tools.ietf.org/html/rfc3492#section-3.4
	 */
	var adapt = function adapt(delta, numPoints, firstTime) {
	  var k = 0;
	  delta = firstTime ? floor$4(delta / damp) : delta >> 1;
	  delta += floor$4(delta / numPoints);
	  while (delta > baseMinusTMin * tMax >> 1) {
	    delta = floor$4(delta / baseMinusTMin);
	    k += base;
	  }
	  return floor$4(k + (baseMinusTMin + 1) * delta / (delta + skew));
	};

	/**
	 * Converts a string of Unicode symbols (e.g. a domain name label) to a
	 * Punycode string of ASCII-only symbols.
	 */
	var encode = function encode(input) {
	  var output = [];

	  // Convert the input in UCS-2 to an array of Unicode code points.
	  input = ucs2decode(input);

	  // Cache the length.
	  var inputLength = input.length;

	  // Initialize the state.
	  var n = initialN;
	  var delta = 0;
	  var bias = initialBias;
	  var i, currentValue;

	  // Handle the basic code points.
	  for (i = 0; i < input.length; i++) {
	    currentValue = input[i];
	    if (currentValue < 0x80) {
	      push$2(output, fromCharCode(currentValue));
	    }
	  }
	  var basicLength = output.length; // number of basic code points.
	  var handledCPCount = basicLength; // number of code points that have been handled;

	  // Finish the basic string with a delimiter unless it's empty.
	  if (basicLength) {
	    push$2(output, delimiter);
	  }

	  // Main encoding loop:
	  while (handledCPCount < inputLength) {
	    // All non-basic code points < n have been handled already. Find the next larger one:
	    var m = maxInt;
	    for (i = 0; i < input.length; i++) {
	      currentValue = input[i];
	      if (currentValue >= n && currentValue < m) {
	        m = currentValue;
	      }
	    }

	    // Increase `delta` enough to advance the decoder's <n,i> state to <m,0>, but guard against overflow.
	    var handledCPCountPlusOne = handledCPCount + 1;
	    if (m - n > floor$4((maxInt - delta) / handledCPCountPlusOne)) {
	      throw $RangeError(OVERFLOW_ERROR);
	    }
	    delta += (m - n) * handledCPCountPlusOne;
	    n = m;
	    for (i = 0; i < input.length; i++) {
	      currentValue = input[i];
	      if (currentValue < n && ++delta > maxInt) {
	        throw $RangeError(OVERFLOW_ERROR);
	      }
	      if (currentValue == n) {
	        // Represent delta as a generalized variable-length integer.
	        var q = delta;
	        var k = base;
	        while (true) {
	          var t = k <= bias ? tMin : k >= bias + tMax ? tMax : k - bias;
	          if (q < t) break;
	          var qMinusT = q - t;
	          var baseMinusT = base - t;
	          push$2(output, fromCharCode(digitToBasic(t + qMinusT % baseMinusT)));
	          q = floor$4(qMinusT / baseMinusT);
	          k += base;
	        }
	        push$2(output, fromCharCode(digitToBasic(q)));
	        bias = adapt(delta, handledCPCountPlusOne, handledCPCount == basicLength);
	        delta = 0;
	        handledCPCount++;
	      }
	    }
	    delta++;
	    n++;
	  }
	  return join$2(output, '');
	};
	var stringPunycodeToAscii = function stringPunycodeToAscii(input) {
	  var encoded = [];
	  var labels = split$6(replace$2(toLowerCase$1(input), regexSeparators, "."), '.');
	  var i, label;
	  for (i = 0; i < labels.length; i++) {
	    label = labels[i];
	    push$2(encoded, exec$1(regexNonASCII, label) ? 'xn--' + encode(label) : label);
	  }
	  return join$2(encoded, '.');
	};
	var stringPunycodeToAscii$1 = /*@__PURE__*/getDefaultExportFromCjs(stringPunycodeToAscii);

	'use strict';
	// TODO: in core-js@4, move /modules/ dependencies to public entries for better optimization by tools like `preset-env`

	var $$2 = _export;
	var global$2 = global$Z;
	var call$1 = functionCall;
	var uncurryThis$2 = functionUncurryThis;
	var DESCRIPTORS$2 = descriptors;
	var USE_NATIVE_URL$1 = urlConstructorDetection;
	var defineBuiltIn$1 = defineBuiltIn$m;
	var defineBuiltInAccessor$2 = defineBuiltInAccessor$h;
	var defineBuiltIns = defineBuiltIns$5;
	var setToStringTag$1 = setToStringTag$d;
	var createIteratorConstructor = iteratorCreateConstructor;
	var InternalStateModule$1 = internalState;
	var anInstance$1 = anInstance$a;
	var isCallable = isCallable$z;
	var hasOwn$1 = hasOwnProperty_1;
	var bind$1 = functionBindContext;
	var classof = classof$m;
	var anObject = anObject$D;
	var isObject = isObject$z;
	var $toString$1 = toString$x;
	var create = objectCreate;
	var createPropertyDescriptor = createPropertyDescriptor$c;
	var getIterator = getIterator$4;
	var getIteratorMethod = getIteratorMethod$5;
	var validateArgumentsLength$1 = validateArgumentsLength$8;
	var wellKnownSymbol = wellKnownSymbol$z;
	var arraySort = arraySort$1;
	var ITERATOR = wellKnownSymbol('iterator');
	var URL_SEARCH_PARAMS = 'URLSearchParams';
	var URL_SEARCH_PARAMS_ITERATOR = URL_SEARCH_PARAMS + 'Iterator';
	var setInternalState$1 = InternalStateModule$1.set;
	var getInternalParamsState = InternalStateModule$1.getterFor(URL_SEARCH_PARAMS);
	var getInternalIteratorState = InternalStateModule$1.getterFor(URL_SEARCH_PARAMS_ITERATOR);
	// eslint-disable-next-line es/no-object-getownpropertydescriptor -- safe
	var getOwnPropertyDescriptor = Object.getOwnPropertyDescriptor;

	// Avoid NodeJS experimental warning
	var safeGetBuiltIn = function safeGetBuiltIn(name) {
	  if (!DESCRIPTORS$2) return global$2[name];
	  var descriptor = getOwnPropertyDescriptor(global$2, name);
	  return descriptor && descriptor.value;
	};
	var nativeFetch = safeGetBuiltIn('fetch');
	var NativeRequest = safeGetBuiltIn('Request');
	var Headers = safeGetBuiltIn('Headers');
	var RequestPrototype = NativeRequest && NativeRequest.prototype;
	var HeadersPrototype = Headers && Headers.prototype;
	var RegExp$1 = global$2.RegExp;
	var TypeError$2 = global$2.TypeError;
	var decodeURIComponent$1 = global$2.decodeURIComponent;
	var encodeURIComponent$1 = global$2.encodeURIComponent;
	var charAt$1 = uncurryThis$2(''.charAt);
	var join$1 = uncurryThis$2([].join);
	var push$1 = uncurryThis$2([].push);
	var replace$1 = uncurryThis$2(''.replace);
	var shift$1 = uncurryThis$2([].shift);
	var splice = uncurryThis$2([].splice);
	var split$5 = uncurryThis$2(''.split);
	var stringSlice$1 = uncurryThis$2(''.slice);
	var plus = /\+/g;
	var sequences = Array(4);
	var percentSequence = function percentSequence(bytes) {
	  return sequences[bytes - 1] || (sequences[bytes - 1] = RegExp$1('((?:%[\\da-f]{2}){' + bytes + '})', 'gi'));
	};
	var percentDecode = function percentDecode(sequence) {
	  try {
	    return decodeURIComponent$1(sequence);
	  } catch (error) {
	    return sequence;
	  }
	};
	var deserialize$1 = function deserialize(it) {
	  var result = replace$1(it, plus, ' ');
	  var bytes = 4;
	  try {
	    return decodeURIComponent$1(result);
	  } catch (error) {
	    while (bytes) {
	      result = replace$1(result, percentSequence(bytes--), percentDecode);
	    }
	    return result;
	  }
	};
	var find = /[!'()~]|%20/g;
	var replacements = {
	  '!': '%21',
	  "'": '%27',
	  '(': '%28',
	  ')': '%29',
	  '~': '%7E',
	  '%20': '+'
	};
	var replacer = function replacer(match) {
	  return replacements[match];
	};
	var _serialize = function serialize(it) {
	  return replace$1(encodeURIComponent$1(it), find, replacer);
	};
	var URLSearchParamsIterator = createIteratorConstructor(function Iterator(params, kind) {
	  setInternalState$1(this, {
	    type: URL_SEARCH_PARAMS_ITERATOR,
	    iterator: getIterator(getInternalParamsState(params).entries),
	    kind: kind
	  });
	}, 'Iterator', function next() {
	  var state = getInternalIteratorState(this);
	  var kind = state.kind;
	  var step = state.iterator.next();
	  var entry = step.value;
	  if (!step.done) {
	    step.value = kind === 'keys' ? entry.key : kind === 'values' ? entry.value : [entry.key, entry.value];
	  }
	  return step;
	}, true);
	var URLSearchParamsState = function URLSearchParamsState(init) {
	  this.entries = [];
	  this.url = null;
	  if (init !== undefined) {
	    if (isObject(init)) this.parseObject(init);else this.parseQuery(typeof init == 'string' ? charAt$1(init, 0) === '?' ? stringSlice$1(init, 1) : init : $toString$1(init));
	  }
	};
	URLSearchParamsState.prototype = {
	  type: URL_SEARCH_PARAMS,
	  bindURL: function bindURL(url) {
	    this.url = url;
	    this.update();
	  },
	  parseObject: function parseObject(object) {
	    var iteratorMethod = getIteratorMethod(object);
	    var iterator, next, step, entryIterator, entryNext, first, second;
	    if (iteratorMethod) {
	      iterator = getIterator(object, iteratorMethod);
	      next = iterator.next;
	      while (!(step = call$1(next, iterator)).done) {
	        entryIterator = getIterator(anObject(step.value));
	        entryNext = entryIterator.next;
	        if ((first = call$1(entryNext, entryIterator)).done || (second = call$1(entryNext, entryIterator)).done || !call$1(entryNext, entryIterator).done) throw TypeError$2('Expected sequence with length 2');
	        push$1(this.entries, {
	          key: $toString$1(first.value),
	          value: $toString$1(second.value)
	        });
	      }
	    } else for (var key in object) if (hasOwn$1(object, key)) {
	      push$1(this.entries, {
	        key: key,
	        value: $toString$1(object[key])
	      });
	    }
	  },
	  parseQuery: function parseQuery(query) {
	    if (query) {
	      var attributes = split$5(query, '&');
	      var index = 0;
	      var attribute, entry;
	      while (index < attributes.length) {
	        attribute = attributes[index++];
	        if (attribute.length) {
	          entry = split$5(attribute, '=');
	          push$1(this.entries, {
	            key: deserialize$1(shift$1(entry)),
	            value: deserialize$1(join$1(entry, '='))
	          });
	        }
	      }
	    }
	  },
	  serialize: function serialize() {
	    var entries = this.entries;
	    var result = [];
	    var index = 0;
	    var entry;
	    while (index < entries.length) {
	      entry = entries[index++];
	      push$1(result, _serialize(entry.key) + '=' + _serialize(entry.value));
	    }
	    return join$1(result, '&');
	  },
	  update: function update() {
	    this.entries.length = 0;
	    this.parseQuery(this.url.query);
	  },
	  updateURL: function updateURL() {
	    if (this.url) this.url.update();
	  }
	};

	// `URLSearchParams` constructor
	// https://url.spec.whatwg.org/#interface-urlsearchparams
	var URLSearchParamsConstructor = function URLSearchParams( /* init */
	) {
	  anInstance$1(this, URLSearchParamsPrototype$1);
	  var init = arguments.length > 0 ? arguments[0] : undefined;
	  var state = setInternalState$1(this, new URLSearchParamsState(init));
	  if (!DESCRIPTORS$2) this.length = state.entries.length;
	};
	var URLSearchParamsPrototype$1 = URLSearchParamsConstructor.prototype;
	defineBuiltIns(URLSearchParamsPrototype$1, {
	  // `URLSearchParams.prototype.append` method
	  // https://url.spec.whatwg.org/#dom-urlsearchparams-append
	  append: function append(name, value) {
	    validateArgumentsLength$1(arguments.length, 2);
	    var state = getInternalParamsState(this);
	    push$1(state.entries, {
	      key: $toString$1(name),
	      value: $toString$1(value)
	    });
	    if (!DESCRIPTORS$2) this.length++;
	    state.updateURL();
	  },
	  // `URLSearchParams.prototype.delete` method
	  // https://url.spec.whatwg.org/#dom-urlsearchparams-delete
	  'delete': function _delete(name) {
	    validateArgumentsLength$1(arguments.length, 1);
	    var state = getInternalParamsState(this);
	    var entries = state.entries;
	    var key = $toString$1(name);
	    var index = 0;
	    while (index < entries.length) {
	      if (entries[index].key === key) splice(entries, index, 1);else index++;
	    }
	    if (!DESCRIPTORS$2) this.length = entries.length;
	    state.updateURL();
	  },
	  // `URLSearchParams.prototype.get` method
	  // https://url.spec.whatwg.org/#dom-urlsearchparams-get
	  get: function get(name) {
	    validateArgumentsLength$1(arguments.length, 1);
	    var entries = getInternalParamsState(this).entries;
	    var key = $toString$1(name);
	    var index = 0;
	    for (; index < entries.length; index++) {
	      if (entries[index].key === key) return entries[index].value;
	    }
	    return null;
	  },
	  // `URLSearchParams.prototype.getAll` method
	  // https://url.spec.whatwg.org/#dom-urlsearchparams-getall
	  getAll: function getAll(name) {
	    validateArgumentsLength$1(arguments.length, 1);
	    var entries = getInternalParamsState(this).entries;
	    var key = $toString$1(name);
	    var result = [];
	    var index = 0;
	    for (; index < entries.length; index++) {
	      if (entries[index].key === key) push$1(result, entries[index].value);
	    }
	    return result;
	  },
	  // `URLSearchParams.prototype.has` method
	  // https://url.spec.whatwg.org/#dom-urlsearchparams-has
	  has: function has(name) {
	    validateArgumentsLength$1(arguments.length, 1);
	    var entries = getInternalParamsState(this).entries;
	    var key = $toString$1(name);
	    var index = 0;
	    while (index < entries.length) {
	      if (entries[index++].key === key) return true;
	    }
	    return false;
	  },
	  // `URLSearchParams.prototype.set` method
	  // https://url.spec.whatwg.org/#dom-urlsearchparams-set
	  set: function set(name, value) {
	    validateArgumentsLength$1(arguments.length, 1);
	    var state = getInternalParamsState(this);
	    var entries = state.entries;
	    var found = false;
	    var key = $toString$1(name);
	    var val = $toString$1(value);
	    var index = 0;
	    var entry;
	    for (; index < entries.length; index++) {
	      entry = entries[index];
	      if (entry.key === key) {
	        if (found) splice(entries, index--, 1);else {
	          found = true;
	          entry.value = val;
	        }
	      }
	    }
	    if (!found) push$1(entries, {
	      key: key,
	      value: val
	    });
	    if (!DESCRIPTORS$2) this.length = entries.length;
	    state.updateURL();
	  },
	  // `URLSearchParams.prototype.sort` method
	  // https://url.spec.whatwg.org/#dom-urlsearchparams-sort
	  sort: function sort() {
	    var state = getInternalParamsState(this);
	    arraySort(state.entries, function (a, b) {
	      return a.key > b.key ? 1 : -1;
	    });
	    state.updateURL();
	  },
	  // `URLSearchParams.prototype.forEach` method
	  forEach: function forEach(callback /* , thisArg */) {
	    var entries = getInternalParamsState(this).entries;
	    var boundFunction = bind$1(callback, arguments.length > 1 ? arguments[1] : undefined);
	    var index = 0;
	    var entry;
	    while (index < entries.length) {
	      entry = entries[index++];
	      boundFunction(entry.value, entry.key, this);
	    }
	  },
	  // `URLSearchParams.prototype.keys` method
	  keys: function keys() {
	    return new URLSearchParamsIterator(this, 'keys');
	  },
	  // `URLSearchParams.prototype.values` method
	  values: function values() {
	    return new URLSearchParamsIterator(this, 'values');
	  },
	  // `URLSearchParams.prototype.entries` method
	  entries: function entries() {
	    return new URLSearchParamsIterator(this, 'entries');
	  }
	}, {
	  enumerable: true
	});

	// `URLSearchParams.prototype[@@iterator]` method
	defineBuiltIn$1(URLSearchParamsPrototype$1, ITERATOR, URLSearchParamsPrototype$1.entries, {
	  name: 'entries'
	});

	// `URLSearchParams.prototype.toString` method
	// https://url.spec.whatwg.org/#urlsearchparams-stringification-behavior
	defineBuiltIn$1(URLSearchParamsPrototype$1, 'toString', function toString() {
	  return getInternalParamsState(this).serialize();
	}, {
	  enumerable: true
	});

	// `URLSearchParams.prototype.size` getter
	// https://github.com/whatwg/url/pull/734
	if (DESCRIPTORS$2) defineBuiltInAccessor$2(URLSearchParamsPrototype$1, 'size', {
	  get: function size() {
	    return getInternalParamsState(this).entries.length;
	  },
	  configurable: true,
	  enumerable: true
	});
	setToStringTag$1(URLSearchParamsConstructor, URL_SEARCH_PARAMS);
	$$2({
	  global: true,
	  constructor: true,
	  forced: !USE_NATIVE_URL$1
	}, {
	  URLSearchParams: URLSearchParamsConstructor
	});

	// Wrap `fetch` and `Request` for correct work with polyfilled `URLSearchParams`
	if (!USE_NATIVE_URL$1 && isCallable(Headers)) {
	  var headersHas = uncurryThis$2(HeadersPrototype.has);
	  var headersSet = uncurryThis$2(HeadersPrototype.set);
	  var wrapRequestOptions = function wrapRequestOptions(init) {
	    if (isObject(init)) {
	      var body = init.body;
	      var headers;
	      if (classof(body) === URL_SEARCH_PARAMS) {
	        headers = init.headers ? new Headers(init.headers) : new Headers();
	        if (!headersHas(headers, 'content-type')) {
	          headersSet(headers, 'content-type', 'application/x-www-form-urlencoded;charset=UTF-8');
	        }
	        return create(init, {
	          body: createPropertyDescriptor(0, $toString$1(body)),
	          headers: createPropertyDescriptor(0, headers)
	        });
	      }
	    }
	    return init;
	  };
	  if (isCallable(nativeFetch)) {
	    $$2({
	      global: true,
	      enumerable: true,
	      dontCallGetSet: true,
	      forced: true
	    }, {
	      fetch: function fetch(input /* , init */) {
	        return nativeFetch(input, arguments.length > 1 ? wrapRequestOptions(arguments[1]) : {});
	      }
	    });
	  }
	  if (isCallable(NativeRequest)) {
	    var RequestConstructor = function Request(input /* , init */) {
	      anInstance$1(this, RequestPrototype);
	      return new NativeRequest(input, arguments.length > 1 ? wrapRequestOptions(arguments[1]) : {});
	    };
	    RequestPrototype.constructor = RequestConstructor;
	    RequestConstructor.prototype = RequestPrototype;
	    $$2({
	      global: true,
	      constructor: true,
	      dontCallGetSet: true,
	      forced: true
	    }, {
	      Request: RequestConstructor
	    });
	  }
	}
	var web_urlSearchParams_constructor = {
	  URLSearchParams: URLSearchParamsConstructor,
	  getState: getInternalParamsState
	};
	var web_urlSearchParams_constructor$1 = /*@__PURE__*/getDefaultExportFromCjs(web_urlSearchParams_constructor);

	'use strict';
	// TODO: in core-js@4, move /modules/ dependencies to public entries for better optimization by tools like `preset-env`

	var $$1 = _export;
	var DESCRIPTORS$1 = descriptors;
	var USE_NATIVE_URL = urlConstructorDetection;
	var global$1 = global$Z;
	var bind = functionBindContext;
	var uncurryThis$1 = functionUncurryThis;
	var defineBuiltIn = defineBuiltIn$m;
	var defineBuiltInAccessor$1 = defineBuiltInAccessor$h;
	var anInstance = anInstance$a;
	var hasOwn = hasOwnProperty_1;
	var assign = objectAssign;
	var arrayFrom = arrayFrom$1;
	var arraySlice = arraySliceSimple;
	var codeAt = stringMultibyte.codeAt;
	var toASCII = stringPunycodeToAscii;
	var $toString = toString$x;
	var setToStringTag = setToStringTag$d;
	var validateArgumentsLength = validateArgumentsLength$8;
	var URLSearchParamsModule = web_urlSearchParams_constructor;
	var InternalStateModule = internalState;
	var setInternalState = InternalStateModule.set;
	var getInternalURLState = InternalStateModule.getterFor('URL');
	var URLSearchParams$1 = URLSearchParamsModule.URLSearchParams;
	var getInternalSearchParamsState = URLSearchParamsModule.getState;
	var NativeURL = global$1.URL;
	var TypeError$1 = global$1.TypeError;
	var parseInt$1 = global$1.parseInt;
	var floor$3 = Math.floor;
	var pow$4 = Math.pow;
	var charAt = uncurryThis$1(''.charAt);
	var exec = uncurryThis$1(/./.exec);
	var join = uncurryThis$1([].join);
	var numberToString = uncurryThis$1(1.0.toString);
	var pop = uncurryThis$1([].pop);
	var push = uncurryThis$1([].push);
	var replace = uncurryThis$1(''.replace);
	var shift = uncurryThis$1([].shift);
	var split$4 = uncurryThis$1(''.split);
	var stringSlice = uncurryThis$1(''.slice);
	var toLowerCase = uncurryThis$1(''.toLowerCase);
	var unshift = uncurryThis$1([].unshift);
	var INVALID_AUTHORITY = 'Invalid authority';
	var INVALID_SCHEME = 'Invalid scheme';
	var INVALID_HOST = 'Invalid host';
	var INVALID_PORT = 'Invalid port';
	var ALPHA = /[a-z]/i;
	// eslint-disable-next-line regexp/no-obscure-range -- safe
	var ALPHANUMERIC = /[\d+-.a-z]/i;
	var DIGIT = /\d/;
	var HEX_START = /^0x/i;
	var OCT = /^[0-7]+$/;
	var DEC = /^\d+$/;
	var HEX = /^[\da-f]+$/i;
	/* eslint-disable regexp/no-control-character -- safe */
	var FORBIDDEN_HOST_CODE_POINT = /[\0\t\n\r #%/:<>?@[\\\]^|]/;
	var FORBIDDEN_HOST_CODE_POINT_EXCLUDING_PERCENT = /[\0\t\n\r #/:<>?@[\\\]^|]/;
	var LEADING_C0_CONTROL_OR_SPACE = /^[\u0000-\u0020]+/;
	var TRAILING_C0_CONTROL_OR_SPACE = /(^|[^\u0000-\u0020])[\u0000-\u0020]+$/;
	var TAB_AND_NEW_LINE = /[\t\n\r]/g;
	/* eslint-enable regexp/no-control-character -- safe */
	var EOF;

	// https://url.spec.whatwg.org/#ipv4-number-parser
	var parseIPv4 = function parseIPv4(input) {
	  var parts = split$4(input, '.');
	  var partsLength, numbers, index, part, radix, number, ipv4;
	  if (parts.length && parts[parts.length - 1] == '') {
	    parts.length--;
	  }
	  partsLength = parts.length;
	  if (partsLength > 4) return input;
	  numbers = [];
	  for (index = 0; index < partsLength; index++) {
	    part = parts[index];
	    if (part == '') return input;
	    radix = 10;
	    if (part.length > 1 && charAt(part, 0) == '0') {
	      radix = exec(HEX_START, part) ? 16 : 8;
	      part = stringSlice(part, radix == 8 ? 1 : 2);
	    }
	    if (part === '') {
	      number = 0;
	    } else {
	      if (!exec(radix == 10 ? DEC : radix == 8 ? OCT : HEX, part)) return input;
	      number = parseInt$1(part, radix);
	    }
	    push(numbers, number);
	  }
	  for (index = 0; index < partsLength; index++) {
	    number = numbers[index];
	    if (index == partsLength - 1) {
	      if (number >= pow$4(256, 5 - partsLength)) return null;
	    } else if (number > 255) return null;
	  }
	  ipv4 = pop(numbers);
	  for (index = 0; index < numbers.length; index++) {
	    ipv4 += numbers[index] * pow$4(256, 3 - index);
	  }
	  return ipv4;
	};

	// https://url.spec.whatwg.org/#concept-ipv6-parser
	// eslint-disable-next-line max-statements -- TODO
	var parseIPv6 = function parseIPv6(input) {
	  var address = [0, 0, 0, 0, 0, 0, 0, 0];
	  var pieceIndex = 0;
	  var compress = null;
	  var pointer = 0;
	  var value, length, numbersSeen, ipv4Piece, number, swaps, swap;
	  var chr = function chr() {
	    return charAt(input, pointer);
	  };
	  if (chr() == ':') {
	    if (charAt(input, 1) != ':') return;
	    pointer += 2;
	    pieceIndex++;
	    compress = pieceIndex;
	  }
	  while (chr()) {
	    if (pieceIndex == 8) return;
	    if (chr() == ':') {
	      if (compress !== null) return;
	      pointer++;
	      pieceIndex++;
	      compress = pieceIndex;
	      continue;
	    }
	    value = length = 0;
	    while (length < 4 && exec(HEX, chr())) {
	      value = value * 16 + parseInt$1(chr(), 16);
	      pointer++;
	      length++;
	    }
	    if (chr() == '.') {
	      if (length == 0) return;
	      pointer -= length;
	      if (pieceIndex > 6) return;
	      numbersSeen = 0;
	      while (chr()) {
	        ipv4Piece = null;
	        if (numbersSeen > 0) {
	          if (chr() == '.' && numbersSeen < 4) pointer++;else return;
	        }
	        if (!exec(DIGIT, chr())) return;
	        while (exec(DIGIT, chr())) {
	          number = parseInt$1(chr(), 10);
	          if (ipv4Piece === null) ipv4Piece = number;else if (ipv4Piece == 0) return;else ipv4Piece = ipv4Piece * 10 + number;
	          if (ipv4Piece > 255) return;
	          pointer++;
	        }
	        address[pieceIndex] = address[pieceIndex] * 256 + ipv4Piece;
	        numbersSeen++;
	        if (numbersSeen == 2 || numbersSeen == 4) pieceIndex++;
	      }
	      if (numbersSeen != 4) return;
	      break;
	    } else if (chr() == ':') {
	      pointer++;
	      if (!chr()) return;
	    } else if (chr()) return;
	    address[pieceIndex++] = value;
	  }
	  if (compress !== null) {
	    swaps = pieceIndex - compress;
	    pieceIndex = 7;
	    while (pieceIndex != 0 && swaps > 0) {
	      swap = address[pieceIndex];
	      address[pieceIndex--] = address[compress + swaps - 1];
	      address[compress + --swaps] = swap;
	    }
	  } else if (pieceIndex != 8) return;
	  return address;
	};
	var findLongestZeroSequence = function findLongestZeroSequence(ipv6) {
	  var maxIndex = null;
	  var maxLength = 1;
	  var currStart = null;
	  var currLength = 0;
	  var index = 0;
	  for (; index < 8; index++) {
	    if (ipv6[index] !== 0) {
	      if (currLength > maxLength) {
	        maxIndex = currStart;
	        maxLength = currLength;
	      }
	      currStart = null;
	      currLength = 0;
	    } else {
	      if (currStart === null) currStart = index;
	      ++currLength;
	    }
	  }
	  if (currLength > maxLength) {
	    maxIndex = currStart;
	    maxLength = currLength;
	  }
	  return maxIndex;
	};

	// https://url.spec.whatwg.org/#host-serializing
	var serializeHost = function serializeHost(host) {
	  var result, index, compress, ignore0;
	  // ipv4
	  if (typeof host == 'number') {
	    result = [];
	    for (index = 0; index < 4; index++) {
	      unshift(result, host % 256);
	      host = floor$3(host / 256);
	    }
	    return join(result, '.');
	    // ipv6
	  } else if (_typeof(host) == 'object') {
	    result = '';
	    compress = findLongestZeroSequence(host);
	    for (index = 0; index < 8; index++) {
	      if (ignore0 && host[index] === 0) continue;
	      if (ignore0) ignore0 = false;
	      if (compress === index) {
	        result += index ? ':' : '::';
	        ignore0 = true;
	      } else {
	        result += numberToString(host[index], 16);
	        if (index < 7) result += ':';
	      }
	    }
	    return '[' + result + ']';
	  }
	  return host;
	};
	var C0ControlPercentEncodeSet = {};
	var fragmentPercentEncodeSet = assign({}, C0ControlPercentEncodeSet, {
	  ' ': 1,
	  '"': 1,
	  '<': 1,
	  '>': 1,
	  '`': 1
	});
	var pathPercentEncodeSet = assign({}, fragmentPercentEncodeSet, {
	  '#': 1,
	  '?': 1,
	  '{': 1,
	  '}': 1
	});
	var userinfoPercentEncodeSet = assign({}, pathPercentEncodeSet, {
	  '/': 1,
	  ':': 1,
	  ';': 1,
	  '=': 1,
	  '@': 1,
	  '[': 1,
	  '\\': 1,
	  ']': 1,
	  '^': 1,
	  '|': 1
	});
	var percentEncode = function percentEncode(chr, set) {
	  var code = codeAt(chr, 0);
	  return code > 0x20 && code < 0x7F && !hasOwn(set, chr) ? chr : encodeURIComponent(chr);
	};

	// https://url.spec.whatwg.org/#special-scheme
	var specialSchemes = {
	  ftp: 21,
	  file: null,
	  http: 80,
	  https: 443,
	  ws: 80,
	  wss: 443
	};

	// https://url.spec.whatwg.org/#windows-drive-letter
	var isWindowsDriveLetter = function isWindowsDriveLetter(string, normalized) {
	  var second;
	  return string.length == 2 && exec(ALPHA, charAt(string, 0)) && ((second = charAt(string, 1)) == ':' || !normalized && second == '|');
	};

	// https://url.spec.whatwg.org/#start-with-a-windows-drive-letter
	var startsWithWindowsDriveLetter = function startsWithWindowsDriveLetter(string) {
	  var third;
	  return string.length > 1 && isWindowsDriveLetter(stringSlice(string, 0, 2)) && (string.length == 2 || (third = charAt(string, 2)) === '/' || third === '\\' || third === '?' || third === '#');
	};

	// https://url.spec.whatwg.org/#single-dot-path-segment
	var isSingleDot = function isSingleDot(segment) {
	  return segment === '.' || toLowerCase(segment) === '%2e';
	};

	// https://url.spec.whatwg.org/#double-dot-path-segment
	var isDoubleDot = function isDoubleDot(segment) {
	  segment = toLowerCase(segment);
	  return segment === '..' || segment === '%2e.' || segment === '.%2e' || segment === '%2e%2e';
	};

	// States:
	var SCHEME_START = {};
	var SCHEME = {};
	var NO_SCHEME = {};
	var SPECIAL_RELATIVE_OR_AUTHORITY = {};
	var PATH_OR_AUTHORITY = {};
	var RELATIVE = {};
	var RELATIVE_SLASH = {};
	var SPECIAL_AUTHORITY_SLASHES = {};
	var SPECIAL_AUTHORITY_IGNORE_SLASHES = {};
	var AUTHORITY = {};
	var HOST = {};
	var HOSTNAME = {};
	var PORT = {};
	var FILE = {};
	var FILE_SLASH = {};
	var FILE_HOST = {};
	var PATH_START = {};
	var PATH = {};
	var CANNOT_BE_A_BASE_URL_PATH = {};
	var QUERY = {};
	var FRAGMENT = {};
	var URLState = function URLState(url, isBase, base) {
	  var urlString = $toString(url);
	  var baseState, failure, searchParams;
	  if (isBase) {
	    failure = this.parse(urlString);
	    if (failure) throw TypeError$1(failure);
	    this.searchParams = null;
	  } else {
	    if (base !== undefined) baseState = new URLState(base, true);
	    failure = this.parse(urlString, null, baseState);
	    if (failure) throw TypeError$1(failure);
	    searchParams = getInternalSearchParamsState(new URLSearchParams$1());
	    searchParams.bindURL(this);
	    this.searchParams = searchParams;
	  }
	};
	URLState.prototype = {
	  type: 'URL',
	  // https://url.spec.whatwg.org/#url-parsing
	  // eslint-disable-next-line max-statements -- TODO
	  parse: function parse(input, stateOverride, base) {
	    var url = this;
	    var state = stateOverride || SCHEME_START;
	    var pointer = 0;
	    var buffer = '';
	    var seenAt = false;
	    var seenBracket = false;
	    var seenPasswordToken = false;
	    var codePoints, chr, bufferCodePoints, failure;
	    input = $toString(input);
	    if (!stateOverride) {
	      url.scheme = '';
	      url.username = '';
	      url.password = '';
	      url.host = null;
	      url.port = null;
	      url.path = [];
	      url.query = null;
	      url.fragment = null;
	      url.cannotBeABaseURL = false;
	      input = replace(input, LEADING_C0_CONTROL_OR_SPACE, '');
	      input = replace(input, TRAILING_C0_CONTROL_OR_SPACE, '$1');
	    }
	    input = replace(input, TAB_AND_NEW_LINE, '');
	    codePoints = arrayFrom(input);
	    while (pointer <= codePoints.length) {
	      chr = codePoints[pointer];
	      switch (state) {
	        case SCHEME_START:
	          if (chr && exec(ALPHA, chr)) {
	            buffer += toLowerCase(chr);
	            state = SCHEME;
	          } else if (!stateOverride) {
	            state = NO_SCHEME;
	            continue;
	          } else return INVALID_SCHEME;
	          break;
	        case SCHEME:
	          if (chr && (exec(ALPHANUMERIC, chr) || chr == '+' || chr == '-' || chr == '.')) {
	            buffer += toLowerCase(chr);
	          } else if (chr == ':') {
	            if (stateOverride && (url.isSpecial() != hasOwn(specialSchemes, buffer) || buffer == 'file' && (url.includesCredentials() || url.port !== null) || url.scheme == 'file' && !url.host)) return;
	            url.scheme = buffer;
	            if (stateOverride) {
	              if (url.isSpecial() && specialSchemes[url.scheme] == url.port) url.port = null;
	              return;
	            }
	            buffer = '';
	            if (url.scheme == 'file') {
	              state = FILE;
	            } else if (url.isSpecial() && base && base.scheme == url.scheme) {
	              state = SPECIAL_RELATIVE_OR_AUTHORITY;
	            } else if (url.isSpecial()) {
	              state = SPECIAL_AUTHORITY_SLASHES;
	            } else if (codePoints[pointer + 1] == '/') {
	              state = PATH_OR_AUTHORITY;
	              pointer++;
	            } else {
	              url.cannotBeABaseURL = true;
	              push(url.path, '');
	              state = CANNOT_BE_A_BASE_URL_PATH;
	            }
	          } else if (!stateOverride) {
	            buffer = '';
	            state = NO_SCHEME;
	            pointer = 0;
	            continue;
	          } else return INVALID_SCHEME;
	          break;
	        case NO_SCHEME:
	          if (!base || base.cannotBeABaseURL && chr != '#') return INVALID_SCHEME;
	          if (base.cannotBeABaseURL && chr == '#') {
	            url.scheme = base.scheme;
	            url.path = arraySlice(base.path);
	            url.query = base.query;
	            url.fragment = '';
	            url.cannotBeABaseURL = true;
	            state = FRAGMENT;
	            break;
	          }
	          state = base.scheme == 'file' ? FILE : RELATIVE;
	          continue;
	        case SPECIAL_RELATIVE_OR_AUTHORITY:
	          if (chr == '/' && codePoints[pointer + 1] == '/') {
	            state = SPECIAL_AUTHORITY_IGNORE_SLASHES;
	            pointer++;
	          } else {
	            state = RELATIVE;
	            continue;
	          }
	          break;
	        case PATH_OR_AUTHORITY:
	          if (chr == '/') {
	            state = AUTHORITY;
	            break;
	          } else {
	            state = PATH;
	            continue;
	          }
	        case RELATIVE:
	          url.scheme = base.scheme;
	          if (chr == EOF) {
	            url.username = base.username;
	            url.password = base.password;
	            url.host = base.host;
	            url.port = base.port;
	            url.path = arraySlice(base.path);
	            url.query = base.query;
	          } else if (chr == '/' || chr == '\\' && url.isSpecial()) {
	            state = RELATIVE_SLASH;
	          } else if (chr == '?') {
	            url.username = base.username;
	            url.password = base.password;
	            url.host = base.host;
	            url.port = base.port;
	            url.path = arraySlice(base.path);
	            url.query = '';
	            state = QUERY;
	          } else if (chr == '#') {
	            url.username = base.username;
	            url.password = base.password;
	            url.host = base.host;
	            url.port = base.port;
	            url.path = arraySlice(base.path);
	            url.query = base.query;
	            url.fragment = '';
	            state = FRAGMENT;
	          } else {
	            url.username = base.username;
	            url.password = base.password;
	            url.host = base.host;
	            url.port = base.port;
	            url.path = arraySlice(base.path);
	            url.path.length--;
	            state = PATH;
	            continue;
	          }
	          break;
	        case RELATIVE_SLASH:
	          if (url.isSpecial() && (chr == '/' || chr == '\\')) {
	            state = SPECIAL_AUTHORITY_IGNORE_SLASHES;
	          } else if (chr == '/') {
	            state = AUTHORITY;
	          } else {
	            url.username = base.username;
	            url.password = base.password;
	            url.host = base.host;
	            url.port = base.port;
	            state = PATH;
	            continue;
	          }
	          break;
	        case SPECIAL_AUTHORITY_SLASHES:
	          state = SPECIAL_AUTHORITY_IGNORE_SLASHES;
	          if (chr != '/' || charAt(buffer, pointer + 1) != '/') continue;
	          pointer++;
	          break;
	        case SPECIAL_AUTHORITY_IGNORE_SLASHES:
	          if (chr != '/' && chr != '\\') {
	            state = AUTHORITY;
	            continue;
	          }
	          break;
	        case AUTHORITY:
	          if (chr == '@') {
	            if (seenAt) buffer = '%40' + buffer;
	            seenAt = true;
	            bufferCodePoints = arrayFrom(buffer);
	            for (var i = 0; i < bufferCodePoints.length; i++) {
	              var codePoint = bufferCodePoints[i];
	              if (codePoint == ':' && !seenPasswordToken) {
	                seenPasswordToken = true;
	                continue;
	              }
	              var encodedCodePoints = percentEncode(codePoint, userinfoPercentEncodeSet);
	              if (seenPasswordToken) url.password += encodedCodePoints;else url.username += encodedCodePoints;
	            }
	            buffer = '';
	          } else if (chr == EOF || chr == '/' || chr == '?' || chr == '#' || chr == '\\' && url.isSpecial()) {
	            if (seenAt && buffer == '') return INVALID_AUTHORITY;
	            pointer -= arrayFrom(buffer).length + 1;
	            buffer = '';
	            state = HOST;
	          } else buffer += chr;
	          break;
	        case HOST:
	        case HOSTNAME:
	          if (stateOverride && url.scheme == 'file') {
	            state = FILE_HOST;
	            continue;
	          } else if (chr == ':' && !seenBracket) {
	            if (buffer == '') return INVALID_HOST;
	            failure = url.parseHost(buffer);
	            if (failure) return failure;
	            buffer = '';
	            state = PORT;
	            if (stateOverride == HOSTNAME) return;
	          } else if (chr == EOF || chr == '/' || chr == '?' || chr == '#' || chr == '\\' && url.isSpecial()) {
	            if (url.isSpecial() && buffer == '') return INVALID_HOST;
	            if (stateOverride && buffer == '' && (url.includesCredentials() || url.port !== null)) return;
	            failure = url.parseHost(buffer);
	            if (failure) return failure;
	            buffer = '';
	            state = PATH_START;
	            if (stateOverride) return;
	            continue;
	          } else {
	            if (chr == '[') seenBracket = true;else if (chr == ']') seenBracket = false;
	            buffer += chr;
	          }
	          break;
	        case PORT:
	          if (exec(DIGIT, chr)) {
	            buffer += chr;
	          } else if (chr == EOF || chr == '/' || chr == '?' || chr == '#' || chr == '\\' && url.isSpecial() || stateOverride) {
	            if (buffer != '') {
	              var port = parseInt$1(buffer, 10);
	              if (port > 0xFFFF) return INVALID_PORT;
	              url.port = url.isSpecial() && port === specialSchemes[url.scheme] ? null : port;
	              buffer = '';
	            }
	            if (stateOverride) return;
	            state = PATH_START;
	            continue;
	          } else return INVALID_PORT;
	          break;
	        case FILE:
	          url.scheme = 'file';
	          if (chr == '/' || chr == '\\') state = FILE_SLASH;else if (base && base.scheme == 'file') {
	            if (chr == EOF) {
	              url.host = base.host;
	              url.path = arraySlice(base.path);
	              url.query = base.query;
	            } else if (chr == '?') {
	              url.host = base.host;
	              url.path = arraySlice(base.path);
	              url.query = '';
	              state = QUERY;
	            } else if (chr == '#') {
	              url.host = base.host;
	              url.path = arraySlice(base.path);
	              url.query = base.query;
	              url.fragment = '';
	              state = FRAGMENT;
	            } else {
	              if (!startsWithWindowsDriveLetter(join(arraySlice(codePoints, pointer), ''))) {
	                url.host = base.host;
	                url.path = arraySlice(base.path);
	                url.shortenPath();
	              }
	              state = PATH;
	              continue;
	            }
	          } else {
	            state = PATH;
	            continue;
	          }
	          break;
	        case FILE_SLASH:
	          if (chr == '/' || chr == '\\') {
	            state = FILE_HOST;
	            break;
	          }
	          if (base && base.scheme == 'file' && !startsWithWindowsDriveLetter(join(arraySlice(codePoints, pointer), ''))) {
	            if (isWindowsDriveLetter(base.path[0], true)) push(url.path, base.path[0]);else url.host = base.host;
	          }
	          state = PATH;
	          continue;
	        case FILE_HOST:
	          if (chr == EOF || chr == '/' || chr == '\\' || chr == '?' || chr == '#') {
	            if (!stateOverride && isWindowsDriveLetter(buffer)) {
	              state = PATH;
	            } else if (buffer == '') {
	              url.host = '';
	              if (stateOverride) return;
	              state = PATH_START;
	            } else {
	              failure = url.parseHost(buffer);
	              if (failure) return failure;
	              if (url.host == 'localhost') url.host = '';
	              if (stateOverride) return;
	              buffer = '';
	              state = PATH_START;
	            }
	            continue;
	          } else buffer += chr;
	          break;
	        case PATH_START:
	          if (url.isSpecial()) {
	            state = PATH;
	            if (chr != '/' && chr != '\\') continue;
	          } else if (!stateOverride && chr == '?') {
	            url.query = '';
	            state = QUERY;
	          } else if (!stateOverride && chr == '#') {
	            url.fragment = '';
	            state = FRAGMENT;
	          } else if (chr != EOF) {
	            state = PATH;
	            if (chr != '/') continue;
	          }
	          break;
	        case PATH:
	          if (chr == EOF || chr == '/' || chr == '\\' && url.isSpecial() || !stateOverride && (chr == '?' || chr == '#')) {
	            if (isDoubleDot(buffer)) {
	              url.shortenPath();
	              if (chr != '/' && !(chr == '\\' && url.isSpecial())) {
	                push(url.path, '');
	              }
	            } else if (isSingleDot(buffer)) {
	              if (chr != '/' && !(chr == '\\' && url.isSpecial())) {
	                push(url.path, '');
	              }
	            } else {
	              if (url.scheme == 'file' && !url.path.length && isWindowsDriveLetter(buffer)) {
	                if (url.host) url.host = '';
	                buffer = charAt(buffer, 0) + ':'; // normalize windows drive letter
	              }

	              push(url.path, buffer);
	            }
	            buffer = '';
	            if (url.scheme == 'file' && (chr == EOF || chr == '?' || chr == '#')) {
	              while (url.path.length > 1 && url.path[0] === '') {
	                shift(url.path);
	              }
	            }
	            if (chr == '?') {
	              url.query = '';
	              state = QUERY;
	            } else if (chr == '#') {
	              url.fragment = '';
	              state = FRAGMENT;
	            }
	          } else {
	            buffer += percentEncode(chr, pathPercentEncodeSet);
	          }
	          break;
	        case CANNOT_BE_A_BASE_URL_PATH:
	          if (chr == '?') {
	            url.query = '';
	            state = QUERY;
	          } else if (chr == '#') {
	            url.fragment = '';
	            state = FRAGMENT;
	          } else if (chr != EOF) {
	            url.path[0] += percentEncode(chr, C0ControlPercentEncodeSet);
	          }
	          break;
	        case QUERY:
	          if (!stateOverride && chr == '#') {
	            url.fragment = '';
	            state = FRAGMENT;
	          } else if (chr != EOF) {
	            if (chr == "'" && url.isSpecial()) url.query += '%27';else if (chr == '#') url.query += '%23';else url.query += percentEncode(chr, C0ControlPercentEncodeSet);
	          }
	          break;
	        case FRAGMENT:
	          if (chr != EOF) url.fragment += percentEncode(chr, fragmentPercentEncodeSet);
	          break;
	      }
	      pointer++;
	    }
	  },
	  // https://url.spec.whatwg.org/#host-parsing
	  parseHost: function parseHost(input) {
	    var result, codePoints, index;
	    if (charAt(input, 0) == '[') {
	      if (charAt(input, input.length - 1) != ']') return INVALID_HOST;
	      result = parseIPv6(stringSlice(input, 1, -1));
	      if (!result) return INVALID_HOST;
	      this.host = result;
	      // opaque host
	    } else if (!this.isSpecial()) {
	      if (exec(FORBIDDEN_HOST_CODE_POINT_EXCLUDING_PERCENT, input)) return INVALID_HOST;
	      result = '';
	      codePoints = arrayFrom(input);
	      for (index = 0; index < codePoints.length; index++) {
	        result += percentEncode(codePoints[index], C0ControlPercentEncodeSet);
	      }
	      this.host = result;
	    } else {
	      input = toASCII(input);
	      if (exec(FORBIDDEN_HOST_CODE_POINT, input)) return INVALID_HOST;
	      result = parseIPv4(input);
	      if (result === null) return INVALID_HOST;
	      this.host = result;
	    }
	  },
	  // https://url.spec.whatwg.org/#cannot-have-a-username-password-port
	  cannotHaveUsernamePasswordPort: function cannotHaveUsernamePasswordPort() {
	    return !this.host || this.cannotBeABaseURL || this.scheme == 'file';
	  },
	  // https://url.spec.whatwg.org/#include-credentials
	  includesCredentials: function includesCredentials() {
	    return this.username != '' || this.password != '';
	  },
	  // https://url.spec.whatwg.org/#is-special
	  isSpecial: function isSpecial() {
	    return hasOwn(specialSchemes, this.scheme);
	  },
	  // https://url.spec.whatwg.org/#shorten-a-urls-path
	  shortenPath: function shortenPath() {
	    var path = this.path;
	    var pathSize = path.length;
	    if (pathSize && (this.scheme != 'file' || pathSize != 1 || !isWindowsDriveLetter(path[0], true))) {
	      path.length--;
	    }
	  },
	  // https://url.spec.whatwg.org/#concept-url-serializer
	  serialize: function serialize() {
	    var url = this;
	    var scheme = url.scheme;
	    var username = url.username;
	    var password = url.password;
	    var host = url.host;
	    var port = url.port;
	    var path = url.path;
	    var query = url.query;
	    var fragment = url.fragment;
	    var output = scheme + ':';
	    if (host !== null) {
	      output += '//';
	      if (url.includesCredentials()) {
	        output += username + (password ? ':' + password : '') + '@';
	      }
	      output += serializeHost(host);
	      if (port !== null) output += ':' + port;
	    } else if (scheme == 'file') output += '//';
	    output += url.cannotBeABaseURL ? path[0] : path.length ? '/' + join(path, '/') : '';
	    if (query !== null) output += '?' + query;
	    if (fragment !== null) output += '#' + fragment;
	    return output;
	  },
	  // https://url.spec.whatwg.org/#dom-url-href
	  setHref: function setHref(href) {
	    var failure = this.parse(href);
	    if (failure) throw TypeError$1(failure);
	    this.searchParams.update();
	  },
	  // https://url.spec.whatwg.org/#dom-url-origin
	  getOrigin: function getOrigin() {
	    var scheme = this.scheme;
	    var port = this.port;
	    if (scheme == 'blob') try {
	      return new URLConstructor(scheme.path[0]).origin;
	    } catch (error) {
	      return 'null';
	    }
	    if (scheme == 'file' || !this.isSpecial()) return 'null';
	    return scheme + '://' + serializeHost(this.host) + (port !== null ? ':' + port : '');
	  },
	  // https://url.spec.whatwg.org/#dom-url-protocol
	  getProtocol: function getProtocol() {
	    return this.scheme + ':';
	  },
	  setProtocol: function setProtocol(protocol) {
	    this.parse($toString(protocol) + ':', SCHEME_START);
	  },
	  // https://url.spec.whatwg.org/#dom-url-username
	  getUsername: function getUsername() {
	    return this.username;
	  },
	  setUsername: function setUsername(username) {
	    var codePoints = arrayFrom($toString(username));
	    if (this.cannotHaveUsernamePasswordPort()) return;
	    this.username = '';
	    for (var i = 0; i < codePoints.length; i++) {
	      this.username += percentEncode(codePoints[i], userinfoPercentEncodeSet);
	    }
	  },
	  // https://url.spec.whatwg.org/#dom-url-password
	  getPassword: function getPassword() {
	    return this.password;
	  },
	  setPassword: function setPassword(password) {
	    var codePoints = arrayFrom($toString(password));
	    if (this.cannotHaveUsernamePasswordPort()) return;
	    this.password = '';
	    for (var i = 0; i < codePoints.length; i++) {
	      this.password += percentEncode(codePoints[i], userinfoPercentEncodeSet);
	    }
	  },
	  // https://url.spec.whatwg.org/#dom-url-host
	  getHost: function getHost() {
	    var host = this.host;
	    var port = this.port;
	    return host === null ? '' : port === null ? serializeHost(host) : serializeHost(host) + ':' + port;
	  },
	  setHost: function setHost(host) {
	    if (this.cannotBeABaseURL) return;
	    this.parse(host, HOST);
	  },
	  // https://url.spec.whatwg.org/#dom-url-hostname
	  getHostname: function getHostname() {
	    var host = this.host;
	    return host === null ? '' : serializeHost(host);
	  },
	  setHostname: function setHostname(hostname) {
	    if (this.cannotBeABaseURL) return;
	    this.parse(hostname, HOSTNAME);
	  },
	  // https://url.spec.whatwg.org/#dom-url-port
	  getPort: function getPort() {
	    var port = this.port;
	    return port === null ? '' : $toString(port);
	  },
	  setPort: function setPort(port) {
	    if (this.cannotHaveUsernamePasswordPort()) return;
	    port = $toString(port);
	    if (port == '') this.port = null;else this.parse(port, PORT);
	  },
	  // https://url.spec.whatwg.org/#dom-url-pathname
	  getPathname: function getPathname() {
	    var path = this.path;
	    return this.cannotBeABaseURL ? path[0] : path.length ? '/' + join(path, '/') : '';
	  },
	  setPathname: function setPathname(pathname) {
	    if (this.cannotBeABaseURL) return;
	    this.path = [];
	    this.parse(pathname, PATH_START);
	  },
	  // https://url.spec.whatwg.org/#dom-url-search
	  getSearch: function getSearch() {
	    var query = this.query;
	    return query ? '?' + query : '';
	  },
	  setSearch: function setSearch(search) {
	    search = $toString(search);
	    if (search == '') {
	      this.query = null;
	    } else {
	      if ('?' == charAt(search, 0)) search = stringSlice(search, 1);
	      this.query = '';
	      this.parse(search, QUERY);
	    }
	    this.searchParams.update();
	  },
	  // https://url.spec.whatwg.org/#dom-url-searchparams
	  getSearchParams: function getSearchParams() {
	    return this.searchParams.facade;
	  },
	  // https://url.spec.whatwg.org/#dom-url-hash
	  getHash: function getHash() {
	    var fragment = this.fragment;
	    return fragment ? '#' + fragment : '';
	  },
	  setHash: function setHash(hash) {
	    hash = $toString(hash);
	    if (hash == '') {
	      this.fragment = null;
	      return;
	    }
	    if ('#' == charAt(hash, 0)) hash = stringSlice(hash, 1);
	    this.fragment = '';
	    this.parse(hash, FRAGMENT);
	  },
	  update: function update() {
	    this.query = this.searchParams.serialize() || null;
	  }
	};

	// `URL` constructor
	// https://url.spec.whatwg.org/#url-class
	var URLConstructor = function URL(url /* , base */) {
	  var that = anInstance(this, URLPrototype);
	  var base = validateArgumentsLength(arguments.length, 1) > 1 ? arguments[1] : undefined;
	  var state = setInternalState(that, new URLState(url, false, base));
	  if (!DESCRIPTORS$1) {
	    that.href = state.serialize();
	    that.origin = state.getOrigin();
	    that.protocol = state.getProtocol();
	    that.username = state.getUsername();
	    that.password = state.getPassword();
	    that.host = state.getHost();
	    that.hostname = state.getHostname();
	    that.port = state.getPort();
	    that.pathname = state.getPathname();
	    that.search = state.getSearch();
	    that.searchParams = state.getSearchParams();
	    that.hash = state.getHash();
	  }
	};
	var URLPrototype = URLConstructor.prototype;
	var accessorDescriptor = function accessorDescriptor(getter, setter) {
	  return {
	    get: function get() {
	      return getInternalURLState(this)[getter]();
	    },
	    set: setter && function (value) {
	      return getInternalURLState(this)[setter](value);
	    },
	    configurable: true,
	    enumerable: true
	  };
	};
	if (DESCRIPTORS$1) {
	  // `URL.prototype.href` accessors pair
	  // https://url.spec.whatwg.org/#dom-url-href
	  defineBuiltInAccessor$1(URLPrototype, 'href', accessorDescriptor('serialize', 'setHref'));
	  // `URL.prototype.origin` getter
	  // https://url.spec.whatwg.org/#dom-url-origin
	  defineBuiltInAccessor$1(URLPrototype, 'origin', accessorDescriptor('getOrigin'));
	  // `URL.prototype.protocol` accessors pair
	  // https://url.spec.whatwg.org/#dom-url-protocol
	  defineBuiltInAccessor$1(URLPrototype, 'protocol', accessorDescriptor('getProtocol', 'setProtocol'));
	  // `URL.prototype.username` accessors pair
	  // https://url.spec.whatwg.org/#dom-url-username
	  defineBuiltInAccessor$1(URLPrototype, 'username', accessorDescriptor('getUsername', 'setUsername'));
	  // `URL.prototype.password` accessors pair
	  // https://url.spec.whatwg.org/#dom-url-password
	  defineBuiltInAccessor$1(URLPrototype, 'password', accessorDescriptor('getPassword', 'setPassword'));
	  // `URL.prototype.host` accessors pair
	  // https://url.spec.whatwg.org/#dom-url-host
	  defineBuiltInAccessor$1(URLPrototype, 'host', accessorDescriptor('getHost', 'setHost'));
	  // `URL.prototype.hostname` accessors pair
	  // https://url.spec.whatwg.org/#dom-url-hostname
	  defineBuiltInAccessor$1(URLPrototype, 'hostname', accessorDescriptor('getHostname', 'setHostname'));
	  // `URL.prototype.port` accessors pair
	  // https://url.spec.whatwg.org/#dom-url-port
	  defineBuiltInAccessor$1(URLPrototype, 'port', accessorDescriptor('getPort', 'setPort'));
	  // `URL.prototype.pathname` accessors pair
	  // https://url.spec.whatwg.org/#dom-url-pathname
	  defineBuiltInAccessor$1(URLPrototype, 'pathname', accessorDescriptor('getPathname', 'setPathname'));
	  // `URL.prototype.search` accessors pair
	  // https://url.spec.whatwg.org/#dom-url-search
	  defineBuiltInAccessor$1(URLPrototype, 'search', accessorDescriptor('getSearch', 'setSearch'));
	  // `URL.prototype.searchParams` getter
	  // https://url.spec.whatwg.org/#dom-url-searchparams
	  defineBuiltInAccessor$1(URLPrototype, 'searchParams', accessorDescriptor('getSearchParams'));
	  // `URL.prototype.hash` accessors pair
	  // https://url.spec.whatwg.org/#dom-url-hash
	  defineBuiltInAccessor$1(URLPrototype, 'hash', accessorDescriptor('getHash', 'setHash'));
	}

	// `URL.prototype.toJSON` method
	// https://url.spec.whatwg.org/#dom-url-tojson
	defineBuiltIn(URLPrototype, 'toJSON', function toJSON() {
	  return getInternalURLState(this).serialize();
	}, {
	  enumerable: true
	});

	// `URL.prototype.toString` method
	// https://url.spec.whatwg.org/#URL-stringification-behavior
	defineBuiltIn(URLPrototype, 'toString', function toString() {
	  return getInternalURLState(this).serialize();
	}, {
	  enumerable: true
	});
	if (NativeURL) {
	  var nativeCreateObjectURL = NativeURL.createObjectURL;
	  var nativeRevokeObjectURL = NativeURL.revokeObjectURL;
	  // `URL.createObjectURL` method
	  // https://developer.mozilla.org/en-US/docs/Web/API/URL/createObjectURL
	  if (nativeCreateObjectURL) defineBuiltIn(URLConstructor, 'createObjectURL', bind(nativeCreateObjectURL, NativeURL));
	  // `URL.revokeObjectURL` method
	  // https://developer.mozilla.org/en-US/docs/Web/API/URL/revokeObjectURL
	  if (nativeRevokeObjectURL) defineBuiltIn(URLConstructor, 'revokeObjectURL', bind(nativeRevokeObjectURL, NativeURL));
	}
	setToStringTag(URLConstructor, 'URL');
	$$1({
	  global: true,
	  constructor: true,
	  forced: !USE_NATIVE_URL,
	  sham: !DESCRIPTORS$1
	}, {
	  URL: URLConstructor
	});

	var web_url_toJson = {};

	'use strict';
	var $ = _export;
	var call = functionCall;

	// `URL.prototype.toJSON` method
	// https://url.spec.whatwg.org/#dom-url-tojson
	$({
	  target: 'URL',
	  proto: true,
	  enumerable: true
	}, {
	  toJSON: function toJSON() {
	    return call(URL.prototype.toString, this);
	  }
	});

	var web_urlSearchParams = {};

	var web_urlSearchParams_size = {};

	'use strict';
	var DESCRIPTORS = descriptors;
	var uncurryThis = functionUncurryThis;
	var defineBuiltInAccessor = defineBuiltInAccessor$h;
	var URLSearchParamsPrototype = URLSearchParams.prototype;
	var forEach = uncurryThis(URLSearchParamsPrototype.forEach);

	// `URLSearchParams.prototype.size` getter
	// https://github.com/whatwg/url/pull/734
	if (DESCRIPTORS && !('size' in URLSearchParamsPrototype)) {
	  defineBuiltInAccessor(URLSearchParamsPrototype, 'size', {
	    get: function size() {
	      var count = 0;
	      forEach(this, function () {
	        count++;
	      });
	      return count;
	    },
	    configurable: true,
	    enumerable: true
	  });
	}

	var stable = path$2;
	var index$2 = /*@__PURE__*/getDefaultExportFromCjs(stable);

	var runtime$1 = {exports: {}};

	var runtime_1 = runtime$1.exports;
	(function (module) {
	  var runtime = function (exports) {
	    "use strict";

	    var Op = Object.prototype;
	    var hasOwn = Op.hasOwnProperty;
	    var undefined$1; // More compressible than void 0.
	    var $Symbol = typeof Symbol === "function" ? Symbol : {};
	    var iteratorSymbol = $Symbol.iterator || "@@iterator";
	    var asyncIteratorSymbol = $Symbol.asyncIterator || "@@asyncIterator";
	    var toStringTagSymbol = $Symbol.toStringTag || "@@toStringTag";
	    function define(obj, key, value) {
	      Object.defineProperty(obj, key, {
	        value: value,
	        enumerable: true,
	        configurable: true,
	        writable: true
	      });
	      return obj[key];
	    }
	    try {
	      // IE 8 has a broken Object.defineProperty that only works on DOM objects.
	      define({}, "");
	    } catch (err) {
	      define = function define(obj, key, value) {
	        return obj[key] = value;
	      };
	    }
	    function wrap(innerFn, outerFn, self, tryLocsList) {
	      // If outerFn provided and outerFn.prototype is a Generator, then outerFn.prototype instanceof Generator.
	      var protoGenerator = outerFn && outerFn.prototype instanceof Generator ? outerFn : Generator;
	      var generator = Object.create(protoGenerator.prototype);
	      var context = new Context(tryLocsList || []);

	      // The ._invoke method unifies the implementations of the .next,
	      // .throw, and .return methods.
	      generator._invoke = makeInvokeMethod(innerFn, self, context);
	      return generator;
	    }
	    exports.wrap = wrap;

	    // Try/catch helper to minimize deoptimizations. Returns a completion
	    // record like context.tryEntries[i].completion. This interface could
	    // have been (and was previously) designed to take a closure to be
	    // invoked without arguments, but in all the cases we care about we
	    // already have an existing method we want to call, so there's no need
	    // to create a new function object. We can even get away with assuming
	    // the method takes exactly one argument, since that happens to be true
	    // in every case, so we don't have to touch the arguments object. The
	    // only additional allocation required is the completion record, which
	    // has a stable shape and so hopefully should be cheap to allocate.
	    function tryCatch(fn, obj, arg) {
	      try {
	        return {
	          type: "normal",
	          arg: fn.call(obj, arg)
	        };
	      } catch (err) {
	        return {
	          type: "throw",
	          arg: err
	        };
	      }
	    }
	    var GenStateSuspendedStart = "suspendedStart";
	    var GenStateSuspendedYield = "suspendedYield";
	    var GenStateExecuting = "executing";
	    var GenStateCompleted = "completed";

	    // Returning this object from the innerFn has the same effect as
	    // breaking out of the dispatch switch statement.
	    var ContinueSentinel = {};

	    // Dummy constructor functions that we use as the .constructor and
	    // .constructor.prototype properties for functions that return Generator
	    // objects. For full spec compliance, you may wish to configure your
	    // minifier not to mangle the names of these two functions.
	    function Generator() {}
	    function GeneratorFunction() {}
	    function GeneratorFunctionPrototype() {}

	    // This is a polyfill for %IteratorPrototype% for environments that
	    // don't natively support it.
	    var IteratorPrototype = {};
	    IteratorPrototype[iteratorSymbol] = function () {
	      return this;
	    };
	    var getProto = Object.getPrototypeOf;
	    var NativeIteratorPrototype = getProto && getProto(getProto(values([])));
	    if (NativeIteratorPrototype && NativeIteratorPrototype !== Op && hasOwn.call(NativeIteratorPrototype, iteratorSymbol)) {
	      // This environment has a native %IteratorPrototype%; use it instead
	      // of the polyfill.
	      IteratorPrototype = NativeIteratorPrototype;
	    }
	    var Gp = GeneratorFunctionPrototype.prototype = Generator.prototype = Object.create(IteratorPrototype);
	    GeneratorFunction.prototype = Gp.constructor = GeneratorFunctionPrototype;
	    GeneratorFunctionPrototype.constructor = GeneratorFunction;
	    GeneratorFunction.displayName = define(GeneratorFunctionPrototype, toStringTagSymbol, "GeneratorFunction");

	    // Helper for defining the .next, .throw, and .return methods of the
	    // Iterator interface in terms of a single ._invoke method.
	    function defineIteratorMethods(prototype) {
	      ["next", "throw", "return"].forEach(function (method) {
	        define(prototype, method, function (arg) {
	          return this._invoke(method, arg);
	        });
	      });
	    }
	    exports.isGeneratorFunction = function (genFun) {
	      var ctor = typeof genFun === "function" && genFun.constructor;
	      return ctor ? ctor === GeneratorFunction ||
	      // For the native GeneratorFunction constructor, the best we can
	      // do is to check its .name property.
	      (ctor.displayName || ctor.name) === "GeneratorFunction" : false;
	    };
	    exports.mark = function (genFun) {
	      if (Object.setPrototypeOf) {
	        Object.setPrototypeOf(genFun, GeneratorFunctionPrototype);
	      } else {
	        genFun.__proto__ = GeneratorFunctionPrototype;
	        define(genFun, toStringTagSymbol, "GeneratorFunction");
	      }
	      genFun.prototype = Object.create(Gp);
	      return genFun;
	    };

	    // Within the body of any async function, `await x` is transformed to
	    // `yield regeneratorRuntime.awrap(x)`, so that the runtime can test
	    // `hasOwn.call(value, "__await")` to determine if the yielded value is
	    // meant to be awaited.
	    exports.awrap = function (arg) {
	      return {
	        __await: arg
	      };
	    };
	    function AsyncIterator(generator, PromiseImpl) {
	      function invoke(method, arg, resolve, reject) {
	        var record = tryCatch(generator[method], generator, arg);
	        if (record.type === "throw") {
	          reject(record.arg);
	        } else {
	          var result = record.arg;
	          var value = result.value;
	          if (value && _typeof(value) === "object" && hasOwn.call(value, "__await")) {
	            return PromiseImpl.resolve(value.__await).then(function (value) {
	              invoke("next", value, resolve, reject);
	            }, function (err) {
	              invoke("throw", err, resolve, reject);
	            });
	          }
	          return PromiseImpl.resolve(value).then(function (unwrapped) {
	            // When a yielded Promise is resolved, its final value becomes
	            // the .value of the Promise<{value,done}> result for the
	            // current iteration.
	            result.value = unwrapped;
	            resolve(result);
	          }, function (error) {
	            // If a rejected Promise was yielded, throw the rejection back
	            // into the async generator function so it can be handled there.
	            return invoke("throw", error, resolve, reject);
	          });
	        }
	      }
	      var previousPromise;
	      function enqueue(method, arg) {
	        function callInvokeWithMethodAndArg() {
	          return new PromiseImpl(function (resolve, reject) {
	            invoke(method, arg, resolve, reject);
	          });
	        }
	        return previousPromise =
	        // If enqueue has been called before, then we want to wait until
	        // all previous Promises have been resolved before calling invoke,
	        // so that results are always delivered in the correct order. If
	        // enqueue has not been called before, then it is important to
	        // call invoke immediately, without waiting on a callback to fire,
	        // so that the async generator function has the opportunity to do
	        // any necessary setup in a predictable way. This predictability
	        // is why the Promise constructor synchronously invokes its
	        // executor callback, and why async functions synchronously
	        // execute code before the first await. Since we implement simple
	        // async functions in terms of async generators, it is especially
	        // important to get this right, even though it requires care.
	        previousPromise ? previousPromise.then(callInvokeWithMethodAndArg,
	        // Avoid propagating failures to Promises returned by later
	        // invocations of the iterator.
	        callInvokeWithMethodAndArg) : callInvokeWithMethodAndArg();
	      }

	      // Define the unified helper method that is used to implement .next,
	      // .throw, and .return (see defineIteratorMethods).
	      this._invoke = enqueue;
	    }
	    defineIteratorMethods(AsyncIterator.prototype);
	    AsyncIterator.prototype[asyncIteratorSymbol] = function () {
	      return this;
	    };
	    exports.AsyncIterator = AsyncIterator;

	    // Note that simple async functions are implemented on top of
	    // AsyncIterator objects; they just return a Promise for the value of
	    // the final result produced by the iterator.
	    exports.async = function (innerFn, outerFn, self, tryLocsList, PromiseImpl) {
	      if (PromiseImpl === void 0) PromiseImpl = Promise;
	      var iter = new AsyncIterator(wrap(innerFn, outerFn, self, tryLocsList), PromiseImpl);
	      return exports.isGeneratorFunction(outerFn) ? iter // If outerFn is a generator, return the full iterator.
	      : iter.next().then(function (result) {
	        return result.done ? result.value : iter.next();
	      });
	    };
	    function makeInvokeMethod(innerFn, self, context) {
	      var state = GenStateSuspendedStart;
	      return function invoke(method, arg) {
	        if (state === GenStateExecuting) {
	          throw new Error("Generator is already running");
	        }
	        if (state === GenStateCompleted) {
	          if (method === "throw") {
	            throw arg;
	          }

	          // Be forgiving, per 25.3.3.3.3 of the spec:
	          // https://people.mozilla.org/~jorendorff/es6-draft.html#sec-generatorresume
	          return doneResult();
	        }
	        context.method = method;
	        context.arg = arg;
	        while (true) {
	          var delegate = context.delegate;
	          if (delegate) {
	            var delegateResult = maybeInvokeDelegate(delegate, context);
	            if (delegateResult) {
	              if (delegateResult === ContinueSentinel) continue;
	              return delegateResult;
	            }
	          }
	          if (context.method === "next") {
	            // Setting context._sent for legacy support of Babel's
	            // function.sent implementation.
	            context.sent = context._sent = context.arg;
	          } else if (context.method === "throw") {
	            if (state === GenStateSuspendedStart) {
	              state = GenStateCompleted;
	              throw context.arg;
	            }
	            context.dispatchException(context.arg);
	          } else if (context.method === "return") {
	            context.abrupt("return", context.arg);
	          }
	          state = GenStateExecuting;
	          var record = tryCatch(innerFn, self, context);
	          if (record.type === "normal") {
	            // If an exception is thrown from innerFn, we leave state ===
	            // GenStateExecuting and loop back for another invocation.
	            state = context.done ? GenStateCompleted : GenStateSuspendedYield;
	            if (record.arg === ContinueSentinel) {
	              continue;
	            }
	            return {
	              value: record.arg,
	              done: context.done
	            };
	          } else if (record.type === "throw") {
	            state = GenStateCompleted;
	            // Dispatch the exception by looping back around to the
	            // context.dispatchException(context.arg) call above.
	            context.method = "throw";
	            context.arg = record.arg;
	          }
	        }
	      };
	    }

	    // Call delegate.iterator[context.method](context.arg) and handle the
	    // result, either by returning a { value, done } result from the
	    // delegate iterator, or by modifying context.method and context.arg,
	    // setting context.delegate to null, and returning the ContinueSentinel.
	    function maybeInvokeDelegate(delegate, context) {
	      var method = delegate.iterator[context.method];
	      if (method === undefined$1) {
	        // A .throw or .return when the delegate iterator has no .throw
	        // method always terminates the yield* loop.
	        context.delegate = null;
	        if (context.method === "throw") {
	          // Note: ["return"] must be used for ES3 parsing compatibility.
	          if (delegate.iterator["return"]) {
	            // If the delegate iterator has a return method, give it a
	            // chance to clean up.
	            context.method = "return";
	            context.arg = undefined$1;
	            maybeInvokeDelegate(delegate, context);
	            if (context.method === "throw") {
	              // If maybeInvokeDelegate(context) changed context.method from
	              // "return" to "throw", let that override the TypeError below.
	              return ContinueSentinel;
	            }
	          }
	          context.method = "throw";
	          context.arg = new TypeError("The iterator does not provide a 'throw' method");
	        }
	        return ContinueSentinel;
	      }
	      var record = tryCatch(method, delegate.iterator, context.arg);
	      if (record.type === "throw") {
	        context.method = "throw";
	        context.arg = record.arg;
	        context.delegate = null;
	        return ContinueSentinel;
	      }
	      var info = record.arg;
	      if (!info) {
	        context.method = "throw";
	        context.arg = new TypeError("iterator result is not an object");
	        context.delegate = null;
	        return ContinueSentinel;
	      }
	      if (info.done) {
	        // Assign the result of the finished delegate to the temporary
	        // variable specified by delegate.resultName (see delegateYield).
	        context[delegate.resultName] = info.value;

	        // Resume execution at the desired location (see delegateYield).
	        context.next = delegate.nextLoc;

	        // If context.method was "throw" but the delegate handled the
	        // exception, let the outer generator proceed normally. If
	        // context.method was "next", forget context.arg since it has been
	        // "consumed" by the delegate iterator. If context.method was
	        // "return", allow the original .return call to continue in the
	        // outer generator.
	        if (context.method !== "return") {
	          context.method = "next";
	          context.arg = undefined$1;
	        }
	      } else {
	        // Re-yield the result returned by the delegate method.
	        return info;
	      }

	      // The delegate iterator is finished, so forget it and continue with
	      // the outer generator.
	      context.delegate = null;
	      return ContinueSentinel;
	    }

	    // Define Generator.prototype.{next,throw,return} in terms of the
	    // unified ._invoke helper method.
	    defineIteratorMethods(Gp);
	    define(Gp, toStringTagSymbol, "Generator");

	    // A Generator should always return itself as the iterator object when the
	    // @@iterator function is called on it. Some browsers' implementations of the
	    // iterator prototype chain incorrectly implement this, causing the Generator
	    // object to not be returned from this call. This ensures that doesn't happen.
	    // See https://github.com/facebook/regenerator/issues/274 for more details.
	    Gp[iteratorSymbol] = function () {
	      return this;
	    };
	    Gp.toString = function () {
	      return "[object Generator]";
	    };
	    function pushTryEntry(locs) {
	      var entry = {
	        tryLoc: locs[0]
	      };
	      if (1 in locs) {
	        entry.catchLoc = locs[1];
	      }
	      if (2 in locs) {
	        entry.finallyLoc = locs[2];
	        entry.afterLoc = locs[3];
	      }
	      this.tryEntries.push(entry);
	    }
	    function resetTryEntry(entry) {
	      var record = entry.completion || {};
	      record.type = "normal";
	      delete record.arg;
	      entry.completion = record;
	    }
	    function Context(tryLocsList) {
	      // The root entry object (effectively a try statement without a catch
	      // or a finally block) gives us a place to store values thrown from
	      // locations where there is no enclosing try statement.
	      this.tryEntries = [{
	        tryLoc: "root"
	      }];
	      tryLocsList.forEach(pushTryEntry, this);
	      this.reset(true);
	    }
	    exports.keys = function (object) {
	      var keys = [];
	      for (var key in object) {
	        keys.push(key);
	      }
	      keys.reverse();

	      // Rather than returning an object with a next method, we keep
	      // things simple and return the next function itself.
	      return function next() {
	        while (keys.length) {
	          var key = keys.pop();
	          if (key in object) {
	            next.value = key;
	            next.done = false;
	            return next;
	          }
	        }

	        // To avoid creating an additional object, we just hang the .value
	        // and .done properties off the next function object itself. This
	        // also ensures that the minifier will not anonymize the function.
	        next.done = true;
	        return next;
	      };
	    };
	    function values(iterable) {
	      if (iterable) {
	        var iteratorMethod = iterable[iteratorSymbol];
	        if (iteratorMethod) {
	          return iteratorMethod.call(iterable);
	        }
	        if (typeof iterable.next === "function") {
	          return iterable;
	        }
	        if (!isNaN(iterable.length)) {
	          var i = -1,
	            next = function next() {
	              while (++i < iterable.length) {
	                if (hasOwn.call(iterable, i)) {
	                  next.value = iterable[i];
	                  next.done = false;
	                  return next;
	                }
	              }
	              next.value = undefined$1;
	              next.done = true;
	              return next;
	            };
	          return next.next = next;
	        }
	      }

	      // Return an iterator with no values.
	      return {
	        next: doneResult
	      };
	    }
	    exports.values = values;
	    function doneResult() {
	      return {
	        value: undefined$1,
	        done: true
	      };
	    }
	    Context.prototype = {
	      constructor: Context,
	      reset: function reset(skipTempReset) {
	        this.prev = 0;
	        this.next = 0;
	        // Resetting context._sent for legacy support of Babel's
	        // function.sent implementation.
	        this.sent = this._sent = undefined$1;
	        this.done = false;
	        this.delegate = null;
	        this.method = "next";
	        this.arg = undefined$1;
	        this.tryEntries.forEach(resetTryEntry);
	        if (!skipTempReset) {
	          for (var name in this) {
	            // Not sure about the optimal order of these conditions:
	            if (name.charAt(0) === "t" && hasOwn.call(this, name) && !isNaN(+name.slice(1))) {
	              this[name] = undefined$1;
	            }
	          }
	        }
	      },
	      stop: function stop() {
	        this.done = true;
	        var rootEntry = this.tryEntries[0];
	        var rootRecord = rootEntry.completion;
	        if (rootRecord.type === "throw") {
	          throw rootRecord.arg;
	        }
	        return this.rval;
	      },
	      dispatchException: function dispatchException(exception) {
	        if (this.done) {
	          throw exception;
	        }
	        var context = this;
	        function handle(loc, caught) {
	          record.type = "throw";
	          record.arg = exception;
	          context.next = loc;
	          if (caught) {
	            // If the dispatched exception was caught by a catch block,
	            // then let that catch block handle the exception normally.
	            context.method = "next";
	            context.arg = undefined$1;
	          }
	          return !!caught;
	        }
	        for (var i = this.tryEntries.length - 1; i >= 0; --i) {
	          var entry = this.tryEntries[i];
	          var record = entry.completion;
	          if (entry.tryLoc === "root") {
	            // Exception thrown outside of any try block that could handle
	            // it, so set the completion value of the entire function to
	            // throw the exception.
	            return handle("end");
	          }
	          if (entry.tryLoc <= this.prev) {
	            var hasCatch = hasOwn.call(entry, "catchLoc");
	            var hasFinally = hasOwn.call(entry, "finallyLoc");
	            if (hasCatch && hasFinally) {
	              if (this.prev < entry.catchLoc) {
	                return handle(entry.catchLoc, true);
	              } else if (this.prev < entry.finallyLoc) {
	                return handle(entry.finallyLoc);
	              }
	            } else if (hasCatch) {
	              if (this.prev < entry.catchLoc) {
	                return handle(entry.catchLoc, true);
	              }
	            } else if (hasFinally) {
	              if (this.prev < entry.finallyLoc) {
	                return handle(entry.finallyLoc);
	              }
	            } else {
	              throw new Error("try statement without catch or finally");
	            }
	          }
	        }
	      },
	      abrupt: function abrupt(type, arg) {
	        for (var i = this.tryEntries.length - 1; i >= 0; --i) {
	          var entry = this.tryEntries[i];
	          if (entry.tryLoc <= this.prev && hasOwn.call(entry, "finallyLoc") && this.prev < entry.finallyLoc) {
	            var finallyEntry = entry;
	            break;
	          }
	        }
	        if (finallyEntry && (type === "break" || type === "continue") && finallyEntry.tryLoc <= arg && arg <= finallyEntry.finallyLoc) {
	          // Ignore the finally entry if control is not jumping to a
	          // location outside the try/catch block.
	          finallyEntry = null;
	        }
	        var record = finallyEntry ? finallyEntry.completion : {};
	        record.type = type;
	        record.arg = arg;
	        if (finallyEntry) {
	          this.method = "next";
	          this.next = finallyEntry.finallyLoc;
	          return ContinueSentinel;
	        }
	        return this.complete(record);
	      },
	      complete: function complete(record, afterLoc) {
	        if (record.type === "throw") {
	          throw record.arg;
	        }
	        if (record.type === "break" || record.type === "continue") {
	          this.next = record.arg;
	        } else if (record.type === "return") {
	          this.rval = this.arg = record.arg;
	          this.method = "return";
	          this.next = "end";
	        } else if (record.type === "normal" && afterLoc) {
	          this.next = afterLoc;
	        }
	        return ContinueSentinel;
	      },
	      finish: function finish(finallyLoc) {
	        for (var i = this.tryEntries.length - 1; i >= 0; --i) {
	          var entry = this.tryEntries[i];
	          if (entry.finallyLoc === finallyLoc) {
	            this.complete(entry.completion, entry.afterLoc);
	            resetTryEntry(entry);
	            return ContinueSentinel;
	          }
	        }
	      },
	      "catch": function _catch(tryLoc) {
	        for (var i = this.tryEntries.length - 1; i >= 0; --i) {
	          var entry = this.tryEntries[i];
	          if (entry.tryLoc === tryLoc) {
	            var record = entry.completion;
	            if (record.type === "throw") {
	              var thrown = record.arg;
	              resetTryEntry(entry);
	            }
	            return thrown;
	          }
	        }

	        // The context.catch method must only be called with a location
	        // argument that corresponds to a known catch block.
	        throw new Error("illegal catch attempt");
	      },
	      delegateYield: function delegateYield(iterable, resultName, nextLoc) {
	        this.delegate = {
	          iterator: values(iterable),
	          resultName: resultName,
	          nextLoc: nextLoc
	        };
	        if (this.method === "next") {
	          // Deliberately forget the last sent value so that we don't
	          // accidentally pass it on to the delegate.
	          this.arg = undefined$1;
	        }
	        return ContinueSentinel;
	      }
	    };

	    // Regardless of whether this script is executing as a CommonJS module
	    // or not, return the runtime object so that we can declare the variable
	    // regeneratorRuntime in the outer scope, which allows this module to be
	    // injected easily by `bin/regenerator --include-runtime script.js`.
	    return exports;
	  }(
	  // If this script is executing as a CommonJS module, use module.exports
	  // as the regeneratorRuntime namespace. Otherwise create a new empty
	  // object. Either way, the resulting object will be used to initialize
	  // the regeneratorRuntime variable at the top of this file.
	  'object' === "object" ? module.exports : {});
	  try {
	    regeneratorRuntime = runtime;
	  } catch (accidentalStrictMode) {
	    // This module should not be running in strict mode, so the above
	    // assignment should always work unless something is misconfigured. Just
	    // in case runtime.js accidentally runs in strict mode, we can escape
	    // strict mode using a global Function call. This could conceivably fail
	    // if a Content Security Policy forbids using Function, but in that case
	    // the proper solution is to fix the accidental strict mode problem. If
	    // you've misconfigured your bundler to force strict mode and applied a
	    // CSP to forbid Function, and you're not willing to fix either of those
	    // problems, please detail your unique predicament in a GitHub issue.
	    Function("r", "regeneratorRuntime = r")(runtime);
	  }
	})(runtime$1);
	var runtimeExports = runtime$1.exports;
	var runtime = /*@__PURE__*/getDefaultExportFromCjs(runtimeExports);

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var EPSILON_FLOAT32$1 = 1e-7;
	var EPSILON_FLOAT16$1 = 1e-4;
	/** Convenient class for storing tensor-related data. */
	var DataStorage = /*#__PURE__*/function () {
	  function DataStorage(backend, dataMover) {
	    _classCallCheck(this, DataStorage);
	    this.backend = backend;
	    this.dataMover = dataMover;
	    this.data = new WeakMap();
	    this.dataIdsCount = 0;
	  }
	  _createClass(DataStorage, [{
	    key: "get",
	    value: function get(dataId) {
	      if (!this.data.has(dataId)) {
	        this.dataMover.moveData(this.backend, dataId);
	      }
	      return this.data.get(dataId);
	    }
	  }, {
	    key: "set",
	    value: function set(dataId, value) {
	      this.dataIdsCount++;
	      this.data.set(dataId, value);
	    }
	  }, {
	    key: "has",
	    value: function has(dataId) {
	      return this.data.has(dataId);
	    }
	  }, {
	    key: "delete",
	    value: function _delete(dataId) {
	      this.dataIdsCount--;
	      return this.data.delete(dataId);
	    }
	  }, {
	    key: "numDataIds",
	    value: function numDataIds() {
	      return this.dataIdsCount;
	    }
	  }]);
	  return DataStorage;
	}();
	/**
	 * The interface that defines the kernels that should be implemented when
	 * adding a new backend. New backends don't need to implement every one of the
	 * methods, this can be done gradually (throw an error for unimplemented
	 * methods).
	 */
	var KernelBackend = /*#__PURE__*/function () {
	  function KernelBackend() {
	    _classCallCheck(this, KernelBackend);
	  }
	  _createClass(KernelBackend, [{
	    key: "refCount",
	    value: function refCount(dataId) {
	      return notYetImplemented('refCount');
	    }
	  }, {
	    key: "incRef",
	    value: function incRef(dataId) {
	      return notYetImplemented('incRef');
	    }
	  }, {
	    key: "timerAvailable",
	    value: function timerAvailable() {
	      return true;
	    }
	  }, {
	    key: "time",
	    value: function time(f) {
	      return notYetImplemented('time');
	    }
	  }, {
	    key: "read",
	    value: function read(dataId) {
	      return notYetImplemented('read');
	    }
	  }, {
	    key: "readSync",
	    value: function readSync(dataId) {
	      return notYetImplemented('readSync');
	    }
	  }, {
	    key: "readToGPU",
	    value: function readToGPU(dataId, options) {
	      return notYetImplemented('readToGPU');
	    }
	  }, {
	    key: "numDataIds",
	    value: function numDataIds() {
	      return notYetImplemented('numDataIds');
	    }
	  }, {
	    key: "disposeData",
	    value: function disposeData(dataId, force) {
	      return notYetImplemented('disposeData');
	    }
	  }, {
	    key: "write",
	    value: function write(values, shape, dtype) {
	      return notYetImplemented('write');
	    }
	  }, {
	    key: "move",
	    value: function move(dataId, values, shape, dtype, refCount) {
	      return notYetImplemented('move');
	    }
	  }, {
	    key: "createTensorFromGPUData",
	    value: function createTensorFromGPUData(values, shape, dtype) {
	      return notYetImplemented('createTensorFromGPUData');
	    }
	  }, {
	    key: "memory",
	    value: function memory() {
	      return notYetImplemented('memory');
	    }
	    /** Returns the highest precision for floats in bits (e.g. 16 or 32) */
	  }, {
	    key: "floatPrecision",
	    value: function floatPrecision() {
	      return notYetImplemented('floatPrecision');
	    }
	    /** Returns the smallest representable number.  */
	  }, {
	    key: "epsilon",
	    value: function epsilon() {
	      return this.floatPrecision() === 32 ? EPSILON_FLOAT32$1 : EPSILON_FLOAT16$1;
	    }
	  }, {
	    key: "dispose",
	    value: function dispose() {
	      return notYetImplemented('dispose');
	    }
	  }]);
	  return KernelBackend;
	}();
	function notYetImplemented(kernelName) {
	  throw new Error("'".concat(kernelName, "' not yet implemented or not found in the registry. ") + "This kernel may not be supported by the tfjs backend you have chosen");
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Shuffles the array in-place using Fisher-Yates algorithm.
	 *
	 * ```js
	 * const a = [1, 2, 3, 4, 5];
	 * tf.util.shuffle(a);
	 * console.log(a);
	 * ```
	 *
	 * @param array The array to shuffle in-place.
	 *
	 * @doc {heading: 'Util', namespace: 'util'}
	 */
	// tslint:disable-next-line:no-any
	function shuffle(array) {
	  var counter = array.length;
	  var index = 0;
	  // While there are elements in the array
	  while (counter > 0) {
	    // Pick a random index
	    index = Math.random() * counter | 0;
	    // Decrease counter by 1
	    counter--;
	    // And swap the last element with it
	    swap(array, counter, index);
	  }
	}
	/**
	 * Shuffles two arrays in-place the same way using Fisher-Yates algorithm.
	 *
	 * ```js
	 * const a = [1,2,3,4,5];
	 * const b = [11,22,33,44,55];
	 * tf.util.shuffleCombo(a, b);
	 * console.log(a, b);
	 * ```
	 *
	 * @param array The first array to shuffle in-place.
	 * @param array2 The second array to shuffle in-place with the same permutation
	 *     as the first array.
	 *
	 * @doc {heading: 'Util', namespace: 'util'}
	 */
	function shuffleCombo(
	// tslint:disable-next-line:no-any
	array,
	// tslint:disable-next-line:no-any
	array2) {
	  if (array.length !== array2.length) {
	    throw new Error("Array sizes must match to be shuffled together " + "First array length was ".concat(array.length) + "Second array length was ".concat(array2.length));
	  }
	  var counter = array.length;
	  var index = 0;
	  // While there are elements in the array
	  while (counter > 0) {
	    // Pick a random index
	    index = Math.random() * counter | 0;
	    // Decrease counter by 1
	    counter--;
	    // And swap the last element of each array with it
	    swap(array, counter, index);
	    swap(array2, counter, index);
	  }
	}
	/** Clamps a value to a specified range. */
	function clamp(min, x, max) {
	  return Math.max(min, Math.min(x, max));
	}
	function nearestLargerEven(val) {
	  return val % 2 === 0 ? val : val + 1;
	}
	function swap(object, left, right) {
	  var temp = object[left];
	  object[left] = object[right];
	  object[right] = temp;
	}
	function sum$4(arr) {
	  var sum = 0;
	  for (var i = 0; i < arr.length; i++) {
	    sum += arr[i];
	  }
	  return sum;
	}
	/**
	 * Returns a sample from a uniform [a, b) distribution.
	 *
	 * @param a The minimum support (inclusive).
	 * @param b The maximum support (exclusive).
	 * @return A pseudorandom number on the half-open interval [a,b).
	 */
	function randUniform(a, b) {
	  var r = Math.random();
	  return b * r + (1 - r) * a;
	}
	/** Returns the squared Euclidean distance between two vectors. */
	function distSquared(a, b) {
	  var result = 0;
	  for (var i = 0; i < a.length; i++) {
	    var diff = Number(a[i]) - Number(b[i]);
	    result += diff * diff;
	  }
	  return result;
	}
	/**
	 * Asserts that the expression is true. Otherwise throws an error with the
	 * provided message.
	 *
	 * ```js
	 * const x = 2;
	 * tf.util.assert(x === 2, 'x is not 2');
	 * ```
	 *
	 * @param expr The expression to assert (as a boolean).
	 * @param msg A function that returns the message to report when throwing an
	 *     error. We use a function for performance reasons.
	 *
	 * @doc {heading: 'Util', namespace: 'util'}
	 */
	function assert$1(expr, msg) {
	  if (!expr) {
	    throw new Error(typeof msg === 'string' ? msg : msg());
	  }
	}
	function assertShapesMatch(shapeA, shapeB) {
	  var errorMessagePrefix = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '';
	  assert$1(arraysEqual(shapeA, shapeB), function () {
	    return errorMessagePrefix + " Shapes ".concat(shapeA, " and ").concat(shapeB, " must match");
	  });
	}
	function assertNonNull(a) {
	  assert$1(a != null, function () {
	    return "The input to the tensor constructor must be a non-null value.";
	  });
	}
	/**
	 * Returns the size (number of elements) of the tensor given its shape.
	 *
	 * ```js
	 * const shape = [3, 4, 2];
	 * const size = tf.util.sizeFromShape(shape);
	 * console.log(size);
	 * ```
	 *
	 * @doc {heading: 'Util', namespace: 'util'}
	 */
	function sizeFromShape(shape) {
	  if (shape.length === 0) {
	    // Scalar.
	    return 1;
	  }
	  var size = shape[0];
	  for (var i = 1; i < shape.length; i++) {
	    size *= shape[i];
	  }
	  return size;
	}
	function isScalarShape(shape) {
	  return shape.length === 0;
	}
	function arraysEqualWithNull(n1, n2) {
	  if (n1 === n2) {
	    return true;
	  }
	  if (n1 == null || n2 == null) {
	    return false;
	  }
	  if (n1.length !== n2.length) {
	    return false;
	  }
	  for (var i = 0; i < n1.length; i++) {
	    if (n1[i] !== null && n2[i] !== null && n1[i] !== n2[i]) {
	      return false;
	    }
	  }
	  return true;
	}
	function arraysEqual(n1, n2) {
	  if (n1 === n2) {
	    return true;
	  }
	  if (n1 == null || n2 == null) {
	    return false;
	  }
	  if (n1.length !== n2.length) {
	    return false;
	  }
	  for (var i = 0; i < n1.length; i++) {
	    if (n1[i] !== n2[i]) {
	      return false;
	    }
	  }
	  return true;
	}
	function isInt(a) {
	  return a % 1 === 0;
	}
	function tanh$3(x) {
	  // tslint:disable-next-line:no-any
	  if (Math.tanh != null) {
	    // tslint:disable-next-line:no-any
	    return Math.tanh(x);
	  }
	  if (x === Infinity) {
	    return 1;
	  } else if (x === -Infinity) {
	    return -1;
	  } else {
	    var e2x = Math.exp(2 * x);
	    return (e2x - 1) / (e2x + 1);
	  }
	}
	function sizeToSquarishShape(size) {
	  var width = Math.ceil(Math.sqrt(size));
	  return [width, Math.ceil(size / width)];
	}
	/**
	 * Creates a new array with randomized indices to a given quantity.
	 *
	 * ```js
	 * const randomTen = tf.util.createShuffledIndices(10);
	 * console.log(randomTen);
	 * ```
	 *
	 * @param number Quantity of how many shuffled indices to create.
	 *
	 * @doc {heading: 'Util', namespace: 'util'}
	 */
	function createShuffledIndices(n) {
	  var shuffledIndices = new Uint32Array(n);
	  for (var i = 0; i < n; ++i) {
	    shuffledIndices[i] = i;
	  }
	  shuffle(shuffledIndices);
	  return shuffledIndices;
	}
	function rightPad(a, size) {
	  if (size <= a.length) {
	    return a;
	  }
	  return a + ' '.repeat(size - a.length);
	}
	function repeatedTry(checkFn) {
	  var delayFn = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : function (counter) {
	    return 0;
	  };
	  var maxCounter = arguments.length > 2 ? arguments[2] : undefined;
	  var scheduleFn = arguments.length > 3 ? arguments[3] : undefined;
	  return new Promise(function (resolve, reject) {
	    var tryCount = 0;
	    var tryFn = function tryFn() {
	      if (checkFn()) {
	        resolve();
	        return;
	      }
	      tryCount++;
	      var nextBackoff = delayFn(tryCount);
	      if (maxCounter != null && tryCount >= maxCounter) {
	        reject();
	        return;
	      }
	      if (scheduleFn != null) {
	        scheduleFn(tryFn, nextBackoff);
	      } else {
	        // google3 does not allow assigning another variable to setTimeout.
	        // Don't refactor this so scheduleFn has a default value of setTimeout.
	        setTimeout(tryFn, nextBackoff);
	      }
	    };
	    tryFn();
	  });
	}
	/**
	 * Given the full size of the array and a shape that may contain -1 as the
	 * implicit dimension, returns the inferred shape where -1 is replaced.
	 * E.g. For shape=[2, -1, 3] and size=24, it will return [2, 4, 3].
	 *
	 * @param shape The shape, which may contain -1 in some dimension.
	 * @param size The full size (number of elements) of the array.
	 * @return The inferred shape where -1 is replaced with the inferred size.
	 */
	function inferFromImplicitShape(shape, size) {
	  var shapeProd = 1;
	  var implicitIdx = -1;
	  for (var i = 0; i < shape.length; ++i) {
	    if (shape[i] >= 0) {
	      shapeProd *= shape[i];
	    } else if (shape[i] === -1) {
	      if (implicitIdx !== -1) {
	        throw Error("Shapes can only have 1 implicit size. " + "Found -1 at dim ".concat(implicitIdx, " and dim ").concat(i));
	      }
	      implicitIdx = i;
	    } else if (shape[i] < 0) {
	      throw Error("Shapes can not be < 0. Found ".concat(shape[i], " at dim ").concat(i));
	    }
	  }
	  if (implicitIdx === -1) {
	    if (size > 0 && size !== shapeProd) {
	      throw Error("Size(".concat(size, ") must match the product of shape ").concat(shape));
	    }
	    return shape;
	  }
	  if (shapeProd === 0) {
	    throw Error("Cannot infer the missing size in [".concat(shape, "] when ") + "there are 0 elements");
	  }
	  if (size % shapeProd !== 0) {
	    throw Error("The implicit shape can't be a fractional number. " + "Got ".concat(size, " / ").concat(shapeProd));
	  }
	  var newShape = shape.slice();
	  newShape[implicitIdx] = size / shapeProd;
	  return newShape;
	}
	function parseAxisParam(axis, shape) {
	  var rank = shape.length;
	  // Normalize input
	  axis = axis == null ? shape.map(function (s, i) {
	    return i;
	  }) : [].concat(axis);
	  // Check for valid range
	  assert$1(axis.every(function (ax) {
	    return ax >= -rank && ax < rank;
	  }), function () {
	    return "All values in axis param must be in range [-".concat(rank, ", ").concat(rank, ") but ") + "got axis ".concat(axis);
	  });
	  // Check for only integers
	  assert$1(axis.every(function (ax) {
	    return isInt(ax);
	  }), function () {
	    return "All values in axis param must be integers but " + "got axis ".concat(axis);
	  });
	  // Handle negative axis.
	  return axis.map(function (a) {
	    return a < 0 ? rank + a : a;
	  });
	}
	/** Reduces the shape by removing all dimensions of shape 1. */
	function squeezeShape(shape, axis) {
	  var newShape = [];
	  var keptDims = [];
	  var isEmptyArray = axis != null && Array.isArray(axis) && axis.length === 0;
	  var axes = axis == null || isEmptyArray ? null : parseAxisParam(axis, shape).sort();
	  var j = 0;
	  for (var i = 0; i < shape.length; ++i) {
	    if (axes != null) {
	      if (axes[j] === i && shape[i] !== 1) {
	        throw new Error("Can't squeeze axis ".concat(i, " since its dim '").concat(shape[i], "' is not 1"));
	      }
	      if ((axes[j] == null || axes[j] > i) && shape[i] === 1) {
	        newShape.push(shape[i]);
	        keptDims.push(i);
	      }
	      if (axes[j] <= i) {
	        j++;
	      }
	    }
	    if (shape[i] !== 1) {
	      newShape.push(shape[i]);
	      keptDims.push(i);
	    }
	  }
	  return {
	    newShape: newShape,
	    keptDims: keptDims
	  };
	}
	function getTypedArrayFromDType(dtype, size) {
	  return getArrayFromDType(dtype, size);
	}
	function getArrayFromDType(dtype, size) {
	  var values = null;
	  if (dtype == null || dtype === 'float32') {
	    values = new Float32Array(size);
	  } else if (dtype === 'int32') {
	    values = new Int32Array(size);
	  } else if (dtype === 'bool') {
	    values = new Uint8Array(size);
	  } else if (dtype === 'string') {
	    values = new Array(size);
	  } else {
	    throw new Error("Unknown data type ".concat(dtype));
	  }
	  return values;
	}
	function checkConversionForErrors(vals, dtype) {
	  for (var i = 0; i < vals.length; i++) {
	    var num = vals[i];
	    if (isNaN(num) || !isFinite(num)) {
	      throw Error("A tensor of type ".concat(dtype, " being uploaded contains ").concat(num, "."));
	    }
	  }
	}
	/** Returns true if the dtype is valid. */
	function isValidDtype(dtype) {
	  return dtype === 'bool' || dtype === 'complex64' || dtype === 'float32' || dtype === 'int32' || dtype === 'string';
	}
	/**
	 * Returns true if the new type can't encode the old type without loss of
	 * precision.
	 */
	function hasEncodingLoss(oldType, newType) {
	  if (newType === 'complex64') {
	    return false;
	  }
	  if (newType === 'float32' && oldType !== 'complex64') {
	    return false;
	  }
	  if (newType === 'int32' && oldType !== 'float32' && oldType !== 'complex64') {
	    return false;
	  }
	  if (newType === 'bool' && oldType === 'bool') {
	    return false;
	  }
	  return true;
	}
	function bytesPerElement(dtype) {
	  if (dtype === 'float32' || dtype === 'int32') {
	    return 4;
	  } else if (dtype === 'complex64') {
	    return 8;
	  } else if (dtype === 'bool') {
	    return 1;
	  } else {
	    throw new Error("Unknown dtype ".concat(dtype));
	  }
	}
	/**
	 * Returns the approximate number of bytes allocated in the string array - 2
	 * bytes per character. Computing the exact bytes for a native string in JS
	 * is not possible since it depends on the encoding of the html page that
	 * serves the website.
	 */
	function bytesFromStringArray(arr) {
	  if (arr == null) {
	    return 0;
	  }
	  var bytes = 0;
	  arr.forEach(function (x) {
	    return bytes += x.length;
	  });
	  return bytes;
	}
	/** Returns true if the value is a string. */
	function isString(value) {
	  return typeof value === 'string' || value instanceof String;
	}
	function isBoolean(value) {
	  return typeof value === 'boolean';
	}
	function isNumber(value) {
	  return typeof value === 'number';
	}
	function inferDtype(values) {
	  if (Array.isArray(values)) {
	    return inferDtype(values[0]);
	  }
	  if (values instanceof Float32Array) {
	    return 'float32';
	  } else if (values instanceof Int32Array || values instanceof Uint8Array || values instanceof Uint8ClampedArray) {
	    return 'int32';
	  } else if (isNumber(values)) {
	    return 'float32';
	  } else if (isString(values)) {
	    return 'string';
	  } else if (isBoolean(values)) {
	    return 'bool';
	  }
	  return 'float32';
	}
	function isFunction(f) {
	  return !!(f && f.constructor && f.call && f.apply);
	}
	function nearestDivisor(size, start) {
	  for (var i = start; i < size; ++i) {
	    if (size % i === 0) {
	      return i;
	    }
	  }
	  return size;
	}
	function computeStrides(shape) {
	  var rank = shape.length;
	  if (rank < 2) {
	    return [];
	  }
	  // Last dimension has implicit stride of 1, thus having D-1 (instead of D)
	  // strides.
	  var strides = new Array(rank - 1);
	  strides[rank - 2] = shape[rank - 1];
	  for (var i = rank - 3; i >= 0; --i) {
	    strides[i] = strides[i + 1] * shape[i + 1];
	  }
	  return strides;
	}
	function createNestedArray(offset, shape, a) {
	  var isComplex = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var ret = new Array();
	  if (shape.length === 1) {
	    var d = shape[0] * (isComplex ? 2 : 1);
	    for (var i = 0; i < d; i++) {
	      ret[i] = a[offset + i];
	    }
	  } else {
	    var _d = shape[0];
	    var rest = shape.slice(1);
	    var len = rest.reduce(function (acc, c) {
	      return acc * c;
	    }) * (isComplex ? 2 : 1);
	    for (var _i = 0; _i < _d; _i++) {
	      ret[_i] = createNestedArray(offset + _i * len, rest, a, isComplex);
	    }
	  }
	  return ret;
	}
	// Provide a nested array of TypedArray in given shape.
	function toNestedArray(shape, a) {
	  var isComplex = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  if (shape.length === 0) {
	    // Scalar type should return a single number.
	    return a[0];
	  }
	  var size = shape.reduce(function (acc, c) {
	    return acc * c;
	  }) * (isComplex ? 2 : 1);
	  if (size === 0) {
	    // A tensor with shape zero should be turned into empty list.
	    return [];
	  }
	  if (size !== a.length) {
	    throw new Error("[".concat(shape, "] does not match the input size ").concat(a.length).concat(isComplex ? ' for a complex tensor' : '', "."));
	  }
	  return createNestedArray(0, shape, a, isComplex);
	}
	function convertBackendValuesAndArrayBuffer(data, dtype) {
	  // If is type Uint8Array[], return it directly.
	  if (Array.isArray(data)) {
	    return data;
	  }
	  if (dtype === 'float32') {
	    return data instanceof Float32Array ? data : new Float32Array(data);
	  } else if (dtype === 'int32') {
	    return data instanceof Int32Array ? data : new Int32Array(data);
	  } else if (dtype === 'bool' || dtype === 'string') {
	    return Uint8Array.from(new Int32Array(data));
	  } else {
	    throw new Error("Unknown dtype ".concat(dtype));
	  }
	}
	function makeOnesTypedArray(size, dtype) {
	  var array = makeZerosTypedArray(size, dtype);
	  for (var i = 0; i < array.length; i++) {
	    array[i] = 1;
	  }
	  return array;
	}
	function makeZerosTypedArray(size, dtype) {
	  if (dtype == null || dtype === 'float32' || dtype === 'complex64') {
	    return new Float32Array(size);
	  } else if (dtype === 'int32') {
	    return new Int32Array(size);
	  } else if (dtype === 'bool') {
	    return new Uint8Array(size);
	  } else {
	    throw new Error("Unknown data type ".concat(dtype));
	  }
	}
	/**
	 * Make nested `TypedArray` filled with zeros.
	 * @param shape The shape information for the nested array.
	 * @param dtype dtype of the array element.
	 */
	function makeZerosNestedTypedArray(shape, dtype) {
	  var size = shape.reduce(function (prev, curr) {
	    return prev * curr;
	  }, 1);
	  if (dtype == null || dtype === 'float32') {
	    return toNestedArray(shape, new Float32Array(size));
	  } else if (dtype === 'int32') {
	    return toNestedArray(shape, new Int32Array(size));
	  } else if (dtype === 'bool') {
	    return toNestedArray(shape, new Uint8Array(size));
	  } else {
	    throw new Error("Unknown data type ".concat(dtype));
	  }
	}
	function assertNonNegativeIntegerDimensions(shape) {
	  shape.forEach(function (dimSize) {
	    assert$1(Number.isInteger(dimSize) && dimSize >= 0, function () {
	      return "Tensor must have a shape comprised of positive integers but got " + "shape [".concat(shape, "].");
	    });
	  });
	}
	/**
	 * Computes flat index for a given location (multidimentionsal index) in a
	 * Tensor/multidimensional array.
	 *
	 * @param locs Location in the tensor.
	 * @param rank Rank of the tensor.
	 * @param strides Tensor strides.
	 */
	function locToIndex(locs, rank, strides) {
	  if (rank === 0) {
	    return 0;
	  } else if (rank === 1) {
	    return locs[0];
	  }
	  var index = locs[locs.length - 1];
	  for (var i = 0; i < locs.length - 1; ++i) {
	    index += strides[i] * locs[i];
	  }
	  return index;
	}
	/**
	 * Computes the location (multidimensional index) in a
	 * tensor/multidimentional array for a given flat index.
	 *
	 * @param index Index in flat array.
	 * @param rank Rank of tensor.
	 * @param strides Strides of tensor.
	 */
	function indexToLoc(index, rank, strides) {
	  if (rank === 0) {
	    return [];
	  } else if (rank === 1) {
	    return [index];
	  }
	  var locs = new Array(rank);
	  for (var i = 0; i < locs.length - 1; ++i) {
	    locs[i] = Math.floor(index / strides[i]);
	    index -= locs[i] * strides[i];
	  }
	  locs[locs.length - 1] = index;
	  return locs;
	}
	/**
	 * This method asserts whether an object is a Promise instance.
	 * @param object
	 */
	// tslint:disable-next-line: no-any
	function isPromise(object) {
	  //  We chose to not use 'obj instanceOf Promise' for two reasons:
	  //  1. It only reliably works for es6 Promise, not other Promise
	  //  implementations.
	  //  2. It doesn't work with framework that uses zone.js. zone.js monkey
	  //  patch the async calls, so it is possible the obj (patched) is
	  //  comparing to a pre-patched Promise.
	  return object && object.then && typeof object.then === 'function';
	}

	// Expects flags from URL in the format ?tfjsflags=FLAG1:1,FLAG2:true.
	var TENSORFLOWJS_FLAGS_PREFIX = 'tfjsflags';
	/**
	 * The environment contains evaluated flags as well as the registered platform.
	 * This is always used as a global singleton and can be retrieved with
	 * `tf.env()`.
	 *
	 * @doc {heading: 'Environment'}
	 */
	var Environment = /*#__PURE__*/function () {
	  // tslint:disable-next-line: no-any
	  function Environment(global) {
	    _classCallCheck(this, Environment);
	    this.global = global;
	    this.flags = {};
	    this.flagRegistry = {};
	    this.urlFlags = {};
	    // Jasmine spies on this in 'environment_test.ts'
	    this.getQueryParams = getQueryParams;
	    this.populateURLFlags();
	  }
	  _createClass(Environment, [{
	    key: "setPlatform",
	    value: function setPlatform(platformName, platform) {
	      if (this.platform != null) {
	        if (!(env().getBool('IS_TEST') || env().getBool('PROD'))) {
	          console.warn("Platform ".concat(this.platformName, " has already been set. ") + "Overwriting the platform with ".concat(platformName, "."));
	        }
	      }
	      this.platformName = platformName;
	      this.platform = platform;
	    }
	  }, {
	    key: "registerFlag",
	    value: function registerFlag(flagName, evaluationFn, setHook) {
	      this.flagRegistry[flagName] = {
	        evaluationFn: evaluationFn,
	        setHook: setHook
	      };
	      // Override the flag value from the URL. This has to happen here because
	      // the environment is initialized before flags get registered.
	      if (this.urlFlags[flagName] != null) {
	        var flagValue = this.urlFlags[flagName];
	        if (!(env().getBool('IS_TEST') || env().getBool('PROD'))) {
	          console.warn("Setting feature override from URL ".concat(flagName, ": ").concat(flagValue, "."));
	        }
	        this.set(flagName, flagValue);
	      }
	    }
	  }, {
	    key: "getAsync",
	    value: function () {
	      var _getAsync = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(flagName) {
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              if (!(flagName in this.flags)) {
	                _context.next = 2;
	                break;
	              }
	              return _context.abrupt("return", this.flags[flagName]);
	            case 2:
	              _context.next = 4;
	              return this.evaluateFlag(flagName);
	            case 4:
	              this.flags[flagName] = _context.sent;
	              return _context.abrupt("return", this.flags[flagName]);
	            case 6:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function getAsync(_x) {
	        return _getAsync.apply(this, arguments);
	      }
	      return getAsync;
	    }()
	  }, {
	    key: "get",
	    value: function get(flagName) {
	      if (flagName in this.flags) {
	        return this.flags[flagName];
	      }
	      var flagValue = this.evaluateFlag(flagName);
	      if (isPromise(flagValue)) {
	        throw new Error("Flag ".concat(flagName, " cannot be synchronously evaluated. ") + "Please use getAsync() instead.");
	      }
	      this.flags[flagName] = flagValue;
	      return this.flags[flagName];
	    }
	  }, {
	    key: "getNumber",
	    value: function getNumber(flagName) {
	      return this.get(flagName);
	    }
	  }, {
	    key: "getBool",
	    value: function getBool(flagName) {
	      return this.get(flagName);
	    }
	  }, {
	    key: "getString",
	    value: function getString(flagName) {
	      return this.get(flagName);
	    }
	  }, {
	    key: "getFlags",
	    value: function getFlags() {
	      return this.flags;
	    }
	    // For backwards compatibility.
	  }, {
	    key: "features",
	    get: function get() {
	      return this.flags;
	    }
	  }, {
	    key: "set",
	    value: function set(flagName, value) {
	      if (this.flagRegistry[flagName] == null) {
	        throw new Error("Cannot set flag ".concat(flagName, " as it has not been registered."));
	      }
	      this.flags[flagName] = value;
	      if (this.flagRegistry[flagName].setHook != null) {
	        this.flagRegistry[flagName].setHook(value);
	      }
	    }
	  }, {
	    key: "evaluateFlag",
	    value: function evaluateFlag(flagName) {
	      if (this.flagRegistry[flagName] == null) {
	        throw new Error("Cannot evaluate flag '".concat(flagName, "': no evaluation function found."));
	      }
	      return this.flagRegistry[flagName].evaluationFn();
	    }
	  }, {
	    key: "setFlags",
	    value: function setFlags(flags) {
	      this.flags = Object.assign({}, flags);
	    }
	  }, {
	    key: "reset",
	    value: function reset() {
	      this.flags = {};
	      this.urlFlags = {};
	      this.populateURLFlags();
	    }
	  }, {
	    key: "populateURLFlags",
	    value: function populateURLFlags() {
	      var _this = this;
	      if (typeof this.global === 'undefined' || typeof this.global.location === 'undefined' || typeof this.global.location.search === 'undefined') {
	        return;
	      }
	      var urlParams = this.getQueryParams(this.global.location.search);
	      if (TENSORFLOWJS_FLAGS_PREFIX in urlParams) {
	        var keyValues = urlParams[TENSORFLOWJS_FLAGS_PREFIX].split(',');
	        keyValues.forEach(function (keyValue) {
	          var _keyValue$split = keyValue.split(':'),
	            _keyValue$split2 = _slicedToArray(_keyValue$split, 2),
	            key = _keyValue$split2[0],
	            value = _keyValue$split2[1];
	          _this.urlFlags[key] = parseValue(key, value);
	        });
	      }
	    }
	  }]);
	  return Environment;
	}();
	function getQueryParams(queryString) {
	  var params = {};
	  queryString.replace(/[?&]([^=?&]+)(?:=([^&]*))?/g, function (s) {
	    for (var _len = arguments.length, t = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
	      t[_key - 1] = arguments[_key];
	    }
	    decodeParam(params, t[0], t[1]);
	    return t.join('=');
	  });
	  return params;
	}
	function decodeParam(params, name, value) {
	  params[decodeURIComponent(name)] = decodeURIComponent(value || '');
	}
	function parseValue(flagName, value) {
	  var lowerCaseValue = value.toLowerCase();
	  if (lowerCaseValue === 'true' || lowerCaseValue === 'false') {
	    return lowerCaseValue === 'true';
	  } else if ("".concat(+lowerCaseValue) === lowerCaseValue) {
	    return +lowerCaseValue;
	  } else {
	    return value;
	  }
	}
	/**
	 * Returns the current environment (a global singleton).
	 *
	 * The environment object contains the evaluated feature values as well as the
	 * active platform.
	 *
	 * @doc {heading: 'Environment'}
	 */
	function env() {
	  return exports.ENV;
	}
	exports.ENV = null;
	function setEnvironmentGlobal(environment) {
	  exports.ENV = environment;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	// Note that the identifier globalNameSpace is scoped to this module, but will
	// always resolve to the same global object regardless of how the module is
	// resolved.
	// tslint:disable-next-line:no-any
	var globalNameSpace;
	// tslint:disable-next-line:no-any
	function getGlobalNamespace() {
	  if (globalNameSpace == null) {
	    // tslint:disable-next-line:no-any
	    var ns;
	    if (typeof window !== 'undefined') {
	      ns = window;
	    } else if (typeof global !== 'undefined') {
	      ns = global;
	    } else if (typeof process !== 'undefined') {
	      ns = process;
	    } else if (typeof self !== 'undefined') {
	      ns = self;
	    } else {
	      throw new Error('Could not find a global object');
	    }
	    globalNameSpace = ns;
	  }
	  return globalNameSpace;
	}
	// tslint:disable-next-line:no-any
	function getGlobalMap() {
	  var ns = getGlobalNamespace();
	  if (ns._tfGlobals == null) {
	    ns._tfGlobals = new Map();
	  }
	  return ns._tfGlobals;
	}
	/**
	 * Returns a globally accessible 'singleton' object.
	 *
	 * @param key the name of the object
	 * @param init a function to initialize to initialize this object
	 *             the first time it is fetched.
	 */
	function getGlobal(key, init) {
	  var globalMap = getGlobalMap();
	  if (globalMap.has(key)) {
	    return globalMap.get(key);
	  } else {
	    var singleton = init();
	    globalMap.set(key, singleton);
	    return globalMap.get(key);
	  }
	}

	var Abs = 'Abs';
	var Acos = 'Acos';
	var Acosh = 'Acosh';
	var Add$1 = 'Add';
	var AddN = 'AddN';
	var All = 'All';
	var Any = 'Any';
	var ArgMax = 'ArgMax';
	var ArgMin = 'ArgMin';
	var Asin = 'Asin';
	var Asinh = 'Asinh';
	var Atan = 'Atan';
	var Atanh = 'Atanh';
	var Atan2 = 'Atan2';
	var AvgPool = 'AvgPool';
	var AvgPoolGrad = 'AvgPoolGrad';
	var AvgPool3D = 'AvgPool3D';
	var AvgPool3DGrad = 'AvgPool3DGrad';
	var BatchMatMul = 'BatchMatMul';
	var BatchToSpaceND = 'BatchToSpaceND';
	var Bincount = 'Bincount';
	var BitwiseAnd = 'BitwiseAnd';
	var BroadcastTo = 'BroadcastTo';
	var BroadcastArgs = 'BroadcastArgs';
	var Cast = 'Cast';
	var Ceil = 'Ceil';
	var ClipByValue = 'ClipByValue';
	var Complex = 'Complex';
	var ComplexAbs = 'ComplexAbs';
	var Concat = 'Concat';
	var Conv2D$1 = 'Conv2D';
	var Conv2DBackpropFilter = 'Conv2DBackpropFilter';
	var Conv2DBackpropInput = 'Conv2DBackpropInput';
	var Conv3D$1 = 'Conv3D';
	var Conv3DBackpropFilterV2 = 'Conv3DBackpropFilterV2';
	var Conv3DBackpropInputV2 = 'Conv3DBackpropInputV2';
	var Cos = 'Cos';
	var Cosh = 'Cosh';
	var Cumprod = 'Cumprod';
	var Cumsum = 'Cumsum';
	var CropAndResize = 'CropAndResize';
	var DenseBincount = 'DenseBincount';
	var DepthToSpace = 'DepthToSpace';
	var DepthwiseConv2dNative = 'DepthwiseConv2dNative';
	var DepthwiseConv2dNativeBackpropFilter = 'DepthwiseConv2dNativeBackpropFilter';
	var DepthwiseConv2dNativeBackpropInput = 'DepthwiseConv2dNativeBackpropInput';
	var Diag = 'Diag';
	var Dilation2D = 'Dilation2D';
	var Dilation2DBackpropInput = 'Dilation2DBackpropInput';
	var Dilation2DBackpropFilter = 'Dilation2DBackpropFilter';
	var Draw = 'Draw';
	var RealDiv = 'RealDiv';
	var Einsum = 'Einsum';
	var Elu$1 = 'Elu';
	var EluGrad = 'EluGrad';
	var Erf = 'Erf';
	var Equal = 'Equal';
	var Exp = 'Exp';
	var ExpandDims = 'ExpandDims';
	var Expm1 = 'Expm1';
	var FFT = 'FFT';
	var Fill = 'Fill';
	var FlipLeftRight = 'FlipLeftRight';
	var Floor = 'Floor';
	var FloorDiv = 'FloorDiv';
	var FusedBatchNorm = 'FusedBatchNorm';
	var GatherV2 = 'GatherV2';
	var GatherNd = 'GatherNd';
	var Greater = 'Greater';
	var GreaterEqual = 'GreaterEqual';
	var Identity$1 = 'Identity';
	var IFFT = 'IFFT';
	var Imag = 'Imag';
	var IsFinite = 'IsFinite';
	var IsInf = 'IsInf';
	var IsNan = 'IsNan';
	var LeakyRelu = 'LeakyRelu';
	var Less = 'Less';
	var LessEqual = 'LessEqual';
	var LinSpace = 'LinSpace';
	var Log = 'Log';
	var Log1p = 'Log1p';
	var LogicalAnd = 'LogicalAnd';
	var LogicalNot = 'LogicalNot';
	var LogicalOr = 'LogicalOr';
	var LogicalXor = 'LogicalXor';
	var LogSoftmax$1 = 'LogSoftmax';
	var LowerBound = 'LowerBound';
	var LRN = 'LRN';
	var LRNGrad = 'LRNGrad';
	var MatrixBandPart = 'MatrixBandPart';
	var Max = 'Max';
	var Maximum$1 = 'Maximum';
	var MaxPool = 'MaxPool';
	var MaxPoolGrad = 'MaxPoolGrad';
	var MaxPool3D = 'MaxPool3D';
	var MaxPool3DGrad = 'MaxPool3DGrad';
	var MaxPoolWithArgmax = 'MaxPoolWithArgmax';
	var Mean = 'Mean';
	var Min = 'Min';
	var Minimum$1 = 'Minimum';
	var MirrorPad = 'MirrorPad';
	var Mod = 'Mod';
	var Multinomial = 'Multinomial';
	var Multiply$1 = 'Multiply';
	var Neg = 'Neg';
	var NotEqual = 'NotEqual';
	var NonMaxSuppressionV3 = 'NonMaxSuppressionV3';
	var NonMaxSuppressionV4 = 'NonMaxSuppressionV4';
	var NonMaxSuppressionV5 = 'NonMaxSuppressionV5';
	var OnesLike = 'OnesLike';
	var OneHot = 'OneHot';
	var Pack = 'Pack';
	var PadV2 = 'PadV2';
	var Pool = 'Pool';
	var Pow = 'Pow';
	var Prelu = 'Prelu';
	var Prod = 'Prod';
	var RaggedGather = 'RaggedGather';
	var RaggedRange = 'RaggedRange';
	var RaggedTensorToTensor = 'RaggedTensorToTensor';
	var Range = 'Range';
	var Real = 'Real';
	var Reciprocal = 'Reciprocal';
	var Relu$1 = 'Relu';
	var Reshape$1 = 'Reshape';
	var ResizeNearestNeighbor = 'ResizeNearestNeighbor';
	var ResizeNearestNeighborGrad = 'ResizeNearestNeighborGrad';
	var ResizeBilinear = 'ResizeBilinear';
	var ResizeBilinearGrad = 'ResizeBilinearGrad';
	var Relu6$1 = 'Relu6';
	var Reverse = 'Reverse';
	var Round = 'Round';
	var Rsqrt = 'Rsqrt';
	var ScatterNd = 'ScatterNd';
	var TensorScatterUpdate = 'TensorScatterUpdate';
	var SearchSorted = 'SearchSorted';
	var Select = 'Select';
	var Selu$1 = 'Selu';
	var Slice = 'Slice';
	var Sin = 'Sin';
	var Sinh = 'Sinh';
	var Sign = 'Sign';
	var Sigmoid$1 = 'Sigmoid';
	var Softplus$1 = 'Softplus';
	var Sqrt = 'Sqrt';
	var Sum = 'Sum';
	var SpaceToBatchND = 'SpaceToBatchND';
	var SplitV = 'SplitV';
	var Softmax$2 = 'Softmax';
	var SparseFillEmptyRows = 'SparseFillEmptyRows';
	var SparseReshape = 'SparseReshape';
	var SparseSegmentMean = 'SparseSegmentMean';
	var SparseSegmentSum = 'SparseSegmentSum';
	var SparseToDense = 'SparseToDense';
	var SquaredDifference = 'SquaredDifference';
	var Square = 'Square';
	var StaticRegexReplace = 'StaticRegexReplace';
	var StridedSlice = 'StridedSlice';
	var StringNGrams = 'StringNGrams';
	var StringSplit = 'StringSplit';
	var StringToHashBucketFast = 'StringToHashBucketFast';
	var Sub = 'Sub';
	var Tan = 'Tan';
	var Tanh$1 = 'Tanh';
	var Tile = 'Tile';
	var TopK = 'TopK';
	var Transform = 'Transform';
	var Transpose = 'Transpose';
	var Unique = 'Unique';
	var Unpack = 'Unpack';
	var UnsortedSegmentSum = 'UnsortedSegmentSum';
	var UpperBound = 'UpperBound';
	var ZerosLike = 'ZerosLike';
	/**
	 * TensorFlow.js-only kernels
	 */
	var Step = 'Step';
	var FromPixels = 'FromPixels';
	var RotateWithOffset = 'RotateWithOffset';
	var _FusedMatMul = '_FusedMatMul';
	var FusedConv2D = 'FusedConv2D';
	var FusedDepthwiseConv2D = 'FusedDepthwiseConv2D';

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function warn() {
	  if (!(env().getBool('IS_TEST') || env().getBool('PROD'))) {
	    var _console;
	    (_console = console).warn.apply(_console, arguments);
	  }
	}
	function log$3() {
	  if (!(env().getBool('IS_TEST') || env().getBool('PROD'))) {
	    var _console2;
	    (_console2 = console).log.apply(_console2, arguments);
	  }
	}

	var kernelRegistry = getGlobal('kernelRegistry', function () {
	  return new Map();
	});
	var gradRegistry = getGlobal('gradRegistry', function () {
	  return new Map();
	});
	/**
	 * Returns the kernel function (code) associated with the provided names.
	 *
	 * @param kernelName The official name of the kernel.
	 * @param backendName The official name of the backend.
	 */
	function getKernel(kernelName, backendName) {
	  var key = makeKey(kernelName, backendName);
	  return kernelRegistry.get(key);
	}
	/**
	 * Returns the registered gradient info associated with the provided kernel.
	 * @param kernelName The official TF kernel name.
	 */
	function getGradient(kernelName) {
	  return gradRegistry.get(kernelName);
	}
	function getKernelsForBackend(backendName) {
	  var it = kernelRegistry.entries();
	  var result = [];
	  while (true) {
	    var _it$next = it.next(),
	      done = _it$next.done,
	      value = _it$next.value;
	    if (done) {
	      break;
	    }
	    var _value = _slicedToArray(value, 2),
	      key = _value[0],
	      config = _value[1];
	    var _key$split = key.split('_'),
	      _key$split2 = _slicedToArray(_key$split, 1),
	      backend = _key$split2[0];
	    if (backend === backendName) {
	      result.push(config);
	    }
	  }
	  return result;
	}
	/**
	 * Registers the function (forward pass) for the kernel in a global registry.
	 *
	 * @param config A config object with the following properties:
	 * - `kernelName` The official name of the kernel.
	 * - `backendName` The official name of the backend.
	 * - `kernelFunc` The function to run during the forward pass of the kernel.
	 * - `setupFunc` Optional. Gets called once, after the backend initializes.
	 * - `disposeFunc` Optional. Gets called once, right before the backend is
	 * disposed.
	 */
	function registerKernel(config) {
	  var kernelName = config.kernelName,
	    backendName = config.backendName;
	  var key = makeKey(kernelName, backendName);
	  if (kernelRegistry.has(key)) {
	    warn("The kernel '".concat(kernelName, "' for backend ") + "'".concat(backendName, "' is already registered"));
	  }
	  kernelRegistry.set(key, config);
	}
	/**
	 * Registers a gradient function for a given kernel in the global registry,
	 * to be used during the back-propagation of that kernel.
	 *
	 * @param config An object with the following properties:
	 * - `kernelName` The name of the kernel that the gradient function is for.
	 * - `gradFunc` The function to run during back-propagation.
	 */
	function registerGradient(config) {
	  var kernelName = config.kernelName;
	  if (gradRegistry.has(kernelName)) {
	    // TODO (yassogba) after 3.0 assess whether we need to keep this gated
	    // to debug mode.
	    if (env().getBool('DEBUG')) {
	      warn("Overriding the gradient for '".concat(kernelName, "'"));
	    }
	  }
	  gradRegistry.set(kernelName, config);
	}
	/**
	 * Removes the kernel function from the registry.
	 *
	 * @param kernelName The official name of the kernel.
	 * @param backendName The official name of the backend.
	 *
	 */
	function unregisterKernel(kernelName, backendName) {
	  var key = makeKey(kernelName, backendName);
	  if (!kernelRegistry.has(key)) {
	    throw new Error("The kernel '".concat(kernelName, "' for backend ") + "'".concat(backendName, "' is not registered"));
	  }
	  kernelRegistry.delete(key);
	}
	/** Removes the registered gradient from the global registry. */
	function unregisterGradient(kernelName) {
	  if (!gradRegistry.has(kernelName)) {
	    throw new Error("The gradient '".concat(kernelName, "' for backend is not registered"));
	  }
	  gradRegistry.delete(kernelName);
	}
	/**
	 * Finds kernels that have already been registered to a backend and re-registers
	 * them for a new backend. Useful for registering custom backends.
	 * @param registeredBackendName Already registered backend.
	 * @param newBackendName New backend.
	 */
	function copyRegisteredKernels(registeredBackendName, newBackendName) {
	  var kernels = getKernelsForBackend(registeredBackendName);
	  kernels.forEach(function (kernelConfig) {
	    var newKernelConfig = Object.assign({}, kernelConfig, {
	      backendName: newBackendName
	    });
	    registerKernel(newKernelConfig);
	  });
	}
	function makeKey(kernelName, backendName) {
	  return "".concat(backendName, "_").concat(kernelName);
	}

	/**
	 * @license
	 * Copyright 2023 Google LLC.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function isTypedArrayBrowser(a) {
	  return a instanceof Float32Array || a instanceof Int32Array || a instanceof Uint8Array || a instanceof Uint8ClampedArray;
	}

	var long = Long$1;

	/**
	 * wasm optimizations, to do native i64 multiplication and divide
	 */
	var wasm = null;
	try {
	  wasm = new WebAssembly.Instance(new WebAssembly.Module(new Uint8Array([0, 97, 115, 109, 1, 0, 0, 0, 1, 13, 2, 96, 0, 1, 127, 96, 4, 127, 127, 127, 127, 1, 127, 3, 7, 6, 0, 1, 1, 1, 1, 1, 6, 6, 1, 127, 1, 65, 0, 11, 7, 50, 6, 3, 109, 117, 108, 0, 1, 5, 100, 105, 118, 95, 115, 0, 2, 5, 100, 105, 118, 95, 117, 0, 3, 5, 114, 101, 109, 95, 115, 0, 4, 5, 114, 101, 109, 95, 117, 0, 5, 8, 103, 101, 116, 95, 104, 105, 103, 104, 0, 0, 10, 191, 1, 6, 4, 0, 35, 0, 11, 36, 1, 1, 126, 32, 0, 173, 32, 1, 173, 66, 32, 134, 132, 32, 2, 173, 32, 3, 173, 66, 32, 134, 132, 126, 34, 4, 66, 32, 135, 167, 36, 0, 32, 4, 167, 11, 36, 1, 1, 126, 32, 0, 173, 32, 1, 173, 66, 32, 134, 132, 32, 2, 173, 32, 3, 173, 66, 32, 134, 132, 127, 34, 4, 66, 32, 135, 167, 36, 0, 32, 4, 167, 11, 36, 1, 1, 126, 32, 0, 173, 32, 1, 173, 66, 32, 134, 132, 32, 2, 173, 32, 3, 173, 66, 32, 134, 132, 128, 34, 4, 66, 32, 135, 167, 36, 0, 32, 4, 167, 11, 36, 1, 1, 126, 32, 0, 173, 32, 1, 173, 66, 32, 134, 132, 32, 2, 173, 32, 3, 173, 66, 32, 134, 132, 129, 34, 4, 66, 32, 135, 167, 36, 0, 32, 4, 167, 11, 36, 1, 1, 126, 32, 0, 173, 32, 1, 173, 66, 32, 134, 132, 32, 2, 173, 32, 3, 173, 66, 32, 134, 132, 130, 34, 4, 66, 32, 135, 167, 36, 0, 32, 4, 167, 11])), {}).exports;
	} catch (e) {
	  // no wasm support :(
	}

	/**
	 * Constructs a 64 bit two's-complement integer, given its low and high 32 bit values as *signed* integers.
	 *  See the from* functions below for more convenient ways of constructing Longs.
	 * @exports Long
	 * @class A Long class for representing a 64 bit two's-complement integer value.
	 * @param {number} low The low (signed) 32 bits of the long
	 * @param {number} high The high (signed) 32 bits of the long
	 * @param {boolean=} unsigned Whether unsigned or not, defaults to signed
	 * @constructor
	 */
	function Long$1(low, high, unsigned) {
	  /**
	   * The low 32 bits as a signed value.
	   * @type {number}
	   */
	  this.low = low | 0;

	  /**
	   * The high 32 bits as a signed value.
	   * @type {number}
	   */
	  this.high = high | 0;

	  /**
	   * Whether unsigned or not.
	   * @type {boolean}
	   */
	  this.unsigned = !!unsigned;
	}

	// The internal representation of a long is the two given signed, 32-bit values.
	// We use 32-bit pieces because these are the size of integers on which
	// Javascript performs bit-operations.  For operations like addition and
	// multiplication, we split each number into 16 bit pieces, which can easily be
	// multiplied within Javascript's floating-point representation without overflow
	// or change in sign.
	//
	// In the algorithms below, we frequently reduce the negative case to the
	// positive case by negating the input(s) and then post-processing the result.
	// Note that we must ALWAYS check specially whether those values are MIN_VALUE
	// (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
	// a positive number, it overflows back into a negative).  Not handling this
	// case would often result in infinite recursion.
	//
	// Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the from*
	// methods on which they depend.

	/**
	 * An indicator used to reliably determine if an object is a Long or not.
	 * @type {boolean}
	 * @const
	 * @private
	 */
	Long$1.prototype.__isLong__;
	Object.defineProperty(Long$1.prototype, "__isLong__", {
	  value: true
	});

	/**
	 * @function
	 * @param {*} obj Object
	 * @returns {boolean}
	 * @inner
	 */
	function isLong(obj) {
	  return (obj && obj["__isLong__"]) === true;
	}

	/**
	 * Tests if the specified object is a Long.
	 * @function
	 * @param {*} obj Object
	 * @returns {boolean}
	 */
	Long$1.isLong = isLong;

	/**
	 * A cache of the Long representations of small integer values.
	 * @type {!Object}
	 * @inner
	 */
	var INT_CACHE = {};

	/**
	 * A cache of the Long representations of small unsigned integer values.
	 * @type {!Object}
	 * @inner
	 */
	var UINT_CACHE = {};

	/**
	 * @param {number} value
	 * @param {boolean=} unsigned
	 * @returns {!Long}
	 * @inner
	 */
	function fromInt(value, unsigned) {
	  var obj, cachedObj, cache;
	  if (unsigned) {
	    value >>>= 0;
	    if (cache = 0 <= value && value < 256) {
	      cachedObj = UINT_CACHE[value];
	      if (cachedObj) return cachedObj;
	    }
	    obj = fromBits(value, (value | 0) < 0 ? -1 : 0, true);
	    if (cache) UINT_CACHE[value] = obj;
	    return obj;
	  } else {
	    value |= 0;
	    if (cache = -128 <= value && value < 128) {
	      cachedObj = INT_CACHE[value];
	      if (cachedObj) return cachedObj;
	    }
	    obj = fromBits(value, value < 0 ? -1 : 0, false);
	    if (cache) INT_CACHE[value] = obj;
	    return obj;
	  }
	}

	/**
	 * Returns a Long representing the given 32 bit integer value.
	 * @function
	 * @param {number} value The 32 bit integer in question
	 * @param {boolean=} unsigned Whether unsigned or not, defaults to signed
	 * @returns {!Long} The corresponding Long value
	 */
	Long$1.fromInt = fromInt;

	/**
	 * @param {number} value
	 * @param {boolean=} unsigned
	 * @returns {!Long}
	 * @inner
	 */
	function fromNumber(value, unsigned) {
	  if (isNaN(value)) return unsigned ? UZERO : ZERO;
	  if (unsigned) {
	    if (value < 0) return UZERO;
	    if (value >= TWO_PWR_64_DBL) return MAX_UNSIGNED_VALUE;
	  } else {
	    if (value <= -TWO_PWR_63_DBL) return MIN_VALUE;
	    if (value + 1 >= TWO_PWR_63_DBL) return MAX_VALUE;
	  }
	  if (value < 0) return fromNumber(-value, unsigned).neg();
	  return fromBits(value % TWO_PWR_32_DBL | 0, value / TWO_PWR_32_DBL | 0, unsigned);
	}

	/**
	 * Returns a Long representing the given value, provided that it is a finite number. Otherwise, zero is returned.
	 * @function
	 * @param {number} value The number in question
	 * @param {boolean=} unsigned Whether unsigned or not, defaults to signed
	 * @returns {!Long} The corresponding Long value
	 */
	Long$1.fromNumber = fromNumber;

	/**
	 * @param {number} lowBits
	 * @param {number} highBits
	 * @param {boolean=} unsigned
	 * @returns {!Long}
	 * @inner
	 */
	function fromBits(lowBits, highBits, unsigned) {
	  return new Long$1(lowBits, highBits, unsigned);
	}

	/**
	 * Returns a Long representing the 64 bit integer that comes by concatenating the given low and high bits. Each is
	 *  assumed to use 32 bits.
	 * @function
	 * @param {number} lowBits The low 32 bits
	 * @param {number} highBits The high 32 bits
	 * @param {boolean=} unsigned Whether unsigned or not, defaults to signed
	 * @returns {!Long} The corresponding Long value
	 */
	Long$1.fromBits = fromBits;

	/**
	 * @function
	 * @param {number} base
	 * @param {number} exponent
	 * @returns {number}
	 * @inner
	 */
	var pow_dbl = Math.pow; // Used 4 times (4*8 to 15+4)

	/**
	 * @param {string} str
	 * @param {(boolean|number)=} unsigned
	 * @param {number=} radix
	 * @returns {!Long}
	 * @inner
	 */
	function fromString(str, unsigned, radix) {
	  if (str.length === 0) throw Error('empty string');
	  if (str === "NaN" || str === "Infinity" || str === "+Infinity" || str === "-Infinity") return ZERO;
	  if (typeof unsigned === 'number') {
	    // For goog.math.long compatibility
	    radix = unsigned, unsigned = false;
	  } else {
	    unsigned = !!unsigned;
	  }
	  radix = radix || 10;
	  if (radix < 2 || 36 < radix) throw RangeError('radix');
	  var p;
	  if ((p = str.indexOf('-')) > 0) throw Error('interior hyphen');else if (p === 0) {
	    return fromString(str.substring(1), unsigned, radix).neg();
	  }

	  // Do several (8) digits each time through the loop, so as to
	  // minimize the calls to the very expensive emulated div.
	  var radixToPower = fromNumber(pow_dbl(radix, 8));
	  var result = ZERO;
	  for (var i = 0; i < str.length; i += 8) {
	    var size = Math.min(8, str.length - i),
	      value = parseInt(str.substring(i, i + size), radix);
	    if (size < 8) {
	      var power = fromNumber(pow_dbl(radix, size));
	      result = result.mul(power).add(fromNumber(value));
	    } else {
	      result = result.mul(radixToPower);
	      result = result.add(fromNumber(value));
	    }
	  }
	  result.unsigned = unsigned;
	  return result;
	}

	/**
	 * Returns a Long representation of the given string, written using the specified radix.
	 * @function
	 * @param {string} str The textual representation of the Long
	 * @param {(boolean|number)=} unsigned Whether unsigned or not, defaults to signed
	 * @param {number=} radix The radix in which the text is written (2-36), defaults to 10
	 * @returns {!Long} The corresponding Long value
	 */
	Long$1.fromString = fromString;

	/**
	 * @function
	 * @param {!Long|number|string|!{low: number, high: number, unsigned: boolean}} val
	 * @param {boolean=} unsigned
	 * @returns {!Long}
	 * @inner
	 */
	function fromValue(val, unsigned) {
	  if (typeof val === 'number') return fromNumber(val, unsigned);
	  if (typeof val === 'string') return fromString(val, unsigned);
	  // Throws for non-objects, converts non-instanceof Long:
	  return fromBits(val.low, val.high, typeof unsigned === 'boolean' ? unsigned : val.unsigned);
	}

	/**
	 * Converts the specified value to a Long using the appropriate from* function for its type.
	 * @function
	 * @param {!Long|number|string|!{low: number, high: number, unsigned: boolean}} val Value
	 * @param {boolean=} unsigned Whether unsigned or not, defaults to signed
	 * @returns {!Long}
	 */
	Long$1.fromValue = fromValue;

	// NOTE: the compiler should inline these constant values below and then remove these variables, so there should be
	// no runtime penalty for these.

	/**
	 * @type {number}
	 * @const
	 * @inner
	 */
	var TWO_PWR_16_DBL = 1 << 16;

	/**
	 * @type {number}
	 * @const
	 * @inner
	 */
	var TWO_PWR_24_DBL = 1 << 24;

	/**
	 * @type {number}
	 * @const
	 * @inner
	 */
	var TWO_PWR_32_DBL = TWO_PWR_16_DBL * TWO_PWR_16_DBL;

	/**
	 * @type {number}
	 * @const
	 * @inner
	 */
	var TWO_PWR_64_DBL = TWO_PWR_32_DBL * TWO_PWR_32_DBL;

	/**
	 * @type {number}
	 * @const
	 * @inner
	 */
	var TWO_PWR_63_DBL = TWO_PWR_64_DBL / 2;

	/**
	 * @type {!Long}
	 * @const
	 * @inner
	 */
	var TWO_PWR_24 = fromInt(TWO_PWR_24_DBL);

	/**
	 * @type {!Long}
	 * @inner
	 */
	var ZERO = fromInt(0);

	/**
	 * Signed zero.
	 * @type {!Long}
	 */
	Long$1.ZERO = ZERO;

	/**
	 * @type {!Long}
	 * @inner
	 */
	var UZERO = fromInt(0, true);

	/**
	 * Unsigned zero.
	 * @type {!Long}
	 */
	Long$1.UZERO = UZERO;

	/**
	 * @type {!Long}
	 * @inner
	 */
	var ONE = fromInt(1);

	/**
	 * Signed one.
	 * @type {!Long}
	 */
	Long$1.ONE = ONE;

	/**
	 * @type {!Long}
	 * @inner
	 */
	var UONE = fromInt(1, true);

	/**
	 * Unsigned one.
	 * @type {!Long}
	 */
	Long$1.UONE = UONE;

	/**
	 * @type {!Long}
	 * @inner
	 */
	var NEG_ONE = fromInt(-1);

	/**
	 * Signed negative one.
	 * @type {!Long}
	 */
	Long$1.NEG_ONE = NEG_ONE;

	/**
	 * @type {!Long}
	 * @inner
	 */
	var MAX_VALUE = fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0, false);

	/**
	 * Maximum signed value.
	 * @type {!Long}
	 */
	Long$1.MAX_VALUE = MAX_VALUE;

	/**
	 * @type {!Long}
	 * @inner
	 */
	var MAX_UNSIGNED_VALUE = fromBits(0xFFFFFFFF | 0, 0xFFFFFFFF | 0, true);

	/**
	 * Maximum unsigned value.
	 * @type {!Long}
	 */
	Long$1.MAX_UNSIGNED_VALUE = MAX_UNSIGNED_VALUE;

	/**
	 * @type {!Long}
	 * @inner
	 */
	var MIN_VALUE = fromBits(0, 0x80000000 | 0, false);

	/**
	 * Minimum signed value.
	 * @type {!Long}
	 */
	Long$1.MIN_VALUE = MIN_VALUE;

	/**
	 * @alias Long.prototype
	 * @inner
	 */
	var LongPrototype = Long$1.prototype;

	/**
	 * Converts the Long to a 32 bit integer, assuming it is a 32 bit integer.
	 * @returns {number}
	 */
	LongPrototype.toInt = function toInt() {
	  return this.unsigned ? this.low >>> 0 : this.low;
	};

	/**
	 * Converts the Long to a the nearest floating-point representation of this value (double, 53 bit mantissa).
	 * @returns {number}
	 */
	LongPrototype.toNumber = function toNumber() {
	  if (this.unsigned) return (this.high >>> 0) * TWO_PWR_32_DBL + (this.low >>> 0);
	  return this.high * TWO_PWR_32_DBL + (this.low >>> 0);
	};

	/**
	 * Converts the Long to a string written in the specified radix.
	 * @param {number=} radix Radix (2-36), defaults to 10
	 * @returns {string}
	 * @override
	 * @throws {RangeError} If `radix` is out of range
	 */
	LongPrototype.toString = function toString(radix) {
	  radix = radix || 10;
	  if (radix < 2 || 36 < radix) throw RangeError('radix');
	  if (this.isZero()) return '0';
	  if (this.isNegative()) {
	    // Unsigned Longs are never negative
	    if (this.eq(MIN_VALUE)) {
	      // We need to change the Long value before it can be negated, so we remove
	      // the bottom-most digit in this base and then recurse to do the rest.
	      var radixLong = fromNumber(radix),
	        div = this.div(radixLong),
	        rem1 = div.mul(radixLong).sub(this);
	      return div.toString(radix) + rem1.toInt().toString(radix);
	    } else return '-' + this.neg().toString(radix);
	  }

	  // Do several (6) digits each time through the loop, so as to
	  // minimize the calls to the very expensive emulated div.
	  var radixToPower = fromNumber(pow_dbl(radix, 6), this.unsigned),
	    rem = this;
	  var result = '';
	  while (true) {
	    var remDiv = rem.div(radixToPower),
	      intval = rem.sub(remDiv.mul(radixToPower)).toInt() >>> 0,
	      digits = intval.toString(radix);
	    rem = remDiv;
	    if (rem.isZero()) return digits + result;else {
	      while (digits.length < 6) digits = '0' + digits;
	      result = '' + digits + result;
	    }
	  }
	};

	/**
	 * Gets the high 32 bits as a signed integer.
	 * @returns {number} Signed high bits
	 */
	LongPrototype.getHighBits = function getHighBits() {
	  return this.high;
	};

	/**
	 * Gets the high 32 bits as an unsigned integer.
	 * @returns {number} Unsigned high bits
	 */
	LongPrototype.getHighBitsUnsigned = function getHighBitsUnsigned() {
	  return this.high >>> 0;
	};

	/**
	 * Gets the low 32 bits as a signed integer.
	 * @returns {number} Signed low bits
	 */
	LongPrototype.getLowBits = function getLowBits() {
	  return this.low;
	};

	/**
	 * Gets the low 32 bits as an unsigned integer.
	 * @returns {number} Unsigned low bits
	 */
	LongPrototype.getLowBitsUnsigned = function getLowBitsUnsigned() {
	  return this.low >>> 0;
	};

	/**
	 * Gets the number of bits needed to represent the absolute value of this Long.
	 * @returns {number}
	 */
	LongPrototype.getNumBitsAbs = function getNumBitsAbs() {
	  if (this.isNegative())
	    // Unsigned Longs are never negative
	    return this.eq(MIN_VALUE) ? 64 : this.neg().getNumBitsAbs();
	  var val = this.high != 0 ? this.high : this.low;
	  for (var bit = 31; bit > 0; bit--) if ((val & 1 << bit) != 0) break;
	  return this.high != 0 ? bit + 33 : bit + 1;
	};

	/**
	 * Tests if this Long's value equals zero.
	 * @returns {boolean}
	 */
	LongPrototype.isZero = function isZero() {
	  return this.high === 0 && this.low === 0;
	};

	/**
	 * Tests if this Long's value equals zero. This is an alias of {@link Long#isZero}.
	 * @returns {boolean}
	 */
	LongPrototype.eqz = LongPrototype.isZero;

	/**
	 * Tests if this Long's value is negative.
	 * @returns {boolean}
	 */
	LongPrototype.isNegative = function isNegative() {
	  return !this.unsigned && this.high < 0;
	};

	/**
	 * Tests if this Long's value is positive.
	 * @returns {boolean}
	 */
	LongPrototype.isPositive = function isPositive() {
	  return this.unsigned || this.high >= 0;
	};

	/**
	 * Tests if this Long's value is odd.
	 * @returns {boolean}
	 */
	LongPrototype.isOdd = function isOdd() {
	  return (this.low & 1) === 1;
	};

	/**
	 * Tests if this Long's value is even.
	 * @returns {boolean}
	 */
	LongPrototype.isEven = function isEven() {
	  return (this.low & 1) === 0;
	};

	/**
	 * Tests if this Long's value equals the specified's.
	 * @param {!Long|number|string} other Other value
	 * @returns {boolean}
	 */
	LongPrototype.equals = function equals(other) {
	  if (!isLong(other)) other = fromValue(other);
	  if (this.unsigned !== other.unsigned && this.high >>> 31 === 1 && other.high >>> 31 === 1) return false;
	  return this.high === other.high && this.low === other.low;
	};

	/**
	 * Tests if this Long's value equals the specified's. This is an alias of {@link Long#equals}.
	 * @function
	 * @param {!Long|number|string} other Other value
	 * @returns {boolean}
	 */
	LongPrototype.eq = LongPrototype.equals;

	/**
	 * Tests if this Long's value differs from the specified's.
	 * @param {!Long|number|string} other Other value
	 * @returns {boolean}
	 */
	LongPrototype.notEquals = function notEquals(other) {
	  return !this.eq( /* validates */other);
	};

	/**
	 * Tests if this Long's value differs from the specified's. This is an alias of {@link Long#notEquals}.
	 * @function
	 * @param {!Long|number|string} other Other value
	 * @returns {boolean}
	 */
	LongPrototype.neq = LongPrototype.notEquals;

	/**
	 * Tests if this Long's value differs from the specified's. This is an alias of {@link Long#notEquals}.
	 * @function
	 * @param {!Long|number|string} other Other value
	 * @returns {boolean}
	 */
	LongPrototype.ne = LongPrototype.notEquals;

	/**
	 * Tests if this Long's value is less than the specified's.
	 * @param {!Long|number|string} other Other value
	 * @returns {boolean}
	 */
	LongPrototype.lessThan = function lessThan(other) {
	  return this.comp( /* validates */other) < 0;
	};

	/**
	 * Tests if this Long's value is less than the specified's. This is an alias of {@link Long#lessThan}.
	 * @function
	 * @param {!Long|number|string} other Other value
	 * @returns {boolean}
	 */
	LongPrototype.lt = LongPrototype.lessThan;

	/**
	 * Tests if this Long's value is less than or equal the specified's.
	 * @param {!Long|number|string} other Other value
	 * @returns {boolean}
	 */
	LongPrototype.lessThanOrEqual = function lessThanOrEqual(other) {
	  return this.comp( /* validates */other) <= 0;
	};

	/**
	 * Tests if this Long's value is less than or equal the specified's. This is an alias of {@link Long#lessThanOrEqual}.
	 * @function
	 * @param {!Long|number|string} other Other value
	 * @returns {boolean}
	 */
	LongPrototype.lte = LongPrototype.lessThanOrEqual;

	/**
	 * Tests if this Long's value is less than or equal the specified's. This is an alias of {@link Long#lessThanOrEqual}.
	 * @function
	 * @param {!Long|number|string} other Other value
	 * @returns {boolean}
	 */
	LongPrototype.le = LongPrototype.lessThanOrEqual;

	/**
	 * Tests if this Long's value is greater than the specified's.
	 * @param {!Long|number|string} other Other value
	 * @returns {boolean}
	 */
	LongPrototype.greaterThan = function greaterThan(other) {
	  return this.comp( /* validates */other) > 0;
	};

	/**
	 * Tests if this Long's value is greater than the specified's. This is an alias of {@link Long#greaterThan}.
	 * @function
	 * @param {!Long|number|string} other Other value
	 * @returns {boolean}
	 */
	LongPrototype.gt = LongPrototype.greaterThan;

	/**
	 * Tests if this Long's value is greater than or equal the specified's.
	 * @param {!Long|number|string} other Other value
	 * @returns {boolean}
	 */
	LongPrototype.greaterThanOrEqual = function greaterThanOrEqual(other) {
	  return this.comp( /* validates */other) >= 0;
	};

	/**
	 * Tests if this Long's value is greater than or equal the specified's. This is an alias of {@link Long#greaterThanOrEqual}.
	 * @function
	 * @param {!Long|number|string} other Other value
	 * @returns {boolean}
	 */
	LongPrototype.gte = LongPrototype.greaterThanOrEqual;

	/**
	 * Tests if this Long's value is greater than or equal the specified's. This is an alias of {@link Long#greaterThanOrEqual}.
	 * @function
	 * @param {!Long|number|string} other Other value
	 * @returns {boolean}
	 */
	LongPrototype.ge = LongPrototype.greaterThanOrEqual;

	/**
	 * Compares this Long's value with the specified's.
	 * @param {!Long|number|string} other Other value
	 * @returns {number} 0 if they are the same, 1 if the this is greater and -1
	 *  if the given one is greater
	 */
	LongPrototype.compare = function compare(other) {
	  if (!isLong(other)) other = fromValue(other);
	  if (this.eq(other)) return 0;
	  var thisNeg = this.isNegative(),
	    otherNeg = other.isNegative();
	  if (thisNeg && !otherNeg) return -1;
	  if (!thisNeg && otherNeg) return 1;
	  // At this point the sign bits are the same
	  if (!this.unsigned) return this.sub(other).isNegative() ? -1 : 1;
	  // Both are positive if at least one is unsigned
	  return other.high >>> 0 > this.high >>> 0 || other.high === this.high && other.low >>> 0 > this.low >>> 0 ? -1 : 1;
	};

	/**
	 * Compares this Long's value with the specified's. This is an alias of {@link Long#compare}.
	 * @function
	 * @param {!Long|number|string} other Other value
	 * @returns {number} 0 if they are the same, 1 if the this is greater and -1
	 *  if the given one is greater
	 */
	LongPrototype.comp = LongPrototype.compare;

	/**
	 * Negates this Long's value.
	 * @returns {!Long} Negated Long
	 */
	LongPrototype.negate = function negate() {
	  if (!this.unsigned && this.eq(MIN_VALUE)) return MIN_VALUE;
	  return this.not().add(ONE);
	};

	/**
	 * Negates this Long's value. This is an alias of {@link Long#negate}.
	 * @function
	 * @returns {!Long} Negated Long
	 */
	LongPrototype.neg = LongPrototype.negate;

	/**
	 * Returns the sum of this and the specified Long.
	 * @param {!Long|number|string} addend Addend
	 * @returns {!Long} Sum
	 */
	LongPrototype.add = function add(addend) {
	  if (!isLong(addend)) addend = fromValue(addend);

	  // Divide each number into 4 chunks of 16 bits, and then sum the chunks.

	  var a48 = this.high >>> 16;
	  var a32 = this.high & 0xFFFF;
	  var a16 = this.low >>> 16;
	  var a00 = this.low & 0xFFFF;
	  var b48 = addend.high >>> 16;
	  var b32 = addend.high & 0xFFFF;
	  var b16 = addend.low >>> 16;
	  var b00 = addend.low & 0xFFFF;
	  var c48 = 0,
	    c32 = 0,
	    c16 = 0,
	    c00 = 0;
	  c00 += a00 + b00;
	  c16 += c00 >>> 16;
	  c00 &= 0xFFFF;
	  c16 += a16 + b16;
	  c32 += c16 >>> 16;
	  c16 &= 0xFFFF;
	  c32 += a32 + b32;
	  c48 += c32 >>> 16;
	  c32 &= 0xFFFF;
	  c48 += a48 + b48;
	  c48 &= 0xFFFF;
	  return fromBits(c16 << 16 | c00, c48 << 16 | c32, this.unsigned);
	};

	/**
	 * Returns the difference of this and the specified Long.
	 * @param {!Long|number|string} subtrahend Subtrahend
	 * @returns {!Long} Difference
	 */
	LongPrototype.subtract = function subtract(subtrahend) {
	  if (!isLong(subtrahend)) subtrahend = fromValue(subtrahend);
	  return this.add(subtrahend.neg());
	};

	/**
	 * Returns the difference of this and the specified Long. This is an alias of {@link Long#subtract}.
	 * @function
	 * @param {!Long|number|string} subtrahend Subtrahend
	 * @returns {!Long} Difference
	 */
	LongPrototype.sub = LongPrototype.subtract;

	/**
	 * Returns the product of this and the specified Long.
	 * @param {!Long|number|string} multiplier Multiplier
	 * @returns {!Long} Product
	 */
	LongPrototype.multiply = function multiply(multiplier) {
	  if (this.isZero()) return ZERO;
	  if (!isLong(multiplier)) multiplier = fromValue(multiplier);

	  // use wasm support if present
	  if (wasm) {
	    var low = wasm.mul(this.low, this.high, multiplier.low, multiplier.high);
	    return fromBits(low, wasm.get_high(), this.unsigned);
	  }
	  if (multiplier.isZero()) return ZERO;
	  if (this.eq(MIN_VALUE)) return multiplier.isOdd() ? MIN_VALUE : ZERO;
	  if (multiplier.eq(MIN_VALUE)) return this.isOdd() ? MIN_VALUE : ZERO;
	  if (this.isNegative()) {
	    if (multiplier.isNegative()) return this.neg().mul(multiplier.neg());else return this.neg().mul(multiplier).neg();
	  } else if (multiplier.isNegative()) return this.mul(multiplier.neg()).neg();

	  // If both longs are small, use float multiplication
	  if (this.lt(TWO_PWR_24) && multiplier.lt(TWO_PWR_24)) return fromNumber(this.toNumber() * multiplier.toNumber(), this.unsigned);

	  // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
	  // We can skip products that would overflow.

	  var a48 = this.high >>> 16;
	  var a32 = this.high & 0xFFFF;
	  var a16 = this.low >>> 16;
	  var a00 = this.low & 0xFFFF;
	  var b48 = multiplier.high >>> 16;
	  var b32 = multiplier.high & 0xFFFF;
	  var b16 = multiplier.low >>> 16;
	  var b00 = multiplier.low & 0xFFFF;
	  var c48 = 0,
	    c32 = 0,
	    c16 = 0,
	    c00 = 0;
	  c00 += a00 * b00;
	  c16 += c00 >>> 16;
	  c00 &= 0xFFFF;
	  c16 += a16 * b00;
	  c32 += c16 >>> 16;
	  c16 &= 0xFFFF;
	  c16 += a00 * b16;
	  c32 += c16 >>> 16;
	  c16 &= 0xFFFF;
	  c32 += a32 * b00;
	  c48 += c32 >>> 16;
	  c32 &= 0xFFFF;
	  c32 += a16 * b16;
	  c48 += c32 >>> 16;
	  c32 &= 0xFFFF;
	  c32 += a00 * b32;
	  c48 += c32 >>> 16;
	  c32 &= 0xFFFF;
	  c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
	  c48 &= 0xFFFF;
	  return fromBits(c16 << 16 | c00, c48 << 16 | c32, this.unsigned);
	};

	/**
	 * Returns the product of this and the specified Long. This is an alias of {@link Long#multiply}.
	 * @function
	 * @param {!Long|number|string} multiplier Multiplier
	 * @returns {!Long} Product
	 */
	LongPrototype.mul = LongPrototype.multiply;

	/**
	 * Returns this Long divided by the specified. The result is signed if this Long is signed or
	 *  unsigned if this Long is unsigned.
	 * @param {!Long|number|string} divisor Divisor
	 * @returns {!Long} Quotient
	 */
	LongPrototype.divide = function divide(divisor) {
	  if (!isLong(divisor)) divisor = fromValue(divisor);
	  if (divisor.isZero()) throw Error('division by zero');

	  // use wasm support if present
	  if (wasm) {
	    // guard against signed division overflow: the largest
	    // negative number / -1 would be 1 larger than the largest
	    // positive number, due to two's complement.
	    if (!this.unsigned && this.high === -0x80000000 && divisor.low === -1 && divisor.high === -1) {
	      // be consistent with non-wasm code path
	      return this;
	    }
	    var low = (this.unsigned ? wasm.div_u : wasm.div_s)(this.low, this.high, divisor.low, divisor.high);
	    return fromBits(low, wasm.get_high(), this.unsigned);
	  }
	  if (this.isZero()) return this.unsigned ? UZERO : ZERO;
	  var approx, rem, res;
	  if (!this.unsigned) {
	    // This section is only relevant for signed longs and is derived from the
	    // closure library as a whole.
	    if (this.eq(MIN_VALUE)) {
	      if (divisor.eq(ONE) || divisor.eq(NEG_ONE)) return MIN_VALUE; // recall that -MIN_VALUE == MIN_VALUE
	      else if (divisor.eq(MIN_VALUE)) return ONE;else {
	        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
	        var halfThis = this.shr(1);
	        approx = halfThis.div(divisor).shl(1);
	        if (approx.eq(ZERO)) {
	          return divisor.isNegative() ? ONE : NEG_ONE;
	        } else {
	          rem = this.sub(divisor.mul(approx));
	          res = approx.add(rem.div(divisor));
	          return res;
	        }
	      }
	    } else if (divisor.eq(MIN_VALUE)) return this.unsigned ? UZERO : ZERO;
	    if (this.isNegative()) {
	      if (divisor.isNegative()) return this.neg().div(divisor.neg());
	      return this.neg().div(divisor).neg();
	    } else if (divisor.isNegative()) return this.div(divisor.neg()).neg();
	    res = ZERO;
	  } else {
	    // The algorithm below has not been made for unsigned longs. It's therefore
	    // required to take special care of the MSB prior to running it.
	    if (!divisor.unsigned) divisor = divisor.toUnsigned();
	    if (divisor.gt(this)) return UZERO;
	    if (divisor.gt(this.shru(1)))
	      // 15 >>> 1 = 7 ; with divisor = 8 ; true
	      return UONE;
	    res = UZERO;
	  }

	  // Repeat the following until the remainder is less than other:  find a
	  // floating-point that approximates remainder / other *from below*, add this
	  // into the result, and subtract it from the remainder.  It is critical that
	  // the approximate value is less than or equal to the real value so that the
	  // remainder never becomes negative.
	  rem = this;
	  while (rem.gte(divisor)) {
	    // Approximate the result of division. This may be a little greater or
	    // smaller than the actual value.
	    approx = Math.max(1, Math.floor(rem.toNumber() / divisor.toNumber()));

	    // We will tweak the approximate result by changing it in the 48-th digit or
	    // the smallest non-fractional digit, whichever is larger.
	    var log2 = Math.ceil(Math.log(approx) / Math.LN2),
	      delta = log2 <= 48 ? 1 : pow_dbl(2, log2 - 48),
	      // Decrease the approximation until it is smaller than the remainder.  Note
	      // that if it is too large, the product overflows and is negative.
	      approxRes = fromNumber(approx),
	      approxRem = approxRes.mul(divisor);
	    while (approxRem.isNegative() || approxRem.gt(rem)) {
	      approx -= delta;
	      approxRes = fromNumber(approx, this.unsigned);
	      approxRem = approxRes.mul(divisor);
	    }

	    // We know the answer can't be zero... and actually, zero would cause
	    // infinite recursion since we would make no progress.
	    if (approxRes.isZero()) approxRes = ONE;
	    res = res.add(approxRes);
	    rem = rem.sub(approxRem);
	  }
	  return res;
	};

	/**
	 * Returns this Long divided by the specified. This is an alias of {@link Long#divide}.
	 * @function
	 * @param {!Long|number|string} divisor Divisor
	 * @returns {!Long} Quotient
	 */
	LongPrototype.div = LongPrototype.divide;

	/**
	 * Returns this Long modulo the specified.
	 * @param {!Long|number|string} divisor Divisor
	 * @returns {!Long} Remainder
	 */
	LongPrototype.modulo = function modulo(divisor) {
	  if (!isLong(divisor)) divisor = fromValue(divisor);

	  // use wasm support if present
	  if (wasm) {
	    var low = (this.unsigned ? wasm.rem_u : wasm.rem_s)(this.low, this.high, divisor.low, divisor.high);
	    return fromBits(low, wasm.get_high(), this.unsigned);
	  }
	  return this.sub(this.div(divisor).mul(divisor));
	};

	/**
	 * Returns this Long modulo the specified. This is an alias of {@link Long#modulo}.
	 * @function
	 * @param {!Long|number|string} divisor Divisor
	 * @returns {!Long} Remainder
	 */
	LongPrototype.mod = LongPrototype.modulo;

	/**
	 * Returns this Long modulo the specified. This is an alias of {@link Long#modulo}.
	 * @function
	 * @param {!Long|number|string} divisor Divisor
	 * @returns {!Long} Remainder
	 */
	LongPrototype.rem = LongPrototype.modulo;

	/**
	 * Returns the bitwise NOT of this Long.
	 * @returns {!Long}
	 */
	LongPrototype.not = function not() {
	  return fromBits(~this.low, ~this.high, this.unsigned);
	};

	/**
	 * Returns the bitwise AND of this Long and the specified.
	 * @param {!Long|number|string} other Other Long
	 * @returns {!Long}
	 */
	LongPrototype.and = function and(other) {
	  if (!isLong(other)) other = fromValue(other);
	  return fromBits(this.low & other.low, this.high & other.high, this.unsigned);
	};

	/**
	 * Returns the bitwise OR of this Long and the specified.
	 * @param {!Long|number|string} other Other Long
	 * @returns {!Long}
	 */
	LongPrototype.or = function or(other) {
	  if (!isLong(other)) other = fromValue(other);
	  return fromBits(this.low | other.low, this.high | other.high, this.unsigned);
	};

	/**
	 * Returns the bitwise XOR of this Long and the given one.
	 * @param {!Long|number|string} other Other Long
	 * @returns {!Long}
	 */
	LongPrototype.xor = function xor(other) {
	  if (!isLong(other)) other = fromValue(other);
	  return fromBits(this.low ^ other.low, this.high ^ other.high, this.unsigned);
	};

	/**
	 * Returns this Long with bits shifted to the left by the given amount.
	 * @param {number|!Long} numBits Number of bits
	 * @returns {!Long} Shifted Long
	 */
	LongPrototype.shiftLeft = function shiftLeft(numBits) {
	  if (isLong(numBits)) numBits = numBits.toInt();
	  if ((numBits &= 63) === 0) return this;else if (numBits < 32) return fromBits(this.low << numBits, this.high << numBits | this.low >>> 32 - numBits, this.unsigned);else return fromBits(0, this.low << numBits - 32, this.unsigned);
	};

	/**
	 * Returns this Long with bits shifted to the left by the given amount. This is an alias of {@link Long#shiftLeft}.
	 * @function
	 * @param {number|!Long} numBits Number of bits
	 * @returns {!Long} Shifted Long
	 */
	LongPrototype.shl = LongPrototype.shiftLeft;

	/**
	 * Returns this Long with bits arithmetically shifted to the right by the given amount.
	 * @param {number|!Long} numBits Number of bits
	 * @returns {!Long} Shifted Long
	 */
	LongPrototype.shiftRight = function shiftRight(numBits) {
	  if (isLong(numBits)) numBits = numBits.toInt();
	  if ((numBits &= 63) === 0) return this;else if (numBits < 32) return fromBits(this.low >>> numBits | this.high << 32 - numBits, this.high >> numBits, this.unsigned);else return fromBits(this.high >> numBits - 32, this.high >= 0 ? 0 : -1, this.unsigned);
	};

	/**
	 * Returns this Long with bits arithmetically shifted to the right by the given amount. This is an alias of {@link Long#shiftRight}.
	 * @function
	 * @param {number|!Long} numBits Number of bits
	 * @returns {!Long} Shifted Long
	 */
	LongPrototype.shr = LongPrototype.shiftRight;

	/**
	 * Returns this Long with bits logically shifted to the right by the given amount.
	 * @param {number|!Long} numBits Number of bits
	 * @returns {!Long} Shifted Long
	 */
	LongPrototype.shiftRightUnsigned = function shiftRightUnsigned(numBits) {
	  if (isLong(numBits)) numBits = numBits.toInt();
	  numBits &= 63;
	  if (numBits === 0) return this;else {
	    var high = this.high;
	    if (numBits < 32) {
	      var low = this.low;
	      return fromBits(low >>> numBits | high << 32 - numBits, high >>> numBits, this.unsigned);
	    } else if (numBits === 32) return fromBits(high, 0, this.unsigned);else return fromBits(high >>> numBits - 32, 0, this.unsigned);
	  }
	};

	/**
	 * Returns this Long with bits logically shifted to the right by the given amount. This is an alias of {@link Long#shiftRightUnsigned}.
	 * @function
	 * @param {number|!Long} numBits Number of bits
	 * @returns {!Long} Shifted Long
	 */
	LongPrototype.shru = LongPrototype.shiftRightUnsigned;

	/**
	 * Returns this Long with bits logically shifted to the right by the given amount. This is an alias of {@link Long#shiftRightUnsigned}.
	 * @function
	 * @param {number|!Long} numBits Number of bits
	 * @returns {!Long} Shifted Long
	 */
	LongPrototype.shr_u = LongPrototype.shiftRightUnsigned;

	/**
	 * Converts this Long to signed.
	 * @returns {!Long} Signed long
	 */
	LongPrototype.toSigned = function toSigned() {
	  if (!this.unsigned) return this;
	  return fromBits(this.low, this.high, false);
	};

	/**
	 * Converts this Long to unsigned.
	 * @returns {!Long} Unsigned long
	 */
	LongPrototype.toUnsigned = function toUnsigned() {
	  if (this.unsigned) return this;
	  return fromBits(this.low, this.high, true);
	};

	/**
	 * Converts this Long to its byte representation.
	 * @param {boolean=} le Whether little or big endian, defaults to big endian
	 * @returns {!Array.<number>} Byte representation
	 */
	LongPrototype.toBytes = function toBytes(le) {
	  return le ? this.toBytesLE() : this.toBytesBE();
	};

	/**
	 * Converts this Long to its little endian byte representation.
	 * @returns {!Array.<number>} Little endian byte representation
	 */
	LongPrototype.toBytesLE = function toBytesLE() {
	  var hi = this.high,
	    lo = this.low;
	  return [lo & 0xff, lo >>> 8 & 0xff, lo >>> 16 & 0xff, lo >>> 24, hi & 0xff, hi >>> 8 & 0xff, hi >>> 16 & 0xff, hi >>> 24];
	};

	/**
	 * Converts this Long to its big endian byte representation.
	 * @returns {!Array.<number>} Big endian byte representation
	 */
	LongPrototype.toBytesBE = function toBytesBE() {
	  var hi = this.high,
	    lo = this.low;
	  return [hi >>> 24, hi >>> 16 & 0xff, hi >>> 8 & 0xff, hi & 0xff, lo >>> 24, lo >>> 16 & 0xff, lo >>> 8 & 0xff, lo & 0xff];
	};

	/**
	 * Creates a Long from its byte representation.
	 * @param {!Array.<number>} bytes Byte representation
	 * @param {boolean=} unsigned Whether unsigned or not, defaults to signed
	 * @param {boolean=} le Whether little or big endian, defaults to big endian
	 * @returns {Long} The corresponding Long value
	 */
	Long$1.fromBytes = function fromBytes(bytes, unsigned, le) {
	  return le ? Long$1.fromBytesLE(bytes, unsigned) : Long$1.fromBytesBE(bytes, unsigned);
	};

	/**
	 * Creates a Long from its little endian byte representation.
	 * @param {!Array.<number>} bytes Little endian byte representation
	 * @param {boolean=} unsigned Whether unsigned or not, defaults to signed
	 * @returns {Long} The corresponding Long value
	 */
	Long$1.fromBytesLE = function fromBytesLE(bytes, unsigned) {
	  return new Long$1(bytes[0] | bytes[1] << 8 | bytes[2] << 16 | bytes[3] << 24, bytes[4] | bytes[5] << 8 | bytes[6] << 16 | bytes[7] << 24, unsigned);
	};

	/**
	 * Creates a Long from its big endian byte representation.
	 * @param {!Array.<number>} bytes Big endian byte representation
	 * @param {boolean=} unsigned Whether unsigned or not, defaults to signed
	 * @returns {Long} The corresponding Long value
	 */
	Long$1.fromBytesBE = function fromBytesBE(bytes, unsigned) {
	  return new Long$1(bytes[4] << 24 | bytes[5] << 16 | bytes[6] << 8 | bytes[7], bytes[0] << 24 | bytes[1] << 16 | bytes[2] << 8 | bytes[3], unsigned);
	};
	var long$1 = /*@__PURE__*/getDefaultExportFromCjs(long);

	var LongExports = /*#__PURE__*/_mergeNamespaces({
		__proto__: null,
		default: long$1
	}, [long]);

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	// tslint:disable-next-line
	var Long =
	// tslint:disable-next-line
	long$1 || LongExports;
	function hexToLong(hex) {
	  return Long.fromString(hex, true, 16);
	}
	// Some primes between 2^63 and 2^64 for various uses.
	// Hex 0xc3a5c85c97cb3127
	var k0 = hexToLong('c3a5c85c97cb3127');
	// Hex 0xb492b66fbe98f273
	var k1 = hexToLong('b492b66fbe98f273');
	// Hex 0x9ae16a3b2f90404f
	var k2 = hexToLong('9ae16a3b2f90404f');
	function shiftMix(val) {
	  return val.xor(val.shru(47));
	}
	function fetch$2(s, offset, numBytes) {
	  var bytes = s.slice(offset, offset + numBytes);
	  return Long.fromBytes(Array.from(bytes), true, true);
	}
	function fetch64(s, offset) {
	  return fetch$2(s, offset, 8);
	}
	function fetch32(s, offset) {
	  return fetch$2(s, offset, 4);
	}
	function rotate64(val, shift) {
	  // Avoid shifting by 64: doing so yields an undefined result.
	  return shift === 0 ? val : val.shru(shift).or(val.shl(64 - shift));
	}
	function hashLen16(u, v) {
	  var mul = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : hexToLong('9ddfea08eb382d69');
	  // Murmur-inspired hashing.
	  var a = u.xor(v).mul(mul);
	  a = a.xor(a.shru(47));
	  var b = v.xor(a).mul(mul);
	  b = b.xor(b.shru(47));
	  b = b.mul(mul);
	  return b;
	}
	// Return a 16-byte hash for 48 bytes.  Quick and dirty.
	// Callers do best to use "random-looking" values for a and b.
	function weakHashLen32WithSeeds(w, x, y, z, a, b) {
	  a = a.add(w);
	  b = rotate64(b.add(a).add(z), 21);
	  var c = a;
	  a = a.add(x);
	  a = a.add(y);
	  b = b.add(rotate64(a, 44));
	  return [a.add(z), b.add(c)];
	}
	function weakHashLen32WithSeedsStr(s, offset, a, b) {
	  return weakHashLen32WithSeeds(fetch64(s, offset), fetch64(s, offset + 8), fetch64(s, offset + 16), fetch64(s, offset + 24), a, b);
	}
	function hashLen0to16(s) {
	  var len = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : s.length;
	  if (len >= 8) {
	    var mul = k2.add(len * 2);
	    var a = fetch64(s, 0).add(k2);
	    var b = fetch64(s, len - 8);
	    var c = rotate64(b, 37).mul(mul).add(a);
	    var d = rotate64(a, 25).add(b).mul(mul);
	    return hashLen16(c, d, mul);
	  }
	  if (len >= 4) {
	    var _mul = k2.add(len * 2);
	    var _a = fetch32(s, 0);
	    return hashLen16(_a.shl(3).add(len), fetch32(s, len - 4), _mul);
	  }
	  if (len > 0) {
	    var _a2 = s[0];
	    var _b = s[len >> 1];
	    var _c = s[len - 1];
	    var y = _a2 + (_b << 8);
	    var z = len + (_c << 2);
	    return shiftMix(k2.mul(y).xor(k0.mul(z))).mul(k2);
	  }
	  return k2;
	}
	function hashLen17to32(s) {
	  var len = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : s.length;
	  var mul = k2.add(len * 2);
	  var a = fetch64(s, 0).mul(k1);
	  var b = fetch64(s, 8);
	  var c = fetch64(s, len - 8).mul(mul);
	  var d = fetch64(s, len - 16).mul(k2);
	  return hashLen16(rotate64(a.add(b), 43).add(rotate64(c, 30)).add(d), a.add(rotate64(b.add(k2), 18)).add(c), mul);
	}
	function hashLen33to64(s) {
	  var len = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : s.length;
	  var mul = k2.add(len * 2);
	  var a = fetch64(s, 0).mul(k2);
	  var b = fetch64(s, 8);
	  var c = fetch64(s, len - 8).mul(mul);
	  var d = fetch64(s, len - 16).mul(k2);
	  var y = rotate64(a.add(b), 43).add(rotate64(c, 30)).add(d);
	  var z = hashLen16(y, a.add(rotate64(b.add(k2), 18)).add(c), mul);
	  var e = fetch64(s, 16).mul(mul);
	  var f = fetch64(s, 24);
	  var g = y.add(fetch64(s, len - 32)).mul(mul);
	  var h = z.add(fetch64(s, len - 24)).mul(mul);
	  return hashLen16(rotate64(e.add(f), 43).add(rotate64(g, 30)).add(h), e.add(rotate64(f.add(a), 18)).add(g), mul);
	}
	function fingerPrint64(s) {
	  var len = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : s.length;
	  var seed = Long.fromNumber(81, true);
	  if (len <= 32) {
	    if (len <= 16) {
	      return hashLen0to16(s, len);
	    } else {
	      return hashLen17to32(s, len);
	    }
	  } else if (len <= 64) {
	    return hashLen33to64(s, len);
	  }
	  // For strings over 64 bytes we loop.  Internal state consists of
	  // 56 bytes: v, w, x, y, and z.
	  var x = seed;
	  var y = seed.mul(k1).add(113);
	  var z = shiftMix(y.mul(k2).add(113)).mul(k2);
	  var v = [Long.UZERO, Long.UZERO];
	  var w = [Long.UZERO, Long.UZERO];
	  x = x.mul(k2).add(fetch64(s, 0));
	  var offset = 0;
	  // Set end so that after the loop we have 1 to 64 bytes left to process.
	  var end = (len - 1 >> 6) * 64;
	  var last64 = end + (len - 1 & 63) - 63;
	  do {
	    x = rotate64(x.add(y).add(v[0]).add(fetch64(s, offset + 8)), 37).mul(k1);
	    y = rotate64(y.add(v[1]).add(fetch64(s, offset + 48)), 42).mul(k1);
	    x = x.xor(w[1]);
	    y = y.add(v[0]).add(fetch64(s, offset + 40));
	    z = rotate64(z.add(w[0]), 33).mul(k1);
	    v = weakHashLen32WithSeedsStr(s, offset, v[1].mul(k1), x.add(w[0]));
	    w = weakHashLen32WithSeedsStr(s, offset + 32, z.add(w[1]), y.add(fetch64(s, offset + 16)));
	    var _ref = [x, z];
	    z = _ref[0];
	    x = _ref[1];
	    offset += 64;
	  } while (offset !== end);
	  var mul = k1.add(z.and(0xff).shl(1));
	  // Point to the last 64 bytes of input.
	  offset = last64;
	  w[0] = w[0].add(len - 1 & 63);
	  v[0] = v[0].add(w[0]);
	  w[0] = w[0].add(v[0]);
	  x = rotate64(x.add(y).add(v[0]).add(fetch64(s, offset + 8)), 37).mul(mul);
	  y = rotate64(y.add(v[1]).add(fetch64(s, offset + 48)), 42).mul(mul);
	  x = x.xor(w[1].mul(9));
	  y = y.add(v[0].mul(9).add(fetch64(s, offset + 40)));
	  z = rotate64(z.add(w[0]), 33).mul(mul);
	  v = weakHashLen32WithSeedsStr(s, offset, v[1].mul(mul), x.add(w[0]));
	  w = weakHashLen32WithSeedsStr(s, offset + 32, z.add(w[1]), y.add(fetch64(s, offset + 16)));
	  var _ref2 = [x, z];
	  z = _ref2[0];
	  x = _ref2[1];
	  return hashLen16(hashLen16(v[0], w[0], mul).add(shiftMix(y).mul(k0)).add(z), hashLen16(v[1], w[1], mul).add(x), mul);
	}

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Create typed array for scalar value. Used for storing in `DataStorage`.
	 */
	function createScalarValue(value, dtype) {
	  if (dtype === 'string') {
	    return encodeString(value);
	  }
	  return toTypedArray([value], dtype);
	}
	function noConversionNeeded(a, dtype) {
	  return a instanceof Float32Array && dtype === 'float32' || a instanceof Int32Array && dtype === 'int32' || a instanceof Uint8Array && dtype === 'bool';
	}
	function toTypedArray(a, dtype) {
	  if (dtype === 'string') {
	    throw new Error('Cannot convert a string[] to a TypedArray');
	  }
	  if (Array.isArray(a)) {
	    a = flatten$2(a);
	  }
	  if (env().getBool('DEBUG')) {
	    checkConversionForErrors(a, dtype);
	  }
	  if (noConversionNeeded(a, dtype)) {
	    return a;
	  }
	  if (dtype == null || dtype === 'float32' || dtype === 'complex64') {
	    return new Float32Array(a);
	  } else if (dtype === 'int32') {
	    return new Int32Array(a);
	  } else if (dtype === 'bool') {
	    var bool = new Uint8Array(a.length);
	    for (var i = 0; i < bool.length; ++i) {
	      if (Math.round(a[i]) !== 0) {
	        bool[i] = 1;
	      }
	    }
	    return bool;
	  } else {
	    throw new Error("Unknown data type ".concat(dtype));
	  }
	}
	/**
	 * Returns the current high-resolution time in milliseconds relative to an
	 * arbitrary time in the past. It works across different platforms (node.js,
	 * browsers).
	 *
	 * ```js
	 * console.log(tf.util.now());
	 * ```
	 *
	 * @doc {heading: 'Util', namespace: 'util'}
	 */
	function now() {
	  return env().platform.now();
	}
	/**
	 * Returns a platform-specific implementation of
	 * [`fetch`](https://developer.mozilla.org/en-US/docs/Web/API/Fetch_API).
	 *
	 * If `fetch` is defined on the global object (`window`, `process`, etc.),
	 * `tf.util.fetch` returns that function.
	 *
	 * If not, `tf.util.fetch` returns a platform-specific solution.
	 *
	 * ```js
	 * const resource = await tf.util.fetch('https://cdn.jsdelivr.net/npm/@tensorflow/tfjs');
	 * // handle response
	 * ```
	 *
	 * @doc {heading: 'Util'}
	 */
	function fetch$1(path, requestInits) {
	  return env().platform.fetch(path, requestInits);
	}
	/**
	 * Encodes the provided string into bytes using the provided encoding scheme.
	 *
	 * @param s The string to encode.
	 * @param encoding The encoding scheme. Defaults to utf-8.
	 *
	 * @doc {heading: 'Util'}
	 */
	function encodeString(s) {
	  var encoding = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'utf-8';
	  encoding = encoding || 'utf-8';
	  return env().platform.encode(s, encoding);
	}
	/**
	 * Decodes the provided bytes into a string using the provided encoding scheme.
	 * @param bytes The bytes to decode.
	 *
	 * @param encoding The encoding scheme. Defaults to utf-8.
	 *
	 * @doc {heading: 'Util'}
	 */
	function decodeString(bytes) {
	  var encoding = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'utf-8';
	  encoding = encoding || 'utf-8';
	  return env().platform.decode(bytes, encoding);
	}
	function isTypedArray(a) {
	  // TODO(mattsoulanille): Remove this fallback in 5.0.0
	  if (env().platform.isTypedArray != null) {
	    return env().platform.isTypedArray(a);
	  } else {
	    return isTypedArrayBrowser(a);
	  }
	}
	// NOTE: We explicitly type out what T extends instead of any so that
	// util.flatten on a nested array of number doesn't try to infer T as a
	// number[][], causing us to explicitly type util.flatten<number>().
	/**
	 *  Flattens an arbitrarily nested array.
	 *
	 * ```js
	 * const a = [[1, 2], [3, 4], [5, [6, [7]]]];
	 * const flat = tf.util.flatten(a);
	 * console.log(flat);
	 * ```
	 *
	 *  @param arr The nested array to flatten.
	 *  @param result The destination array which holds the elements.
	 *  @param skipTypedArray If true, avoids flattening the typed arrays. Defaults
	 *      to false.
	 *
	 * @doc {heading: 'Util', namespace: 'util'}
	 */
	function flatten$2(arr) {
	  var result = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
	  var skipTypedArray = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  if (result == null) {
	    result = [];
	  }
	  if (typeof arr === 'boolean' || typeof arr === 'number' || typeof arr === 'string' || isPromise(arr) || arr == null || isTypedArray(arr) && skipTypedArray) {
	    result.push(arr);
	  } else if (Array.isArray(arr) || isTypedArray(arr)) {
	    for (var i = 0; i < arr.length; ++i) {
	      flatten$2(arr[i], result, skipTypedArray);
	    }
	  } else {
	    var maxIndex = -1;
	    for (var _i = 0, _Object$keys = Object.keys(arr); _i < _Object$keys.length; _i++) {
	      var key = _Object$keys[_i];
	      // 0 or positive integer.
	      if (/^([1-9]+[0-9]*|0)$/.test(key)) {
	        maxIndex = Math.max(maxIndex, Number(key));
	      }
	    }
	    for (var _i2 = 0; _i2 <= maxIndex; _i2++) {
	      // tslint:disable-next-line: no-unnecessary-type-assertion
	      flatten$2(arr[_i2], result, skipTypedArray);
	    }
	  }
	  return result;
	}

	var util = {
		__proto__: null,
		arraysEqual: arraysEqual,
		arraysEqualWithNull: arraysEqualWithNull,
		assert: assert$1,
		assertNonNegativeIntegerDimensions: assertNonNegativeIntegerDimensions,
		assertNonNull: assertNonNull,
		assertShapesMatch: assertShapesMatch,
		bytesFromStringArray: bytesFromStringArray,
		bytesPerElement: bytesPerElement,
		checkConversionForErrors: checkConversionForErrors,
		clamp: clamp,
		computeStrides: computeStrides,
		convertBackendValuesAndArrayBuffer: convertBackendValuesAndArrayBuffer,
		createScalarValue: createScalarValue,
		createShuffledIndices: createShuffledIndices,
		decodeString: decodeString,
		distSquared: distSquared,
		encodeString: encodeString,
		fetch: fetch$1,
		fingerPrint64: fingerPrint64,
		flatten: flatten$2,
		getArrayFromDType: getArrayFromDType,
		getTypedArrayFromDType: getTypedArrayFromDType,
		hasEncodingLoss: hasEncodingLoss,
		hexToLong: hexToLong,
		indexToLoc: indexToLoc,
		inferDtype: inferDtype,
		inferFromImplicitShape: inferFromImplicitShape,
		isBoolean: isBoolean,
		isFunction: isFunction,
		isInt: isInt,
		isNumber: isNumber,
		isPromise: isPromise,
		isScalarShape: isScalarShape,
		isString: isString,
		isTypedArray: isTypedArray,
		isValidDtype: isValidDtype,
		locToIndex: locToIndex,
		makeOnesTypedArray: makeOnesTypedArray,
		makeZerosNestedTypedArray: makeZerosNestedTypedArray,
		makeZerosTypedArray: makeZerosTypedArray,
		nearestDivisor: nearestDivisor,
		nearestLargerEven: nearestLargerEven,
		now: now,
		parseAxisParam: parseAxisParam,
		randUniform: randUniform,
		repeatedTry: repeatedTry,
		rightPad: rightPad,
		shuffle: shuffle,
		shuffleCombo: shuffleCombo,
		sizeFromShape: sizeFromShape,
		sizeToSquarishShape: sizeToSquarishShape,
		squeezeShape: squeezeShape,
		sum: sum$4,
		swap: swap,
		tanh: tanh$3,
		toNestedArray: toNestedArray,
		toTypedArray: toTypedArray
	};

	var Profiler = /*#__PURE__*/function () {
	  function Profiler(backendTimer, logger) {
	    _classCallCheck(this, Profiler);
	    this.backendTimer = backendTimer;
	    this.logger = logger;
	    if (logger == null) {
	      this.logger = new Logger();
	    }
	  }
	  _createClass(Profiler, [{
	    key: "profileKernel",
	    value: function profileKernel(kernelName, inputs, f) {
	      var outputs;
	      var holdResultWrapperFn = function holdResultWrapperFn() {
	        outputs = f();
	      };
	      var timer;
	      var start = now();
	      if (this.backendTimer.timerAvailable()) {
	        timer = this.backendTimer.time(holdResultWrapperFn);
	      } else {
	        holdResultWrapperFn();
	        var _iterator = _createForOfIteratorHelper(outputs),
	          _step;
	        try {
	          for (_iterator.s(); !(_step = _iterator.n()).done;) {
	            var output = _step.value;
	            output.dataSync();
	          }
	        } catch (err) {
	          _iterator.e(err);
	        } finally {
	          _iterator.f();
	        }
	        timer = Promise.resolve({
	          kernelMs: now() - start
	        });
	      }
	      if (env().getBool('CHECK_COMPUTATION_FOR_ERRORS')) {
	        var _loop = function _loop() {
	          var output = outputs[i];
	          // Dangling promise here because we don't want to propagate up
	          // asynchronicity.
	          output.data().then(function (tensorVals) {
	            checkComputationForErrors(tensorVals, output.dtype, kernelName);
	          });
	        };
	        for (var i = 0; i < outputs.length; i++) {
	          _loop();
	        }
	      }
	      var kernelProfile = {
	        kernelName: kernelName,
	        outputs: outputs,
	        inputs: inputs,
	        timeMs: timer.then(function (timing) {
	          return timing.kernelMs;
	        }),
	        extraInfo: timer.then(function (timing) {
	          return timing.getExtraProfileInfo != null ? timing.getExtraProfileInfo() : '';
	        })
	      };
	      return kernelProfile;
	    }
	  }, {
	    key: "logKernelProfile",
	    value: function logKernelProfile(kernelProfile) {
	      var _this = this;
	      var kernelName = kernelProfile.kernelName,
	        outputs = kernelProfile.outputs,
	        timeMs = kernelProfile.timeMs,
	        inputs = kernelProfile.inputs,
	        extraInfo = kernelProfile.extraInfo;
	      outputs.forEach(function (result) {
	        Promise.all([result.data(), timeMs, extraInfo]).then(function (valueContainer) {
	          _this.logger.logKernelProfile(kernelName, result, valueContainer[0], valueContainer[1], inputs, valueContainer[2]);
	        });
	      });
	    }
	  }]);
	  return Profiler;
	}();
	function checkComputationForErrors(vals, dtype, kernelName) {
	  if (dtype !== 'float32') {
	    // Only floating point computations will generate NaN values
	    return false;
	  }
	  for (var i = 0; i < vals.length; i++) {
	    var num = vals[i];
	    if (isNaN(num) || !isFinite(num)) {
	      // Throwing custom exception so behavior is testable.
	      console.warn("Found ".concat(num, " in the result of '").concat(kernelName, "'"));
	      return true;
	    }
	  }
	  return false;
	}
	var Logger = /*#__PURE__*/function () {
	  function Logger() {
	    _classCallCheck(this, Logger);
	  }
	  _createClass(Logger, [{
	    key: "logKernelProfile",
	    value: function logKernelProfile(name, result, vals, timeMs, inputs, extraInfo) {
	      var time = typeof timeMs === 'number' ? rightPad("".concat(timeMs, "ms"), 9) : timeMs['error'];
	      var paddedName = rightPad(name, 25);
	      var rank = result.rank;
	      var size = result.size;
	      var shape = rightPad(result.shape.toString(), 14);
	      var inputShapesDescription = '';
	      for (var _name in inputs) {
	        var input = inputs[_name];
	        if (input != null) {
	          // The input might be a non-tensor (e.g HTMLImageElement), in which case
	          // we claim the output shape as input shape.
	          var inputShape = input.shape || result.shape;
	          var inputRank = inputShape.length;
	          inputShapesDescription += "".concat(_name, ": ").concat(inputRank, "D ").concat(inputRank > 0 ? inputShape : '', " ");
	        }
	      }
	      console.log("%c".concat(paddedName, "\t%c").concat(time, "\t%c").concat(rank, "D ").concat(shape, "\t%c").concat(size, "\t%c").concat(inputShapesDescription, "\t%c").concat(extraInfo), 'font-weight:bold', 'color:red', 'color:blue', 'color: orange', 'color: green', 'color: steelblue');
	    }
	  }]);
	  return Logger;
	}();

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes a list of TapeNodes that connect x to y, filtering everything else
	 * out and preserving the order of the original tape elements.
	 *
	 * @param tape The tape elements to filter.
	 * @param xs The input Tensors.
	 * @param y The output Tensor.
	 */
	function getFilteredNodesXToY(tape, xs, y) {
	  // Forward pass to compute all the nodes and Tensors that are transitively a
	  // function of x.
	  var tensorsFromX = {};
	  var nodesFromX = {};
	  for (var i = 0; i < xs.length; i++) {
	    tensorsFromX[xs[i].id] = true;
	  }
	  for (var _i = 0; _i < tape.length; _i++) {
	    var node = tape[_i];
	    var nodeInputs = node.inputs;
	    for (var inputName in nodeInputs) {
	      var input = nodeInputs[inputName];
	      var anyInputFromX = false;
	      for (var j = 0; j < xs.length; j++) {
	        if (tensorsFromX[input.id]) {
	          node.outputs.forEach(function (output) {
	            return tensorsFromX[output.id] = true;
	          });
	          anyInputFromX = true;
	          nodesFromX[node.id] = true;
	          break;
	        }
	      }
	      if (anyInputFromX) {
	        break;
	      }
	    }
	  }
	  // Backward pass to find all of the nodes and Tensors that lead to y.
	  var tensorsLeadToY = {};
	  tensorsLeadToY[y.id] = true;
	  var nodesToY = {};
	  for (var _i2 = tape.length - 1; _i2 >= 0; _i2--) {
	    var _node = tape[_i2];
	    var _nodeInputs = _node.inputs;
	    // If any of the outputs lead to y, mark all of the inputs as leading to y.
	    for (var _j = 0; _j < _node.outputs.length; _j++) {
	      if (tensorsLeadToY[_node.outputs[_j].id]) {
	        for (var _inputName in _nodeInputs) {
	          tensorsLeadToY[_nodeInputs[_inputName].id] = true;
	          nodesToY[_node.id] = true;
	        }
	        break;
	      }
	    }
	  }
	  // Return the paths that come from x and lead to y.
	  var filteredTape = [];
	  for (var _i3 = 0; _i3 < tape.length; _i3++) {
	    var _node2 = tape[_i3];
	    if (nodesFromX[_node2.id] && nodesToY[_node2.id]) {
	      // Prune the inputs from the node that aren't a function of x.
	      var prunedInputs = {};
	      for (var _inputName2 in _node2.inputs) {
	        var nodeInput = _node2.inputs[_inputName2];
	        if (tensorsFromX[nodeInput.id]) {
	          prunedInputs[_inputName2] = nodeInput;
	        }
	      }
	      // Copy the node and overwrite inputsAndArgs to the pruned version.
	      var prunedNode = Object.assign({}, _node2);
	      prunedNode.inputs = prunedInputs;
	      prunedNode.outputs = _node2.outputs;
	      filteredTape.push(prunedNode);
	    }
	  }
	  return filteredTape;
	}
	/**
	 * Backpropagate gradients through the filtered TapeNodes.
	 *
	 * @param tensorAccumulatedGradientMap A map of Tensor to its gradient. This map
	 * is mutated by this method.
	 * @param filteredTape The filtered TapeNodes to backprop through.
	 */
	function backpropagateGradients(tensorAccumulatedGradientMap, filteredTape, tidy, add) {
	  var _loop = function _loop() {
	    var node = filteredTape[i];
	    var dys = [];
	    node.outputs.forEach(function (o) {
	      var gradTensor = tensorAccumulatedGradientMap[o.id];
	      if (gradTensor != null) {
	        dys.push(gradTensor);
	      } else {
	        // This particular output is not in the back-propagation subgraph, so it
	        // does not affect the final output, thus we put null for its dy.
	        dys.push(null);
	      }
	    });
	    if (node.gradient == null) {
	      throw new Error("Cannot compute gradient: gradient function not found " + "for ".concat(node.kernelName, "."));
	    }
	    // Backprop dy through this node and accumulate gradients over the inputs.
	    var inputGradients = node.gradient(dys);
	    var _loop2 = function _loop2(inputName) {
	      if (!(inputName in inputGradients)) {
	        throw new Error("Cannot backprop through input ".concat(inputName, ". ") + "Available gradients found: ".concat(Object.keys(inputGradients), "."));
	      }
	      // Call the gradient function.
	      var dx = tidy(function () {
	        return inputGradients[inputName]();
	      });
	      if (dx.dtype !== 'float32') {
	        throw new Error("Error in gradient for op ".concat(node.kernelName, ". The gradient of input ") + "".concat(inputName, " must have 'float32' dtype, but has '").concat(dx.dtype, "'"));
	      }
	      var x = node.inputs[inputName];
	      if (!arraysEqual(dx.shape, x.shape)) {
	        throw new Error("Error in gradient for op ".concat(node.kernelName, ". The gradient of input ") + "'".concat(inputName, "' has shape '").concat(dx.shape, "', which does not match ") + "the shape of the input '".concat(x.shape, "'"));
	      }
	      if (tensorAccumulatedGradientMap[x.id] == null) {
	        tensorAccumulatedGradientMap[x.id] = dx;
	      } else {
	        var curGradient = tensorAccumulatedGradientMap[x.id];
	        tensorAccumulatedGradientMap[x.id] = add(curGradient, dx);
	        curGradient.dispose();
	      }
	    };
	    for (var inputName in node.inputs) {
	      _loop2(inputName);
	    }
	  };
	  // Walk the tape backward and keep a map of Tensor to its gradient.
	  for (var i = filteredTape.length - 1; i >= 0; i--) {
	    _loop();
	  }
	}

	// Maximum number of values before we decide to show ellipsis.
	var FORMAT_LIMIT_NUM_VALS = 20;
	// Number of first and last values to show when displaying a, b,...,y, z.
	var FORMAT_NUM_FIRST_LAST_VALS = 3;
	// Number of significant digits to show.
	var FORMAT_NUM_SIG_DIGITS = 7;
	function tensorToString(vals, shape, dtype, verbose) {
	  var strides = computeStrides(shape);
	  var padPerCol = computeMaxSizePerColumn(vals, shape, dtype, strides);
	  var rank = shape.length;
	  var valsLines = subTensorToString(vals, shape, dtype, strides, padPerCol);
	  var lines = ['Tensor'];
	  if (verbose) {
	    lines.push("  dtype: ".concat(dtype));
	    lines.push("  rank: ".concat(rank));
	    lines.push("  shape: [".concat(shape, "]"));
	    lines.push("  values:");
	  }
	  lines.push(valsLines.map(function (l) {
	    return '    ' + l;
	  }).join('\n'));
	  return lines.join('\n');
	}
	function computeMaxSizePerColumn(vals, shape, dtype, strides) {
	  var n = sizeFromShape(shape);
	  var numCols = strides[strides.length - 1];
	  var padPerCol = new Array(numCols).fill(0);
	  var rank = shape.length;
	  var valuesOrTuples = dtype === 'complex64' ? createComplexTuples(vals) : vals;
	  if (rank > 1) {
	    for (var row = 0; row < n / numCols; row++) {
	      var offset = row * numCols;
	      for (var j = 0; j < numCols; j++) {
	        padPerCol[j] = Math.max(padPerCol[j], valToString(valuesOrTuples[offset + j], 0, dtype).length);
	      }
	    }
	  }
	  return padPerCol;
	}
	function valToString(val, pad, dtype) {
	  var valStr;
	  if (Array.isArray(val)) {
	    valStr = "".concat(parseFloat(val[0].toFixed(FORMAT_NUM_SIG_DIGITS)), " + ") + "".concat(parseFloat(val[1].toFixed(FORMAT_NUM_SIG_DIGITS)), "j");
	  } else if (isString(val)) {
	    valStr = "'".concat(val, "'");
	  } else if (dtype === 'bool') {
	    valStr = boolNumToString(val);
	  } else {
	    valStr = parseFloat(val.toFixed(FORMAT_NUM_SIG_DIGITS)).toString();
	  }
	  return rightPad(valStr, pad);
	}
	function boolNumToString(v) {
	  return v === 0 ? 'false' : 'true';
	}
	function subTensorToString(vals, shape, dtype, strides, padPerCol) {
	  var isLast = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : true;
	  var storagePerElement = dtype === 'complex64' ? 2 : 1;
	  var size = shape[0];
	  var rank = shape.length;
	  if (rank === 0) {
	    if (dtype === 'complex64') {
	      var complexTuple = createComplexTuples(vals);
	      return [valToString(complexTuple[0], 0, dtype)];
	    }
	    if (dtype === 'bool') {
	      return [boolNumToString(vals[0])];
	    }
	    return [vals[0].toString()];
	  }
	  if (rank === 1) {
	    if (size > FORMAT_LIMIT_NUM_VALS) {
	      var firstValsSize = FORMAT_NUM_FIRST_LAST_VALS * storagePerElement;
	      var firstVals = Array.from(vals.slice(0, firstValsSize));
	      var lastVals = Array.from(vals.slice((size - FORMAT_NUM_FIRST_LAST_VALS) * storagePerElement, size * storagePerElement));
	      if (dtype === 'complex64') {
	        firstVals = createComplexTuples(firstVals);
	        lastVals = createComplexTuples(lastVals);
	      }
	      return ['[' + firstVals.map(function (x, i) {
	        return valToString(x, padPerCol[i], dtype);
	      }).join(', ') + ', ..., ' + lastVals.map(function (x, i) {
	        return valToString(x, padPerCol[size - FORMAT_NUM_FIRST_LAST_VALS + i], dtype);
	      }).join(', ') + ']'];
	    }
	    var displayVals = dtype === 'complex64' ? createComplexTuples(vals) : Array.from(vals);
	    return ['[' + displayVals.map(function (x, i) {
	      return valToString(x, padPerCol[i], dtype);
	    }).join(', ') + ']'];
	  }
	  // The array is rank 2 or more.
	  var subshape = shape.slice(1);
	  var substrides = strides.slice(1);
	  var stride = strides[0] * storagePerElement;
	  var lines = [];
	  if (size > FORMAT_LIMIT_NUM_VALS) {
	    for (var i = 0; i < FORMAT_NUM_FIRST_LAST_VALS; i++) {
	      var start = i * stride;
	      var end = start + stride;
	      lines.push.apply(lines, _toConsumableArray(subTensorToString(vals.slice(start, end), subshape, dtype, substrides, padPerCol, false /* isLast */)));
	    }

	    lines.push('...');
	    for (var _i = size - FORMAT_NUM_FIRST_LAST_VALS; _i < size; _i++) {
	      var _start = _i * stride;
	      var _end = _start + stride;
	      lines.push.apply(lines, _toConsumableArray(subTensorToString(vals.slice(_start, _end), subshape, dtype, substrides, padPerCol, _i === size - 1 /* isLast */)));
	    }
	  } else {
	    for (var _i2 = 0; _i2 < size; _i2++) {
	      var _start2 = _i2 * stride;
	      var _end2 = _start2 + stride;
	      lines.push.apply(lines, _toConsumableArray(subTensorToString(vals.slice(_start2, _end2), subshape, dtype, substrides, padPerCol, _i2 === size - 1 /* isLast */)));
	    }
	  }

	  var sep = rank === 2 ? ',' : '';
	  lines[0] = '[' + (size > 0 ? lines[0] + sep : '');
	  for (var _i3 = 1; _i3 < lines.length - 1; _i3++) {
	    lines[_i3] = ' ' + lines[_i3] + sep;
	  }
	  var newLineSep = ',\n';
	  for (var _i4 = 2; _i4 < rank; _i4++) {
	    newLineSep += '\n';
	  }
	  lines[lines.length - 1] = ' ' + lines[lines.length - 1] + ']' + (isLast ? '' : newLineSep);
	  return lines;
	}
	function createComplexTuples(vals) {
	  var complexTuples = [];
	  for (var i = 0; i < vals.length; i += 2) {
	    complexTuples.push([vals[i], vals[i + 1]]);
	  }
	  return complexTuples;
	}

	/**
	 * A mutable object, similar to `tf.Tensor`, that allows users to set values
	 * at locations before converting to an immutable `tf.Tensor`.
	 *
	 * See `tf.buffer` for creating a tensor buffer.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Classes'}
	 */
	var TensorBuffer = /*#__PURE__*/function () {
	  function TensorBuffer(shape, dtype, values) {
	    var _this = this;
	    _classCallCheck(this, TensorBuffer);
	    this.dtype = dtype;
	    this.shape = shape.slice();
	    this.size = sizeFromShape(shape);
	    if (values != null) {
	      var n = values.length;
	      assert$1(n === this.size, function () {
	        return "Length of values '".concat(n, "' does not match the size ") + "inferred by the shape '".concat(_this.size, "'.");
	      });
	    }
	    if (dtype === 'complex64') {
	      throw new Error("complex64 dtype TensorBuffers are not supported. Please create " + "a TensorBuffer for the real and imaginary parts separately and " + "call tf.complex(real, imag).");
	    }
	    this.values = values || getArrayFromDType(dtype, this.size);
	    this.strides = computeStrides(shape);
	  }
	  /**
	   * Sets a value in the buffer at a given location.
	   *
	   * @param value The value to set.
	   * @param locs  The location indices.
	   *
	   * @doc {heading: 'Tensors', subheading: 'Creation'}
	   */
	  _createClass(TensorBuffer, [{
	    key: "set",
	    value: function set(value) {
	      var _this2 = this;
	      for (var _len = arguments.length, locs = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
	        locs[_key - 1] = arguments[_key];
	      }
	      if (locs.length === 0) {
	        locs = [0];
	      }
	      assert$1(locs.length === this.rank, function () {
	        return "The number of provided coordinates (".concat(locs.length, ") must ") + "match the rank (".concat(_this2.rank, ")");
	      });
	      var index = this.locToIndex(locs);
	      this.values[index] = value;
	    }
	    /**
	     * Returns the value in the buffer at the provided location.
	     *
	     * @param locs The location indices.
	     *
	     * @doc {heading: 'Tensors', subheading: 'Creation'}
	     */
	  }, {
	    key: "get",
	    value: function get() {
	      for (var _len2 = arguments.length, locs = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
	        locs[_key2] = arguments[_key2];
	      }
	      if (locs.length === 0) {
	        locs = [0];
	      }
	      var i = 0;
	      for (var _i = 0, _locs = locs; _i < _locs.length; _i++) {
	        var loc = _locs[_i];
	        if (loc < 0 || loc >= this.shape[i]) {
	          var msg = "Requested out of range element at ".concat(locs, ". ") + "  Buffer shape=".concat(this.shape);
	          throw new Error(msg);
	        }
	        i++;
	      }
	      var index = locs[locs.length - 1];
	      for (var _i2 = 0; _i2 < locs.length - 1; ++_i2) {
	        index += this.strides[_i2] * locs[_i2];
	      }
	      return this.values[index];
	    }
	  }, {
	    key: "locToIndex",
	    value: function locToIndex(locs) {
	      if (this.rank === 0) {
	        return 0;
	      } else if (this.rank === 1) {
	        return locs[0];
	      }
	      var index = locs[locs.length - 1];
	      for (var i = 0; i < locs.length - 1; ++i) {
	        index += this.strides[i] * locs[i];
	      }
	      return index;
	    }
	  }, {
	    key: "indexToLoc",
	    value: function indexToLoc(index) {
	      if (this.rank === 0) {
	        return [];
	      } else if (this.rank === 1) {
	        return [index];
	      }
	      var locs = new Array(this.shape.length);
	      for (var i = 0; i < locs.length - 1; ++i) {
	        locs[i] = Math.floor(index / this.strides[i]);
	        index -= locs[i] * this.strides[i];
	      }
	      locs[locs.length - 1] = index;
	      return locs;
	    }
	  }, {
	    key: "rank",
	    get: function get() {
	      return this.shape.length;
	    }
	    /**
	     * Creates an immutable `tf.Tensor` object from the buffer.
	     *
	     * @doc {heading: 'Tensors', subheading: 'Creation'}
	     */
	  }, {
	    key: "toTensor",
	    value: function toTensor() {
	      return trackerFn().makeTensor(this.values, this.shape, this.dtype);
	    }
	  }]);
	  return TensorBuffer;
	}();
	// For tracking tensor creation and disposal.
	var trackerFn = null;
	// Used by chaining methods to call into ops.
	var opHandler$1 = null;
	// Used to warn about deprecated methods.
	var deprecationWarningFn = null;
	// This here so that we can use this method on dev branches and keep the
	// functionality at master.
	// tslint:disable-next-line:no-unused-expression
	[deprecationWarningFn];
	/**
	 * An external consumer can register itself as the tensor tracker. This way
	 * the Tensor class can notify the tracker for every tensor created and
	 * disposed.
	 */
	function setTensorTracker(fn) {
	  trackerFn = fn;
	}
	/**
	 * An external consumer can register itself as the op handler. This way the
	 * Tensor class can have chaining methods that call into ops via the op
	 * handler.
	 */
	function setOpHandler(handler) {
	  opHandler$1 = handler;
	}
	/**
	 * Sets the deprecation warning function to be used by this file. This way the
	 * Tensor class can be a leaf but still use the environment.
	 */
	function setDeprecationWarningFn(fn) {
	  deprecationWarningFn = fn;
	}
	/**
	 * A `tf.Tensor` object represents an immutable, multidimensional array of
	 * numbers that has a shape and a data type.
	 *
	 * For performance reasons, functions that create tensors do not necessarily
	 * perform a copy of the data passed to them (e.g. if the data is passed as a
	 * `Float32Array`), and changes to the data will change the tensor. This is not
	 * a feature and is not supported. To avoid this behavior, use the tensor before
	 * changing the input data or create a copy with `copy = tf.add(yourTensor, 0)`.
	 *
	 * See `tf.tensor` for details on how to create a `tf.Tensor`.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Classes'}
	 */
	var Tensor = /*#__PURE__*/function () {
	  function Tensor(shape, dtype, dataId, id) {
	    _classCallCheck(this, Tensor);
	    /** Whether this tensor has been globally kept. */
	    this.kept = false;
	    this.isDisposedInternal = false;
	    this.shape = shape.slice();
	    this.dtype = dtype || 'float32';
	    this.size = sizeFromShape(shape);
	    this.strides = computeStrides(shape);
	    this.dataId = dataId;
	    this.id = id;
	    this.rankType = this.rank < 5 ? this.rank.toString() : 'higher';
	  }
	  _createClass(Tensor, [{
	    key: "rank",
	    get: function get() {
	      return this.shape.length;
	    }
	    /**
	     * Returns a promise of `tf.TensorBuffer` that holds the underlying data.
	     *
	     * @doc {heading: 'Tensors', subheading: 'Classes'}
	     */
	  }, {
	    key: "buffer",
	    value: function () {
	      var _buffer = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        var vals;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              _context.next = 2;
	              return this.data();
	            case 2:
	              vals = _context.sent;
	              return _context.abrupt("return", opHandler$1.buffer(this.shape, this.dtype, vals));
	            case 4:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function buffer() {
	        return _buffer.apply(this, arguments);
	      }
	      return buffer;
	    }()
	    /**
	     * Returns a `tf.TensorBuffer` that holds the underlying data.
	     * @doc {heading: 'Tensors', subheading: 'Classes'}
	     */
	  }, {
	    key: "bufferSync",
	    value: function bufferSync() {
	      return opHandler$1.buffer(this.shape, this.dtype, this.dataSync());
	    }
	    /**
	     * Returns the tensor data as a nested array. The transfer of data is done
	     * asynchronously.
	     *
	     * @doc {heading: 'Tensors', subheading: 'Classes'}
	     */
	  }, {
	    key: "array",
	    value: function () {
	      var _array = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2() {
	        var vals;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              _context2.next = 2;
	              return this.data();
	            case 2:
	              vals = _context2.sent;
	              return _context2.abrupt("return", toNestedArray(this.shape, vals, this.dtype === 'complex64'));
	            case 4:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function array() {
	        return _array.apply(this, arguments);
	      }
	      return array;
	    }()
	    /**
	     * Returns the tensor data as a nested array. The transfer of data is done
	     * synchronously.
	     *
	     * @doc {heading: 'Tensors', subheading: 'Classes'}
	     */
	  }, {
	    key: "arraySync",
	    value: function arraySync() {
	      return toNestedArray(this.shape, this.dataSync(), this.dtype === 'complex64');
	    }
	    /**
	     * Asynchronously downloads the values from the `tf.Tensor`. Returns a
	     * promise of `TypedArray` that resolves when the computation has finished.
	     *
	     * @doc {heading: 'Tensors', subheading: 'Classes'}
	     */
	  }, {
	    key: "data",
	    value: function () {
	      var _data = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3() {
	        var data, bytes;
	        return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	          while (1) switch (_context3.prev = _context3.next) {
	            case 0:
	              this.throwIfDisposed();
	              data = trackerFn().read(this.dataId);
	              if (!(this.dtype === 'string')) {
	                _context3.next = 13;
	                break;
	              }
	              _context3.next = 5;
	              return data;
	            case 5:
	              bytes = _context3.sent;
	              _context3.prev = 6;
	              return _context3.abrupt("return", bytes.map(function (b) {
	                return decodeString(b);
	              }));
	            case 10:
	              _context3.prev = 10;
	              _context3.t0 = _context3["catch"](6);
	              throw new Error('Failed to decode the string bytes into utf-8. ' + 'To get the original bytes, call tensor.bytes().');
	            case 13:
	              return _context3.abrupt("return", data);
	            case 14:
	            case "end":
	              return _context3.stop();
	          }
	        }, _callee3, this, [[6, 10]]);
	      }));
	      function data() {
	        return _data.apply(this, arguments);
	      }
	      return data;
	    }()
	    /**
	     * Copy the tensor's data to a new GPU resource. Comparing to the `dataSync()`
	     * and `data()`, this method prevents data from being downloaded to CPU.
	     *
	     * For WebGL backend, the data will be stored on a densely packed texture.
	     * This means that the texture will use the RGBA channels to store value.
	     *
	     * For WebGPU backend, the data will be stored on a buffer. There is no
	     * parameter, so can not use a user-defined size to create the buffer.
	     *
	     * @param options:
	     *     For WebGL,
	     *         - customTexShape: Optional. If set, will use the user defined
	     *     texture shape to create the texture.
	     *
	     * @returns For WebGL backend, a GPUData contains the new texture and
	     *     its information.
	     *     {
	     *        tensorRef: The tensor that is associated with this texture,
	     *        texture: WebGLTexture,
	     *        texShape: [number, number] // [height, width]
	     *     }
	     *
	     *     For WebGPU backend, a GPUData contains the new buffer.
	     *     {
	     *        tensorRef: The tensor that is associated with this buffer,
	     *        buffer: GPUBuffer,
	     *     }
	     *
	     *     Remember to dispose the GPUData after it is used by
	     *     `res.tensorRef.dispose()`.
	     *
	     * @doc {heading: 'Tensors', subheading: 'Classes'}
	     */
	  }, {
	    key: "dataToGPU",
	    value: function dataToGPU(options) {
	      this.throwIfDisposed();
	      return trackerFn().readToGPU(this.dataId, options);
	    }
	    /**
	     * Synchronously downloads the values from the `tf.Tensor`. This blocks the
	     * UI thread until the values are ready, which can cause performance issues.
	     *
	     * @doc {heading: 'Tensors', subheading: 'Classes'}
	     */
	  }, {
	    key: "dataSync",
	    value: function dataSync() {
	      this.throwIfDisposed();
	      var data = trackerFn().readSync(this.dataId);
	      if (this.dtype === 'string') {
	        try {
	          return data.map(function (b) {
	            return decodeString(b);
	          });
	        } catch (_a) {
	          throw new Error('Failed to decode the string bytes into utf-8. ' + 'To get the original bytes, call tensor.bytes().');
	        }
	      }
	      return data;
	    }
	    /** Returns the underlying bytes of the tensor's data. */
	  }, {
	    key: "bytes",
	    value: function () {
	      var _bytes = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4() {
	        var data;
	        return _regeneratorRuntime().wrap(function _callee4$(_context4) {
	          while (1) switch (_context4.prev = _context4.next) {
	            case 0:
	              this.throwIfDisposed();
	              _context4.next = 3;
	              return trackerFn().read(this.dataId);
	            case 3:
	              data = _context4.sent;
	              if (!(this.dtype === 'string')) {
	                _context4.next = 8;
	                break;
	              }
	              return _context4.abrupt("return", data);
	            case 8:
	              return _context4.abrupt("return", new Uint8Array(data.buffer));
	            case 9:
	            case "end":
	              return _context4.stop();
	          }
	        }, _callee4, this);
	      }));
	      function bytes() {
	        return _bytes.apply(this, arguments);
	      }
	      return bytes;
	    }()
	    /**
	     * Disposes `tf.Tensor` from memory.
	     *
	     * @doc {heading: 'Tensors', subheading: 'Classes'}
	     */
	  }, {
	    key: "dispose",
	    value: function dispose() {
	      if (this.isDisposed) {
	        return;
	      }
	      if (this.kerasMask) {
	        this.kerasMask.dispose();
	      }
	      trackerFn().disposeTensor(this);
	      this.isDisposedInternal = true;
	    }
	  }, {
	    key: "isDisposed",
	    get: function get() {
	      return this.isDisposedInternal;
	    }
	  }, {
	    key: "throwIfDisposed",
	    value: function throwIfDisposed() {
	      if (this.isDisposed) {
	        throw new Error("Tensor is disposed.");
	      }
	    }
	    /**
	     * Prints the `tf.Tensor`. See `tf.print` for details.
	     *
	     * @param verbose Whether to print verbose information about the tensor,
	     *    including dtype and size.
	     *
	     * @doc {heading: 'Tensors', subheading: 'Classes'}
	     */
	  }, {
	    key: "print",
	    value: function print() {
	      var verbose = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
	      return opHandler$1.print(this, verbose);
	    }
	    /**
	     * Returns a copy of the tensor. See `tf.clone` for details.
	     * @doc {heading: 'Tensors', subheading: 'Classes'}
	     */
	  }, {
	    key: "clone",
	    value: function clone() {
	      this.throwIfDisposed();
	      return opHandler$1.clone(this);
	    }
	    /**
	     * Returns a human-readable description of the tensor. Useful for logging.
	     *
	     * @doc {heading: 'Tensors', subheading: 'Classes'}
	     */
	  }, {
	    key: "toString",
	    value: function toString() {
	      var verbose = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
	      var vals = this.dataSync();
	      return tensorToString(vals, this.shape, this.dtype, verbose);
	    }
	  }, {
	    key: "cast",
	    value: function cast(dtype) {
	      this.throwIfDisposed();
	      return opHandler$1.cast(this, dtype);
	    }
	  }, {
	    key: "variable",
	    value: function variable() {
	      var trainable = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
	      var name = arguments.length > 1 ? arguments[1] : undefined;
	      var dtype = arguments.length > 2 ? arguments[2] : undefined;
	      this.throwIfDisposed();
	      return trackerFn().makeVariable(this, trainable, name, dtype);
	    }
	  }]);
	  return Tensor;
	}();
	Object.defineProperty(Tensor, Symbol.hasInstance, {
	  value: function value(instance) {
	    // Implementation note: we should use properties of the object that will be
	    // defined before the constructor body has finished executing (methods).
	    // This is because when this code is transpiled by babel, babel will call
	    // classCallCheck before the constructor body is run.
	    // See https://github.com/tensorflow/tfjs/issues/3384 for backstory.
	    return !!instance && instance.data != null && instance.dataSync != null && instance.throwIfDisposed != null;
	  }
	});
	function getGlobalTensorClass() {
	  // Use getGlobal so that we can augment the Tensor class across package
	  // boundaries because the node resolution alg may result in different modules
	  // being returned for this file depending on the path they are loaded from.
	  return getGlobal('Tensor', function () {
	    return Tensor;
	  });
	}
	// Global side effect. Cache global reference to Tensor class
	getGlobalTensorClass();
	/**
	 * A mutable `tf.Tensor`, useful for persisting state, e.g. for training.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Classes'}
	 */
	var Variable = /*#__PURE__*/function (_Tensor) {
	  _inherits(Variable, _Tensor);
	  var _super = _createSuper(Variable);
	  function Variable(initialValue, trainable, name, tensorId) {
	    var _this3;
	    _classCallCheck(this, Variable);
	    _this3 = _super.call(this, initialValue.shape, initialValue.dtype, initialValue.dataId, tensorId);
	    _this3.trainable = trainable;
	    _this3.name = name;
	    return _this3;
	  }
	  /**
	   * Assign a new `tf.Tensor` to this variable. The new `tf.Tensor` must have
	   * the same shape and dtype as the old `tf.Tensor`.
	   *
	   * @param newValue New tensor to be assigned to this variable.
	   *
	   * @doc {heading: 'Tensors', subheading: 'Classes'}
	   */
	  _createClass(Variable, [{
	    key: "assign",
	    value: function assign(newValue) {
	      if (newValue.dtype !== this.dtype) {
	        throw new Error("dtype of the new value (".concat(newValue.dtype, ") and ") + "previous value (".concat(this.dtype, ") must match"));
	      }
	      if (!arraysEqual(newValue.shape, this.shape)) {
	        throw new Error("shape of the new value (".concat(newValue.shape, ") and ") + "previous value (".concat(this.shape, ") must match"));
	      }
	      trackerFn().disposeTensor(this);
	      this.dataId = newValue.dataId;
	      trackerFn().incRef(this, null /* backend */);
	    }
	  }, {
	    key: "dispose",
	    value: function dispose() {
	      trackerFn().disposeVariable(this);
	      this.isDisposedInternal = true;
	    }
	  }]);
	  return Variable;
	}(Tensor);
	Object.defineProperty(Variable, Symbol.hasInstance, {
	  value: function value(instance) {
	    return instance instanceof Tensor && instance.assign != null && instance.assign instanceof Function;
	  }
	});

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	exports.Rank = void 0;
	(function (Rank) {
	  Rank["R0"] = "R0";
	  Rank["R1"] = "R1";
	  Rank["R2"] = "R2";
	  Rank["R3"] = "R3";
	  Rank["R4"] = "R4";
	  Rank["R5"] = "R5";
	  Rank["R6"] = "R6";
	})(exports.Rank || (exports.Rank = {}));
	// Looks for upcasting types. Used, for example, in operations with mixed dtype
	// inputs.
	var UpcastInt32AndMap;
	(function (UpcastInt32AndMap) {
	  UpcastInt32AndMap["float32"] = "float32";
	  UpcastInt32AndMap["int32"] = "int32";
	  UpcastInt32AndMap["bool"] = "int32";
	  UpcastInt32AndMap["complex64"] = "complex64";
	})(UpcastInt32AndMap || (UpcastInt32AndMap = {}));
	var UpcastBoolAndMap;
	(function (UpcastBoolAndMap) {
	  UpcastBoolAndMap["float32"] = "float32";
	  UpcastBoolAndMap["int32"] = "int32";
	  UpcastBoolAndMap["bool"] = "bool";
	  UpcastBoolAndMap["complex64"] = "complex64";
	})(UpcastBoolAndMap || (UpcastBoolAndMap = {}));
	var UpcastFloat32AndMap;
	(function (UpcastFloat32AndMap) {
	  UpcastFloat32AndMap["float32"] = "float32";
	  UpcastFloat32AndMap["int32"] = "float32";
	  UpcastFloat32AndMap["bool"] = "float32";
	  UpcastFloat32AndMap["complex64"] = "complex64";
	})(UpcastFloat32AndMap || (UpcastFloat32AndMap = {}));
	var UpcastComplex64AndMap;
	(function (UpcastComplex64AndMap) {
	  UpcastComplex64AndMap["float32"] = "complex64";
	  UpcastComplex64AndMap["int32"] = "complex64";
	  UpcastComplex64AndMap["bool"] = "complex64";
	  UpcastComplex64AndMap["complex64"] = "complex64";
	})(UpcastComplex64AndMap || (UpcastComplex64AndMap = {}));
	var upcastTypeMap = {
	  'float32': UpcastFloat32AndMap,
	  'int32': UpcastInt32AndMap,
	  'bool': UpcastBoolAndMap,
	  'complex64': UpcastComplex64AndMap
	};
	function upcastType(typeA, typeB) {
	  if (typeA === 'string' || typeB === 'string') {
	    if (typeA === 'string' && typeB === 'string') {
	      return 'string';
	    }
	    throw new Error("Can not upcast ".concat(typeA, " with ").concat(typeB));
	  }
	  return upcastTypeMap[typeA][typeB];
	}
	/** Returns the output type after summation. */
	function sumOutType(type) {
	  return upcastType(type, 'int32');
	}
	function isWebGLData(values) {
	  return values != null && _typeof(values) === 'object' && 'texture' in values && values.texture instanceof WebGLTexture;
	}
	function isWebGPUData(values) {
	  return typeof GPUBuffer !== 'undefined' && values != null && _typeof(values) === 'object' && 'buffer' in values && values.buffer instanceof GPUBuffer;
	}

	function makeTypesMatch(a, b) {
	  if (a.dtype === b.dtype) {
	    return [a, b];
	  }
	  var dtype = upcastType(a.dtype, b.dtype);
	  return [a.cast(dtype), b.cast(dtype)];
	}
	function assertTypesMatch(a, b) {
	  assert$1(a.dtype === b.dtype, function () {
	    return "The dtypes of the first(".concat(a.dtype, ") and") + " second(".concat(b.dtype, ") input must match");
	  });
	}
	function isTensorInList(tensor, tensorList) {
	  return tensorList.some(function (x) {
	    return x.id === tensor.id;
	  });
	}
	/**
	 * Extracts any `Tensor`s found within the provided object.
	 *
	 * @param container an object that may be a `Tensor` or may directly contain
	 *   `Tensor`s, such as a `Tensor[]` or `{key: Tensor, ...}`. In general it
	 *   is safe to pass any object here, except that `Promise`s are not
	 *   supported.
	 * @returns An array of `Tensors` found within the passed object. If the
	 *   argument is simply a `Tensor', a list containing that `Tensor` is
	 *   returned. If the object is not a `Tensor` or does not
	 *   contain `Tensors`, an empty list is returned.
	 */
	function getTensorsInContainer(result) {
	  var list = [];
	  var seen = new Set();
	  walkTensorContainer(result, list, seen);
	  return list;
	}
	function walkTensorContainer(container, list, seen) {
	  if (container == null) {
	    return;
	  }
	  if (container instanceof Tensor) {
	    list.push(container);
	    return;
	  }
	  if (!isIterable$1(container)) {
	    return;
	  }
	  // Iteration over keys works also for arrays.
	  var iterable = container;
	  for (var k in iterable) {
	    var val = iterable[k];
	    if (!seen.has(val)) {
	      seen.add(val);
	      walkTensorContainer(val, list, seen);
	    }
	  }
	}
	// tslint:disable-next-line:no-any
	function isIterable$1(obj) {
	  return Array.isArray(obj) || _typeof(obj) === 'object';
	}

	var tensor_util = {
		__proto__: null,
		assertTypesMatch: assertTypesMatch,
		getTensorsInContainer: getTensorsInContainer,
		isTensorInList: isTensorInList,
		makeTypesMatch: makeTypesMatch
	};

	function isRegisteredKernelInvocation(kernelInvocation) {
	  return kernelInvocation.kernelName != null;
	}
	var EngineState = /*#__PURE__*/function () {
	  function EngineState() {
	    _classCallCheck(this, EngineState);
	    // Public since optimizers will use it.
	    this.registeredVariables = {};
	    this.nextTapeNodeId = 0;
	    this.numBytes = 0;
	    this.numTensors = 0;
	    this.numStringTensors = 0;
	    this.numDataBuffers = 0;
	    // Number of nested tf.grad() statements when computing higher-order
	    // gradients. E.g. `1` for first-order gradients and `2` for second-order
	    // gradients. Used to track if the tape should be removed after a backprop.
	    this.gradientDepth = 0;
	    // Number of nested kernel calls. When kernel depth is greater than 1, we turn
	    // off the tape.
	    this.kernelDepth = 0;
	    this.scopeStack = [];
	    /**
	     * Keeps track of the number of data moves during a kernel execution. We
	     * maintain a stack since kernels can call other kernels, recursively.
	     */
	    this.numDataMovesStack = [];
	    this.nextScopeId = 0;
	    this.tensorInfo = new WeakMap();
	    this.profiling = false;
	    this.activeProfile = {
	      newBytes: 0,
	      newTensors: 0,
	      peakBytes: 0,
	      kernels: [],
	      result: null,
	      get kernelNames() {
	        return Array.from(new Set(this.kernels.map(function (k) {
	          return k.name;
	        })));
	      }
	    };
	  }
	  _createClass(EngineState, [{
	    key: "dispose",
	    value: function dispose() {
	      for (var variableName in this.registeredVariables) {
	        this.registeredVariables[variableName].dispose();
	      }
	    }
	  }]);
	  return EngineState;
	}();
	var Engine = /*#__PURE__*/function () {
	  function Engine(ENV) {
	    _classCallCheck(this, Engine);
	    this.ENV = ENV;
	    this.registry = {};
	    this.registryFactory = {};
	    this.pendingBackendInitId = 0;
	    this.state = new EngineState();
	  }
	  _createClass(Engine, [{
	    key: "ready",
	    value: function () {
	      var _ready = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        var sortedBackends, i, backendName, success;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              if (!(this.pendingBackendInit != null)) {
	                _context.next = 2;
	                break;
	              }
	              return _context.abrupt("return", this.pendingBackendInit.then(function () {}));
	            case 2:
	              if (!(this.backendInstance != null)) {
	                _context.next = 4;
	                break;
	              }
	              return _context.abrupt("return");
	            case 4:
	              sortedBackends = this.getSortedBackends();
	              i = 0;
	            case 6:
	              if (!(i < sortedBackends.length)) {
	                _context.next = 18;
	                break;
	              }
	              backendName = sortedBackends[i];
	              _context.next = 10;
	              return this.initializeBackend(backendName).success;
	            case 10:
	              success = _context.sent;
	              if (!success) {
	                _context.next = 15;
	                break;
	              }
	              _context.next = 14;
	              return this.setBackend(backendName);
	            case 14:
	              return _context.abrupt("return");
	            case 15:
	              i++;
	              _context.next = 6;
	              break;
	            case 18:
	              throw new Error("Could not initialize any backends, all backend initializations " + "failed.");
	            case 19:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function ready() {
	        return _ready.apply(this, arguments);
	      }
	      return ready;
	    }()
	  }, {
	    key: "backend",
	    get: function get() {
	      if (this.pendingBackendInit != null) {
	        throw new Error("Backend '".concat(this.backendName, "' has not yet been initialized. Make ") + "sure to await tf.ready() or await tf.setBackend() before calling " + "other methods");
	      }
	      if (this.backendInstance == null) {
	        var _this$initializeBacke = this.initializeBackendsAndReturnBest(),
	          name = _this$initializeBacke.name,
	          asyncInit = _this$initializeBacke.asyncInit;
	        if (asyncInit) {
	          throw new Error("The highest priority backend '".concat(name, "' has not yet been ") + "initialized. Make sure to await tf.ready() or " + "await tf.setBackend() before calling other methods");
	        }
	        this.setBackend(name);
	      }
	      return this.backendInstance;
	    }
	  }, {
	    key: "backendNames",
	    value: function backendNames() {
	      return Object.keys(this.registryFactory);
	    }
	  }, {
	    key: "findBackend",
	    value: function findBackend(backendName) {
	      if (!(backendName in this.registry)) {
	        // If the backend hasn't been initialized but we have a registry entry for
	        // it, initialize it and return it.
	        if (backendName in this.registryFactory) {
	          var _this$initializeBacke2 = this.initializeBackend(backendName),
	            asyncInit = _this$initializeBacke2.asyncInit;
	          if (asyncInit) {
	            // Backend is not ready yet.
	            return null;
	          }
	        } else {
	          return null;
	        }
	      }
	      return this.registry[backendName];
	    }
	  }, {
	    key: "findBackendFactory",
	    value: function findBackendFactory(backendName) {
	      if (!(backendName in this.registryFactory)) {
	        return null;
	      }
	      return this.registryFactory[backendName].factory;
	    }
	  }, {
	    key: "registerBackend",
	    value: function registerBackend(backendName, factory) {
	      var priority = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;
	      if (backendName in this.registryFactory) {
	        warn("".concat(backendName, " backend was already registered. ") + "Reusing existing backend factory.");
	        return false;
	      }
	      this.registryFactory[backendName] = {
	        factory: factory,
	        priority: priority
	      };
	      return true;
	    }
	  }, {
	    key: "setBackend",
	    value: function () {
	      var _setBackend = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(backendName) {
	        var _this$initializeBacke3, success, asyncInit, result;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              if (!(this.registryFactory[backendName] == null)) {
	                _context2.next = 2;
	                break;
	              }
	              throw new Error("Backend name '".concat(backendName, "' not found in registry"));
	            case 2:
	              this.backendName = backendName;
	              if (!(this.registry[backendName] == null)) {
	                _context2.next = 16;
	                break;
	              }
	              this.backendInstance = null;
	              _this$initializeBacke3 = this.initializeBackend(backendName), success = _this$initializeBacke3.success, asyncInit = _this$initializeBacke3.asyncInit;
	              if (!asyncInit) {
	                _context2.next = 12;
	                break;
	              }
	              _context2.next = 9;
	              return success;
	            case 9:
	              _context2.t0 = _context2.sent;
	              _context2.next = 13;
	              break;
	            case 12:
	              _context2.t0 = success;
	            case 13:
	              result = _context2.t0;
	              if (result) {
	                _context2.next = 16;
	                break;
	              }
	              return _context2.abrupt("return", false);
	            case 16:
	              this.backendInstance = this.registry[backendName];
	              this.setupRegisteredKernels();
	              // Reset the profiler.
	              this.profiler = new Profiler(this.backendInstance);
	              return _context2.abrupt("return", true);
	            case 20:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function setBackend(_x) {
	        return _setBackend.apply(this, arguments);
	      }
	      return setBackend;
	    }()
	  }, {
	    key: "setupRegisteredKernels",
	    value: function setupRegisteredKernels() {
	      var _this = this;
	      var kernels = getKernelsForBackend(this.backendName);
	      kernels.forEach(function (kernel) {
	        if (kernel.setupFunc != null) {
	          kernel.setupFunc(_this.backendInstance);
	        }
	      });
	    }
	  }, {
	    key: "disposeRegisteredKernels",
	    value: function disposeRegisteredKernels(backendName) {
	      var _this2 = this;
	      var kernels = getKernelsForBackend(backendName);
	      kernels.forEach(function (kernel) {
	        if (kernel.disposeFunc != null) {
	          kernel.disposeFunc(_this2.registry[backendName]);
	        }
	      });
	    }
	    /**
	     * Initializes a backend by looking up the backend name in the factory
	     * registry and calling the factory method. Returns a boolean representing
	     * whether the initialization of the backend succeeded. Throws an error if
	     * there is no backend in the factory registry.
	     */
	  }, {
	    key: "initializeBackend",
	    value: function initializeBackend(backendName) {
	      var _this3 = this;
	      var registryFactoryEntry = this.registryFactory[backendName];
	      if (registryFactoryEntry == null) {
	        throw new Error("Cannot initialize backend ".concat(backendName, ", no registration found."));
	      }
	      try {
	        var backend = registryFactoryEntry.factory();
	        /* Test if the factory returns a promise.
	        Done in a more liberal way than
	        previous 'Promise.resolve(backend)===backend'
	        as we needed to account for custom Promise
	        implementations (e.g. Angular) */
	        if (backend && !(backend instanceof KernelBackend) && typeof backend.then === 'function') {
	          var promiseId = ++this.pendingBackendInitId;
	          var success = backend.then(function (backendInstance) {
	            // Outdated promise. Another backend was set in the meantime.
	            if (promiseId < _this3.pendingBackendInitId) {
	              return false;
	            }
	            _this3.registry[backendName] = backendInstance;
	            _this3.pendingBackendInit = null;
	            return true;
	          }).catch(function (err) {
	            // Outdated promise. Another backend was set in the meantime.
	            if (promiseId < _this3.pendingBackendInitId) {
	              return false;
	            }
	            _this3.pendingBackendInit = null;
	            warn("Initialization of backend ".concat(backendName, " failed"));
	            warn(err.stack || err.message);
	            return false;
	          });
	          this.pendingBackendInit = success;
	          return {
	            success: success,
	            asyncInit: true
	          };
	        } else {
	          this.registry[backendName] = backend;
	          return {
	            success: true,
	            asyncInit: false
	          };
	        }
	      } catch (err) {
	        warn("Initialization of backend ".concat(backendName, " failed"));
	        warn(err.stack || err.message);
	        return {
	          success: false,
	          asyncInit: false
	        };
	      }
	    }
	  }, {
	    key: "removeBackend",
	    value: function removeBackend(backendName) {
	      if (!(backendName in this.registryFactory)) {
	        throw new Error("".concat(backendName, " backend not found in registry"));
	      }
	      if (this.backendName === backendName && this.pendingBackendInit != null) {
	        // There is a pending promise of the backend we want to remove. Make it
	        // obsolete.
	        this.pendingBackendInitId++;
	      }
	      if (backendName in this.registry) {
	        this.disposeRegisteredKernels(backendName);
	        this.registry[backendName].dispose();
	        delete this.registry[backendName];
	      }
	      delete this.registryFactory[backendName];
	      // Unset the backend if it is active.
	      if (this.backendName === backendName) {
	        this.pendingBackendInit = null;
	        this.backendName = null;
	        this.backendInstance = null;
	      }
	    }
	  }, {
	    key: "getSortedBackends",
	    value: function getSortedBackends() {
	      var _this4 = this;
	      if (Object.keys(this.registryFactory).length === 0) {
	        throw new Error('No backend found in registry.');
	      }
	      return Object.keys(this.registryFactory).sort(function (a, b) {
	        // Highest priority comes first.
	        return _this4.registryFactory[b].priority - _this4.registryFactory[a].priority;
	      });
	    }
	  }, {
	    key: "initializeBackendsAndReturnBest",
	    value: function initializeBackendsAndReturnBest() {
	      var sortedBackends = this.getSortedBackends();
	      for (var i = 0; i < sortedBackends.length; i++) {
	        var backendName = sortedBackends[i];
	        var _this$initializeBacke4 = this.initializeBackend(backendName),
	          success = _this$initializeBacke4.success,
	          asyncInit = _this$initializeBacke4.asyncInit;
	        if (asyncInit || success) {
	          return {
	            name: backendName,
	            asyncInit: asyncInit
	          };
	        }
	      }
	      throw new Error("Could not initialize any backends, all backend initializations " + "failed.");
	    }
	  }, {
	    key: "moveData",
	    value: function moveData(backend, dataId) {
	      var info = this.state.tensorInfo.get(dataId);
	      var srcBackend = info.backend;
	      var values = this.readSync(dataId);
	      var refCount = srcBackend.refCount(dataId);
	      // Delete the tensor from the old backend and move it to the new
	      // backend.
	      srcBackend.disposeData(dataId, true);
	      info.backend = backend;
	      backend.move(dataId, values, info.shape, info.dtype, refCount);
	      if (this.shouldCheckForMemLeaks()) {
	        // Track the number of moves during a kernel execution to correctly
	        // detect memory leaks.
	        this.state.numDataMovesStack[this.state.numDataMovesStack.length - 1]++;
	      }
	    }
	  }, {
	    key: "tidy",
	    value: function tidy(nameOrFn, fn) {
	      var _this5 = this;
	      var name = null;
	      if (fn == null) {
	        // Called with only 1 argument.
	        if (typeof nameOrFn !== 'function') {
	          throw new Error('Please provide a function to tidy()');
	        }
	        fn = nameOrFn;
	      } else {
	        // Called with 2 arguments.
	        if (typeof nameOrFn !== 'string' && !(nameOrFn instanceof String)) {
	          throw new Error('When calling with two arguments, the first argument ' + 'to tidy() must be a string');
	        }
	        if (typeof fn !== 'function') {
	          throw new Error('When calling with two arguments, the 2nd argument ' + 'to tidy() must be a function');
	        }
	        name = nameOrFn;
	        // TODO(nsthorat,smilkov): Do operation logging and performance
	        // profiling.
	      }

	      var result;
	      return this.scopedRun(function () {
	        return _this5.startScope(name);
	      }, function () {
	        return _this5.endScope(result);
	      }, function () {
	        result = fn();
	        if (result instanceof Promise) {
	          console.error('Cannot return a Promise inside of tidy.');
	        }
	        return result;
	      });
	    }
	  }, {
	    key: "scopedRun",
	    value: function scopedRun(start, end, f) {
	      start();
	      try {
	        var res = f();
	        end();
	        return res;
	      } catch (ex) {
	        end();
	        throw ex;
	      }
	    }
	  }, {
	    key: "nextTensorId",
	    value: function nextTensorId() {
	      return Engine.nextTensorId++;
	    }
	  }, {
	    key: "nextVariableId",
	    value: function nextVariableId() {
	      return Engine.nextVariableId++;
	    }
	    /**
	     * This method is called instead of the public-facing tensor.clone() when
	     * saving a tensor for backwards pass. It makes sure to add the clone
	     * operation to the tape regardless of being called inside a kernel
	     * execution.
	     */
	  }, {
	    key: "clone",
	    value: function clone(x) {
	      var y = ENGINE.runKernel(Identity$1, {
	        x: x
	      });
	      var inputs = {
	        x: x
	      };
	      var grad = function grad(dy) {
	        return {
	          x: function x() {
	            var dtype = 'float32';
	            var gradInputs = {
	              x: dy
	            };
	            var attrs = {
	              dtype: dtype
	            };
	            return ENGINE.runKernel(Cast, gradInputs,
	            // tslint:disable-next-line: no-unnecessary-type-assertion
	            attrs);
	          }
	        };
	      };
	      var saved = [];
	      this.addTapeNode(this.state.activeScope.name, inputs, [y], grad, saved, {});
	      return y;
	    }
	    /**
	     * Execute a kernel with the given name and return the output tensor.
	     *
	     * @param kernelName The name of the kernel to execute.
	     * @param inputs A map of input names to tensors.
	     * @param attrs A map of attribute names to their values. An attribute is a
	     *     primitive (non-tensor) input to the kernel.
	     * @param inputsToSave A list of tensors, inputs to save for the backprop
	     *     computation.
	     * @param outputsToSave A list of booleans, specifying which output to save
	     *     for the backprop computation. These are booleans since the output
	     * tensors are not visible to the user.
	     */
	  }, {
	    key: "runKernel",
	    value: function runKernel(kernelName, inputs, attrs) {
	      if (this.backendName == null) {
	        // backend has not been initialized yet (backend initialization is lazy
	        // can be deferred until an op/ kernel is run).
	        // The below getter has side effects that will try to initialize the
	        // backend and set properties like this.backendName
	        // tslint:disable-next-line: no-unused-expression
	        this.backend;
	      }
	      var hasKernel = getKernel(kernelName, this.backendName) != null;
	      if (!hasKernel) {
	        throw new Error("Kernel '".concat(kernelName, "' not registered for backend '").concat(this.backendName, "'"));
	      }
	      return this.runKernelFunc({
	        kernelName: kernelName,
	        inputs: inputs,
	        attrs: attrs
	      });
	    }
	  }, {
	    key: "shouldCheckForMemLeaks",
	    value: function shouldCheckForMemLeaks() {
	      return this.ENV.getBool('IS_TEST');
	    }
	  }, {
	    key: "checkKernelForMemLeak",
	    value: function checkKernelForMemLeak(kernelName, numDataIdsBefore, outInfos) {
	      var numDataIdsAfter = this.backend.numDataIds();
	      // Count the number of data ids associated with the result of the kernel.
	      var numOutputDataIds = 0;
	      outInfos.forEach(function (info) {
	        // Complex numbers allocate 3 data ids, one for 'real', one for
	        // 'imaginary', and one for the container that holds the former two.
	        numOutputDataIds += info.dtype === 'complex64' ? 3 : 1;
	      });
	      // Account for the number of moves during kernel execution. A "data move"
	      // can happen in the middle of a kernel execution, placing a new (key,value)
	      // pair in the data storage. Since data moves have net zero effect (we
	      // always remove the data from the old backend), we have to cancel them out
	      // when detecting memory leaks.
	      var numMoves = this.state.numDataMovesStack[this.state.numDataMovesStack.length - 1];
	      var dataIdsLeaked = numDataIdsAfter - numDataIdsBefore - numOutputDataIds - numMoves;
	      if (dataIdsLeaked > 0) {
	        throw new Error("Backend '".concat(this.backendName, "' has an internal memory leak ") + "(".concat(dataIdsLeaked, " data ids) after running '").concat(kernelName, "'"));
	      }
	    }
	    /**
	     * Internal helper method to execute a kernel Func
	     *
	     * Use `runKernel` to execute kernels from outside of engine.
	     */
	  }, {
	    key: "runKernelFunc",
	    value: function runKernelFunc(kernelParams) {
	      var _this6 = this;
	      var outputs;
	      var saved = [];
	      var isTapeOn = this.isTapeOn();
	      var startingBytecount = this.state.numBytes;
	      var startingNumTensors = this.state.numTensors;
	      if (this.shouldCheckForMemLeaks()) {
	        this.state.numDataMovesStack.push(0);
	      }
	      var kernelFunc;
	      if (this.backendName == null) {
	        // backend has not been initialized yet (backend initialization is lazy
	        // can be deferred until an op/ kernel is run).
	        // The below getter has side effects that will try to initialize the
	        // backend and set properties like this.backendName
	        // tslint:disable-next-line: no-unused-expression
	        this.backend;
	      }
	      var out;
	      var kernelOrScopeName = isRegisteredKernelInvocation(kernelParams) ? kernelParams.kernelName : this.state.activeScope != null ? this.state.activeScope.name : '';
	      // Create the kernelFunc from either a registered kernel OR passed in
	      // forward/backward functions (used by custom grad). In this context a
	      // kernelFunc wraps a kernel implementation with some bookkeeping.
	      if (isRegisteredKernelInvocation(kernelParams)) {
	        var kernelName = kernelParams.kernelName,
	          _inputs = kernelParams.inputs,
	          _attrs = kernelParams.attrs;
	        if (this.backendName == null) {
	          // backend has not been initialized yet (backend initialization is lazy
	          // can be deferred until an op/ kernel is run).
	          // The below getter has side effects that will try to initialize the
	          // backend and set properties like this.backendName
	          // tslint:disable-next-line: no-unused-expression
	          this.backend;
	        }
	        var kernel = getKernel(kernelName, this.backendName);
	        assert$1(kernel != null, function () {
	          return "Cannot find registered kernel '".concat(kernelName, "' for backend '").concat(_this6.backendName, "'");
	        });
	        kernelFunc = function kernelFunc() {
	          var numDataIdsBefore = _this6.backend.numDataIds();
	          out = kernel.kernelFunc({
	            inputs: _inputs,
	            attrs: _attrs,
	            backend: _this6.backend
	          });
	          var outInfos = Array.isArray(out) ? out : [out];
	          if (_this6.shouldCheckForMemLeaks()) {
	            _this6.checkKernelForMemLeak(kernelName, numDataIdsBefore, outInfos);
	          }
	          var outTensors = outInfos.map(function (outInfo) {
	            // todo (yassogba) remove this option (Tensor) when node backend
	            // methods have been modularized and they all return tensorInfo.
	            // TensorInfos do not have a rank attribute.
	            if (outInfo.rank != null) {
	              return outInfo;
	            }
	            return _this6.makeTensorFromTensorInfo(outInfo);
	          });
	          // Save any required inputs and outputs.
	          // Do not save unless we are recording to the tape. Otherwise it would
	          // cause a mem leak since there would be no backprop for these tensors
	          // (which would otherwise dispose them).
	          if (isTapeOn) {
	            var tensorsToSave = _this6.getTensorsForGradient(kernelName, _inputs, outTensors);
	            saved = _this6.saveTensorsForBackwardMode(tensorsToSave);
	          }
	          return outTensors;
	        };
	      } else {
	        var forwardFunc = kernelParams.forwardFunc;
	        // Running a customGrad op.
	        var saveFunc = function saveFunc(tensors) {
	          // Do not save unless we are recording to the tape. Otherwise it would
	          // cause a mem leak since we would never run backprop, which disposes
	          // the kept tensors.
	          if (!isTapeOn) {
	            return;
	          }
	          saved = tensors.map(function (tensor) {
	            return _this6.keep(_this6.clone(tensor));
	          });
	        };
	        kernelFunc = function kernelFunc() {
	          var numDataIdsBefore = _this6.backend.numDataIds();
	          out = _this6.tidy(function () {
	            return forwardFunc(_this6.backend, saveFunc);
	          });
	          var outs = Array.isArray(out) ? out : [out];
	          if (_this6.shouldCheckForMemLeaks()) {
	            // Scope name is used to print a more helpful error message if needed.
	            _this6.checkKernelForMemLeak(kernelOrScopeName, numDataIdsBefore, outs);
	          }
	          return outs;
	        };
	      }
	      //
	      // Run the kernelFunc. Optionally profiling it.
	      //
	      var inputs = kernelParams.inputs,
	        attrs = kernelParams.attrs;
	      var backwardsFunc = isRegisteredKernelInvocation(kernelParams) ? null : kernelParams.backwardsFunc;
	      var kernelProfile;
	      this.scopedRun(
	      // Stop recording to a tape when running a kernel.
	      function () {
	        return _this6.state.kernelDepth++;
	      }, function () {
	        return _this6.state.kernelDepth--;
	      }, function () {
	        if (!_this6.ENV.getBool('DEBUG') && !_this6.state.profiling) {
	          outputs = kernelFunc();
	        } else {
	          kernelProfile = _this6.profiler.profileKernel(kernelOrScopeName, inputs, function () {
	            return kernelFunc();
	          });
	          if (_this6.ENV.getBool('DEBUG')) {
	            _this6.profiler.logKernelProfile(kernelProfile);
	          }
	          outputs = kernelProfile.outputs;
	        }
	      });
	      if (isTapeOn) {
	        this.addTapeNode(kernelOrScopeName, inputs, outputs, backwardsFunc, saved, attrs);
	      }
	      if (this.state.profiling) {
	        this.state.activeProfile.kernels.push({
	          name: kernelOrScopeName,
	          bytesAdded: this.state.numBytes - startingBytecount,
	          totalBytesSnapshot: this.state.numBytes,
	          tensorsAdded: this.state.numTensors - startingNumTensors,
	          totalTensorsSnapshot: this.state.numTensors,
	          inputShapes: Object.keys(inputs).map(function (key) {
	            return inputs[key] != null ? inputs[key].shape : null;
	          }),
	          outputShapes: outputs.map(function (item) {
	            return item.shape;
	          }),
	          kernelTimeMs: kernelProfile.timeMs,
	          extraInfo: kernelProfile.extraInfo
	        });
	      }
	      return Array.isArray(out) ? outputs : outputs[0];
	    }
	    /**
	     * Saves tensors used in forward mode for use in backward mode.
	     *
	     * @param tensors the list of tensors to save.
	     */
	  }, {
	    key: "saveTensorsForBackwardMode",
	    value: function saveTensorsForBackwardMode(tensors) {
	      var _this7 = this;
	      var saved = tensors.map(function (tensor) {
	        return _this7.keep(_this7.clone(tensor));
	      });
	      return saved;
	    }
	    /**
	     * Returns a list of tensors to save for a given gradient calculation.
	     *
	     * @param kernelName name of kernel to look up gradient for.
	     * @param inputs a map of input tensors.
	     * @param outputs an array of output tensors from forward mode of kernel.
	     */
	  }, {
	    key: "getTensorsForGradient",
	    value: function getTensorsForGradient(kernelName, inputs, outputs) {
	      var gradConfig = getGradient(kernelName);
	      if (gradConfig != null) {
	        var inputsToSave = gradConfig.inputsToSave || [];
	        var outputsToSave = gradConfig.outputsToSave || [];
	        // If saveAllInputs is true, all inputs will be saved. Otherwise, inputs
	        // specified in inputsToSave will be saved.
	        var inputTensorsToSave;
	        if (gradConfig.saveAllInputs) {
	          assert$1(Array.isArray(inputs), function () {
	            return 'saveAllInputs is true, expected inputs to be an array.';
	          });
	          inputTensorsToSave = Object.keys(inputs).map(function (key) {
	            return inputs[key];
	          });
	        } else {
	          inputTensorsToSave = inputsToSave.map(function (inputName) {
	            return inputs[inputName];
	          });
	        }
	        var outputTensorsToSave = outputs.filter(function (_, i) {
	          return outputsToSave[i];
	        });
	        return inputTensorsToSave.concat(outputTensorsToSave);
	      }
	      // We return an empty list rather than throw an error because the kernel we
	      // are looking up may not actually be relevant to backproping through the
	      // overall function
	      //
	      // See 'does not error if irrelevant (pruned) ops are missing grads' test
	      // in gradients_test.ts for an example.
	      return [];
	    }
	    /**
	     * Internal method used by public APIs for tensor creation. Makes a new
	     * tensor with the provided shape, dtype and values. It always
	     * creates a new data id and writes the values to the underlying backend.
	     */
	  }, {
	    key: "makeTensor",
	    value: function makeTensor(values, shape, dtype, backend) {
	      if (values == null) {
	        throw new Error('Values passed to engine.makeTensor() are null');
	      }
	      dtype = dtype || 'float32';
	      backend = backend || this.backend;
	      var backendVals = values;
	      if (dtype === 'string' && isString(values[0])) {
	        backendVals = values.map(function (d) {
	          return encodeString(d);
	        });
	      }
	      var dataId = backend.write(backendVals, shape, dtype);
	      var t = new Tensor(shape, dtype, dataId, this.nextTensorId());
	      this.trackTensor(t, backend);
	      // Count bytes for string tensors.
	      if (dtype === 'string') {
	        var info = this.state.tensorInfo.get(dataId);
	        var newBytes = bytesFromStringArray(backendVals);
	        this.state.numBytes += newBytes - info.bytes;
	        info.bytes = newBytes;
	      }
	      return t;
	    }
	    /**
	     * Internal method used by backends. Makes a new tensor
	     * that is a wrapper around an existing data id. It doesn't create
	     * a new data id, only increments the ref count used in memory tracking.
	     * @deprecated
	     */
	  }, {
	    key: "makeTensorFromDataId",
	    value: function makeTensorFromDataId(dataId, shape, dtype, backend) {
	      dtype = dtype || 'float32';
	      var tensorInfo = {
	        dataId: dataId,
	        shape: shape,
	        dtype: dtype
	      };
	      return this.makeTensorFromTensorInfo(tensorInfo, backend);
	    }
	    /**
	     * Internal method used by backends. Makes a new tensor that is a wrapper
	     * around an existing data id in TensorInfo. It doesn't create a new data id,
	     * only increments the ref count used in memory tracking.
	     */
	  }, {
	    key: "makeTensorFromTensorInfo",
	    value: function makeTensorFromTensorInfo(tensorInfo, backend) {
	      var dataId = tensorInfo.dataId,
	        shape = tensorInfo.shape,
	        dtype = tensorInfo.dtype;
	      var t = new Tensor(shape, dtype, dataId, this.nextTensorId());
	      this.trackTensor(t, backend);
	      return t;
	    }
	  }, {
	    key: "makeVariable",
	    value: function makeVariable(initialValue) {
	      var trainable = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
	      var name = arguments.length > 2 ? arguments[2] : undefined;
	      var dtype = arguments.length > 3 ? arguments[3] : undefined;
	      name = name || this.nextVariableId().toString();
	      if (dtype != null && dtype !== initialValue.dtype) {
	        initialValue = initialValue.cast(dtype);
	      }
	      var v = new Variable(initialValue, trainable, name, this.nextTensorId());
	      if (this.state.registeredVariables[v.name] != null) {
	        throw new Error("Variable with name ".concat(v.name, " was already registered"));
	      }
	      this.state.registeredVariables[v.name] = v;
	      this.incRef(v, this.backend);
	      return v;
	    }
	  }, {
	    key: "trackTensor",
	    value: function trackTensor(a, backend) {
	      this.state.numTensors++;
	      if (a.dtype === 'string') {
	        this.state.numStringTensors++;
	      }
	      // Bytes for complex numbers are counted by their components. Bytes for
	      // string tensors are counted when writing values.
	      var bytes = 0;
	      if (a.dtype !== 'complex64' && a.dtype !== 'string') {
	        bytes = a.size * bytesPerElement(a.dtype);
	      }
	      this.state.numBytes += bytes;
	      if (!this.state.tensorInfo.has(a.dataId)) {
	        this.state.numDataBuffers++;
	        this.state.tensorInfo.set(a.dataId, {
	          backend: backend || this.backend,
	          dtype: a.dtype,
	          shape: a.shape,
	          bytes: bytes
	        });
	      }
	      if (!(a instanceof Variable)) {
	        this.track(a);
	      }
	    }
	    // Track the tensor by dataId and increase the refCount for the dataId in the
	    // backend.
	    // TODO(pyu10055): This is currently used by makeVariable method, to increase
	    // refCount on the backend for the dataId. It can potentially be replaced with
	    // Identity op indead of calling backend directly.
	  }, {
	    key: "incRef",
	    value: function incRef(a, backend) {
	      this.trackTensor(a, backend);
	      this.backend.incRef(a.dataId);
	    }
	  }, {
	    key: "removeDataId",
	    value: function removeDataId(dataId, backend) {
	      if (this.state.tensorInfo.has(dataId) && this.state.tensorInfo.get(dataId).backend === backend) {
	        this.state.tensorInfo.delete(dataId);
	        this.state.numDataBuffers--;
	      }
	    }
	  }, {
	    key: "disposeTensor",
	    value: function disposeTensor(a) {
	      if (!this.state.tensorInfo.has(a.dataId)) {
	        return;
	      }
	      var info = this.state.tensorInfo.get(a.dataId);
	      this.state.numTensors--;
	      if (a.dtype === 'string') {
	        this.state.numStringTensors--;
	        this.state.numBytes -= info.bytes;
	      }
	      // Don't count bytes for complex numbers as they are counted by their
	      // components.
	      if (a.dtype !== 'complex64' && a.dtype !== 'string') {
	        var bytes = a.size * bytesPerElement(a.dtype);
	        this.state.numBytes -= bytes;
	      }
	      // Remove the reference to dataId if backend dispose the data successfully
	      if (info.backend.disposeData(a.dataId)) {
	        this.removeDataId(a.dataId, info.backend);
	      }
	      // TODO(nsthorat): Construct an error and save the stack trace for
	      // debugging when in debug mode. Creating a stack trace is too expensive
	      // to do unconditionally.
	    }
	  }, {
	    key: "disposeVariables",
	    value: function disposeVariables() {
	      for (var varName in this.state.registeredVariables) {
	        var v = this.state.registeredVariables[varName];
	        this.disposeVariable(v);
	      }
	    }
	  }, {
	    key: "disposeVariable",
	    value: function disposeVariable(v) {
	      this.disposeTensor(v);
	      if (this.state.registeredVariables[v.name] != null) {
	        delete this.state.registeredVariables[v.name];
	      }
	    }
	  }, {
	    key: "memory",
	    value: function memory() {
	      var info = this.backend.memory();
	      info.numTensors = this.state.numTensors;
	      info.numDataBuffers = this.state.numDataBuffers;
	      info.numBytes = this.state.numBytes;
	      if (this.state.numStringTensors > 0) {
	        info.unreliable = true;
	        if (info.reasons == null) {
	          info.reasons = [];
	        }
	        info.reasons.push('Memory usage by string tensors is approximate ' + '(2 bytes per character)');
	      }
	      return info;
	    }
	  }, {
	    key: "profile",
	    value: function () {
	      var _profile = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3(query) {
	        var startBytes, startNumTensors, _iterator, _step, kernel;
	        return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	          while (1) switch (_context3.prev = _context3.next) {
	            case 0:
	              this.state.profiling = true;
	              startBytes = this.state.numBytes;
	              startNumTensors = this.state.numTensors;
	              this.state.activeProfile.kernels = [];
	              _context3.next = 6;
	              return query();
	            case 6:
	              this.state.activeProfile.result = _context3.sent;
	              this.state.profiling = false;
	              this.state.activeProfile.peakBytes = Math.max.apply(Math, _toConsumableArray(this.state.activeProfile.kernels.map(function (d) {
	                return d.totalBytesSnapshot;
	              })));
	              this.state.activeProfile.newBytes = this.state.numBytes - startBytes;
	              this.state.activeProfile.newTensors = this.state.numTensors - startNumTensors;
	              _iterator = _createForOfIteratorHelper(this.state.activeProfile.kernels);
	              _context3.prev = 12;
	              _iterator.s();
	            case 14:
	              if ((_step = _iterator.n()).done) {
	                _context3.next = 24;
	                break;
	              }
	              kernel = _step.value;
	              _context3.next = 18;
	              return kernel.kernelTimeMs;
	            case 18:
	              kernel.kernelTimeMs = _context3.sent;
	              _context3.next = 21;
	              return kernel.extraInfo;
	            case 21:
	              kernel.extraInfo = _context3.sent;
	            case 22:
	              _context3.next = 14;
	              break;
	            case 24:
	              _context3.next = 29;
	              break;
	            case 26:
	              _context3.prev = 26;
	              _context3.t0 = _context3["catch"](12);
	              _iterator.e(_context3.t0);
	            case 29:
	              _context3.prev = 29;
	              _iterator.f();
	              return _context3.finish(29);
	            case 32:
	              return _context3.abrupt("return", this.state.activeProfile);
	            case 33:
	            case "end":
	              return _context3.stop();
	          }
	        }, _callee3, this, [[12, 26, 29, 32]]);
	      }));
	      function profile(_x2) {
	        return _profile.apply(this, arguments);
	      }
	      return profile;
	    }()
	  }, {
	    key: "isTapeOn",
	    value: function isTapeOn() {
	      return this.state.gradientDepth > 0 && this.state.kernelDepth === 0;
	    }
	  }, {
	    key: "addTapeNode",
	    value: function addTapeNode(kernelName, inputs, outputs, gradientsFunc, saved, attrs) {
	      var _this8 = this;
	      var tapeNode = {
	        id: this.state.nextTapeNodeId++,
	        kernelName: kernelName,
	        inputs: inputs,
	        outputs: outputs,
	        saved: saved
	      };
	      var gradConfig = getGradient(kernelName);
	      if (gradConfig != null) {
	        gradientsFunc = gradConfig.gradFunc;
	      }
	      if (gradientsFunc != null) {
	        tapeNode.gradient = function (dys) {
	          // TODO(smilkov): To optimize back-prop, pass dys that are not used in
	          // the backprop graph to the user as null instead of zeros
	          dys = dys.map(function (dy, i) {
	            if (dy == null) {
	              var output = outputs[i];
	              var vals = makeZerosTypedArray(output.size, output.dtype);
	              return _this8.makeTensor(vals, output.shape, output.dtype);
	            }
	            return dy;
	          });
	          // Grad functions of ops with single outputs expect a dy, while ops
	          // with multiple outputs expect dys (array of dy).
	          return gradientsFunc(dys.length > 1 ? dys : dys[0], saved, attrs);
	        };
	      }
	      this.state.activeTape.push(tapeNode);
	    }
	  }, {
	    key: "keep",
	    value: function keep(result) {
	      result.kept = true;
	      return result;
	    }
	  }, {
	    key: "startTape",
	    value: function startTape() {
	      if (this.state.gradientDepth === 0) {
	        this.state.activeTape = [];
	      }
	      this.state.gradientDepth++;
	    }
	  }, {
	    key: "endTape",
	    value: function endTape() {
	      this.state.gradientDepth--;
	    }
	    /**
	     * Start a scope. Use this with endScope() to achieve the same functionality
	     * as scope() without the need for a function closure.
	     */
	  }, {
	    key: "startScope",
	    value: function startScope(name) {
	      var scopeInfo = {
	        track: [],
	        name: 'unnamed scope',
	        id: this.state.nextScopeId++
	      };
	      if (name) {
	        scopeInfo.name = name;
	      }
	      this.state.scopeStack.push(scopeInfo);
	      this.state.activeScope = scopeInfo;
	    }
	    /**
	     * End a scope. Use this with startScope() to achieve the same functionality
	     * as scope() without the need for a function closure.
	     */
	  }, {
	    key: "endScope",
	    value: function endScope(result) {
	      var _this9 = this;
	      var tensorsToTrackInParent = getTensorsInContainer(result);
	      var tensorsToTrackInParentSet = new Set(tensorsToTrackInParent.map(function (t) {
	        return t.id;
	      }));
	      // Dispose the arrays tracked in this scope.
	      for (var i = 0; i < this.state.activeScope.track.length; i++) {
	        var tensor = this.state.activeScope.track[i];
	        if (!tensor.kept && !tensorsToTrackInParentSet.has(tensor.id)) {
	          tensor.dispose();
	        }
	      }
	      var oldScope = this.state.scopeStack.pop();
	      this.state.activeScope = this.state.scopeStack.length === 0 ? null : this.state.scopeStack[this.state.scopeStack.length - 1];
	      // Track the current result in the parent scope.
	      tensorsToTrackInParent.forEach(function (tensor) {
	        // Only track the tensor if was allocated in the inner scope and is not
	        // globally kept.
	        if (!tensor.kept && tensor.scopeId === oldScope.id) {
	          _this9.track(tensor);
	        }
	      });
	    }
	    /**
	     * Returns gradients of `f` with respect to each of the `xs`. The gradients
	     * returned are of the same length as `xs`, but some might be null if `f`
	     * was not a function of that `x`. It also takes optional dy to multiply the
	     * gradient, which defaults to `1`.
	     */
	  }, {
	    key: "gradients",
	    value: function gradients(f, xs, dy) {
	      var _this10 = this;
	      var allowNoGradients = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	      assert$1(xs.length > 0, function () {
	        return 'gradients() received an empty list of xs.';
	      });
	      if (dy != null && dy.dtype !== 'float32') {
	        throw new Error("dy must have 'float32' dtype, but has '".concat(dy.dtype, "'"));
	      }
	      var y = this.scopedRun(function () {
	        return _this10.startTape();
	      }, function () {
	        return _this10.endTape();
	      }, function () {
	        return _this10.tidy('forward', f);
	      });
	      assert$1(y instanceof Tensor, function () {
	        return 'The result y returned by f() must be a tensor.';
	      });
	      // Filter out the nodes that don't connect x => y.
	      var filteredTape = getFilteredNodesXToY(this.state.activeTape, xs, y);
	      if (!allowNoGradients && filteredTape.length === 0 && xs.length > 0) {
	        throw new Error('Cannot compute gradient of y=f(x) with respect to x. Make sure ' + 'that the f you passed encloses all operations that lead from x ' + 'to y.');
	      }
	      return this.tidy('backward', function () {
	        var accumulatedGradientMap = {};
	        accumulatedGradientMap[y.id] = dy == null ? ones$2(y.shape) : dy;
	        // Backprop gradients through the filtered nodes.
	        backpropagateGradients(accumulatedGradientMap, filteredTape,
	        // Pass the tidy function to avoid circular dep with `tape.ts`.
	        function (f) {
	          return _this10.tidy(f);
	        },
	        // Pass an add function to avoide a circular dep with `tape.ts`.
	        add$4);
	        var grads = xs.map(function (x) {
	          return accumulatedGradientMap[x.id];
	        });
	        if (_this10.state.gradientDepth === 0) {
	          // This means that we are not computing higher-order gradients
	          // and can clean up the tape.
	          _this10.state.activeTape.forEach(function (node) {
	            var _iterator2 = _createForOfIteratorHelper(node.saved),
	              _step2;
	            try {
	              for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	                var tensor = _step2.value;
	                tensor.dispose();
	              }
	            } catch (err) {
	              _iterator2.e(err);
	            } finally {
	              _iterator2.f();
	            }
	          });
	          _this10.state.activeTape = null;
	        }
	        return {
	          value: y,
	          grads: grads
	        };
	      });
	    }
	  }, {
	    key: "customGrad",
	    value: function customGrad(f) {
	      var _this11 = this;
	      assert$1(isFunction(f), function () {
	        return 'The f passed in customGrad(f) must be a function.';
	      });
	      return function () {
	        for (var _len = arguments.length, inputs = new Array(_len), _key = 0; _key < _len; _key++) {
	          inputs[_key] = arguments[_key];
	        }
	        assert$1(inputs.every(function (t) {
	          return t instanceof Tensor;
	        }), function () {
	          return 'The args passed in customGrad(f)(x1, x2,...) must all be ' + 'tensors';
	        });
	        var res;
	        var inputMap = {};
	        inputs.forEach(function (input, i) {
	          inputMap[i] = input;
	        });
	        var forwardFunc = function forwardFunc(_, save) {
	          res = f.apply(void 0, [].concat(inputs, [save]));
	          assert$1(res.value instanceof Tensor, function () {
	            return 'The function f passed in customGrad(f) must return an ' + 'object where `obj.value` is a tensor';
	          });
	          assert$1(isFunction(res.gradFunc), function () {
	            return 'The function f passed in customGrad(f) must return an ' + 'object where `obj.gradFunc` is a function.';
	          });
	          return res.value;
	        };
	        var backwardsFunc = function backwardsFunc(dy, saved) {
	          var gradRes = res.gradFunc(dy, saved);
	          var grads = Array.isArray(gradRes) ? gradRes : [gradRes];
	          assert$1(grads.length === inputs.length, function () {
	            return 'The function f passed in customGrad(f) must return an ' + 'object where `obj.gradFunc` is a function that returns ' + 'the same number of tensors as inputs passed to f(...).';
	          });
	          assert$1(grads.every(function (t) {
	            return t instanceof Tensor;
	          }), function () {
	            return 'The function f passed in customGrad(f) must return an ' + 'object where `obj.gradFunc` is a function that returns ' + 'a list of only tensors.';
	          });
	          var gradMap = {};
	          grads.forEach(function (grad, i) {
	            gradMap[i] = function () {
	              return grad;
	            };
	          });
	          return gradMap;
	        };
	        return _this11.runKernelFunc({
	          forwardFunc: forwardFunc,
	          backwardsFunc: backwardsFunc,
	          inputs: inputMap
	        });
	      };
	    }
	  }, {
	    key: "readSync",
	    value: function readSync(dataId) {
	      // Route the read to the correct backend.
	      var info = this.state.tensorInfo.get(dataId);
	      return info.backend.readSync(dataId);
	    }
	  }, {
	    key: "read",
	    value: function read(dataId) {
	      // Route the read to the correct backend.
	      var info = this.state.tensorInfo.get(dataId);
	      return info.backend.read(dataId);
	    }
	  }, {
	    key: "readToGPU",
	    value: function readToGPU(dataId, options) {
	      // Route the read to the correct backend.
	      var info = this.state.tensorInfo.get(dataId);
	      return info.backend.readToGPU(dataId, options);
	    }
	  }, {
	    key: "time",
	    value: function () {
	      var _time = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4(query) {
	        var start, timingInfo;
	        return _regeneratorRuntime().wrap(function _callee4$(_context4) {
	          while (1) switch (_context4.prev = _context4.next) {
	            case 0:
	              start = now();
	              _context4.next = 3;
	              return this.backend.time(query);
	            case 3:
	              timingInfo = _context4.sent;
	              timingInfo.wallMs = now() - start;
	              return _context4.abrupt("return", timingInfo);
	            case 6:
	            case "end":
	              return _context4.stop();
	          }
	        }, _callee4, this);
	      }));
	      function time(_x3) {
	        return _time.apply(this, arguments);
	      }
	      return time;
	    }()
	    /**
	     * Tracks a Tensor in the current scope to be automatically cleaned up
	     * when the current scope ends, and returns the value.
	     *
	     * @param result The Tensor to track in the current scope.
	     */
	  }, {
	    key: "track",
	    value: function track(result) {
	      if (this.state.activeScope != null) {
	        result.scopeId = this.state.activeScope.id;
	        this.state.activeScope.track.push(result);
	      }
	      return result;
	    }
	  }, {
	    key: "registeredVariables",
	    get: function get() {
	      return this.state.registeredVariables;
	    }
	    /**
	     * Resets the engine state. Removes all backends but does not remove
	     * registered backend factories.
	     */
	  }, {
	    key: "reset",
	    value: function reset() {
	      // Make any pending promise obsolete.
	      this.pendingBackendInitId++;
	      this.state.dispose();
	      this.ENV.reset();
	      this.state = new EngineState();
	      for (var backendName in this.registry) {
	        this.disposeRegisteredKernels(backendName);
	        this.registry[backendName].dispose();
	        delete this.registry[backendName];
	      }
	      this.backendName = null;
	      this.backendInstance = null;
	      this.pendingBackendInit = null;
	    }
	  }]);
	  return Engine;
	}();
	Engine.nextTensorId = 0;
	Engine.nextVariableId = 0;
	function ones$2(shape) {
	  var values = makeOnesTypedArray(sizeFromShape(shape), 'float32');
	  return ENGINE.makeTensor(values, shape, 'float32');
	}
	function getOrMakeEngine() {
	  var ns = getGlobalNamespace();
	  if (ns._tfengine == null) {
	    var environment = new Environment(ns);
	    ns._tfengine = new Engine(environment);
	  }
	  setEnvironmentGlobal(ns._tfengine.ENV);
	  // Tell the current tensor interface that the global engine is responsible
	  // for tracking.
	  setTensorTracker(function () {
	    return ns._tfengine;
	  });
	  return ns._tfengine;
	}
	var ENGINE = getOrMakeEngine();
	/**
	 * A implementation of the add op for use within engine and tape.
	 *
	 * This allows us to avoid a circular dependency between add.ts and engine.
	 * It is exported to be available in tape tests.
	 */
	function add$4(a, b) {
	  // We duplicate Add here to avoid a circular dependency with add.ts.
	  var inputs = {
	    a: a,
	    b: b
	  };
	  return ENGINE.runKernel(Add$1, inputs);
	}

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	// tslint:disable-next-line:no-any
	function _isNavigatorDefined() {
	  return typeof navigator !== 'undefined' && navigator != null;
	}
	var isMobileMockValue;
	function mockIsMobile(value) {
	  isMobileMockValue = value;
	}
	function isMobile(nav) {
	  if (isMobileMockValue !== undefined) {
	    return isMobileMockValue;
	  }
	  if (nav || _isNavigatorDefined()) {
	    if (!nav) {
	      nav = navigator;
	    }
	    if (nav.product === 'ReactNative') {
	      return true;
	    }
	    var a = nav.userAgent || nav.vendor || (
	    // tslint:disable-next-line:no-any
	    typeof window !== 'undefined' ? window.opera : '');
	    // Use `navigator.userAgentData.mobile` as fallback.
	    if (!a) {
	      // tslint:disable-next-line:no-any
	      var navAny = nav;
	      return navAny.userAgentData && navAny.userAgentData.mobile;
	    }
	    // tslint:disable-next-line:max-line-length
	    return /(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\.(browser|link)|vodafone|wap|windows ce|xda|xiino/i.test(a) ||
	    // tslint:disable-next-line:max-line-length
	    /1207|6310|6590|3gso|4thp|50[1-6]i|770s|802s|a wa|abac|ac(er|oo|s\-)|ai(ko|rn)|al(av|ca|co)|amoi|an(ex|ny|yw)|aptu|ar(ch|go)|as(te|us)|attw|au(di|\-m|r |s )|avan|be(ck|ll|nq)|bi(lb|rd)|bl(ac|az)|br(e|v)w|bumb|bw\-(n|u)|c55\/|capi|ccwa|cdm\-|cell|chtm|cldc|cmd\-|co(mp|nd)|craw|da(it|ll|ng)|dbte|dc\-s|devi|dica|dmob|do(c|p)o|ds(12|\-d)|el(49|ai)|em(l2|ul)|er(ic|k0)|esl8|ez([4-7]0|os|wa|ze)|fetc|fly(\-|_)|g1 u|g560|gene|gf\-5|g\-mo|go(\.w|od)|gr(ad|un)|haie|hcit|hd\-(m|p|t)|hei\-|hi(pt|ta)|hp( i|ip)|hs\-c|ht(c(\-| |_|a|g|p|s|t)|tp)|hu(aw|tc)|i\-(20|go|ma)|i230|iac( |\-|\/)|ibro|idea|ig01|ikom|im1k|inno|ipaq|iris|ja(t|v)a|jbro|jemu|jigs|kddi|keji|kgt( |\/)|klon|kpt |kwc\-|kyo(c|k)|le(no|xi)|lg( g|\/(k|l|u)|50|54|\-[a-w])|libw|lynx|m1\-w|m3ga|m50\/|ma(te|ui|xo)|mc(01|21|ca)|m\-cr|me(rc|ri)|mi(o8|oa|ts)|mmef|mo(01|02|bi|de|do|t(\-| |o|v)|zz)|mt(50|p1|v )|mwbp|mywa|n10[0-2]|n20[2-3]|n30(0|2)|n50(0|2|5)|n7(0(0|1)|10)|ne((c|m)\-|on|tf|wf|wg|wt)|nok(6|i)|nzph|o2im|op(ti|wv)|oran|owg1|p800|pan(a|d|t)|pdxg|pg(13|\-([1-8]|c))|phil|pire|pl(ay|uc)|pn\-2|po(ck|rt|se)|prox|psio|pt\-g|qa\-a|qc(07|12|21|32|60|\-[2-7]|i\-)|qtek|r380|r600|raks|rim9|ro(ve|zo)|s55\/|sa(ge|ma|mm|ms|ny|va)|sc(01|h\-|oo|p\-)|sdk\/|se(c(\-|0|1)|47|mc|nd|ri)|sgh\-|shar|sie(\-|m)|sk\-0|sl(45|id)|sm(al|ar|b3|it|t5)|so(ft|ny)|sp(01|h\-|v\-|v )|sy(01|mb)|t2(18|50)|t6(00|10|18)|ta(gt|lk)|tcl\-|tdg\-|tel(i|m)|tim\-|t\-mo|to(pl|sh)|ts(70|m\-|m3|m5)|tx\-9|up(\.b|g1|si)|utst|v400|v750|veri|vi(rg|te)|vk(40|5[0-3]|\-v)|vm40|voda|vulc|vx(52|53|60|61|70|80|81|83|85|98)|w3c(\-| )|webc|whit|wi(g |nc|nw)|wmlb|wonu|x700|yas\-|your|zeto|zte\-/i.test(a.substr(0, 4));
	  }
	  return false;
	}
	function isBrowser() {
	  return typeof window !== 'undefined' && window.document != null ||
	  //@ts-ignore
	  typeof WorkerGlobalScope !== 'undefined';
	}

	var device_util = {
		__proto__: null,
		isBrowser: isBrowser,
		isMobile: isMobile,
		mockIsMobile: mockIsMobile
	};

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ENV$3 = env();
	/**
	 * This file contains environment-related flag registrations.
	 */
	/** Whether to enable debug mode. */
	ENV$3.registerFlag('DEBUG', function () {
	  return false;
	}, function (debugValue) {
	  if (debugValue) {
	    console.warn('Debugging mode is ON. The output of every math call will ' + 'be downloaded to CPU and checked for NaNs. ' + 'This significantly impacts performance.');
	  }
	});
	/** Whether we are in a browser (as versus, say, node.js) environment. */
	ENV$3.registerFlag('IS_BROWSER', function () {
	  return isBrowser();
	});
	/** Whether we are in a browser (as versus, say, node.js) environment. */
	ENV$3.registerFlag('IS_NODE', function () {
	  return typeof process !== 'undefined' && typeof process.versions !== 'undefined' && typeof process.versions.node !== 'undefined';
	});
	/** Whether this browser is Chrome. */
	ENV$3.registerFlag('IS_CHROME', function () {
	  return typeof navigator !== 'undefined' && navigator != null && navigator.userAgent != null && /Chrome/.test(navigator.userAgent) && /Google Inc/.test(navigator.vendor);
	});
	/** Whether this browser is Safari. */
	ENV$3.registerFlag('IS_SAFARI', function () {
	  return typeof navigator !== 'undefined' && navigator != null && navigator.userAgent != null && /Safari/.test(navigator.userAgent) && /Apple/.test(navigator.vendor);
	});
	/**
	 * True when the environment is "production" where we disable safety checks
	 * to gain performance.
	 */
	ENV$3.registerFlag('PROD', function () {
	  return false;
	});
	/**
	 * Whether to do sanity checks when inferring a shape from user-provided
	 * values, used when creating a new tensor.
	 */
	ENV$3.registerFlag('TENSORLIKE_CHECK_SHAPE_CONSISTENCY', function () {
	  return ENV$3.getBool('DEBUG');
	});
	/** Whether deprecation warnings are enabled. */
	ENV$3.registerFlag('DEPRECATION_WARNINGS_ENABLED', function () {
	  return true;
	});
	/** True if running unit tests. */
	ENV$3.registerFlag('IS_TEST', function () {
	  return false;
	});
	/** Whether to check computation result for errors. */
	ENV$3.registerFlag('CHECK_COMPUTATION_FOR_ERRORS', function () {
	  return ENV$3.getBool('DEBUG');
	});
	/** Whether the backend needs to wrap input to imageBitmap. */
	ENV$3.registerFlag('WRAP_TO_IMAGEBITMAP', function () {
	  return false;
	});
	/** Whether to enable canvas2d willReadFrequently for GPU backends */
	ENV$3.registerFlag('CANVAS2D_WILL_READ_FREQUENTLY_FOR_GPU', function () {
	  return false;
	});
	/** Whether to use setTimeoutCustom */
	ENV$3.registerFlag('USE_SETTIMEOUTCUSTOM', function () {
	  return false;
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function inferShape(val, dtype) {
	  var firstElem = val;
	  if (isTypedArray(val)) {
	    return dtype === 'string' ? [] : [val.length];
	  }
	  if (isWebGLData(val)) {
	    var usedChannels = val.channels || 'RGBA';
	    return [val.height, val.width * usedChannels.length];
	  } else if (isWebGPUData(val)) {
	    return [val.buffer.size / (dtype == null ? 4 : bytesPerElement(dtype))];
	  }
	  if (!Array.isArray(val)) {
	    return []; // Scalar.
	  }

	  var shape = [];
	  while (Array.isArray(firstElem) || isTypedArray(firstElem) && dtype !== 'string') {
	    shape.push(firstElem.length);
	    firstElem = firstElem[0];
	  }
	  if (Array.isArray(val) && env().getBool('TENSORLIKE_CHECK_SHAPE_CONSISTENCY')) {
	    deepAssertShapeConsistency(val, shape, []);
	  }
	  return shape;
	}
	function deepAssertShapeConsistency(val, shape, indices) {
	  indices = indices || [];
	  if (!Array.isArray(val) && !isTypedArray(val)) {
	    assert$1(shape.length === 0, function () {
	      return "Element arr[".concat(indices.join(']['), "] is a primitive, ") + "but should be an array/TypedArray of ".concat(shape[0], " elements");
	    });
	    return;
	  }
	  assert$1(shape.length > 0, function () {
	    return "Element arr[".concat(indices.join(']['), "] should be a primitive, ") + "but is an array of ".concat(val.length, " elements");
	  });
	  assert$1(val.length === shape[0], function () {
	    return "Element arr[".concat(indices.join(']['), "] should have ").concat(shape[0], " ") + "elements, but has ".concat(val.length, " elements");
	  });
	  var subShape = shape.slice(1);
	  for (var i = 0; i < val.length; ++i) {
	    deepAssertShapeConsistency(val[i], subShape, indices.concat(i));
	  }
	}
	function assertDtype(expectedDtype, actualDType, argName, functionName) {
	  if (expectedDtype === 'string_or_numeric') {
	    return;
	  }
	  if (expectedDtype == null) {
	    throw new Error("Expected dtype cannot be null.");
	  }
	  if (expectedDtype !== 'numeric' && expectedDtype !== actualDType || expectedDtype === 'numeric' && actualDType === 'string') {
	    throw new Error("Argument '".concat(argName, "' passed to '").concat(functionName, "' must ") + "be ".concat(expectedDtype, " tensor, but got ").concat(actualDType, " tensor"));
	  }
	}
	function convertToTensor(x, argName, functionName) {
	  var parseAsDtype = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'numeric';
	  if (x instanceof getGlobalTensorClass()) {
	    assertDtype(parseAsDtype, x.dtype, argName, functionName);
	    return x;
	  }
	  var inferredDtype = inferDtype(x);
	  // If the user expects a bool/int/float, use that info to update the
	  // inferredDtype when it is not a string.
	  if (inferredDtype !== 'string' && ['bool', 'int32', 'float32'].indexOf(parseAsDtype) >= 0) {
	    inferredDtype = parseAsDtype;
	  }
	  assertDtype(parseAsDtype, inferredDtype, argName, functionName);
	  if (x == null || !isTypedArray(x) && !Array.isArray(x) && typeof x !== 'number' && typeof x !== 'boolean' && typeof x !== 'string') {
	    var type = x == null ? 'null' : x.constructor.name;
	    throw new Error("Argument '".concat(argName, "' passed to '").concat(functionName, "' must be a ") + "Tensor or TensorLike, but got '".concat(type, "'"));
	  }
	  var inferredShape = inferShape(x, inferredDtype);
	  if (!isTypedArray(x) && !Array.isArray(x)) {
	    x = [x];
	  }
	  var skipTypedArray = true;
	  var values = inferredDtype !== 'string' ? toTypedArray(x, inferredDtype) : flatten$2(x, [], skipTypedArray);
	  return ENGINE.makeTensor(values, inferredShape, inferredDtype);
	}
	function convertToTensorArray(arg, argName, functionName) {
	  var parseAsDtype = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'numeric';
	  if (!Array.isArray(arg)) {
	    throw new Error("Argument ".concat(argName, " passed to ").concat(functionName, " must be a ") + '`Tensor[]` or `TensorLike[]`');
	  }
	  var tensors = arg;
	  return tensors.map(function (t, i) {
	    return convertToTensor(t, "".concat(argName, "[").concat(i, "]"), functionName, parseAsDtype);
	  });
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var OP_SCOPE_SUFFIX = '__op';
	/**
	 * Used for wrapping functions that perform math operations on
	 * Tensors. The function will be wrapped in a named scope that cleans all
	 * memory usage after the function is done.
	 */
	function op(f) {
	  var keys = Object.keys(f);
	  if (keys.length !== 1) {
	    throw new Error("Please provide an object with a single key " + "(operation name) mapping to a function. Got an object with " + "".concat(keys.length, " keys."));
	  }
	  var opName = keys[0];
	  var fn = f[opName];
	  // Strip the underscore from the end of the function name.
	  if (opName.endsWith('_')) {
	    opName = opName.substring(0, opName.length - 1);
	  }
	  // add an __op suffix to distinguish ops from kernels in tf.profile
	  opName = opName + OP_SCOPE_SUFFIX;
	  // tslint:disable-next-line:no-any
	  var f2 = function f2() {
	    ENGINE.startScope(opName);
	    try {
	      var result = fn.apply(void 0, arguments);
	      if (isPromise(result)) {
	        console.error('Cannot return a Promise inside of tidy.');
	      }
	      ENGINE.endScope(result);
	      return result;
	    } catch (ex) {
	      ENGINE.endScope(null);
	      throw ex;
	    }
	  };
	  Object.defineProperty(f2, 'name', {
	    value: opName,
	    configurable: true
	  });
	  // tslint:disable-next-line:no-any
	  return f2;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Converts two real numbers to a complex number.
	 *
	 * Given a tensor `real` representing the real part of a complex number, and a
	 * tensor `imag` representing the imaginary part of a complex number, this
	 * operation returns complex numbers elementwise of the form [r0, i0, r1, i1],
	 * where r represents the real part and i represents the imag part.
	 *
	 * The input tensors real and imag must have the same shape.
	 *
	 * ```js
	 * const real = tf.tensor1d([2.25, 3.25]);
	 * const imag = tf.tensor1d([4.75, 5.75]);
	 * const complex = tf.complex(real, imag);
	 *
	 * complex.print();
	 * ```
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function complex_(real, imag) {
	  var $real = convertToTensor(real, 'real', 'complex');
	  var $imag = convertToTensor(imag, 'imag', 'complex');
	  assertShapesMatch($real.shape, $imag.shape, "real and imag shapes, ".concat($real.shape, " and ").concat($imag.shape, ", ") + "must match in call to tf.complex().");
	  var inputs = {
	    real: $real,
	    imag: $imag
	  };
	  return ENGINE.runKernel(Complex, inputs);
	}
	var complex$2 = /* @__PURE__ */op({
	  complex_: complex_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/** This is shared code across all tensor creation methods. */
	function makeTensor(values, shape, inferredShape, dtype) {
	  if (dtype == null) {
	    dtype = inferDtype(values);
	  } else if (dtype === 'complex64') {
	    throw new Error("Cannot construct a complex64 tensor directly. " + "Please use tf.complex(real, imag).");
	  }
	  if (isWebGPUData(values) || isWebGLData(values)) {
	    if (dtype !== 'float32' && dtype !== 'int32') {
	      throw new Error("Creating tensor from GPU data only supports " + "'float32'|'int32' dtype, while the dtype is ".concat(dtype, "."));
	    }
	    return ENGINE.backend.createTensorFromGPUData(values, shape || inferredShape, dtype);
	  }
	  if (!isTypedArray(values) && !Array.isArray(values) && typeof values !== 'number' && typeof values !== 'boolean' && typeof values !== 'string') {
	    throw new Error('values passed to tensor(values) must be a number/boolean/string or ' + 'an array of numbers/booleans/strings, or a TypedArray');
	  }
	  // Verify that the shape matches the inferred shape.
	  if (shape != null) {
	    assertNonNegativeIntegerDimensions(shape);
	    var providedSize = sizeFromShape(shape);
	    var inferredSize = sizeFromShape(inferredShape);
	    assert$1(providedSize === inferredSize, function () {
	      return "Based on the provided shape, [".concat(shape, "], the tensor should have ") + "".concat(providedSize, " values but has ").concat(inferredSize);
	    });
	    for (var i = 0; i < inferredShape.length; ++i) {
	      var inferred = inferredShape[i];
	      var flatDimsDontMatch = i === inferredShape.length - 1 ? inferred !== sizeFromShape(shape.slice(i)) : true;
	      assert$1(inferredShape[i] === shape[i] || !flatDimsDontMatch, function () {
	        return "Error creating a new Tensor. Inferred shape " + "(".concat(inferredShape, ") does not match the provided ") + "shape (".concat(shape, "). ");
	      });
	    }
	  }
	  if (!isTypedArray(values) && !Array.isArray(values)) {
	    values = [values];
	  }
	  shape = shape || inferredShape;
	  values = dtype !== 'string' ? toTypedArray(values, dtype) : flatten$2(values, [], true);
	  return ENGINE.makeTensor(values, shape, dtype);
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a `tf.Tensor` with the provided values, shape and dtype.
	 *
	 * ```js
	 * // Pass an array of values to create a vector.
	 * tf.tensor([1, 2, 3, 4]).print();
	 * ```
	 *
	 * ```js
	 * // Pass a nested array of values to make a matrix or a higher
	 * // dimensional tensor.
	 * tf.tensor([[1, 2], [3, 4]]).print();
	 * ```
	 *
	 * ```js
	 * // Pass a flat array and specify a shape yourself.
	 * tf.tensor([1, 2, 3, 4], [2, 2]).print();
	 * ```
	 *
	 * ```js
	 * // Pass a `WebGLData` object and specify a shape yourself.
	 *
	 * // This makes it possible for TF.js applications to avoid GPU / CPU sync.
	 * // For example, if your application includes a preprocessing step on the GPU,
	 * // you could upload the GPU output directly to TF.js, rather than first
	 * // downloading the values.
	 *
	 * // Example for WebGL2:
	 * if (tf.findBackend('custom-webgl') == null) {
	 *   const customCanvas = document.createElement('canvas');
	 *   const customBackend = new tf.MathBackendWebGL(customCanvas);
	 *   tf.registerBackend('custom-webgl', () => customBackend);
	 * }
	 * const savedBackend = tf.getBackend();
	 * await tf.setBackend('custom-webgl');
	 * const gl = tf.backend().gpgpu.gl;
	 * const texture = gl.createTexture();
	 * const tex2d = gl.TEXTURE_2D;
	 * const width = 2;
	 * const height = 2;
	 *
	 * gl.bindTexture(tex2d, texture);
	 * gl.texParameteri(tex2d, gl.TEXTURE_WRAP_S, gl.CLAMP_TO_EDGE);
	 * gl.texParameteri(tex2d, gl.TEXTURE_WRAP_T, gl.CLAMP_TO_EDGE);
	 * gl.texParameteri(tex2d, gl.TEXTURE_MIN_FILTER, gl.NEAREST);
	 * gl.texParameteri(tex2d, gl.TEXTURE_MAG_FILTER, gl.NEAREST);
	 * gl.texImage2D(
	 *   tex2d, 0, gl.RGBA32F, // internalFormat
	 *   width, height, 0,
	 *   gl.RGBA, // textureFormat
	 *   gl.FLOAT, // textureType
	 *   new Float32Array([0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15])
	 * );
	 *
	 * // Currently, the `texture` has 4 pixels:
	 * // Pixel0 is {R:0, G:1, B:2, A:3}
	 * // Pixel1 is {R:4, G:5, B:6, A:7}
	 * // Pixel2 is {R:8, G:9, B:10, A:11}
	 * // Pixel3 is {R:12, G:13, B:14, A:15}
	 *
	 * const logicalShape = [height * width * 2];
	 * const a = tf.tensor({texture, height, width, channels: 'BR'}, logicalShape);
	 * a.print();
	 * // Tensor value will be [2, 0, 6, 4, 10, 8, 14, 12], since [2, 0] is the
	 * // values of 'B' and 'R' channels of Pixel0, [6, 4] is the values of 'B' and
	 * 'R'
	 * // channels of Pixel1...
	 *
	 * // For postprocessing on the GPU, it's possible to retrieve the texture
	 * // backing any tensor by calling the tensor's `dataToGPU` method like
	 * // so:
	 *
	 * const tex = a.dataToGPU();
	 * await tf.setBackend(savedBackend);
	 * ```
	 *
	 * ```js
	 * // Pass a `WebGPUData` object and specify a shape yourself.
	 *
	 * // This makes it possible for TF.js applications to avoid GPU / CPU sync.
	 * // For example, if your application includes a preprocessing step on the GPU,
	 * // you could upload the GPU output directly to TF.js, rather than first
	 * // downloading the values. Unlike WebGL, this optionally supports zero copy
	 * // by WebGPUData.zeroCopy. When zeroCopy is false or undefined(default), this
	 * // passing GPUBuffer can be destroyed after tensor is created. When zeroCopy
	 * // is true, this GPUBuffer is bound directly by the tensor, so do not destroy
	 * // this GPUBuffer until all access is done.
	 *
	 * // Example for WebGPU:
	 * function createGPUBufferFromData(device, data, dtype) {
	 *   const bytesPerElement = 4;
	 *   const sizeInBytes = data.length * bytesPerElement;
	 *
	 *   const gpuWriteBuffer = device.createBuffer({
	 *     mappedAtCreation: true,
	 *     size: sizeInBytes,
	 *     usage: GPUBufferUsage.MAP_WRITE | GPUBufferUsage.COPY_SRC
	 *   });
	 *   const arrayBuffer = gpuWriteBuffer.getMappedRange();
	 *   if (dtype === 'float32') {
	 *     new Float32Array(arrayBuffer).set(data);
	 *   } else if (dtype === 'int32') {
	 *     new Int32Array(arrayBuffer).set(data);
	 *   } else {
	 *     throw new Error(
	 *         `Creating tensor from GPUBuffer only supports` +
	 *         `'float32'|'int32' dtype, while the dtype is ${dtype}.`);
	 *   }
	 *   gpuWriteBuffer.unmap();
	 *
	 *   const gpuReadBuffer = device.createBuffer({
	 *     mappedAtCreation: false,
	 *     size: sizeInBytes,
	 *     usage: GPUBufferUsage.COPY_DST | GPUBufferUsage.STORAGE |
	 *         GPUBufferUsage.COPY_SRC
	 *   });
	 *
	 *   const copyEncoder = device.createCommandEncoder();
	 *   copyEncoder.copyBufferToBuffer(
	 *       gpuWriteBuffer, 0, gpuReadBuffer, 0, sizeInBytes);
	 *   const copyCommands = copyEncoder.finish();
	 *   device.queue.submit([copyCommands]);
	 *   gpuWriteBuffer.destroy();
	 *   return gpuReadBuffer;
	 * }
	 *
	 * const savedBackend = tf.getBackend();
	 * await tf.setBackend('webgpu').catch(
	 *     () => {throw new Error(
	 *         'Failed to use WebGPU backend. Please use Chrome Canary to run.')});
	 * const dtype = 'float32';
	 * const device = tf.backend().device;
	 * const aData = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16];
	 * const bData = [1, 2, 3, 4, 1, 2, 3, 4, 1, 2, 3, 4, 1, 2, 3, 4];
	 * const expected = [2, 4, 6, 8, 6, 8, 10, 12, 10, 12, 14, 16, 14, 16, 18, 20];
	 * const aBuffer = createGPUBufferFromData(device, aData, dtype);
	 * const shape = [aData.length];
	 * // To use zeroCopy, use {buffer: aBuffer, zeroCopy: true} instead and destroy
	 * // aBuffer untill all access is done.
	 * const a = tf.tensor({buffer: aBuffer}, shape, dtype);
	 * const b = tf.tensor(bData, shape, dtype);
	 * const result = tf.add(a, b);
	 * result.print();
	 * a.dispose();
	 * b.dispose();
	 * result.dispose();
	 * aBuffer.destroy();
	 * await tf.setBackend(savedBackend);
	 * ```
	 * @param values The values of the tensor. Can be nested array of numbers,
	 * or a flat array, or a `TypedArray`(At the moment it supports Uint8Array,
	 * Uint8ClampedArray, Int32Array, Float32Array) data types, or a `WebGLData`
	 * object, or a `WebGPUData` object. If the values are strings, they will be
	 * encoded as utf-8 and kept as `Uint8Array[]`. If the values is a `WebGLData`
	 * object, the dtype could only be 'float32' or 'int32' and the object has to
	 * have: 1. texture, a `WebGLTexture`, the texture must share the same
	 * `WebGLRenderingContext` with TFJS's WebGL backend (you could create a custom
	 * WebGL backend from your texture's canvas) and the internal texture format
	 * for the input texture must be floating point or normalized integer; 2.
	 * height, the height of the texture; 3. width, the width of the texture; 4.
	 * channels, a non-empty subset of 'RGBA', indicating the values of which
	 * channels will be passed to the tensor, such as 'R' or 'BR' (The order of the
	 * channels affect the order of tensor values. ). (If the values passed from
	 * texture is less than the tensor size, zeros will be padded at the rear.). If
	 * the values is a `WebGPUData` object, the dtype could only be 'float32' or
	 * 'int32 and the object has to have: buffer, a `GPUBuffer`. The buffer must:
	 * 1. share the same `GPUDevice` with TFJS's WebGPU backend; 2. buffer.usage
	 * should at least support GPUBufferUsage.STORAGE | GPUBufferUsage.COPY_SRC; 3.
	 * buffer.size should not be smaller than the byte size of tensor shape.
	 * WebGPUData optionally supports zero copy by flag zeroCopy. When zeroCopy is
	 * false or undefined(default),this passing GPUBuffer can be destroyed after
	 * tensor is created. When zeroCopy is true, this GPUBuffer is bound directly
	 * by the tensor, so do not destroy this GPUBuffer until all access is done.
	 * @param shape The shape of the tensor. Optional. If not provided,
	 *   it is inferred from `values`.
	 * @param dtype The data type.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function tensor(values, shape, dtype) {
	  var inferredShape = inferShape(values, dtype);
	  return makeTensor(values, shape, inferredShape, dtype);
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/* Type definitions for exporting and importing of models. */
	/**
	 * A map from Tensor dtype to number of bytes per element of the Tensor.
	 */
	var DTYPE_VALUE_SIZE_MAP = {
	  'float32': 4,
	  'float16': 2,
	  'int32': 4,
	  'uint16': 2,
	  'uint8': 1,
	  'bool': 1,
	  'complex64': 8
	};

	/**
	 * Wraps a list of ArrayBuffers into a `slice()`-able object without allocating
	 * a large ArrayBuffer.
	 *
	 * Allocating large ArrayBuffers (~2GB) can be unstable on Chrome. TFJS loads
	 * its weights as a list of (usually) 4MB ArrayBuffers and then slices the
	 * weight tensors out of them. For small models, it's safe to concatenate all
	 * the weight buffers into a single ArrayBuffer and then slice the weight
	 * tensors out of it, but for large models, a different approach is needed.
	 */
	var CompositeArrayBuffer = /*#__PURE__*/function () {
	  function CompositeArrayBuffer(buffers) {
	    _classCallCheck(this, CompositeArrayBuffer);
	    this.shards = [];
	    this.previousShardIndex = 0;
	    if (buffers == null) {
	      return;
	    }
	    // Normalize the `buffers` input to be `ArrayBuffer[]`.
	    if (!(buffers instanceof Array)) {
	      buffers = [buffers];
	    }
	    buffers = buffers.map(function (bufferOrTypedArray) {
	      if (isTypedArray(bufferOrTypedArray)) {
	        return bufferOrTypedArray.buffer;
	      }
	      return bufferOrTypedArray;
	    });
	    // Skip setting up shards if there are no buffers.
	    if (buffers.length === 0) {
	      return;
	    }
	    this.bufferUniformSize = buffers[0].byteLength;
	    var start = 0;
	    for (var i = 0; i < buffers.length; i++) {
	      var buffer = buffers[i];
	      // Check that all buffers except the last one have the same length.
	      if (i !== buffers.length - 1 && buffer.byteLength !== this.bufferUniformSize) {
	        // Unset the buffer uniform size, since the buffer sizes are not
	        // uniform.
	        this.bufferUniformSize = undefined;
	      }
	      // Create the shards, including their start and end points.
	      var end = start + buffer.byteLength;
	      this.shards.push({
	        buffer: buffer,
	        start: start,
	        end: end
	      });
	      start = end;
	    }
	    // Set the byteLength
	    if (this.shards.length === 0) {
	      this.byteLength = 0;
	    }
	    this.byteLength = this.shards[this.shards.length - 1].end;
	  }
	  _createClass(CompositeArrayBuffer, [{
	    key: "slice",
	    value: function slice() {
	      var start = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
	      var end = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : this.byteLength;
	      // If there are no shards, then the CompositeArrayBuffer was initialized
	      // with no data.
	      if (this.shards.length === 0) {
	        return new ArrayBuffer(0);
	      }
	      // NaN is treated as zero for slicing. This matches ArrayBuffer's behavior.
	      start = isNaN(Number(start)) ? 0 : start;
	      end = isNaN(Number(end)) ? 0 : end;
	      // Fix the bounds to within the array.
	      start = Math.max(0, start);
	      end = Math.min(this.byteLength, end);
	      if (end <= start) {
	        return new ArrayBuffer(0);
	      }
	      var startShardIndex = this.findShardForByte(start);
	      if (startShardIndex === -1) {
	        // This should not happen since the start and end indices are always
	        // within 0 and the composite array's length.
	        throw new Error("Could not find start shard for byte ".concat(start));
	      }
	      var size = end - start;
	      var outputBuffer = new ArrayBuffer(size);
	      var outputArray = new Uint8Array(outputBuffer);
	      var sliced = 0;
	      for (var i = startShardIndex; i < this.shards.length; i++) {
	        var shard = this.shards[i];
	        var globalStart = start + sliced;
	        var localStart = globalStart - shard.start;
	        var outputStart = sliced;
	        var globalEnd = Math.min(end, shard.end);
	        var localEnd = globalEnd - shard.start;
	        var outputSlice = new Uint8Array(shard.buffer, localStart, localEnd - localStart);
	        outputArray.set(outputSlice, outputStart);
	        sliced += outputSlice.length;
	        if (end < shard.end) {
	          break;
	        }
	      }
	      return outputBuffer;
	    }
	    /**
	     * Get the index of the shard that contains the byte at `byteIndex`.
	     */
	  }, {
	    key: "findShardForByte",
	    value: function findShardForByte(byteIndex) {
	      if (this.shards.length === 0 || byteIndex < 0 || byteIndex >= this.byteLength) {
	        return -1;
	      }
	      // If the buffers have a uniform size, compute the shard directly.
	      if (this.bufferUniformSize != null) {
	        this.previousShardIndex = Math.floor(byteIndex / this.bufferUniformSize);
	        return this.previousShardIndex;
	      }
	      // If the buffers don't have a uniform size, we need to search for the
	      // shard. That means we need a function to check where the byteIndex lies
	      // relative to a given shard.
	      function check(shard) {
	        if (byteIndex < shard.start) {
	          return -1;
	        }
	        if (byteIndex >= shard.end) {
	          return 1;
	        }
	        return 0;
	      }
	      // For efficiency, try the previous shard first.
	      if (check(this.shards[this.previousShardIndex]) === 0) {
	        return this.previousShardIndex;
	      }
	      // Otherwise, use a generic search function.
	      // This should almost never end up being used in practice since the weight
	      // entries should always be in order.
	      var index = search(this.shards, check);
	      if (index === -1) {
	        return -1;
	      }
	      this.previousShardIndex = index;
	      return this.previousShardIndex;
	    }
	  }], [{
	    key: "join",
	    value:
	    /**
	     * Concatenate a number of ArrayBuffers into one.
	     *
	     * @param buffers An array of ArrayBuffers to concatenate, or a single
	     *     ArrayBuffer.
	     * @returns Result of concatenating `buffers` in order.
	     */
	    function join(buffers) {
	      return new CompositeArrayBuffer(buffers).slice();
	    }
	  }]);
	  return CompositeArrayBuffer;
	}();
	/**
	 * Search for an element of a sorted array.
	 *
	 * @param sortedArray The sorted array to search
	 * @param compare A function to compare the current value against the searched
	 *     value. Return 0 on a match, negative if the searched value is less than
	 *     the value passed to the function, and positive if the searched value is
	 *     greater than the value passed to the function.
	 * @returns The index of the element, or -1 if it's not in the array.
	 */
	function search(sortedArray, compare) {
	  // Binary search
	  var min = 0;
	  var max = sortedArray.length;
	  while (min <= max) {
	    var middle = Math.floor((max - min) / 2) + min;
	    var side = compare(sortedArray[middle]);
	    if (side === 0) {
	      return middle;
	    } else if (side < 0) {
	      max = middle;
	    } else {
	      min = middle + 1;
	    }
	  }
	  return -1;
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Enables production mode which disables correctness checks in favor of
	 * performance.
	 *
	 * @doc {heading: 'Environment'}
	 */
	function enableProdMode() {
	  env().set('PROD', true);
	}
	/**
	 * Enables debug mode which will log information about all executed kernels:
	 * the elapsed time of the kernel execution, as well as the rank, shape, and
	 * size of the output tensor.
	 *
	 * Debug mode will significantly slow down your application as it will
	 * download the result of every operation to the CPU. This should not be used in
	 * production. Debug mode does not affect the timing information of the kernel
	 * execution as we do not measure download time in the kernel execution time.
	 *
	 * See also: `tf.profile`, `tf.memory`.
	 *
	 * @doc {heading: 'Environment'}
	 */
	function enableDebugMode() {
	  env().set('DEBUG', true);
	}
	/** Globally disables deprecation warnings */
	function disableDeprecationWarnings() {
	  env().set('DEPRECATION_WARNINGS_ENABLED', false);
	  console.warn("TensorFlow.js deprecation warnings have been disabled.");
	}
	/** Warn users about deprecated functionality. */
	function deprecationWarn(msg) {
	  if (env().getBool('DEPRECATION_WARNINGS_ENABLED')) {
	    console.warn(msg + ' You can disable deprecation warnings with ' + 'tf.disableDeprecationWarnings().');
	  }
	}
	setDeprecationWarningFn(deprecationWarn);
	/**
	 * Dispose all variables kept in backend engine.
	 *
	 * @doc {heading: 'Environment'}
	 */
	function disposeVariables() {
	  ENGINE.disposeVariables();
	}
	/**
	 * It returns the global engine that keeps track of all tensors and backends.
	 *
	 * @doc {heading: 'Environment'}
	 */
	function engine() {
	  return ENGINE;
	}
	/**
	 * Returns memory info at the current time in the program. The result is an
	 * object with the following properties:
	 *
	 * - `numBytes`: Number of bytes allocated (undisposed) at this time.
	 * - `numTensors`: Number of unique tensors allocated.
	 * - `numDataBuffers`: Number of unique data buffers allocated
	 *   (undisposed) at this time, which is ≤ the number of tensors
	 *   (e.g. `a.reshape(newShape)` makes a new Tensor that shares the same
	 *   data buffer with `a`).
	 * - `unreliable`: True if the memory usage is unreliable. See `reasons` when
	 *    `unreliable` is true.
	 * - `reasons`: `string[]`, reasons why the memory is unreliable, present if
	 *    `unreliable` is true.
	 *
	 * WebGL Properties:
	 * - `numBytesInGPU`: Number of bytes allocated (undisposed) in the GPU only at
	 *     this time.
	 *
	 * @doc {heading: 'Performance', subheading: 'Memory'}
	 */
	function memory() {
	  return ENGINE.memory();
	}
	/**
	 * Executes the provided function `f()` and returns a promise that resolves
	 * with information about the function's memory use:
	 * - `newBytes`: the number of new bytes allocated
	 * - `newTensors`: the number of new tensors created
	 * - `peakBytes`: the peak number of bytes allocated
	 * - `kernels`: an array of objects for each kernel involved that reports
	 * their input and output shapes, number of bytes used, and number of new
	 * tensors created.
	 * - `kernelNames`: an array of unique strings with just the names of the
	 * kernels in the `kernels` array.
	 *
	 * ```js
	 * const profile = await tf.profile(() => {
	 *   const x = tf.tensor1d([1, 2, 3]);
	 *   let x2 = x.square();
	 *   x2.dispose();
	 *   x2 = x.square();
	 *   x2.dispose();
	 *   return x;
	 * });
	 *
	 * console.log(`newBytes: ${profile.newBytes}`);
	 * console.log(`newTensors: ${profile.newTensors}`);
	 * console.log(`byte usage over all kernels: ${profile.kernels.map(k =>
	 * k.totalBytesSnapshot)}`);
	 * ```
	 *
	 *
	 * @doc {heading: 'Performance', subheading: 'Profile'}
	 */
	function profile(f) {
	  return ENGINE.profile(f);
	}
	/**
	 * Executes the provided function `fn` and after it is executed, cleans up all
	 * intermediate tensors allocated by `fn` except those returned by `fn`.
	 * `fn` must not return a Promise (async functions not allowed). The returned
	 * result can be a complex object.
	 *
	 * Using this method helps avoid memory leaks. In general, wrap calls to
	 * operations in `tf.tidy` for automatic memory cleanup.
	 *
	 * NOTE: Variables do *not* get cleaned up when inside a tidy(). If you want to
	 * dispose variables, please use `tf.disposeVariables` or call dispose()
	 * directly on variables.
	 *
	 * ```js
	 * // y = 2 ^ 2 + 1
	 * const y = tf.tidy(() => {
	 *   // a, b, and one will be cleaned up when the tidy ends.
	 *   const one = tf.scalar(1);
	 *   const a = tf.scalar(2);
	 *   const b = a.square();
	 *
	 *   console.log('numTensors (in tidy): ' + tf.memory().numTensors);
	 *
	 *   // The value returned inside the tidy function will return
	 *   // through the tidy, in this case to the variable y.
	 *   return b.add(one);
	 * });
	 *
	 * console.log('numTensors (outside tidy): ' + tf.memory().numTensors);
	 * y.print();
	 * ```
	 *
	 * @param nameOrFn The name of the closure, or the function to execute.
	 *     If a name is provided, the 2nd argument should be the function.
	 *     If debug mode is on, the timing and the memory usage of the function
	 *     will be tracked and displayed on the console using the provided name.
	 * @param fn The function to execute.
	 *
	 * @doc {heading: 'Performance', subheading: 'Memory'}
	 */
	function tidy(nameOrFn, fn) {
	  return ENGINE.tidy(nameOrFn, fn);
	}
	/**
	 * Disposes any `tf.Tensor`s found within the provided object.
	 *
	 * @param container an object that may be a `tf.Tensor` or may directly
	 *     contain `tf.Tensor`s, such as a `Tensor[]` or `{key: Tensor, ...}`. If
	 *     the object is not a `tf.Tensor` or does not contain `Tensors`, nothing
	 *     happens. In general it is safe to pass any object here, except that
	 *     `Promise`s are not supported.
	 *
	 * @doc {heading: 'Performance', subheading: 'Memory'}
	 */
	function dispose(container) {
	  var tensors = getTensorsInContainer(container);
	  tensors.forEach(function (tensor) {
	    return tensor.dispose();
	  });
	}
	/**
	 * Keeps a `tf.Tensor` generated inside a `tf.tidy` from being disposed
	 * automatically.
	 *
	 * ```js
	 * let b;
	 * const y = tf.tidy(() => {
	 *   const one = tf.scalar(1);
	 *   const a = tf.scalar(2);
	 *
	 *   // b will not be cleaned up by the tidy. a and one will be cleaned up
	 *   // when the tidy ends.
	 *   b = tf.keep(a.square());
	 *
	 *   console.log('numTensors (in tidy): ' + tf.memory().numTensors);
	 *
	 *   // The value returned inside the tidy function will return
	 *   // through the tidy, in this case to the variable y.
	 *   return b.add(one);
	 * });
	 *
	 * console.log('numTensors (outside tidy): ' + tf.memory().numTensors);
	 * console.log('y:');
	 * y.print();
	 * console.log('b:');
	 * b.print();
	 * ```
	 *
	 * @param result The tensor to keep from being disposed.
	 *
	 * @doc {heading: 'Performance', subheading: 'Memory'}
	 */
	function keep(result) {
	  return ENGINE.keep(result);
	}
	/**
	 * Executes `f()` and returns a promise that resolves with timing
	 * information.
	 *
	 * The result is an object with the following properties:
	 *
	 * - `wallMs`: Wall execution time.
	 * - `kernelMs`: Kernel execution time, ignoring data transfer. If using the
	 * WebGL backend and the query timer extension is not available, this will
	 * return an error object.
	 * - On `WebGL` The following additional properties exist:
	 *   - `uploadWaitMs`: CPU blocking time on texture uploads.
	 *   - `downloadWaitMs`: CPU blocking time on texture downloads (readPixels).
	 *
	 * ```js
	 * const x = tf.randomNormal([20, 20]);
	 * const time = await tf.time(() => x.matMul(x));
	 *
	 * console.log(`kernelMs: ${time.kernelMs}, wallTimeMs: ${time.wallMs}`);
	 * ```
	 *
	 * @param f The function to execute and time.
	 *
	 * @doc {heading: 'Performance', subheading: 'Timing'}
	 */
	function time(f) {
	  return ENGINE.time(f);
	}
	/**
	 * Sets the backend (cpu, webgl, wasm, etc) responsible for creating tensors and
	 * executing operations on those tensors. Returns a promise that resolves
	 * to a boolean if the backend initialization was successful.
	 *
	 * Note this disposes the current backend, if any, as well as any tensors
	 * associated with it. A new backend is initialized, even if it is of the
	 * same type as the previous one.
	 *
	 * @param backendName The name of the backend. Currently supports
	 *     `'webgl'|'cpu'` in the browser, `'tensorflow'` under node.js
	 *     (requires tfjs-node), and `'wasm'` (requires tfjs-backend-wasm).
	 *
	 * @doc {heading: 'Backends'}
	 */
	function setBackend$1(backendName) {
	  return ENGINE.setBackend(backendName);
	}
	/**
	 * Returns a promise that resolves when the currently selected backend (or the
	 * highest priority one) has initialized. Await this promise when you are using
	 * a backend that has async initialization.
	 *
	 * @doc {heading: 'Backends'}
	 */
	function ready() {
	  return ENGINE.ready();
	}
	/**
	 * Returns the current backend name (cpu, webgl, etc). The backend is
	 * responsible for creating tensors and executing operations on those tensors.
	 *
	 * @doc {heading: 'Backends'}
	 */
	function getBackend$1() {
	  return ENGINE.backendName;
	}
	/**
	 * Removes a backend and the registered factory.
	 *
	 * @doc {heading: 'Backends'}
	 */
	function removeBackend(name) {
	  ENGINE.removeBackend(name);
	}
	/**
	 * Finds the backend registered under the provided name. Returns null if the
	 * name is not in the registry, or the registration hasn't finished yet.
	 */
	function findBackend(name) {
	  return ENGINE.findBackend(name);
	}
	/**
	 * Finds the backend factory registered under the provided name. Returns a
	 * function that produces a new backend when called. Returns null if the name
	 * is not in the registry.
	 */
	function findBackendFactory(name) {
	  return ENGINE.findBackendFactory(name);
	}
	/**
	 * Registers a global backend. The registration should happen when importing
	 * a module file (e.g. when importing `backend_webgl.ts`), and is used for
	 * modular builds (e.g. custom tfjs bundle with only webgl support).
	 *
	 * @param factory The backend factory function. When called, it should
	 * return a backend instance, or a promise of an instance.
	 * @param priority The priority of the backend (higher = more important).
	 *     In case multiple backends are registered, the priority is used to find
	 *     the best backend. Defaults to 1.
	 * @return False if there is already a registered backend under this name, true
	 *     if not.
	 *
	 * @doc {heading: 'Backends'}
	 */
	function registerBackend(name, factory) {
	  var priority = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;
	  return ENGINE.registerBackend(name, factory, priority);
	}
	/**
	 * Gets the current backend. If no backends have been initialized, this will
	 * attempt to initialize the best backend. Will throw an error if the highest
	 * priority backend has async initialization, in which case you should call
	 * 'await tf.ready()' before running other code.
	 *
	 * @doc {heading: 'Backends'}
	 */
	function backend$1() {
	  return ENGINE.backend;
	}
	/**
	 * Sets the global platform.
	 *
	 * @param platformName The name of this platform.
	 * @param platform A platform implementation.
	 */
	function setPlatform(platformName, platform) {
	  env().setPlatform(platformName, platform);
	}

	/** Number of bytes reserved for the length of the string. (32bit integer). */
	var NUM_BYTES_STRING_LENGTH = 4;
	/**
	 * Encode a map from names to weight values as an ArrayBuffer, along with an
	 * `Array` of `WeightsManifestEntry` as specification of the encoded weights.
	 *
	 * This function does not perform sharding.
	 *
	 * This function is the reverse of `decodeWeights`.
	 *
	 * @param tensors A map ("dict") from names to tensors.
	 * @param group Group to which the weights belong (optional).
	 * @returns A `Promise` of
	 *   - A flat `ArrayBuffer` with all the binary values of the `Tensor`s
	 *     concatenated.
	 *   - An `Array` of `WeightManifestEntry`s, carrying information including
	 *     tensor names, `dtype`s and shapes.
	 * @throws Error: on unsupported tensor `dtype`.
	 */
	function encodeWeights(_x, _x2) {
	  return _encodeWeights.apply(this, arguments);
	}
	/**
	 * Decode flat ArrayBuffer as weights.
	 *
	 * This function does not handle sharding.
	 *
	 * This function is the reverse of `encodeWeights`.
	 *
	 * @param weightData A flat ArrayBuffer or an array of ArrayBuffers carrying the
	 *   binary values of the tensors concatenated in the order specified in
	 *   `specs`.
	 * @param specs Specifications of the names, dtypes and shapes of the tensors
	 *   whose value are encoded by `buffer`.
	 * @return A map from tensor name to tensor value, with the names corresponding
	 *   to names in `specs`.
	 * @throws Error, if any of the tensors has unsupported dtype.
	 */
	function _encodeWeights() {
	  _encodeWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(tensors, group) {
	    var specs, dataPromises, names, _loop, i, tensorValues;
	    return _regeneratorRuntime().wrap(function _callee2$(_context3) {
	      while (1) switch (_context3.prev = _context3.next) {
	        case 0:
	          // TODO(adarob, cais): Support quantization.
	          specs = [];
	          dataPromises = [];
	          names = Array.isArray(tensors) ? tensors.map(function (tensor) {
	            return tensor.name;
	          }) : Object.keys(tensors);
	          _loop = /*#__PURE__*/_regeneratorRuntime().mark(function _loop() {
	            var name, t, spec, utf8bytes;
	            return _regeneratorRuntime().wrap(function _loop$(_context2) {
	              while (1) switch (_context2.prev = _context2.next) {
	                case 0:
	                  name = names[i];
	                  t = Array.isArray(tensors) ? tensors[i].tensor : tensors[name];
	                  if (!(t.dtype !== 'float32' && t.dtype !== 'int32' && t.dtype !== 'bool' && t.dtype !== 'string' && t.dtype !== 'complex64')) {
	                    _context2.next = 4;
	                    break;
	                  }
	                  throw new Error("Unsupported dtype in weight '".concat(name, "': ").concat(t.dtype));
	                case 4:
	                  spec = {
	                    name: name,
	                    shape: t.shape,
	                    dtype: t.dtype
	                  };
	                  if (t.dtype === 'string') {
	                    utf8bytes = new Promise( /*#__PURE__*/function () {
	                      var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(resolve) {
	                        var vals, totalNumBytes, bytes, offset, _i6, val, bytesOfLength;
	                        return _regeneratorRuntime().wrap(function _callee$(_context) {
	                          while (1) switch (_context.prev = _context.next) {
	                            case 0:
	                              _context.next = 2;
	                              return t.bytes();
	                            case 2:
	                              vals = _context.sent;
	                              totalNumBytes = vals.reduce(function (p, c) {
	                                return p + c.length;
	                              }, 0) + NUM_BYTES_STRING_LENGTH * vals.length;
	                              bytes = new Uint8Array(totalNumBytes);
	                              offset = 0;
	                              for (_i6 = 0; _i6 < vals.length; _i6++) {
	                                val = vals[_i6];
	                                bytesOfLength = new Uint8Array(new Uint32Array([val.length]).buffer);
	                                bytes.set(bytesOfLength, offset);
	                                offset += NUM_BYTES_STRING_LENGTH;
	                                bytes.set(val, offset);
	                                offset += val.length;
	                              }
	                              resolve(bytes);
	                            case 8:
	                            case "end":
	                              return _context.stop();
	                          }
	                        }, _callee);
	                      }));
	                      return function (_x12) {
	                        return _ref.apply(this, arguments);
	                      };
	                    }());
	                    dataPromises.push(utf8bytes);
	                  } else {
	                    dataPromises.push(t.data());
	                  }
	                  if (group != null) {
	                    spec.group = group;
	                  }
	                  specs.push(spec);
	                case 8:
	                case "end":
	                  return _context2.stop();
	              }
	            }, _loop);
	          });
	          i = 0;
	        case 5:
	          if (!(i < names.length)) {
	            _context3.next = 10;
	            break;
	          }
	          return _context3.delegateYield(_loop(), "t0", 7);
	        case 7:
	          ++i;
	          _context3.next = 5;
	          break;
	        case 10:
	          _context3.next = 12;
	          return Promise.all(dataPromises);
	        case 12:
	          tensorValues = _context3.sent;
	          return _context3.abrupt("return", {
	            data: concatenateTypedArrays(tensorValues),
	            specs: specs
	          });
	        case 14:
	        case "end":
	          return _context3.stop();
	      }
	    }, _callee2);
	  }));
	  return _encodeWeights.apply(this, arguments);
	}
	function decodeWeights(weightData, specs) {
	  // TODO(adarob, cais): Support quantization.
	  var compositeBuffer = new CompositeArrayBuffer(weightData);
	  var out = {};
	  var offset = 0;
	  var _iterator = _createForOfIteratorHelper(specs),
	    _step;
	  try {
	    for (_iterator.s(); !(_step = _iterator.n()).done;) {
	      var spec = _step.value;
	      var byteLength = getWeightBytelength(spec, function (start, end) {
	        return compositeBuffer.slice(offset + start, offset + end);
	      });
	      out[spec.name] = decodeWeight(spec, compositeBuffer.slice(offset, offset + byteLength));
	      offset += byteLength;
	    }
	  } catch (err) {
	    _iterator.e(err);
	  } finally {
	    _iterator.f();
	  }
	  return out;
	}
	function getWeightBytelength(spec, slice) {
	  var size = sizeFromShape(spec.shape);
	  var bytesPerValue;
	  if ('quantization' in spec) {
	    var quantization = spec.quantization;
	    bytesPerValue = DTYPE_VALUE_SIZE_MAP[quantization.dtype];
	  } else if (spec.dtype === 'string') {
	    // Can not statically determine string length.
	    var byteLength = 0;
	    for (var i = 0; i < size; i++) {
	      byteLength += NUM_BYTES_STRING_LENGTH + new Uint32Array(slice(byteLength, byteLength + NUM_BYTES_STRING_LENGTH))[0];
	    }
	    return byteLength;
	  } else {
	    bytesPerValue = DTYPE_VALUE_SIZE_MAP[spec.dtype];
	  }
	  return size * bytesPerValue;
	}
	function getWeightBytelengthAsync(_x3, _x4) {
	  return _getWeightBytelengthAsync.apply(this, arguments);
	}
	function _getWeightBytelengthAsync() {
	  _getWeightBytelengthAsync = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3(spec, slice) {
	    var size, bytesPerValue, quantization, byteLength, i;
	    return _regeneratorRuntime().wrap(function _callee3$(_context4) {
	      while (1) switch (_context4.prev = _context4.next) {
	        case 0:
	          size = sizeFromShape(spec.shape);
	          if (!('quantization' in spec)) {
	            _context4.next = 6;
	            break;
	          }
	          quantization = spec.quantization;
	          bytesPerValue = DTYPE_VALUE_SIZE_MAP[quantization.dtype];
	          _context4.next = 25;
	          break;
	        case 6:
	          if (!(spec.dtype === 'string')) {
	            _context4.next = 24;
	            break;
	          }
	          // Can not statically determine string length.
	          byteLength = 0;
	          i = 0;
	        case 9:
	          if (!(i < size)) {
	            _context4.next = 21;
	            break;
	          }
	          _context4.t0 = byteLength;
	          _context4.t1 = NUM_BYTES_STRING_LENGTH;
	          _context4.t2 = Uint32Array;
	          _context4.next = 15;
	          return slice(byteLength, byteLength + NUM_BYTES_STRING_LENGTH);
	        case 15:
	          _context4.t3 = _context4.sent;
	          _context4.t4 = new _context4.t2(_context4.t3)[0];
	          byteLength = _context4.t0 += _context4.t1 + _context4.t4;
	        case 18:
	          i++;
	          _context4.next = 9;
	          break;
	        case 21:
	          return _context4.abrupt("return", byteLength);
	        case 24:
	          bytesPerValue = DTYPE_VALUE_SIZE_MAP[spec.dtype];
	        case 25:
	          return _context4.abrupt("return", size * bytesPerValue);
	        case 26:
	        case "end":
	          return _context4.stop();
	      }
	    }, _callee3);
	  }));
	  return _getWeightBytelengthAsync.apply(this, arguments);
	}
	function decodeWeight(spec, byteBuffer) {
	  var name = spec.name;
	  var dtype = spec.dtype;
	  var shape = spec.shape;
	  var size = sizeFromShape(shape);
	  var values;
	  var offset = 0;
	  if ('quantization' in spec) {
	    var quantization = spec.quantization;
	    if (quantization.dtype === 'uint8' || quantization.dtype === 'uint16') {
	      if (!('min' in quantization && 'scale' in quantization)) {
	        throw new Error("Weight ".concat(spec.name, " with quantization ").concat(quantization.dtype, " ") + "doesn't have corresponding metadata min and scale.");
	      }
	    } else if (quantization.dtype === 'float16') {
	      if (dtype !== 'float32') {
	        throw new Error("Weight ".concat(spec.name, " is quantized with ").concat(quantization.dtype, " ") + "which only supports weights of type float32 not ".concat(dtype, "."));
	      }
	    } else {
	      throw new Error("Weight ".concat(spec.name, " has unknown ") + "quantization dtype ".concat(quantization.dtype, ". ") + "Supported quantization dtypes are: " + "'uint8', 'uint16', and 'float16'.");
	    }
	    var quantizationSizeFactor = DTYPE_VALUE_SIZE_MAP[quantization.dtype];
	    var quantizedArray = quantization.dtype === 'uint8' ? new Uint8Array(byteBuffer) : new Uint16Array(byteBuffer);
	    if (dtype === 'float32') {
	      if (quantization.dtype === 'uint8' || quantization.dtype === 'uint16') {
	        values = new Float32Array(quantizedArray.length);
	        for (var i = 0; i < quantizedArray.length; i++) {
	          var v = quantizedArray[i];
	          values[i] = v * quantization.scale + quantization.min;
	        }
	      } else if (quantization.dtype === 'float16') {
	        // TODO: This is inefficient. Make getFloat16Decoder efficient.
	        var float16Decode = getFloat16Decoder();
	        values = float16Decode(quantizedArray);
	      } else {
	        throw new Error("Unsupported quantization type ".concat(quantization.dtype, " ") + "for weight type float32.");
	      }
	    } else if (dtype === 'int32') {
	      if (quantization.dtype !== 'uint8' && quantization.dtype !== 'uint16') {
	        throw new Error("Unsupported quantization type ".concat(quantization.dtype, " ") + "for weight type int32.");
	      }
	      values = new Int32Array(quantizedArray.length);
	      for (var _i = 0; _i < quantizedArray.length; _i++) {
	        var _v = quantizedArray[_i];
	        values[_i] = Math.round(_v * quantization.scale + quantization.min);
	      }
	    } else {
	      throw new Error("Unsupported dtype in weight '".concat(name, "': ").concat(dtype));
	    }
	    offset += size * quantizationSizeFactor;
	  } else if (dtype === 'string') {
	    var _size = sizeFromShape(spec.shape);
	    values = [];
	    for (var _i2 = 0; _i2 < _size; _i2++) {
	      var byteLength = new Uint32Array(byteBuffer.slice(offset, offset + NUM_BYTES_STRING_LENGTH))[0];
	      offset += NUM_BYTES_STRING_LENGTH;
	      var bytes = new Uint8Array(byteBuffer.slice(offset, offset + byteLength));
	      values.push(bytes);
	      offset += byteLength;
	    }
	  } else {
	    var dtypeFactor = DTYPE_VALUE_SIZE_MAP[dtype];
	    if (dtype === 'float32') {
	      values = new Float32Array(byteBuffer);
	    } else if (dtype === 'int32') {
	      values = new Int32Array(byteBuffer);
	    } else if (dtype === 'bool') {
	      values = new Uint8Array(byteBuffer);
	    } else if (dtype === 'complex64') {
	      values = new Float32Array(byteBuffer);
	      var real = new Float32Array(values.length / 2);
	      var image = new Float32Array(values.length / 2);
	      for (var _i3 = 0; _i3 < real.length; _i3++) {
	        real[_i3] = values[_i3 * 2];
	        image[_i3] = values[_i3 * 2 + 1];
	      }
	      var realTensor = tensor(real, shape, 'float32');
	      var imageTensor = tensor(image, shape, 'float32');
	      var complexTensor = complex$2(realTensor, imageTensor);
	      realTensor.dispose();
	      imageTensor.dispose();
	      return complexTensor;
	    } else {
	      throw new Error("Unsupported dtype in weight '".concat(name, "': ").concat(dtype));
	    }
	    offset += size * dtypeFactor;
	  }
	  return tensor(values, shape, dtype);
	}
	function readToLength(_x5, _x6, _x7) {
	  return _readToLength.apply(this, arguments);
	}
	function _readToLength() {
	  _readToLength = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4(reader, initialData, length) {
	    var data, _yield$reader$read, done, value, missing, newData;
	    return _regeneratorRuntime().wrap(function _callee4$(_context5) {
	      while (1) switch (_context5.prev = _context5.next) {
	        case 0:
	          data = new Uint8Array(initialData);
	        case 1:
	          if (!(data.byteLength < length)) {
	            _context5.next = 16;
	            break;
	          }
	          _context5.next = 4;
	          return reader.read();
	        case 4:
	          _yield$reader$read = _context5.sent;
	          done = _yield$reader$read.done;
	          value = _yield$reader$read.value;
	          if (!(done && value == null)) {
	            _context5.next = 10;
	            break;
	          }
	          missing = length - data.byteLength;
	          throw new Error("Reader is done but ".concat(missing, " bytes are still expected"));
	        case 10:
	          // TODO: Don't create a new array every loop.
	          newData = new Uint8Array(data.length + value.byteLength);
	          newData.set(data, 0);
	          newData.set(new Uint8Array(value), data.length);
	          data = newData;
	          _context5.next = 1;
	          break;
	        case 16:
	          return _context5.abrupt("return", data.buffer);
	        case 17:
	        case "end":
	          return _context5.stop();
	      }
	    }, _callee4);
	  }));
	  return _readToLength.apply(this, arguments);
	}
	function decodeWeightsStream(_x8, _x9) {
	  return _decodeWeightsStream.apply(this, arguments);
	}
	/**
	 * Concatenate TypedArrays into an ArrayBuffer.
	 */
	function _decodeWeightsStream() {
	  _decodeWeightsStream = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee6(weightStream, specs) {
	    var tensors, reader, data, _iterator3, _step3, spec, byteLength, tensorData, weightTensor, b;
	    return _regeneratorRuntime().wrap(function _callee6$(_context7) {
	      while (1) switch (_context7.prev = _context7.next) {
	        case 0:
	          tensors = {};
	          reader = weightStream.getReader();
	          data = new ArrayBuffer(0);
	          _iterator3 = _createForOfIteratorHelper(specs);
	          _context7.prev = 4;
	          _iterator3.s();
	        case 6:
	          if ((_step3 = _iterator3.n()).done) {
	            _context7.next = 21;
	            break;
	          }
	          spec = _step3.value;
	          _context7.next = 10;
	          return getWeightBytelengthAsync(spec, /*#__PURE__*/function () {
	            var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee5(start, end) {
	              return _regeneratorRuntime().wrap(function _callee5$(_context6) {
	                while (1) switch (_context6.prev = _context6.next) {
	                  case 0:
	                    _context6.next = 2;
	                    return readToLength(reader, data, end);
	                  case 2:
	                    data = _context6.sent;
	                    return _context6.abrupt("return", data.slice(start, end));
	                  case 4:
	                  case "end":
	                    return _context6.stop();
	                }
	              }, _callee5);
	            }));
	            return function (_x13, _x14) {
	              return _ref2.apply(this, arguments);
	            };
	          }());
	        case 10:
	          byteLength = _context7.sent;
	          _context7.next = 13;
	          return readToLength(reader, data, byteLength);
	        case 13:
	          data = _context7.sent;
	          // Slice the tensor out
	          tensorData = data.slice(0, byteLength);
	          data = data.slice(byteLength);
	          weightTensor = decodeWeight(spec, tensorData);
	          tensors[spec.name] = weightTensor;
	          // TODO(mattsoulanille): Better way to call uploadToGPU.
	          // TODO(mattsoulanille): Make this work for webgl too.
	          if (getBackend$1() === 'webgpu') {
	            b = backend$1();
	            if ('uploadToGPU' in b && sizeFromShape(weightTensor.shape) >= env().get('WEBGPU_CPU_HANDOFF_SIZE_THRESHOLD')) {
	              b.uploadToGPU(weightTensor.dataId);
	            }
	          }
	        case 19:
	          _context7.next = 6;
	          break;
	        case 21:
	          _context7.next = 26;
	          break;
	        case 23:
	          _context7.prev = 23;
	          _context7.t0 = _context7["catch"](4);
	          _iterator3.e(_context7.t0);
	        case 26:
	          _context7.prev = 26;
	          _iterator3.f();
	          return _context7.finish(26);
	        case 29:
	          return _context7.abrupt("return", tensors);
	        case 30:
	        case "end":
	          return _context7.stop();
	      }
	    }, _callee6, null, [[4, 23, 26, 29]]);
	  }));
	  return _decodeWeightsStream.apply(this, arguments);
	}
	function concatenateTypedArrays(xs) {
	  // TODO(adarob, cais): Support quantization.
	  if (xs === null) {
	    throw new Error("Invalid input value: ".concat(JSON.stringify(xs)));
	  }
	  var totalByteLength = 0;
	  // `normalizedXs` is here for this reason: a `TypedArray`'s `buffer'
	  // can have a different byte length from that of the `TypedArray` itself,
	  // for example, when the `TypedArray` is created from an offset in an
	  // `ArrayBuffer`. `normliazedXs` holds `TypedArray`s whose `buffer`s match
	  // the `TypedArray` in byte length. If an element of `xs` does not show
	  // this property, a new `TypedArray` that satisfy this property will be
	  // constructed and pushed into `normalizedXs`.
	  var normalizedXs = [];
	  xs.forEach(function (x) {
	    totalByteLength += x.byteLength;
	    // tslint:disable:no-any
	    normalizedXs.push(x.byteLength === x.buffer.byteLength ? x : new x.constructor(x));
	    if (!(x instanceof Float32Array || x instanceof Int32Array || x instanceof Uint8Array)) {
	      throw new Error("Unsupported TypedArray subtype: ".concat(x.constructor.name));
	    }
	    // tslint:enable:no-any
	  });

	  var y = new Uint8Array(totalByteLength);
	  var offset = 0;
	  normalizedXs.forEach(function (x) {
	    y.set(new Uint8Array(x.buffer), offset);
	    offset += x.byteLength;
	  });
	  return y.buffer;
	}
	// Use Buffer on Node.js instead of Blob/atob/btoa
	var useNodeBuffer = typeof Buffer !== 'undefined' && (typeof Blob === 'undefined' || typeof atob === 'undefined' || typeof btoa === 'undefined');
	/**
	 * Calculate the byte length of a JavaScript string.
	 *
	 * Note that a JavaScript string can contain wide characters, therefore the
	 * length of the string is not necessarily equal to the byte length.
	 *
	 * @param str Input string.
	 * @returns Byte length.
	 */
	function stringByteLength(str) {
	  if (useNodeBuffer) {
	    return Buffer.byteLength(str, 'utf8');
	  }
	  return new Blob([str]).size;
	}
	/**
	 * Encode an ArrayBuffer as a base64 encoded string.
	 *
	 * @param buffer `ArrayBuffer` to be converted.
	 * @returns A string that base64-encodes `buffer`.
	 */
	function arrayBufferToBase64String(buffer) {
	  if (useNodeBuffer) {
	    return Buffer.from(buffer).toString('base64');
	  }
	  var buf = new Uint8Array(buffer);
	  var s = '';
	  for (var i = 0, l = buf.length; i < l; i++) {
	    s += String.fromCharCode(buf[i]);
	  }
	  return btoa(s);
	}
	/**
	 * Decode a base64 string as an ArrayBuffer.
	 *
	 * @param str Base64 string.
	 * @returns Decoded `ArrayBuffer`.
	 */
	function base64StringToArrayBuffer(str) {
	  if (useNodeBuffer) {
	    var buf = Buffer.from(str, 'base64');
	    return buf.buffer.slice(buf.byteOffset, buf.byteOffset + buf.byteLength);
	  }
	  var s = atob(str);
	  var buffer = new Uint8Array(s.length);
	  for (var i = 0; i < s.length; ++i) {
	    buffer.set([s.charCodeAt(i)], i);
	  }
	  return buffer.buffer;
	}
	/**
	 * Concatenate a number of ArrayBuffers into one.
	 *
	 * @param buffers An array of ArrayBuffers to concatenate, or a single
	 *     ArrayBuffer.
	 * @returns Result of concatenating `buffers` in order.
	 *
	 * @deprecated Use tf.io.CompositeArrayBuffer.join() instead.
	 */
	function concatenateArrayBuffers(buffers) {
	  return CompositeArrayBuffer.join(buffers);
	}
	/**
	 * Get the basename of a path.
	 *
	 * Behaves in a way analogous to Linux's basename command.
	 *
	 * @param path
	 */
	function basename(path) {
	  var SEPARATOR = '/';
	  path = path.trim();
	  while (path.endsWith(SEPARATOR)) {
	    path = path.slice(0, path.length - 1);
	  }
	  var items = path.split(SEPARATOR);
	  return items[items.length - 1];
	}
	/**
	 * Create `ModelJSON` from `ModelArtifacts`.
	 *
	 * @param artifacts Model artifacts, describing the model and its weights.
	 * @param manifest Weight manifest, describing where the weights of the
	 *     `ModelArtifacts` are stored, and some metadata about them.
	 * @returns Object representing the `model.json` file describing the model
	 *     artifacts and weights
	 */
	function getModelJSONForModelArtifacts(artifacts, manifest) {
	  var result = {
	    modelTopology: artifacts.modelTopology,
	    format: artifacts.format,
	    generatedBy: artifacts.generatedBy,
	    convertedBy: artifacts.convertedBy,
	    weightsManifest: manifest
	  };
	  if (artifacts.signature != null) {
	    result.signature = artifacts.signature;
	  }
	  if (artifacts.userDefinedMetadata != null) {
	    result.userDefinedMetadata = artifacts.userDefinedMetadata;
	  }
	  if (artifacts.modelInitializer != null) {
	    result.modelInitializer = artifacts.modelInitializer;
	  }
	  if (artifacts.initializerSignature != null) {
	    result.initializerSignature = artifacts.initializerSignature;
	  }
	  if (artifacts.trainingConfig != null) {
	    result.trainingConfig = artifacts.trainingConfig;
	  }
	  return result;
	}
	/**
	 * Create `ModelArtifacts` from a JSON file and weights.
	 *
	 * @param modelJSON Object containing the parsed JSON of `model.json`
	 * @param weightSpecs The list of WeightsManifestEntry for the model. Must be
	 *     passed if the modelJSON has a weightsManifest.
	 * @param weightData An ArrayBuffer or array of ArrayBuffers of weight data for
	 *     the model corresponding to the weights in weightSpecs. Must be passed if
	 *     the modelJSON has a weightsManifest.
	 * @returns A Promise of the `ModelArtifacts`, as described by the JSON file.
	 */
	function getModelArtifactsForJSONSync(modelJSON, weightSpecs, weightData) {
	  var modelArtifacts = {
	    modelTopology: modelJSON.modelTopology,
	    format: modelJSON.format,
	    generatedBy: modelJSON.generatedBy,
	    convertedBy: modelJSON.convertedBy
	  };
	  if (modelJSON.trainingConfig != null) {
	    modelArtifacts.trainingConfig = modelJSON.trainingConfig;
	  }
	  if (modelJSON.weightsManifest != null) {
	    if (!weightSpecs) {
	      throw new Error('modelJSON has weightsManifest but weightSpecs is null');
	    }
	    if (!weightData) {
	      throw new Error('modelJSON has weightsManifest but weightData is null');
	    }
	    modelArtifacts.weightSpecs = weightSpecs;
	    modelArtifacts.weightData = weightData;
	  }
	  if (modelJSON.signature != null) {
	    modelArtifacts.signature = modelJSON.signature;
	  }
	  if (modelJSON.userDefinedMetadata != null) {
	    modelArtifacts.userDefinedMetadata = modelJSON.userDefinedMetadata;
	  }
	  if (modelJSON.modelInitializer != null) {
	    modelArtifacts.modelInitializer = modelJSON.modelInitializer;
	  }
	  if (modelJSON.initializerSignature != null) {
	    modelArtifacts.initializerSignature = modelJSON.initializerSignature;
	  }
	  return modelArtifacts;
	}
	/**
	 * Create `ModelArtifacts` from a JSON file.
	 *
	 * @param modelJSON Object containing the parsed JSON of `model.json`
	 * @param loadWeights Function that takes the JSON file's weights manifest,
	 *     reads weights from the listed path(s), and returns a Promise of the
	 *     weight manifest entries along with the weights data.
	 * @returns A Promise of the `ModelArtifacts`, as described by the JSON file.
	 */
	function getModelArtifactsForJSON(_x10, _x11) {
	  return _getModelArtifactsForJSON.apply(this, arguments);
	}
	/**
	 * Populate ModelArtifactsInfo fields for a model with JSON topology.
	 * @param modelArtifacts
	 * @returns A ModelArtifactsInfo object.
	 */
	function _getModelArtifactsForJSON() {
	  _getModelArtifactsForJSON = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee7(modelJSON, loadWeights) {
	    var weightSpecs, weightData, _yield$loadWeights, _yield$loadWeights2;
	    return _regeneratorRuntime().wrap(function _callee7$(_context8) {
	      while (1) switch (_context8.prev = _context8.next) {
	        case 0:
	          if (!(modelJSON.weightsManifest != null)) {
	            _context8.next = 7;
	            break;
	          }
	          _context8.next = 3;
	          return loadWeights(modelJSON.weightsManifest);
	        case 3:
	          _yield$loadWeights = _context8.sent;
	          _yield$loadWeights2 = _slicedToArray(_yield$loadWeights, 2);
	          weightSpecs = _yield$loadWeights2[0];
	          weightData = _yield$loadWeights2[1];
	        case 7:
	          return _context8.abrupt("return", getModelArtifactsForJSONSync(modelJSON, weightSpecs, weightData));
	        case 8:
	        case "end":
	          return _context8.stop();
	      }
	    }, _callee7);
	  }));
	  return _getModelArtifactsForJSON.apply(this, arguments);
	}
	function getModelArtifactsInfoForJSON(modelArtifacts) {
	  if (modelArtifacts.modelTopology instanceof ArrayBuffer) {
	    throw new Error('Expected JSON model topology, received ArrayBuffer.');
	  }
	  return {
	    dateSaved: new Date(),
	    modelTopologyType: 'JSON',
	    modelTopologyBytes: modelArtifacts.modelTopology == null ? 0 : stringByteLength(JSON.stringify(modelArtifacts.modelTopology)),
	    weightSpecsBytes: modelArtifacts.weightSpecs == null ? 0 : stringByteLength(JSON.stringify(modelArtifacts.weightSpecs)),
	    weightDataBytes: modelArtifacts.weightData == null ? 0 : new CompositeArrayBuffer(modelArtifacts.weightData).byteLength
	  };
	}
	/**
	 * Concatenate the weights stored in a WeightsManifestConfig into a list of
	 * WeightsManifestEntry
	 *
	 * @param weightsManifest The WeightsManifestConfig to extract weights from.
	 * @returns A list of WeightsManifestEntry of the weights in the weightsManifest
	 */
	function getWeightSpecs(weightsManifest) {
	  var weightSpecs = [];
	  var _iterator2 = _createForOfIteratorHelper(weightsManifest),
	    _step2;
	  try {
	    for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	      var entry = _step2.value;
	      weightSpecs.push.apply(weightSpecs, _toConsumableArray(entry.weights));
	    }
	  } catch (err) {
	    _iterator2.e(err);
	  } finally {
	    _iterator2.f();
	  }
	  return weightSpecs;
	}
	/**
	 * Computes mantisa table for casting Float16 to Float32
	 * See http://www.fox-toolkit.org/ftp/fasthalffloatconversion.pdf
	 *
	 * @returns Uint32Array, 2048 mantissa lookup values.
	 */
	function computeFloat16MantisaTable() {
	  var convertMantissa = function convertMantissa(i) {
	    var m = i << 13;
	    var e = 0;
	    while ((m & 0x00800000) === 0) {
	      e -= 0x00800000;
	      m <<= 1;
	    }
	    m &= ~0x00800000;
	    e += 0x38800000;
	    return m | e;
	  };
	  var mantisaTable = new Uint32Array(2048);
	  mantisaTable[0] = 0;
	  for (var i = 1; i < 1024; i++) {
	    mantisaTable[i] = convertMantissa(i);
	  }
	  for (var _i4 = 1024; _i4 < 2048; _i4++) {
	    mantisaTable[_i4] = 0x38000000 + (_i4 - 1024 << 13);
	  }
	  return mantisaTable;
	}
	/**
	 * Computes exponent table for casting Float16 to Float32
	 * See http://www.fox-toolkit.org/ftp/fasthalffloatconversion.pdf
	 *
	 * @returns Uint32Array, 64 exponent lookup values.
	 */
	function computeFloat16ExponentTable() {
	  var exponentTable = new Uint32Array(64);
	  exponentTable[0] = 0;
	  exponentTable[31] = 0x47800000;
	  exponentTable[32] = 0x80000000;
	  exponentTable[63] = 0xc7800000;
	  for (var i = 1; i < 31; i++) {
	    exponentTable[i] = i << 23;
	  }
	  for (var _i5 = 33; _i5 < 63; _i5++) {
	    exponentTable[_i5] = 0x80000000 + (_i5 - 32 << 23);
	  }
	  return exponentTable;
	}
	/**
	 * Computes offset table for casting Float16 to Float32
	 * See http://www.fox-toolkit.org/ftp/fasthalffloatconversion.pdf
	 *
	 * @returns Uint32Array, 6d offset values.
	 */
	function computeFloat16OffsetTable() {
	  var offsetTable = new Uint32Array(64);
	  for (var i = 0; i < 64; i++) {
	    offsetTable[i] = 1024;
	  }
	  offsetTable[0] = offsetTable[32] = 0;
	  return offsetTable;
	}
	/**
	 * Retrieve a Float16 decoder which will decode a ByteArray of Float16 values
	 * to a Float32Array.
	 *
	 * @returns Function (buffer: Uint16Array) => Float32Array which decodes
	 *          the Uint16Array of Float16 bytes to a Float32Array.
	 */
	function getFloat16Decoder() {
	  // Algorithm is based off of
	  // http://www.fox-toolkit.org/ftp/fasthalffloatconversion.pdf
	  // Cache lookup tables
	  var mantisaTable = computeFloat16MantisaTable();
	  var exponentTable = computeFloat16ExponentTable();
	  var offsetTable = computeFloat16OffsetTable();
	  return function (quantizedArray) {
	    var buffer = new ArrayBuffer(4 * quantizedArray.length);
	    var bufferUint32View = new Uint32Array(buffer);
	    for (var index = 0; index < quantizedArray.length; index++) {
	      var float16Bits = quantizedArray[index];
	      var float32Bits = mantisaTable[offsetTable[float16Bits >> 10] + (float16Bits & 0x3ff)] + exponentTable[float16Bits >> 10];
	      bufferUint32View[index] = float32Bits;
	    }
	    return new Float32Array(buffer);
	  };
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var IORouterRegistry = /*#__PURE__*/function () {
	  function IORouterRegistry() {
	    _classCallCheck(this, IORouterRegistry);
	    this.saveRouters = [];
	    this.loadRouters = [];
	  }
	  _createClass(IORouterRegistry, null, [{
	    key: "getInstance",
	    value: function getInstance() {
	      if (IORouterRegistry.instance == null) {
	        IORouterRegistry.instance = new IORouterRegistry();
	      }
	      return IORouterRegistry.instance;
	    }
	    /**
	     * Register a save-handler router.
	     *
	     * @param saveRouter A function that maps a URL-like string onto an instance
	     * of `IOHandler` with the `save` method defined or `null`.
	     */
	  }, {
	    key: "registerSaveRouter",
	    value: function registerSaveRouter(saveRouter) {
	      IORouterRegistry.getInstance().saveRouters.push(saveRouter);
	    }
	    /**
	     * Register a load-handler router.
	     *
	     * @param loadRouter A function that maps a URL-like string onto an instance
	     * of `IOHandler` with the `load` method defined or `null`.
	     */
	  }, {
	    key: "registerLoadRouter",
	    value: function registerLoadRouter(loadRouter) {
	      IORouterRegistry.getInstance().loadRouters.push(loadRouter);
	    }
	    /**
	     * Look up IOHandler for saving, given a URL-like string.
	     *
	     * @param url
	     * @returns If only one match is found, an instance of IOHandler with the
	     * `save` method defined. If no match is found, `null`.
	     * @throws Error, if more than one match is found.
	     */
	  }, {
	    key: "getSaveHandlers",
	    value: function getSaveHandlers(url) {
	      return IORouterRegistry.getHandlers(url, 'save');
	    }
	    /**
	     * Look up IOHandler for loading, given a URL-like string.
	     *
	     * @param url
	     * @param loadOptions Optional, custom load options.
	     * @returns All valid handlers for `url`, given the currently registered
	     *   handler routers.
	     */
	  }, {
	    key: "getLoadHandlers",
	    value: function getLoadHandlers(url, loadOptions) {
	      return IORouterRegistry.getHandlers(url, 'load', loadOptions);
	    }
	  }, {
	    key: "getHandlers",
	    value: function getHandlers(url, handlerType, loadOptions) {
	      var validHandlers = [];
	      var routers = handlerType === 'load' ? IORouterRegistry.getInstance().loadRouters : IORouterRegistry.getInstance().saveRouters;
	      routers.forEach(function (router) {
	        var handler = router(url, loadOptions);
	        if (handler !== null) {
	          validHandlers.push(handler);
	        }
	      });
	      return validHandlers;
	    }
	  }]);
	  return IORouterRegistry;
	}();
	var registerSaveRouter = function registerSaveRouter(loudRouter) {
	  return IORouterRegistry.registerSaveRouter(loudRouter);
	};
	var registerLoadRouter = function registerLoadRouter(loudRouter) {
	  return IORouterRegistry.registerLoadRouter(loudRouter);
	};
	var getSaveHandlers = function getSaveHandlers(url) {
	  return IORouterRegistry.getSaveHandlers(url);
	};
	var getLoadHandlers = function getLoadHandlers(url, loadOptions) {
	  return IORouterRegistry.getLoadHandlers(url, loadOptions);
	};

	var DATABASE_NAME = 'tensorflowjs';
	var DATABASE_VERSION = 1;
	// Model data and ModelArtifactsInfo (metadata) are stored in two separate
	// stores for efficient access of the list of stored models and their metadata.
	// 1. The object store for model data: topology, weights and weight manifests.
	var MODEL_STORE_NAME = 'models_store';
	// 2. The object store for ModelArtifactsInfo, including meta-information such
	//    as the type of topology (JSON vs binary), byte size of the topology, byte
	//    size of the weights, etc.
	var INFO_STORE_NAME = 'model_info_store';
	/**
	 * Delete the entire database for tensorflow.js, including the models store.
	 */
	function deleteDatabase() {
	  return _deleteDatabase.apply(this, arguments);
	}
	function _deleteDatabase() {
	  _deleteDatabase = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee5() {
	    var idbFactory;
	    return _regeneratorRuntime().wrap(function _callee5$(_context5) {
	      while (1) switch (_context5.prev = _context5.next) {
	        case 0:
	          idbFactory = getIndexedDBFactory();
	          return _context5.abrupt("return", new Promise(function (resolve, reject) {
	            var deleteRequest = idbFactory.deleteDatabase(DATABASE_NAME);
	            deleteRequest.onsuccess = function () {
	              return resolve();
	            };
	            deleteRequest.onerror = function (error) {
	              return reject(error);
	            };
	          }));
	        case 2:
	        case "end":
	          return _context5.stop();
	      }
	    }, _callee5);
	  }));
	  return _deleteDatabase.apply(this, arguments);
	}
	function getIndexedDBFactory() {
	  if (!env().getBool('IS_BROWSER')) {
	    // TODO(cais): Add more info about what IOHandler subtypes are available.
	    //   Maybe point to a doc page on the web and/or automatically determine
	    //   the available IOHandlers and print them in the error message.
	    throw new Error('Failed to obtain IndexedDB factory because the current environment' + 'is not a web browser.');
	  }
	  // tslint:disable-next-line:no-any
	  var theWindow = typeof window === 'undefined' ? self : window;
	  var factory = theWindow.indexedDB || theWindow.mozIndexedDB || theWindow.webkitIndexedDB || theWindow.msIndexedDB || theWindow.shimIndexedDB;
	  if (factory == null) {
	    throw new Error('The current browser does not appear to support IndexedDB.');
	  }
	  return factory;
	}
	function setUpDatabase(openRequest) {
	  var db = openRequest.result;
	  db.createObjectStore(MODEL_STORE_NAME, {
	    keyPath: 'modelPath'
	  });
	  db.createObjectStore(INFO_STORE_NAME, {
	    keyPath: 'modelPath'
	  });
	}
	/**
	 * IOHandler subclass: Browser IndexedDB.
	 *
	 * See the doc string of `browserIndexedDB` for more details.
	 */
	var BrowserIndexedDB = /*#__PURE__*/function () {
	  function BrowserIndexedDB(modelPath) {
	    _classCallCheck(this, BrowserIndexedDB);
	    this.indexedDB = getIndexedDBFactory();
	    if (modelPath == null || !modelPath) {
	      throw new Error('For IndexedDB, modelPath must not be null, undefined or empty.');
	    }
	    this.modelPath = modelPath;
	  }
	  _createClass(BrowserIndexedDB, [{
	    key: "save",
	    value: function () {
	      var _save = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(modelArtifacts) {
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              if (!(modelArtifacts.modelTopology instanceof ArrayBuffer)) {
	                _context.next = 2;
	                break;
	              }
	              throw new Error('BrowserLocalStorage.save() does not support saving model topology ' + 'in binary formats yet.');
	            case 2:
	              return _context.abrupt("return", this.databaseAction(this.modelPath, modelArtifacts));
	            case 3:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function save(_x) {
	        return _save.apply(this, arguments);
	      }
	      return save;
	    }()
	  }, {
	    key: "load",
	    value: function () {
	      var _load = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2() {
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              return _context2.abrupt("return", this.databaseAction(this.modelPath));
	            case 1:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function load() {
	        return _load.apply(this, arguments);
	      }
	      return load;
	    }()
	    /**
	     * Perform database action to put model artifacts into or read model artifacts
	     * from IndexedDB object store.
	     *
	     * Whether the action is put or get depends on whether `modelArtifacts` is
	     * specified. If it is specified, the action will be put; otherwise the action
	     * will be get.
	     *
	     * @param modelPath A unique string path for the model.
	     * @param modelArtifacts If specified, it will be the model artifacts to be
	     *   stored in IndexedDB.
	     * @returns A `Promise` of `SaveResult`, if the action is put, or a `Promise`
	     *   of `ModelArtifacts`, if the action is get.
	     */
	  }, {
	    key: "databaseAction",
	    value: function databaseAction(modelPath, modelArtifacts) {
	      var _this = this;
	      return new Promise(function (resolve, reject) {
	        var openRequest = _this.indexedDB.open(DATABASE_NAME, DATABASE_VERSION);
	        openRequest.onupgradeneeded = function () {
	          return setUpDatabase(openRequest);
	        };
	        openRequest.onsuccess = function () {
	          var db = openRequest.result;
	          if (modelArtifacts == null) {
	            // Read model out from object store.
	            var modelTx = db.transaction(MODEL_STORE_NAME, 'readonly');
	            var modelStore = modelTx.objectStore(MODEL_STORE_NAME);
	            var getRequest = modelStore.get(_this.modelPath);
	            getRequest.onsuccess = function () {
	              if (getRequest.result == null) {
	                db.close();
	                return reject(new Error("Cannot find model with path '".concat(_this.modelPath, "' ") + "in IndexedDB."));
	              } else {
	                resolve(getRequest.result.modelArtifacts);
	              }
	            };
	            getRequest.onerror = function (error) {
	              db.close();
	              return reject(getRequest.error);
	            };
	            modelTx.oncomplete = function () {
	              return db.close();
	            };
	          } else {
	            // Put model into object store.
	            // Concatenate all the model weights into a single ArrayBuffer. Large
	            // models (~1GB) have problems saving if they are not concatenated.
	            // TODO(mattSoulanille): Save large models to multiple indexeddb
	            // records.
	            modelArtifacts.weightData = CompositeArrayBuffer.join(modelArtifacts.weightData);
	            var modelArtifactsInfo = getModelArtifactsInfoForJSON(modelArtifacts);
	            // First, put ModelArtifactsInfo into info store.
	            var infoTx = db.transaction(INFO_STORE_NAME, 'readwrite');
	            var infoStore = infoTx.objectStore(INFO_STORE_NAME);
	            var putInfoRequest;
	            try {
	              putInfoRequest = infoStore.put({
	                modelPath: _this.modelPath,
	                modelArtifactsInfo: modelArtifactsInfo
	              });
	            } catch (error) {
	              return reject(error);
	            }
	            var _modelTx;
	            putInfoRequest.onsuccess = function () {
	              // Second, put model data into model store.
	              _modelTx = db.transaction(MODEL_STORE_NAME, 'readwrite');
	              var modelStore = _modelTx.objectStore(MODEL_STORE_NAME);
	              var putModelRequest;
	              try {
	                putModelRequest = modelStore.put({
	                  modelPath: _this.modelPath,
	                  modelArtifacts: modelArtifacts,
	                  modelArtifactsInfo: modelArtifactsInfo
	                });
	              } catch (error) {
	                // Sometimes, the serialized value is too large to store.
	                return reject(error);
	              }
	              putModelRequest.onsuccess = function () {
	                return resolve({
	                  modelArtifactsInfo: modelArtifactsInfo
	                });
	              };
	              putModelRequest.onerror = function (error) {
	                // If the put-model request fails, roll back the info entry as
	                // well.
	                infoStore = infoTx.objectStore(INFO_STORE_NAME);
	                var deleteInfoRequest = infoStore.delete(_this.modelPath);
	                deleteInfoRequest.onsuccess = function () {
	                  db.close();
	                  return reject(putModelRequest.error);
	                };
	                deleteInfoRequest.onerror = function (error) {
	                  db.close();
	                  return reject(putModelRequest.error);
	                };
	              };
	            };
	            putInfoRequest.onerror = function (error) {
	              db.close();
	              return reject(putInfoRequest.error);
	            };
	            infoTx.oncomplete = function () {
	              if (_modelTx == null) {
	                db.close();
	              } else {
	                _modelTx.oncomplete = function () {
	                  return db.close();
	                };
	              }
	            };
	          }
	        };
	        openRequest.onerror = function (error) {
	          return reject(openRequest.error);
	        };
	      });
	    }
	  }]);
	  return BrowserIndexedDB;
	}();
	BrowserIndexedDB.URL_SCHEME = 'indexeddb://';
	var indexedDBRouter = function indexedDBRouter(url) {
	  if (!env().getBool('IS_BROWSER')) {
	    return null;
	  } else {
	    if (!Array.isArray(url) && url.startsWith(BrowserIndexedDB.URL_SCHEME)) {
	      return browserIndexedDB(url.slice(BrowserIndexedDB.URL_SCHEME.length));
	    } else {
	      return null;
	    }
	  }
	};
	IORouterRegistry.registerSaveRouter(indexedDBRouter);
	IORouterRegistry.registerLoadRouter(indexedDBRouter);
	/**
	 * Creates a browser IndexedDB IOHandler for saving and loading models.
	 *
	 * ```js
	 * const model = tf.sequential();
	 * model.add(
	 *     tf.layers.dense({units: 1, inputShape: [100], activation: 'sigmoid'}));
	 *
	 * const saveResult = await model.save('indexeddb://MyModel'));
	 * console.log(saveResult);
	 * ```
	 *
	 * @param modelPath A unique identifier for the model to be saved. Must be a
	 *   non-empty string.
	 * @returns An instance of `BrowserIndexedDB` (subclass of `IOHandler`),
	 *   which can be used with, e.g., `tf.Model.save`.
	 */
	function browserIndexedDB(modelPath) {
	  return new BrowserIndexedDB(modelPath);
	}
	function maybeStripScheme$1(key) {
	  return key.startsWith(BrowserIndexedDB.URL_SCHEME) ? key.slice(BrowserIndexedDB.URL_SCHEME.length) : key;
	}
	var BrowserIndexedDBManager = /*#__PURE__*/function () {
	  function BrowserIndexedDBManager() {
	    _classCallCheck(this, BrowserIndexedDBManager);
	    this.indexedDB = getIndexedDBFactory();
	  }
	  _createClass(BrowserIndexedDBManager, [{
	    key: "listModels",
	    value: function () {
	      var _listModels = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3() {
	        var _this2 = this;
	        return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	          while (1) switch (_context3.prev = _context3.next) {
	            case 0:
	              return _context3.abrupt("return", new Promise(function (resolve, reject) {
	                var openRequest = _this2.indexedDB.open(DATABASE_NAME, DATABASE_VERSION);
	                openRequest.onupgradeneeded = function () {
	                  return setUpDatabase(openRequest);
	                };
	                openRequest.onsuccess = function () {
	                  var db = openRequest.result;
	                  var tx = db.transaction(INFO_STORE_NAME, 'readonly');
	                  var store = tx.objectStore(INFO_STORE_NAME);
	                  // tslint:disable:max-line-length
	                  // Need to cast `store` as `any` here because TypeScript's DOM
	                  // library does not have the `getAll()` method even though the
	                  // method is supported in the latest version of most mainstream
	                  // browsers:
	                  // https://developer.mozilla.org/en-US/docs/Web/API/IDBObjectStore/getAll
	                  // tslint:enable:max-line-length
	                  // tslint:disable-next-line:no-any
	                  var getAllInfoRequest = store.getAll();
	                  getAllInfoRequest.onsuccess = function () {
	                    var out = {};
	                    var _iterator = _createForOfIteratorHelper(getAllInfoRequest.result),
	                      _step;
	                    try {
	                      for (_iterator.s(); !(_step = _iterator.n()).done;) {
	                        var item = _step.value;
	                        out[item.modelPath] = item.modelArtifactsInfo;
	                      }
	                    } catch (err) {
	                      _iterator.e(err);
	                    } finally {
	                      _iterator.f();
	                    }
	                    resolve(out);
	                  };
	                  getAllInfoRequest.onerror = function (error) {
	                    db.close();
	                    return reject(getAllInfoRequest.error);
	                  };
	                  tx.oncomplete = function () {
	                    return db.close();
	                  };
	                };
	                openRequest.onerror = function (error) {
	                  return reject(openRequest.error);
	                };
	              }));
	            case 1:
	            case "end":
	              return _context3.stop();
	          }
	        }, _callee3);
	      }));
	      function listModels() {
	        return _listModels.apply(this, arguments);
	      }
	      return listModels;
	    }()
	  }, {
	    key: "removeModel",
	    value: function () {
	      var _removeModel = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4(path) {
	        var _this3 = this;
	        return _regeneratorRuntime().wrap(function _callee4$(_context4) {
	          while (1) switch (_context4.prev = _context4.next) {
	            case 0:
	              path = maybeStripScheme$1(path);
	              return _context4.abrupt("return", new Promise(function (resolve, reject) {
	                var openRequest = _this3.indexedDB.open(DATABASE_NAME, DATABASE_VERSION);
	                openRequest.onupgradeneeded = function () {
	                  return setUpDatabase(openRequest);
	                };
	                openRequest.onsuccess = function () {
	                  var db = openRequest.result;
	                  var infoTx = db.transaction(INFO_STORE_NAME, 'readwrite');
	                  var infoStore = infoTx.objectStore(INFO_STORE_NAME);
	                  var getInfoRequest = infoStore.get(path);
	                  var modelTx;
	                  getInfoRequest.onsuccess = function () {
	                    if (getInfoRequest.result == null) {
	                      db.close();
	                      return reject(new Error("Cannot find model with path '".concat(path, "' ") + "in IndexedDB."));
	                    } else {
	                      // First, delete the entry in the info store.
	                      var deleteInfoRequest = infoStore.delete(path);
	                      var deleteModelData = function deleteModelData() {
	                        // Second, delete the entry in the model store.
	                        modelTx = db.transaction(MODEL_STORE_NAME, 'readwrite');
	                        var modelStore = modelTx.objectStore(MODEL_STORE_NAME);
	                        var deleteModelRequest = modelStore.delete(path);
	                        deleteModelRequest.onsuccess = function () {
	                          return resolve(getInfoRequest.result.modelArtifactsInfo);
	                        };
	                        deleteModelRequest.onerror = function (error) {
	                          return reject(getInfoRequest.error);
	                        };
	                      };
	                      // Proceed with deleting model data regardless of whether deletion
	                      // of info data succeeds or not.
	                      deleteInfoRequest.onsuccess = deleteModelData;
	                      deleteInfoRequest.onerror = function (error) {
	                        deleteModelData();
	                        db.close();
	                        return reject(getInfoRequest.error);
	                      };
	                    }
	                  };
	                  getInfoRequest.onerror = function (error) {
	                    db.close();
	                    return reject(getInfoRequest.error);
	                  };
	                  infoTx.oncomplete = function () {
	                    if (modelTx == null) {
	                      db.close();
	                    } else {
	                      modelTx.oncomplete = function () {
	                        return db.close();
	                      };
	                    }
	                  };
	                };
	                openRequest.onerror = function (error) {
	                  return reject(openRequest.error);
	                };
	              }));
	            case 2:
	            case "end":
	              return _context4.stop();
	          }
	        }, _callee4);
	      }));
	      function removeModel(_x2) {
	        return _removeModel.apply(this, arguments);
	      }
	      return removeModel;
	    }()
	  }]);
	  return BrowserIndexedDBManager;
	}();

	var PATH_SEPARATOR = '/';
	var PATH_PREFIX = 'tensorflowjs_models';
	var INFO_SUFFIX = 'info';
	var MODEL_TOPOLOGY_SUFFIX = 'model_topology';
	var WEIGHT_SPECS_SUFFIX = 'weight_specs';
	var WEIGHT_DATA_SUFFIX = 'weight_data';
	var MODEL_METADATA_SUFFIX = 'model_metadata';
	/**
	 * Purge all tensorflow.js-saved model artifacts from local storage.
	 *
	 * @returns Paths of the models purged.
	 */
	function purgeLocalStorageArtifacts() {
	  if (!env().getBool('IS_BROWSER') || typeof window === 'undefined' || typeof window.localStorage === 'undefined') {
	    throw new Error('purgeLocalStorageModels() cannot proceed because local storage is ' + 'unavailable in the current environment.');
	  }
	  var LS = window.localStorage;
	  var purgedModelPaths = [];
	  for (var i = 0; i < LS.length; ++i) {
	    var key = LS.key(i);
	    var prefix = PATH_PREFIX + PATH_SEPARATOR;
	    if (key.startsWith(prefix) && key.length > prefix.length) {
	      LS.removeItem(key);
	      var modelName = getModelPathFromKey(key);
	      if (purgedModelPaths.indexOf(modelName) === -1) {
	        purgedModelPaths.push(modelName);
	      }
	    }
	  }
	  return purgedModelPaths;
	}
	function getModelKeys(path) {
	  return {
	    info: [PATH_PREFIX, path, INFO_SUFFIX].join(PATH_SEPARATOR),
	    topology: [PATH_PREFIX, path, MODEL_TOPOLOGY_SUFFIX].join(PATH_SEPARATOR),
	    weightSpecs: [PATH_PREFIX, path, WEIGHT_SPECS_SUFFIX].join(PATH_SEPARATOR),
	    weightData: [PATH_PREFIX, path, WEIGHT_DATA_SUFFIX].join(PATH_SEPARATOR),
	    modelMetadata: [PATH_PREFIX, path, MODEL_METADATA_SUFFIX].join(PATH_SEPARATOR)
	  };
	}
	function removeItems(keys) {
	  for (var _i = 0, _Object$values = Object.values(keys); _i < _Object$values.length; _i++) {
	    var key = _Object$values[_i];
	    window.localStorage.removeItem(key);
	  }
	}
	/**
	 * Get model path from a local-storage key.
	 *
	 * E.g., 'tensorflowjs_models/my/model/1/info' --> 'my/model/1'
	 *
	 * @param key
	 */
	function getModelPathFromKey(key) {
	  var items = key.split(PATH_SEPARATOR);
	  if (items.length < 3) {
	    throw new Error("Invalid key format: ".concat(key));
	  }
	  return items.slice(1, items.length - 1).join(PATH_SEPARATOR);
	}
	function maybeStripScheme(key) {
	  return key.startsWith(BrowserLocalStorage.URL_SCHEME) ? key.slice(BrowserLocalStorage.URL_SCHEME.length) : key;
	}
	/**
	 * IOHandler subclass: Browser Local Storage.
	 *
	 * See the doc string to `browserLocalStorage` for more details.
	 */
	var BrowserLocalStorage = /*#__PURE__*/function () {
	  function BrowserLocalStorage(modelPath) {
	    _classCallCheck(this, BrowserLocalStorage);
	    if (!env().getBool('IS_BROWSER') || typeof window === 'undefined' || typeof window.localStorage === 'undefined') {
	      // TODO(cais): Add more info about what IOHandler subtypes are
	      // available.
	      //   Maybe point to a doc page on the web and/or automatically determine
	      //   the available IOHandlers and print them in the error message.
	      throw new Error('The current environment does not support local storage.');
	    }
	    this.LS = window.localStorage;
	    if (modelPath == null || !modelPath) {
	      throw new Error('For local storage, modelPath must not be null, undefined or empty.');
	    }
	    this.modelPath = modelPath;
	    this.keys = getModelKeys(this.modelPath);
	  }
	  /**
	   * Save model artifacts to browser local storage.
	   *
	   * See the documentation to `browserLocalStorage` for details on the saved
	   * artifacts.
	   *
	   * @param modelArtifacts The model artifacts to be stored.
	   * @returns An instance of SaveResult.
	   */
	  _createClass(BrowserLocalStorage, [{
	    key: "save",
	    value: function () {
	      var _save = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(modelArtifacts) {
	        var topology, weightSpecs, modelArtifactsInfo, weightBuffer, metadata;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              if (!(modelArtifacts.modelTopology instanceof ArrayBuffer)) {
	                _context.next = 4;
	                break;
	              }
	              throw new Error('BrowserLocalStorage.save() does not support saving model topology ' + 'in binary formats yet.');
	            case 4:
	              topology = JSON.stringify(modelArtifacts.modelTopology);
	              weightSpecs = JSON.stringify(modelArtifacts.weightSpecs);
	              modelArtifactsInfo = getModelArtifactsInfoForJSON(modelArtifacts); // TODO(mattsoulanille): Support saving models over 2GB that exceed
	              // Chrome's ArrayBuffer size limit.
	              weightBuffer = CompositeArrayBuffer.join(modelArtifacts.weightData);
	              _context.prev = 8;
	              this.LS.setItem(this.keys.info, JSON.stringify(modelArtifactsInfo));
	              this.LS.setItem(this.keys.topology, topology);
	              this.LS.setItem(this.keys.weightSpecs, weightSpecs);
	              this.LS.setItem(this.keys.weightData, arrayBufferToBase64String(weightBuffer));
	              // Note that JSON.stringify doesn't write out keys that have undefined
	              // values, so for some keys, we set undefined instead of a null-ish
	              // value.
	              metadata = {
	                format: modelArtifacts.format,
	                generatedBy: modelArtifacts.generatedBy,
	                convertedBy: modelArtifacts.convertedBy,
	                signature: modelArtifacts.signature != null ? modelArtifacts.signature : undefined,
	                userDefinedMetadata: modelArtifacts.userDefinedMetadata != null ? modelArtifacts.userDefinedMetadata : undefined,
	                modelInitializer: modelArtifacts.modelInitializer != null ? modelArtifacts.modelInitializer : undefined,
	                initializerSignature: modelArtifacts.initializerSignature != null ? modelArtifacts.initializerSignature : undefined,
	                trainingConfig: modelArtifacts.trainingConfig != null ? modelArtifacts.trainingConfig : undefined
	              };
	              this.LS.setItem(this.keys.modelMetadata, JSON.stringify(metadata));
	              return _context.abrupt("return", {
	                modelArtifactsInfo: modelArtifactsInfo
	              });
	            case 18:
	              _context.prev = 18;
	              _context.t0 = _context["catch"](8);
	              // If saving failed, clean up all items saved so far.
	              removeItems(this.keys);
	              throw new Error("Failed to save model '".concat(this.modelPath, "' to local storage: ") + "size quota being exceeded is a possible cause of this failure: " + "modelTopologyBytes=".concat(modelArtifactsInfo.modelTopologyBytes, ", ") + "weightSpecsBytes=".concat(modelArtifactsInfo.weightSpecsBytes, ", ") + "weightDataBytes=".concat(modelArtifactsInfo.weightDataBytes, "."));
	            case 22:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this, [[8, 18]]);
	      }));
	      function save(_x) {
	        return _save.apply(this, arguments);
	      }
	      return save;
	    }()
	    /**
	     * Load a model from local storage.
	     *
	     * See the documentation to `browserLocalStorage` for details on the saved
	     * artifacts.
	     *
	     * @returns The loaded model (if loading succeeds).
	     */
	  }, {
	    key: "load",
	    value: function () {
	      var _load = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2() {
	        var info, out, topology, weightSpecs, metadataString, metadata, weightDataBase64;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              info = JSON.parse(this.LS.getItem(this.keys.info));
	              if (!(info == null)) {
	                _context2.next = 3;
	                break;
	              }
	              throw new Error("In local storage, there is no model with name '".concat(this.modelPath, "'"));
	            case 3:
	              if (!(info.modelTopologyType !== 'JSON')) {
	                _context2.next = 5;
	                break;
	              }
	              throw new Error('BrowserLocalStorage does not support loading non-JSON model ' + 'topology yet.');
	            case 5:
	              out = {}; // Load topology.
	              topology = JSON.parse(this.LS.getItem(this.keys.topology));
	              if (!(topology == null)) {
	                _context2.next = 9;
	                break;
	              }
	              throw new Error("In local storage, the topology of model '".concat(this.modelPath, "' ") + "is missing.");
	            case 9:
	              out.modelTopology = topology;
	              // Load weight specs.
	              weightSpecs = JSON.parse(this.LS.getItem(this.keys.weightSpecs));
	              if (!(weightSpecs == null)) {
	                _context2.next = 13;
	                break;
	              }
	              throw new Error("In local storage, the weight specs of model '".concat(this.modelPath, "' ") + "are missing.");
	            case 13:
	              out.weightSpecs = weightSpecs;
	              // Load meta-data fields.
	              metadataString = this.LS.getItem(this.keys.modelMetadata);
	              if (metadataString != null) {
	                metadata = JSON.parse(metadataString);
	                out.format = metadata.format;
	                out.generatedBy = metadata.generatedBy;
	                out.convertedBy = metadata.convertedBy;
	                if (metadata.signature != null) {
	                  out.signature = metadata.signature;
	                }
	                if (metadata.userDefinedMetadata != null) {
	                  out.userDefinedMetadata = metadata.userDefinedMetadata;
	                }
	                if (metadata.modelInitializer != null) {
	                  out.modelInitializer = metadata.modelInitializer;
	                }
	                if (metadata.initializerSignature != null) {
	                  out.initializerSignature = metadata.initializerSignature;
	                }
	                if (metadata.trainingConfig != null) {
	                  out.trainingConfig = metadata.trainingConfig;
	                }
	              }
	              // Load weight data.
	              weightDataBase64 = this.LS.getItem(this.keys.weightData);
	              if (!(weightDataBase64 == null)) {
	                _context2.next = 19;
	                break;
	              }
	              throw new Error("In local storage, the binary weight values of model " + "'".concat(this.modelPath, "' are missing."));
	            case 19:
	              out.weightData = base64StringToArrayBuffer(weightDataBase64);
	              return _context2.abrupt("return", out);
	            case 21:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function load() {
	        return _load.apply(this, arguments);
	      }
	      return load;
	    }()
	  }]);
	  return BrowserLocalStorage;
	}();
	BrowserLocalStorage.URL_SCHEME = 'localstorage://';
	var localStorageRouter = function localStorageRouter(url) {
	  if (!env().getBool('IS_BROWSER')) {
	    return null;
	  } else {
	    if (!Array.isArray(url) && url.startsWith(BrowserLocalStorage.URL_SCHEME)) {
	      return browserLocalStorage(url.slice(BrowserLocalStorage.URL_SCHEME.length));
	    } else {
	      return null;
	    }
	  }
	};
	IORouterRegistry.registerSaveRouter(localStorageRouter);
	IORouterRegistry.registerLoadRouter(localStorageRouter);
	/**
	 * Factory function for local storage IOHandler.
	 *
	 * This `IOHandler` supports both `save` and `load`.
	 *
	 * For each model's saved artifacts, four items are saved to local storage.
	 *   - `${PATH_SEPARATOR}/${modelPath}/info`: Contains meta-info about the
	 *     model, such as date saved, type of the topology, size in bytes, etc.
	 *   - `${PATH_SEPARATOR}/${modelPath}/topology`: Model topology. For Keras-
	 *     style models, this is a stringized JSON.
	 *   - `${PATH_SEPARATOR}/${modelPath}/weight_specs`: Weight specs of the
	 *     model, can be used to decode the saved binary weight values (see
	 *     item below).
	 *   - `${PATH_SEPARATOR}/${modelPath}/weight_data`: Concatenated binary
	 *     weight values, stored as a base64-encoded string.
	 *
	 * Saving may throw an `Error` if the total size of the artifacts exceed the
	 * browser-specific quota.
	 *
	 * @param modelPath A unique identifier for the model to be saved. Must be a
	 *   non-empty string.
	 * @returns An instance of `IOHandler`, which can be used with, e.g.,
	 *   `tf.Model.save`.
	 */
	function browserLocalStorage(modelPath) {
	  return new BrowserLocalStorage(modelPath);
	}
	var BrowserLocalStorageManager = /*#__PURE__*/function () {
	  function BrowserLocalStorageManager() {
	    _classCallCheck(this, BrowserLocalStorageManager);
	    assert$1(env().getBool('IS_BROWSER'), function () {
	      return 'Current environment is not a web browser';
	    });
	    assert$1(typeof window === 'undefined' || typeof window.localStorage !== 'undefined', function () {
	      return 'Current browser does not appear to support localStorage';
	    });
	    this.LS = window.localStorage;
	  }
	  _createClass(BrowserLocalStorageManager, [{
	    key: "listModels",
	    value: function () {
	      var _listModels = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3() {
	        var out, prefix, suffix, i, key, modelPath;
	        return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	          while (1) switch (_context3.prev = _context3.next) {
	            case 0:
	              out = {};
	              prefix = PATH_PREFIX + PATH_SEPARATOR;
	              suffix = PATH_SEPARATOR + INFO_SUFFIX;
	              for (i = 0; i < this.LS.length; ++i) {
	                key = this.LS.key(i);
	                if (key.startsWith(prefix) && key.endsWith(suffix)) {
	                  modelPath = getModelPathFromKey(key);
	                  out[modelPath] = JSON.parse(this.LS.getItem(key));
	                }
	              }
	              return _context3.abrupt("return", out);
	            case 5:
	            case "end":
	              return _context3.stop();
	          }
	        }, _callee3, this);
	      }));
	      function listModels() {
	        return _listModels.apply(this, arguments);
	      }
	      return listModels;
	    }()
	  }, {
	    key: "removeModel",
	    value: function () {
	      var _removeModel = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4(path) {
	        var keys, info;
	        return _regeneratorRuntime().wrap(function _callee4$(_context4) {
	          while (1) switch (_context4.prev = _context4.next) {
	            case 0:
	              path = maybeStripScheme(path);
	              keys = getModelKeys(path);
	              if (!(this.LS.getItem(keys.info) == null)) {
	                _context4.next = 4;
	                break;
	              }
	              throw new Error("Cannot find model at path '".concat(path, "'"));
	            case 4:
	              info = JSON.parse(this.LS.getItem(keys.info));
	              removeItems(keys);
	              return _context4.abrupt("return", info);
	            case 7:
	            case "end":
	              return _context4.stop();
	          }
	        }, _callee4, this);
	      }));
	      function removeModel(_x2) {
	        return _removeModel.apply(this, arguments);
	      }
	      return removeModel;
	    }()
	  }]);
	  return BrowserLocalStorageManager;
	}();

	var URL_SCHEME_SUFFIX = '://';
	var ModelStoreManagerRegistry = /*#__PURE__*/function () {
	  function ModelStoreManagerRegistry() {
	    _classCallCheck(this, ModelStoreManagerRegistry);
	    this.managers = {};
	  }
	  _createClass(ModelStoreManagerRegistry, null, [{
	    key: "getInstance",
	    value: function getInstance() {
	      if (ModelStoreManagerRegistry.instance == null) {
	        ModelStoreManagerRegistry.instance = new ModelStoreManagerRegistry();
	      }
	      return ModelStoreManagerRegistry.instance;
	    }
	    /**
	     * Register a save-handler router.
	     *
	     * @param saveRouter A function that maps a URL-like string onto an instance
	     * of `IOHandler` with the `save` method defined or `null`.
	     */
	  }, {
	    key: "registerManager",
	    value: function registerManager(scheme, manager) {
	      assert$1(scheme != null, function () {
	        return 'scheme must not be undefined or null.';
	      });
	      if (scheme.endsWith(URL_SCHEME_SUFFIX)) {
	        scheme = scheme.slice(0, scheme.indexOf(URL_SCHEME_SUFFIX));
	      }
	      assert$1(scheme.length > 0, function () {
	        return 'scheme must not be an empty string.';
	      });
	      var registry = ModelStoreManagerRegistry.getInstance();
	      assert$1(registry.managers[scheme] == null, function () {
	        return "A model store manager is already registered for scheme '".concat(scheme, "'.");
	      });
	      registry.managers[scheme] = manager;
	    }
	  }, {
	    key: "getManager",
	    value: function getManager(scheme) {
	      var manager = ModelStoreManagerRegistry.getInstance().managers[scheme];
	      if (manager == null) {
	        throw new Error("Cannot find model manager for scheme '".concat(scheme, "'"));
	      }
	      return manager;
	    }
	  }, {
	    key: "getSchemes",
	    value: function getSchemes() {
	      return Object.keys(ModelStoreManagerRegistry.getInstance().managers);
	    }
	  }]);
	  return ModelStoreManagerRegistry;
	}();
	/**
	 * Helper method for parsing a URL string into a scheme and a path.
	 *
	 * @param url E.g., 'localstorage://my-model'
	 * @returns A dictionary with two fields: scheme and path.
	 *   Scheme: e.g., 'localstorage' in the example above.
	 *   Path: e.g., 'my-model' in the example above.
	 */
	function parseURL(url) {
	  if (url.indexOf(URL_SCHEME_SUFFIX) === -1) {
	    throw new Error("The url string provided does not contain a scheme. " + "Supported schemes are: " + "".concat(ModelStoreManagerRegistry.getSchemes().join(',')));
	  }
	  return {
	    scheme: url.split(URL_SCHEME_SUFFIX)[0],
	    path: url.split(URL_SCHEME_SUFFIX)[1]
	  };
	}
	function cloneModelInternal(_x, _x2) {
	  return _cloneModelInternal.apply(this, arguments);
	}
	/**
	 * List all models stored in registered storage mediums.
	 *
	 * For a web browser environment, the registered mediums are Local Storage and
	 * IndexedDB.
	 *
	 * ```js
	 * // First create and save a model.
	 * const model = tf.sequential();
	 * model.add(tf.layers.dense(
	 *     {units: 1, inputShape: [10], activation: 'sigmoid'}));
	 * await model.save('localstorage://demo/management/model1');
	 *
	 * // Then list existing models.
	 * console.log(JSON.stringify(await tf.io.listModels()));
	 *
	 * // Delete the model.
	 * await tf.io.removeModel('localstorage://demo/management/model1');
	 *
	 * // List models again.
	 * console.log(JSON.stringify(await tf.io.listModels()));
	 * ```
	 *
	 * @returns A `Promise` of a dictionary mapping URLs of existing models to
	 * their model artifacts info. URLs include medium-specific schemes, e.g.,
	 *   'indexeddb://my/model/1'. Model artifacts info include type of the
	 * model's topology, byte sizes of the topology, weights, etc.
	 *
	 * @doc {
	 *   heading: 'Models',
	 *   subheading: 'Management',
	 *   namespace: 'io',
	 *   ignoreCI: true
	 * }
	 */
	function _cloneModelInternal() {
	  _cloneModelInternal = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(sourceURL, destURL) {
	    var deleteSource,
	      loadHandlers,
	      loadHandler,
	      saveHandlers,
	      saveHandler,
	      sourceScheme,
	      sourcePath,
	      sameMedium,
	      modelArtifacts,
	      saveResult,
	      _args = arguments;
	    return _regeneratorRuntime().wrap(function _callee$(_context) {
	      while (1) switch (_context.prev = _context.next) {
	        case 0:
	          deleteSource = _args.length > 2 && _args[2] !== undefined ? _args[2] : false;
	          assert$1(sourceURL !== destURL, function () {
	            return "Old path and new path are the same: '".concat(sourceURL, "'");
	          });
	          loadHandlers = IORouterRegistry.getLoadHandlers(sourceURL);
	          assert$1(loadHandlers.length > 0, function () {
	            return "Copying failed because no load handler is found for source URL ".concat(sourceURL, ".");
	          });
	          assert$1(loadHandlers.length < 2, function () {
	            return "Copying failed because more than one (".concat(loadHandlers.length, ") ") + "load handlers for source URL ".concat(sourceURL, ".");
	          });
	          loadHandler = loadHandlers[0];
	          saveHandlers = IORouterRegistry.getSaveHandlers(destURL);
	          assert$1(saveHandlers.length > 0, function () {
	            return "Copying failed because no save handler is found for destination " + "URL ".concat(destURL, ".");
	          });
	          assert$1(saveHandlers.length < 2, function () {
	            return "Copying failed because more than one (".concat(loadHandlers.length, ") ") + "save handlers for destination URL ".concat(destURL, ".");
	          });
	          saveHandler = saveHandlers[0];
	          sourceScheme = parseURL(sourceURL).scheme;
	          sourcePath = parseURL(sourceURL).path;
	          sameMedium = sourceScheme === parseURL(sourceURL).scheme;
	          _context.next = 15;
	          return loadHandler.load();
	        case 15:
	          modelArtifacts = _context.sent;
	          if (!(deleteSource && sameMedium)) {
	            _context.next = 19;
	            break;
	          }
	          _context.next = 19;
	          return ModelStoreManagerRegistry.getManager(sourceScheme).removeModel(sourcePath);
	        case 19:
	          _context.next = 21;
	          return saveHandler.save(modelArtifacts);
	        case 21:
	          saveResult = _context.sent;
	          if (!(deleteSource && !sameMedium)) {
	            _context.next = 25;
	            break;
	          }
	          _context.next = 25;
	          return ModelStoreManagerRegistry.getManager(sourceScheme).removeModel(sourcePath);
	        case 25:
	          return _context.abrupt("return", saveResult.modelArtifactsInfo);
	        case 26:
	        case "end":
	          return _context.stop();
	      }
	    }, _callee);
	  }));
	  return _cloneModelInternal.apply(this, arguments);
	}
	function listModels() {
	  return _listModels.apply(this, arguments);
	}
	/**
	 * Remove a model specified by URL from a registered storage medium.
	 *
	 * ```js
	 * // First create and save a model.
	 * const model = tf.sequential();
	 * model.add(tf.layers.dense(
	 *     {units: 1, inputShape: [10], activation: 'sigmoid'}));
	 * await model.save('localstorage://demo/management/model1');
	 *
	 * // Then list existing models.
	 * console.log(JSON.stringify(await tf.io.listModels()));
	 *
	 * // Delete the model.
	 * await tf.io.removeModel('localstorage://demo/management/model1');
	 *
	 * // List models again.
	 * console.log(JSON.stringify(await tf.io.listModels()));
	 * ```
	 *
	 * @param url A URL to a stored model, with a scheme prefix, e.g.,
	 *   'localstorage://my-model-1', 'indexeddb://my/model/2'.
	 * @returns ModelArtifactsInfo of the deleted model (if and only if deletion
	 *   is successful).
	 * @throws Error if deletion fails, e.g., if no model exists at `path`.
	 *
	 * @doc {
	 *   heading: 'Models',
	 *   subheading: 'Management',
	 *   namespace: 'io',
	 *   ignoreCI: true
	 * }
	 */
	function _listModels() {
	  _listModels = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2() {
	    var schemes, out, _iterator, _step, scheme, schemeOut, path, url;
	    return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	      while (1) switch (_context2.prev = _context2.next) {
	        case 0:
	          schemes = ModelStoreManagerRegistry.getSchemes();
	          out = {};
	          _iterator = _createForOfIteratorHelper(schemes);
	          _context2.prev = 3;
	          _iterator.s();
	        case 5:
	          if ((_step = _iterator.n()).done) {
	            _context2.next = 13;
	            break;
	          }
	          scheme = _step.value;
	          _context2.next = 9;
	          return ModelStoreManagerRegistry.getManager(scheme).listModels();
	        case 9:
	          schemeOut = _context2.sent;
	          for (path in schemeOut) {
	            url = scheme + URL_SCHEME_SUFFIX + path;
	            out[url] = schemeOut[path];
	          }
	        case 11:
	          _context2.next = 5;
	          break;
	        case 13:
	          _context2.next = 18;
	          break;
	        case 15:
	          _context2.prev = 15;
	          _context2.t0 = _context2["catch"](3);
	          _iterator.e(_context2.t0);
	        case 18:
	          _context2.prev = 18;
	          _iterator.f();
	          return _context2.finish(18);
	        case 21:
	          return _context2.abrupt("return", out);
	        case 22:
	        case "end":
	          return _context2.stop();
	      }
	    }, _callee2, null, [[3, 15, 18, 21]]);
	  }));
	  return _listModels.apply(this, arguments);
	}
	function removeModel(_x3) {
	  return _removeModel.apply(this, arguments);
	}
	/**
	 * Copy a model from one URL to another.
	 *
	 * This function supports:
	 *
	 * 1. Copying within a storage medium, e.g.,
	 *    `tf.io.copyModel('localstorage://model-1', 'localstorage://model-2')`
	 * 2. Copying between two storage mediums, e.g.,
	 *    `tf.io.copyModel('localstorage://model-1', 'indexeddb://model-1')`
	 *
	 * ```js
	 * // First create and save a model.
	 * const model = tf.sequential();
	 * model.add(tf.layers.dense(
	 *     {units: 1, inputShape: [10], activation: 'sigmoid'}));
	 * await model.save('localstorage://demo/management/model1');
	 *
	 * // Then list existing models.
	 * console.log(JSON.stringify(await tf.io.listModels()));
	 *
	 * // Copy the model, from Local Storage to IndexedDB.
	 * await tf.io.copyModel(
	 *     'localstorage://demo/management/model1',
	 *     'indexeddb://demo/management/model1');
	 *
	 * // List models again.
	 * console.log(JSON.stringify(await tf.io.listModels()));
	 *
	 * // Remove both models.
	 * await tf.io.removeModel('localstorage://demo/management/model1');
	 * await tf.io.removeModel('indexeddb://demo/management/model1');
	 * ```
	 *
	 * @param sourceURL Source URL of copying.
	 * @param destURL Destination URL of copying.
	 * @returns ModelArtifactsInfo of the copied model (if and only if copying
	 *   is successful).
	 * @throws Error if copying fails, e.g., if no model exists at `sourceURL`, or
	 *   if `oldPath` and `newPath` are identical.
	 *
	 * @doc {
	 *   heading: 'Models',
	 *   subheading: 'Management',
	 *   namespace: 'io',
	 *   ignoreCI: true
	 * }
	 */
	function _removeModel() {
	  _removeModel = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3(url) {
	    var schemeAndPath, manager;
	    return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	      while (1) switch (_context3.prev = _context3.next) {
	        case 0:
	          schemeAndPath = parseURL(url);
	          manager = ModelStoreManagerRegistry.getManager(schemeAndPath.scheme);
	          return _context3.abrupt("return", manager.removeModel(schemeAndPath.path));
	        case 3:
	        case "end":
	          return _context3.stop();
	      }
	    }, _callee3);
	  }));
	  return _removeModel.apply(this, arguments);
	}
	function copyModel(_x4, _x5) {
	  return _copyModel.apply(this, arguments);
	}
	/**
	 * Move a model from one URL to another.
	 *
	 * This function supports:
	 *
	 * 1. Moving within a storage medium, e.g.,
	 *    `tf.io.moveModel('localstorage://model-1', 'localstorage://model-2')`
	 * 2. Moving between two storage mediums, e.g.,
	 *    `tf.io.moveModel('localstorage://model-1', 'indexeddb://model-1')`
	 *
	 * ```js
	 * // First create and save a model.
	 * const model = tf.sequential();
	 * model.add(tf.layers.dense(
	 *     {units: 1, inputShape: [10], activation: 'sigmoid'}));
	 * await model.save('localstorage://demo/management/model1');
	 *
	 * // Then list existing models.
	 * console.log(JSON.stringify(await tf.io.listModels()));
	 *
	 * // Move the model, from Local Storage to IndexedDB.
	 * await tf.io.moveModel(
	 *     'localstorage://demo/management/model1',
	 *     'indexeddb://demo/management/model1');
	 *
	 * // List models again.
	 * console.log(JSON.stringify(await tf.io.listModels()));
	 *
	 * // Remove the moved model.
	 * await tf.io.removeModel('indexeddb://demo/management/model1');
	 * ```
	 *
	 * @param sourceURL Source URL of moving.
	 * @param destURL Destination URL of moving.
	 * @returns ModelArtifactsInfo of the copied model (if and only if copying
	 *   is successful).
	 * @throws Error if moving fails, e.g., if no model exists at `sourceURL`, or
	 *   if `oldPath` and `newPath` are identical.
	 *
	 * @doc {
	 *   heading: 'Models',
	 *   subheading: 'Management',
	 *   namespace: 'io',
	 *   ignoreCI: true
	 * }
	 */
	function _copyModel() {
	  _copyModel = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4(sourceURL, destURL) {
	    var deleteSource;
	    return _regeneratorRuntime().wrap(function _callee4$(_context4) {
	      while (1) switch (_context4.prev = _context4.next) {
	        case 0:
	          deleteSource = false;
	          return _context4.abrupt("return", cloneModelInternal(sourceURL, destURL, deleteSource));
	        case 2:
	        case "end":
	          return _context4.stop();
	      }
	    }, _callee4);
	  }));
	  return _copyModel.apply(this, arguments);
	}
	function moveModel(_x6, _x7) {
	  return _moveModel.apply(this, arguments);
	}
	function _moveModel() {
	  _moveModel = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee5(sourceURL, destURL) {
	    var deleteSource;
	    return _regeneratorRuntime().wrap(function _callee5$(_context5) {
	      while (1) switch (_context5.prev = _context5.next) {
	        case 0:
	          deleteSource = true;
	          return _context5.abrupt("return", cloneModelInternal(sourceURL, destURL, deleteSource));
	        case 2:
	        case "end":
	          return _context5.stop();
	      }
	    }, _callee5);
	  }));
	  return _moveModel.apply(this, arguments);
	}

	var PlatformBrowser = /*#__PURE__*/function () {
	  function PlatformBrowser() {
	    _classCallCheck(this, PlatformBrowser);
	    // For setTimeoutCustom
	    this.messageName = 'setTimeoutCustom';
	    this.functionRefs = [];
	    this.handledMessageCount = 0;
	    this.hasEventListener = false;
	  }
	  _createClass(PlatformBrowser, [{
	    key: "fetch",
	    value: function (_fetch) {
	      function fetch(_x, _x2) {
	        return _fetch.apply(this, arguments);
	      }
	      fetch.toString = function () {
	        return _fetch.toString();
	      };
	      return fetch;
	    }(function (path, init) {
	      return fetch(path, init);
	    })
	  }, {
	    key: "now",
	    value: function now() {
	      return performance.now();
	    }
	  }, {
	    key: "encode",
	    value: function encode(text, encoding) {
	      if (encoding !== 'utf-8' && encoding !== 'utf8') {
	        throw new Error("Browser's encoder only supports utf-8, but got ".concat(encoding));
	      }
	      if (this.textEncoder == null) {
	        this.textEncoder = new TextEncoder();
	      }
	      return this.textEncoder.encode(text);
	    }
	  }, {
	    key: "decode",
	    value: function decode(bytes, encoding) {
	      return new TextDecoder(encoding).decode(bytes);
	    }
	    // If the setTimeout nesting level is greater than 5 and timeout is less
	    // than 4ms, timeout will be clamped to 4ms, which hurts the perf.
	    // Interleaving window.postMessage and setTimeout will trick the browser and
	    // avoid the clamp.
	  }, {
	    key: "setTimeoutCustom",
	    value: function setTimeoutCustom(functionRef, delay) {
	      var _this = this;
	      if (typeof window === 'undefined' || !env().getBool('USE_SETTIMEOUTCUSTOM')) {
	        setTimeout(functionRef, delay);
	        return;
	      }
	      this.functionRefs.push(functionRef);
	      setTimeout(function () {
	        window.postMessage({
	          name: _this.messageName,
	          index: _this.functionRefs.length - 1
	        }, '*');
	      }, delay);
	      if (!this.hasEventListener) {
	        this.hasEventListener = true;
	        window.addEventListener('message', function (event) {
	          if (event.source === window && event.data.name === _this.messageName) {
	            event.stopPropagation();
	            var _functionRef = _this.functionRefs[event.data.index];
	            _functionRef();
	            _this.handledMessageCount++;
	            if (_this.handledMessageCount === _this.functionRefs.length) {
	              _this.functionRefs = [];
	              _this.handledMessageCount = 0;
	            }
	          }
	        }, true);
	      }
	    }
	  }, {
	    key: "isTypedArray",
	    value: function isTypedArray(a) {
	      return isTypedArrayBrowser(a);
	    }
	  }]);
	  return PlatformBrowser;
	}();
	if (env().get('IS_BROWSER')) {
	  env().setPlatform('browser', new PlatformBrowser());
	  // Register LocalStorage IOHandler
	  try {
	    ModelStoreManagerRegistry.registerManager(BrowserLocalStorage.URL_SCHEME, new BrowserLocalStorageManager());
	  } catch (err) {}
	  // Register IndexedDB IOHandler
	  try {
	    ModelStoreManagerRegistry.registerManager(BrowserIndexedDB.URL_SCHEME, new BrowserIndexedDBManager());
	  } catch (err) {}
	}

	// We are wrapping this within an object so it can be stubbed by Jasmine.
	var getNodeFetch = {
	  // tslint:disable-next-line:no-require-imports
	  importFetch: function importFetch() {
	    return require('node-fetch');
	  }
	};
	var systemFetch;
	// These getters and setters are for testing so we don't export a mutable
	// variable.
	function resetSystemFetch() {
	  systemFetch = null;
	}
	function setSystemFetch(fetchFn) {
	  systemFetch = fetchFn;
	}
	function getSystemFetch() {
	  return systemFetch;
	}
	var PlatformNode = /*#__PURE__*/function () {
	  function PlatformNode() {
	    _classCallCheck(this, PlatformNode);
	    // tslint:disable-next-line:no-require-imports
	    this.util = require('util');
	    // According to the spec, the built-in encoder can do only UTF-8 encoding.
	    // https://developer.mozilla.org/en-US/docs/Web/API/TextEncoder/TextEncoder
	    this.textEncoder = new this.util.TextEncoder();
	  }
	  _createClass(PlatformNode, [{
	    key: "fetch",
	    value: function fetch(path, requestInits) {
	      if (env().global.fetch != null) {
	        return env().global.fetch(path, requestInits);
	      }
	      if (systemFetch == null) {
	        systemFetch = getNodeFetch.importFetch();
	      }
	      return systemFetch(path, requestInits);
	    }
	  }, {
	    key: "now",
	    value: function now() {
	      var time = process.hrtime();
	      return time[0] * 1000 + time[1] / 1000000;
	    }
	  }, {
	    key: "encode",
	    value: function encode(text, encoding) {
	      if (encoding !== 'utf-8' && encoding !== 'utf8') {
	        throw new Error("Node built-in encoder only supports utf-8, but got ".concat(encoding));
	      }
	      return this.textEncoder.encode(text);
	    }
	  }, {
	    key: "decode",
	    value: function decode(bytes, encoding) {
	      if (bytes.length === 0) {
	        return '';
	      }
	      return new this.util.TextDecoder(encoding).decode(bytes);
	    }
	  }, {
	    key: "isTypedArray",
	    value: function isTypedArray(a) {
	      return this.util.types.isFloat32Array(a) || this.util.types.isInt32Array(a) || this.util.types.isUint8Array(a) || this.util.types.isUint8ClampedArray(a);
	    }
	  }]);
	  return PlatformNode;
	}();
	if (env().get('IS_NODE') && !env().get('IS_BROWSER')) {
	  env().setPlatform('node', new PlatformNode());
	}

	/**
	 * @license
	 * Copyright 2020 Google Inc. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates an empty `tf.TensorBuffer` with the specified `shape` and `dtype`.
	 *
	 * The values are stored in CPU as `TypedArray`. Fill the buffer using
	 * `buffer.set()`, or by modifying directly `buffer.values`.
	 *
	 * When done, call `buffer.toTensor()` to get an immutable `tf.Tensor` with
	 * those values.
	 *
	 * ```js
	 * // Create a buffer and set values at particular indices.
	 * const buffer = tf.buffer([2, 2]);
	 * buffer.set(3, 0, 0);
	 * buffer.set(5, 1, 0);
	 *
	 * // Convert the buffer back to a tensor.
	 * buffer.toTensor().print();
	 * ```
	 *
	 * @param shape An array of integers defining the output tensor shape.
	 * @param dtype The dtype of the buffer. Defaults to 'float32'.
	 * @param values The values of the buffer as `TypedArray`. Defaults to
	 * zeros.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function buffer(shape) {
	  var dtype = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'float32';
	  var values = arguments.length > 2 ? arguments[2] : undefined;
	  dtype = dtype || 'float32';
	  assertNonNegativeIntegerDimensions(shape);
	  return new TensorBuffer(shape, dtype, values);
	}

	/**
	 * @license
	 * Copyright 2020 Google Inc. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Casts a `tf.Tensor` to a new dtype.
	 *
	 * ```js
	 * const x = tf.tensor1d([1.5, 2.5, 3]);
	 * tf.cast(x, 'int32').print();
	 * ```
	 * @param x The input tensor to be casted.
	 * @param dtype The dtype to cast the input tensor to.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Transformations'}
	 */
	function cast_(x, dtype) {
	  var $x = convertToTensor(x, 'x', 'cast');
	  // Sanity checks.
	  if (!isValidDtype(dtype)) {
	    throw new Error("Failed to cast to unknown dtype ".concat(dtype));
	  }
	  if (dtype === 'string' && $x.dtype !== 'string' || dtype !== 'string' && $x.dtype === 'string') {
	    throw new Error('Only strings can be casted to strings');
	  }
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    dtype: dtype
	  };
	  return ENGINE.runKernel(Cast, inputs, attrs);
	}
	var cast$3 = /* @__PURE__ */op({
	  cast_: cast_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a new tensor with the same values and shape as the specified
	 * tensor.
	 *
	 * ```js
	 * const x = tf.tensor([1, 2]);
	 *
	 * x.clone().print();
	 * ```
	 *
	 * @param x The tensor to clone.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function clone_(x) {
	  var $x = convertToTensor(x, 'x', 'clone', 'string_or_numeric');
	  var inputs = {
	    x: $x
	  };
	  // Note this op is called tf.identity in python. Hence the kernel name used
	  // here.
	  return ENGINE.runKernel(Identity$1, inputs);
	}
	var clone = /* @__PURE__ */op({
	  clone_: clone_
	});

	/**
	 * @license
	 * Copyright 2020 Google Inc. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Prints information about the `tf.Tensor` including its data.
	 *
	 * ```js
	 * const verbose = true;
	 * tf.tensor2d([1, 2, 3, 4], [2, 2]).print(verbose);
	 * ```
	 * @param x The tensor to be printed.
	 * @param verbose Whether to print verbose information about the ` Tensor`,
	 * including dtype and size.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function print(x) {
	  var verbose = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
	  console.log(x.toString(verbose));
	}

	/**
	 * @license
	 * Copyright 2020 Google Inc. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getOrMakeEngine();
	var opHandler = {
	  buffer: buffer,
	  cast: cast$3,
	  clone: clone,
	  print: print
	};
	setOpHandler(opHandler);

	/**
	 * Adds two `tf.Tensor`s element-wise, A + B. Supports broadcasting.
	 *
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 2, 3, 4]);
	 * const b = tf.tensor1d([10, 20, 30, 40]);
	 *
	 * a.add(b).print();  // or tf.add(a, b)
	 * ```
	 *
	 * ```js
	 * // Broadcast add a with b.
	 * const a = tf.scalar(5);
	 * const b = tf.tensor1d([10, 20, 30, 40]);
	 *
	 * a.add(b).print();  // or tf.add(a, b)
	 * ```
	 * @param a The first `tf.Tensor` to add.
	 * @param b The second `tf.Tensor` to add. Must have the same type as `a`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Arithmetic'}
	 */
	function add_(a, b) {
	  var $a = convertToTensor(a, 'a', 'add');
	  var $b = convertToTensor(b, 'b', 'add');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  return ENGINE.runKernel(Add$1, inputs);
	}
	var add$3 = /* @__PURE__ */op({
	  add_: add_
	});

	/**
	 * Divides two `tf.Tensor`s element-wise, A / B. Supports broadcasting.
	 * The result is rounded with floor function.
	 *
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 4, 9, 16]);
	 * const b = tf.tensor1d([1, 2, 3, 4]);
	 *
	 * a.floorDiv(b).print();  // or tf.div(a, b)
	 * ```
	 *
	 * ```js
	 * // Broadcast div a with b.
	 * const a = tf.tensor1d([2, 4, 6, 8]);
	 * const b = tf.scalar(2);
	 *
	 * a.floorDiv(b).print();  // or tf.floorDiv(a, b)
	 * ```
	 *
	 * @param a The first tensor as the numerator.
	 * @param b The second tensor as the denominator. Must have the same dtype as
	 * `a`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Arithmetic'}
	 */
	function floorDiv_(a, b) {
	  var $a = convertToTensor(a, 'a', 'floorDiv');
	  var $b = convertToTensor(b, 'b', 'floorDiv');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  return ENGINE.runKernel(FloorDiv, inputs);
	}
	var floorDiv$2 = /* @__PURE__ */op({
	  floorDiv_: floorDiv_
	});

	/**
	 * Divides two `tf.Tensor`s element-wise, A / B. Supports broadcasting.
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 4, 9, 16]);
	 * const b = tf.tensor1d([1, 2, 3, 4]);
	 *
	 * a.div(b).print();  // or tf.div(a, b)
	 * ```
	 *
	 * ```js
	 * // Broadcast div a with b.
	 * const a = tf.tensor1d([2, 4, 6, 8]);
	 * const b = tf.scalar(2);
	 *
	 * a.div(b).print();  // or tf.div(a, b)
	 * ```
	 *
	 * @param a The first tensor as the numerator.
	 * @param b The second tensor as the denominator. Must have the same dtype as
	 * `a`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Arithmetic'}
	 */
	function div_(a, b) {
	  var $a = convertToTensor(a, 'a', 'div');
	  var $b = convertToTensor(b, 'b', 'div');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  if ($a.dtype === 'int32' && $b.dtype === 'int32') {
	    return floorDiv$2($a, $b);
	  }
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  var attrs = {};
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  return ENGINE.runKernel(RealDiv, inputs, attrs);
	}
	var div$1 = /* @__PURE__ */op({
	  div_: div_
	});

	/**
	 * Multiplies two `tf.Tensor`s element-wise, A * B. Supports broadcasting.
	 *
	 * We also expose `tf.mulStrict` which has the same signature as this op and
	 * asserts that `a` and `b` are the same shape (does not broadcast).
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 2, 3, 4]);
	 * const b = tf.tensor1d([2, 3, 4, 5]);
	 *
	 * a.mul(b).print();  // or tf.mul(a, b)
	 * ```
	 *
	 * ```js
	 * // Broadcast mul a with b.
	 * const a = tf.tensor1d([1, 2, 3, 4]);
	 * const b = tf.scalar(5);
	 *
	 * a.mul(b).print();  // or tf.mul(a, b)
	 * ```
	 * @param a The first tensor to multiply.
	 * @param b The second tensor to multiply. Must have the same dtype as `a`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Arithmetic'}
	 */
	function mul_(a, b) {
	  var $a = convertToTensor(a, 'a', 'mul');
	  var $b = convertToTensor(b, 'b', 'mul');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  return ENGINE.runKernel(Multiply$1, inputs);
	}
	var mul = /* @__PURE__ */op({
	  mul_: mul_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes absolute value element-wise: `abs(x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([-1, 2, -3, 4]);
	 *
	 * x.abs().print();  // or tf.abs(x)
	 * ```
	 * @param x The input `tf.Tensor`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function abs_(x) {
	  var $x = convertToTensor(x, 'x', 'abs');
	  if ($x.dtype === 'complex64') {
	    var inputs = {
	      x: $x
	    };
	    return ENGINE.runKernel(ComplexAbs, inputs);
	  } else {
	    var _inputs = {
	      x: $x
	    };
	    return ENGINE.runKernel(Abs, _inputs);
	  }
	}
	var abs$2 = /* @__PURE__ */op({
	  abs_: abs_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes acos of the input `tf.Tensor` element-wise: `acos(x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([0, 1, -1, .7]);
	 *
	 * x.acos().print();  // or tf.acos(x)
	 * ```
	 * @param x The input tensor.
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function acos_(x) {
	  var $x = convertToTensor(x, 'x', 'acos');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Acos, inputs);
	}
	var acos$2 = /* @__PURE__ */op({
	  acos_: acos_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the inverse hyperbolic cos of the input `tf.Tensor` element-wise:
	 * `acosh(x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([10, 1, 3, 5.7]);
	 *
	 * x.acosh().print();  // or tf.acosh(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function acosh_(x) {
	  var $x = convertToTensor(x, 'x', 'acosh');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Acosh, inputs);
	}
	var acosh$2 = /* @__PURE__ */op({
	  acosh_: acosh_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Adds a list of `tf.Tensor`s element-wise, each with the same shape and dtype.
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 2]);
	 * const b = tf.tensor1d([3, 4]);
	 * const c = tf.tensor1d([5, 6]);
	 *
	 * tf.addN([a, b, c]).print();
	 * ```
	 * @param tensors A list of tensors with the same shape and dtype.
	 * @doc {heading: 'Operations', subheading: 'Arithmetic'}
	 */
	function addN_(tensors) {
	  assert$1(Array.isArray(tensors), function () {
	    return 'The argument passed to tf.addN() must be a list of tensors';
	  });
	  assert$1(tensors.length >= 1, function () {
	    return "Must pass at least one tensor to tf.addN(), but got " + "".concat(tensors.length);
	  });
	  var $tensors = tensors.map(function (t, i) {
	    return convertToTensor(t, "tensors".concat(i), 'addN');
	  });
	  var firstTensor = $tensors[0];
	  $tensors.forEach(function (t) {
	    if (t.dtype !== firstTensor.dtype) {
	      throw new Error('All tensors passed to tf.addN() must have the same dtype');
	    }
	  });
	  $tensors.forEach(function (t) {
	    if (!arraysEqual(t.shape, firstTensor.shape)) {
	      throw new Error('All tensors passed to tf.addN() must have the same shape');
	    }
	  });
	  var inputs = $tensors;
	  return ENGINE.runKernel(AddN, inputs);
	}
	var addN$2 = /* @__PURE__ */op({
	  addN_: addN_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the logical and of elements across dimensions of a `tf.Tensor`.
	 *
	 * Reduces the input along the dimensions given in `axes`. Unless `keepDims`
	 * is true, the rank of the `tf.Tensor` is reduced by 1 for each entry in
	 * `axes`. If `keepDims` is true, the reduced dimensions are retained with
	 * length 1. If `axes` has no entries, all dimensions are reduced, and a
	 * `tf.Tensor` with a single element is returned.
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 1, 1], 'bool');
	 *
	 * x.all().print();  // or tf.all(x)
	 * ```
	 *
	 * ```js
	 * const x = tf.tensor2d([1, 1, 0, 0], [2, 2], 'bool');
	 *
	 * const axis = 1;
	 * x.all(axis).print();  // or tf.all(x, axis)
	 * ```
	 *
	 * @param x The input tensor. Must be of dtype bool.
	 * @param axis The dimension(s) to reduce. By default it reduces
	 *     all dimensions.
	 * @param keepDims If true, retains reduced dimensions with size 1.
	 *
	 * @doc {heading: 'Operations', subheading: 'Reduction'}
	 */
	function all_(x) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
	  var keepDims = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  var $x = convertToTensor(x, 'x', 'all', 'bool');
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    axis: axis,
	    keepDims: keepDims
	  };
	  return ENGINE.runKernel(All, inputs, attrs);
	}
	var all$2 = /* @__PURE__ */op({
	  all_: all_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the logical or of elements across dimensions of a `tf.Tensor`.
	 *
	 * Reduces the input along the dimensions given in `axes`. Unless `keepDims`
	 * is true, the rank of the `tf.Tensor` is reduced by 1 for each entry in
	 * `axes`. If `keepDims` is true, the reduced dimensions are retained with
	 * length 1. If `axes` has no entries, all dimensions are reduced, and a
	 * `tf.Tensor` with a single element is returned.
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 1, 1], 'bool');
	 *
	 * x.any().print();  // or tf.any(x)
	 * ```
	 *
	 * ```js
	 * const x = tf.tensor2d([1, 1, 0, 0], [2, 2], 'bool');
	 *
	 * const axis = 1;
	 * x.any(axis).print();  // or tf.any(x, axis)
	 * ```
	 *
	 * @param x The input tensor. Must be of dtype bool.
	 * @param axis The dimension(s) to reduce. By default it reduces
	 *     all dimensions.
	 * @param keepDims If true, retains reduced dimensions with size 1.
	 *
	 * @doc {heading: 'Operations', subheading: 'Reduction'}
	 */
	function any_(x) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
	  var keepDims = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  var $x = convertToTensor(x, 'x', 'any', 'bool');
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    axis: axis,
	    keepDims: keepDims
	  };
	  return ENGINE.runKernel(Any, inputs, attrs);
	}
	// tslint:disable-next-line:variable-name
	var any$2 = /* @__PURE__ */op({
	  any_: any_
	});

	/**
	 * @license
	 * Copyright 2020 Google Inc. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Returns the indices of the maximum values along an `axis`.
	 *
	 * The result has the same shape as `input` with the dimension along `axis`
	 * removed.
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3]);
	 *
	 * x.argMax().print();  // or tf.argMax(x)
	 * ```
	 *
	 * ```js
	 * const x = tf.tensor2d([1, 2, 4, 3], [2, 2]);
	 *
	 * const axis = 1;
	 * x.argMax(axis).print();  // or tf.argMax(x, axis)
	 * ```
	 *
	 * @param x The input tensor.
	 * @param axis The dimension to reduce. Defaults to 0 (outer-most dimension).
	 *
	 * @doc {heading: 'Operations', subheading: 'Reduction'}
	 */
	function argMax_(x) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
	  var $x = convertToTensor(x, 'x', 'argMax');
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    axis: axis
	  };
	  return ENGINE.runKernel(ArgMax, inputs, attrs);
	}
	var argMax$2 = /* @__PURE__ */op({
	  argMax_: argMax_
	});

	/**
	 * @license
	 * Copyright 2020 Google Inc. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Returns the indices of the minimum values along an `axis`.
	 *
	 * The result has the same shape as `input` with the dimension along `axis`
	 * removed.
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3]);
	 *
	 * x.argMin().print();  // or tf.argMin(x)
	 * ```
	 *
	 * ```js
	 * const x = tf.tensor2d([1, 2, 4, 3], [2, 2]);
	 *
	 * const axis = 1;
	 * x.argMin(axis).print();  // or tf.argMin(x, axis)
	 * ```
	 *
	 * @param x The input tensor.
	 * @param axis The dimension to reduce. Defaults to 0 (outer-most dimension).
	 *
	 * @doc {heading: 'Operations', subheading: 'Reduction'}
	 */
	function argMin_(x) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
	  var $x = convertToTensor(x, 'x', 'argMin');
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    axis: axis
	  };
	  return ENGINE.runKernel(ArgMin, inputs, attrs);
	}
	var argMin$2 = /* @__PURE__ */op({
	  argMin_: argMin_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes asin of the input `tf.Tensor` element-wise: `asin(x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([0, 1, -1, .7]);
	 *
	 * x.asin().print();  // or tf.asin(x)
	 * ```
	 * @param x The input tensor.
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function asin_(x) {
	  var $x = convertToTensor(x, 'x', 'asin');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Asin, inputs);
	}
	var asin$2 = /* @__PURE__ */op({
	  asin_: asin_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes inverse hyperbolic sin of the input `tf.Tensor` element-wise:
	 * `asinh(x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([0, 1, -1, .7]);
	 *
	 * x.asinh().print();  // or tf.asinh(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function asinh_(x) {
	  var $x = convertToTensor(x, 'x', 'asinh');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Asinh, inputs);
	}
	var asinh$2 = /* @__PURE__ */op({
	  asinh_: asinh_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes atan of the input `tf.Tensor` element-wise: `atan(x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([0, 1, -1, .7]);
	 *
	 * x.atan().print();  // or tf.atan(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function atan_(x) {
	  var $x = convertToTensor(x, 'x', 'atan');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Atan, inputs);
	}
	var atan$2 = /* @__PURE__ */op({
	  atan_: atan_
	});

	/**
	 * Computes arctangent of `tf.Tensor`s a / b element-wise: `atan2(a, b)`.
	 * Supports broadcasting.
	 *
	 * ```js
	 * const a = tf.tensor1d([1.0, 1.0, -1.0, .7]);
	 * const b = tf.tensor1d([2.0, 13.0, 3.5, .21]);
	 *
	 * tf.atan2(a, b).print()
	 * ```
	 *
	 * @param a The first tensor.
	 * @param b The second tensor. Must have the same dtype as `a`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function atan2_(a, b) {
	  var $a = convertToTensor(a, 'a', 'atan2');
	  var $b = convertToTensor(b, 'b', 'atan2');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  return ENGINE.runKernel(Atan2, inputs);
	}
	var atan2$2 = /* @__PURE__ */op({
	  atan2_: atan2_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes inverse hyperbolic tan of the input `tf.Tensor` element-wise:
	 * `atanh(x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([0, .1, -.1, .7]);
	 *
	 * x.atanh().print();  // or tf.atanh(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function atanh_(x) {
	  var $x = convertToTensor(x, 'x', 'atanh');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Atanh, inputs);
	}
	var atanh$2 = /* @__PURE__ */op({
	  atanh_: atanh_
	});

	/**
	 *
	 * @param inputShape Input tensor shape is of the following dimensions:
	 *     `[batch, height, width, inChannels]`.
	 * @param filterShape The filter shape is of the following dimensions:
	 *     `[filterHeight, filterWidth, depth]`.
	 * @param strides The strides of the sliding window for each dimension of the
	 *     input tensor: `[strideHeight, strideWidth]`.
	 *     If `strides` is a single number,
	 *     then `strideHeight == strideWidth`.
	 * @param pad The type of padding algorithm.
	 *    - `same` and stride 1: output will be of same size as input,
	 *       regardless of filter size.
	 *    - `valid`: output will be smaller than input if filter is larger
	 *       than 1*1x1.
	 *    - For more info, see this guide:
	 *     [https://www.tensorflow.org/api_docs/python/tf/nn/convolution](
	 *          https://www.tensorflow.org/api_docs/python/tf/nn/convolution)
	 * @param dataFormat The data format of the input and output data.
	 *     Defaults to 'NHWC'.
	 * @param dilations The dilation rates: `[dilationHeight, dilationWidth]`.
	 *     Defaults to `[1, 1]`. If `dilations` is a single number, then
	 *     `dilationHeight == dilationWidth`.
	 */
	function computeDilation2DInfo(inputShape, filterShape, strides, pad) {
	  var dataFormat = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 'NHWC';
	  var dilations = arguments.length > 5 ? arguments[5] : undefined;
	  // `computerConv2DInfo` require filterShape to be in the dimension of:
	  // `[filterHeight, filterWidth, depth, outDepth]`, dilation2d doesn't have
	  // outDepth, it should have the same depth as the input.
	  // Input shape: [batch, height, width, inChannels]
	  var inputChannels = inputShape[3];
	  var $filterShape = [].concat(_toConsumableArray(filterShape), [inputChannels]);
	  var $dataFormat = convertConv2DDataFormat(dataFormat);
	  return computeConv2DInfo(inputShape, $filterShape, strides, dilations, pad, null /* roundingMode */, null /* depthWise */, $dataFormat);
	}
	function computePool2DInfo(inShape, filterSize, strides, dilations, pad, roundingMode) {
	  var dataFormat = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : 'channelsLast';
	  var _parseTupleParam = parseTupleParam(filterSize),
	    _parseTupleParam2 = _slicedToArray(_parseTupleParam, 2),
	    filterHeight = _parseTupleParam2[0],
	    filterWidth = _parseTupleParam2[1];
	  var filterShape;
	  if (dataFormat === 'channelsLast') {
	    filterShape = [filterHeight, filterWidth, inShape[3], inShape[3]];
	  } else if (dataFormat === 'channelsFirst') {
	    filterShape = [filterHeight, filterWidth, inShape[1], inShape[1]];
	  } else {
	    throw new Error("Unknown dataFormat ".concat(dataFormat));
	  }
	  return computeConv2DInfo(inShape, filterShape, strides, dilations, pad, roundingMode, false, dataFormat);
	}
	/**
	 * Computes the information for a forward pass of a pooling3D operation.
	 */
	function computePool3DInfo(inShape, filterSize, strides, dilations, pad, roundingMode) {
	  var dataFormat = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : 'NDHWC';
	  var _parse3TupleParam = parse3TupleParam(filterSize),
	    _parse3TupleParam2 = _slicedToArray(_parse3TupleParam, 3),
	    filterDepth = _parse3TupleParam2[0],
	    filterHeight = _parse3TupleParam2[1],
	    filterWidth = _parse3TupleParam2[2];
	  var filterShape;
	  var $dataFormat;
	  if (dataFormat === 'NDHWC') {
	    $dataFormat = 'channelsLast';
	    filterShape = [filterDepth, filterHeight, filterWidth, inShape[4], inShape[4]];
	  } else if (dataFormat === 'NCDHW') {
	    $dataFormat = 'channelsFirst';
	    filterShape = [filterDepth, filterHeight, filterWidth, inShape[1], inShape[1]];
	  } else {
	    throw new Error("Unknown dataFormat ".concat(dataFormat));
	  }
	  return computeConv3DInfo(inShape, filterShape, strides, dilations, pad, false, $dataFormat, roundingMode);
	}
	/**
	 * Computes the information for a forward pass of a convolution/pooling
	 * operation.
	 */
	function computeConv2DInfo(inShape, filterShape, strides, dilations, pad, roundingMode) {
	  var depthwise = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : false;
	  var dataFormat = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : 'channelsLast';
	  var batchSize = -1,
	    inHeight = -1,
	    inWidth = -1,
	    inChannels = -1;
	  if (dataFormat === 'channelsLast') {
	    var _inShape = _slicedToArray(inShape, 4);
	    batchSize = _inShape[0];
	    inHeight = _inShape[1];
	    inWidth = _inShape[2];
	    inChannels = _inShape[3];
	  } else if (dataFormat === 'channelsFirst') {
	    var _inShape2 = _slicedToArray(inShape, 4);
	    batchSize = _inShape2[0];
	    inChannels = _inShape2[1];
	    inHeight = _inShape2[2];
	    inWidth = _inShape2[3];
	  } else {
	    throw new Error("Unknown dataFormat ".concat(dataFormat));
	  }
	  var _filterShape = _slicedToArray(filterShape, 4),
	    filterHeight = _filterShape[0],
	    filterWidth = _filterShape[1],
	    filterChannels = _filterShape[3];
	  var _parseTupleParam3 = parseTupleParam(strides),
	    _parseTupleParam4 = _slicedToArray(_parseTupleParam3, 2),
	    strideHeight = _parseTupleParam4[0],
	    strideWidth = _parseTupleParam4[1];
	  var _parseTupleParam5 = parseTupleParam(dilations),
	    _parseTupleParam6 = _slicedToArray(_parseTupleParam5, 2),
	    dilationHeight = _parseTupleParam6[0],
	    dilationWidth = _parseTupleParam6[1];
	  var effectiveFilterHeight = getEffectiveFilterSize(filterHeight, dilationHeight);
	  var effectiveFilterWidth = getEffectiveFilterSize(filterWidth, dilationWidth);
	  var _getPadAndOutInfo = getPadAndOutInfo(pad, inHeight, inWidth, strideHeight, strideWidth, effectiveFilterHeight, effectiveFilterWidth, roundingMode, dataFormat),
	    padInfo = _getPadAndOutInfo.padInfo,
	    outHeight = _getPadAndOutInfo.outHeight,
	    outWidth = _getPadAndOutInfo.outWidth;
	  var outChannels = depthwise ? filterChannels * inChannels : filterChannels;
	  var outShape;
	  if (dataFormat === 'channelsFirst') {
	    outShape = [batchSize, outChannels, outHeight, outWidth];
	  } else if (dataFormat === 'channelsLast') {
	    outShape = [batchSize, outHeight, outWidth, outChannels];
	  }
	  return {
	    batchSize: batchSize,
	    dataFormat: dataFormat,
	    inHeight: inHeight,
	    inWidth: inWidth,
	    inChannels: inChannels,
	    outHeight: outHeight,
	    outWidth: outWidth,
	    outChannels: outChannels,
	    padInfo: padInfo,
	    strideHeight: strideHeight,
	    strideWidth: strideWidth,
	    filterHeight: filterHeight,
	    filterWidth: filterWidth,
	    effectiveFilterHeight: effectiveFilterHeight,
	    effectiveFilterWidth: effectiveFilterWidth,
	    dilationHeight: dilationHeight,
	    dilationWidth: dilationWidth,
	    inShape: inShape,
	    outShape: outShape,
	    filterShape: filterShape
	  };
	}
	/**
	 * Computes the information for a forward pass of a 3D convolution/pooling
	 * operation.
	 */
	function computeConv3DInfo(inShape, filterShape, strides, dilations, pad) {
	  var depthwise = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : false;
	  var dataFormat = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : 'channelsLast';
	  var roundingMode = arguments.length > 7 ? arguments[7] : undefined;
	  var batchSize = -1,
	    inDepth = -1,
	    inHeight = -1,
	    inWidth = -1,
	    inChannels = -1;
	  if (dataFormat === 'channelsLast') {
	    var _inShape3 = _slicedToArray(inShape, 5);
	    batchSize = _inShape3[0];
	    inDepth = _inShape3[1];
	    inHeight = _inShape3[2];
	    inWidth = _inShape3[3];
	    inChannels = _inShape3[4];
	  } else if (dataFormat === 'channelsFirst') {
	    var _inShape4 = _slicedToArray(inShape, 5);
	    batchSize = _inShape4[0];
	    inChannels = _inShape4[1];
	    inDepth = _inShape4[2];
	    inHeight = _inShape4[3];
	    inWidth = _inShape4[4];
	  } else {
	    throw new Error("Unknown dataFormat ".concat(dataFormat));
	  }
	  var _filterShape2 = _slicedToArray(filterShape, 5),
	    filterDepth = _filterShape2[0],
	    filterHeight = _filterShape2[1],
	    filterWidth = _filterShape2[2],
	    filterChannels = _filterShape2[4];
	  var _parse3TupleParam3 = parse3TupleParam(strides),
	    _parse3TupleParam4 = _slicedToArray(_parse3TupleParam3, 3),
	    strideDepth = _parse3TupleParam4[0],
	    strideHeight = _parse3TupleParam4[1],
	    strideWidth = _parse3TupleParam4[2];
	  var _parse3TupleParam5 = parse3TupleParam(dilations),
	    _parse3TupleParam6 = _slicedToArray(_parse3TupleParam5, 3),
	    dilationDepth = _parse3TupleParam6[0],
	    dilationHeight = _parse3TupleParam6[1],
	    dilationWidth = _parse3TupleParam6[2];
	  var effectiveFilterDepth = getEffectiveFilterSize(filterDepth, dilationDepth);
	  var effectiveFilterHeight = getEffectiveFilterSize(filterHeight, dilationHeight);
	  var effectiveFilterWidth = getEffectiveFilterSize(filterWidth, dilationWidth);
	  var _get3DPadAndOutInfo = get3DPadAndOutInfo(pad, inDepth, inHeight, inWidth, strideDepth, strideHeight, strideWidth, effectiveFilterDepth, effectiveFilterHeight, effectiveFilterWidth, roundingMode),
	    padInfo = _get3DPadAndOutInfo.padInfo,
	    outDepth = _get3DPadAndOutInfo.outDepth,
	    outHeight = _get3DPadAndOutInfo.outHeight,
	    outWidth = _get3DPadAndOutInfo.outWidth;
	  var outChannels = depthwise ? filterChannels * inChannels : filterChannels;
	  var outShape;
	  if (dataFormat === 'channelsFirst') {
	    outShape = [batchSize, outChannels, outDepth, outHeight, outWidth];
	  } else if (dataFormat === 'channelsLast') {
	    outShape = [batchSize, outDepth, outHeight, outWidth, outChannels];
	  }
	  return {
	    batchSize: batchSize,
	    dataFormat: dataFormat,
	    inDepth: inDepth,
	    inHeight: inHeight,
	    inWidth: inWidth,
	    inChannels: inChannels,
	    outDepth: outDepth,
	    outHeight: outHeight,
	    outWidth: outWidth,
	    outChannels: outChannels,
	    padInfo: padInfo,
	    strideDepth: strideDepth,
	    strideHeight: strideHeight,
	    strideWidth: strideWidth,
	    filterDepth: filterDepth,
	    filterHeight: filterHeight,
	    filterWidth: filterWidth,
	    effectiveFilterDepth: effectiveFilterDepth,
	    effectiveFilterHeight: effectiveFilterHeight,
	    effectiveFilterWidth: effectiveFilterWidth,
	    dilationDepth: dilationDepth,
	    dilationHeight: dilationHeight,
	    dilationWidth: dilationWidth,
	    inShape: inShape,
	    outShape: outShape,
	    filterShape: filterShape
	  };
	}
	function computeOutputShape2D(inShape, fieldSize, stride, zeroPad, roundingMode) {
	  if (zeroPad == null) {
	    zeroPad = computeDefaultPad(inShape, fieldSize, stride);
	  }
	  var inputRows = inShape[0];
	  var inputCols = inShape[1];
	  var outputRows = round$3((inputRows - fieldSize + 2 * zeroPad) / stride + 1, roundingMode);
	  var outputCols = round$3((inputCols - fieldSize + 2 * zeroPad) / stride + 1, roundingMode);
	  return [outputRows, outputCols];
	}
	function computeOutputShape4D(inShape, filterShape, outChannels, strides, zeroPad, roundingMode) {
	  if (zeroPad == null) {
	    zeroPad = computeDefaultPad(inShape, filterShape[0], strides[0]);
	  }
	  var outShape = [0, 0, 0, outChannels];
	  for (var index = 0; index < 3; index++) {
	    if (inShape[index] + 2 * zeroPad >= filterShape[index]) {
	      outShape[index] = round$3((inShape[index] - filterShape[index] + 2 * zeroPad) / strides[index] + 1, roundingMode);
	    }
	  }
	  return outShape;
	}
	function computeDefaultPad(inputShape, fieldSize, stride) {
	  var dilation = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 1;
	  var effectiveFieldSize = getEffectiveFilterSize(fieldSize, dilation);
	  return Math.floor((inputShape[0] * (stride - 1) - stride + effectiveFieldSize) / 2);
	}
	function parseTupleParam(param) {
	  if (typeof param === 'number') {
	    return [param, param, param];
	  }
	  if (param.length === 2) {
	    return [param[0], param[1], 1];
	  }
	  return param;
	}
	function parse3TupleParam(param) {
	  return typeof param === 'number' ? [param, param, param] : param;
	}
	/* See https://www.tensorflow.org/api_docs/python/tf/nn/atrous_conv2d
	 * Atrous convolution is equivalent to standard convolution with upsampled
	 * filters with effective_filter_height =
	 * filter_height + (filter_height - 1) * (dilation - 1)
	 * and effective_filter_width =
	 * filter_width + (filter_width - 1) * (dilation - 1),
	 * produced by inserting dilation - 1 zeros along consecutive elements across
	 * the filters' spatial dimensions.
	 * When there is a dilation, this converts a filter dimension to the
	 * effective filter dimension, so it can be used in a standard convolution.
	 */
	function getEffectiveFilterSize(filterSize, dilation) {
	  if (dilation <= 1) {
	    return filterSize;
	  }
	  return filterSize + (filterSize - 1) * (dilation - 1);
	}
	function getPadAndOutInfo(pad, inHeight, inWidth, strideHeight, strideWidth, filterHeight, filterWidth, roundingMode, dataFormat) {
	  var padInfo;
	  var outHeight;
	  var outWidth;
	  if (typeof pad === 'number') {
	    var padType = pad === 0 ? 'VALID' : 'NUMBER';
	    padInfo = {
	      top: pad,
	      bottom: pad,
	      left: pad,
	      right: pad,
	      type: padType
	    };
	    var outShape = computeOutputShape2D([inHeight, inWidth], filterHeight, strideHeight, pad, roundingMode);
	    outHeight = outShape[0];
	    outWidth = outShape[1];
	  } else if (pad === 'same') {
	    outHeight = Math.ceil(inHeight / strideHeight);
	    outWidth = Math.ceil(inWidth / strideWidth);
	    var padAlongHeight = Math.max(0, (outHeight - 1) * strideHeight + filterHeight - inHeight);
	    var padAlongWidth = Math.max(0, (outWidth - 1) * strideWidth + filterWidth - inWidth);
	    var top = Math.floor(padAlongHeight / 2);
	    var bottom = padAlongHeight - top;
	    var left = Math.floor(padAlongWidth / 2);
	    var right = padAlongWidth - left;
	    padInfo = {
	      top: top,
	      bottom: bottom,
	      left: left,
	      right: right,
	      type: 'SAME'
	    };
	  } else if (pad === 'valid') {
	    padInfo = {
	      top: 0,
	      bottom: 0,
	      left: 0,
	      right: 0,
	      type: 'VALID'
	    };
	    outHeight = Math.ceil((inHeight - filterHeight + 1) / strideHeight);
	    outWidth = Math.ceil((inWidth - filterWidth + 1) / strideWidth);
	  } else if (_typeof(pad) === 'object') {
	    var _top = dataFormat === 'channelsLast' ? pad[1][0] : pad[2][0];
	    var _bottom = dataFormat === 'channelsLast' ? pad[1][1] : pad[2][1];
	    var _left = dataFormat === 'channelsLast' ? pad[2][0] : pad[3][0];
	    var _right = dataFormat === 'channelsLast' ? pad[2][1] : pad[3][1];
	    var _padType = _top === 0 && _bottom === 0 && _left === 0 && _right === 0 ? 'VALID' : 'EXPLICIT';
	    padInfo = {
	      top: _top,
	      bottom: _bottom,
	      left: _left,
	      right: _right,
	      type: _padType
	    };
	    outHeight = round$3((inHeight - filterHeight + _top + _bottom) / strideHeight + 1, roundingMode);
	    outWidth = round$3((inWidth - filterWidth + _left + _right) / strideWidth + 1, roundingMode);
	  } else {
	    throw Error("Unknown padding parameter: ".concat(pad));
	  }
	  return {
	    padInfo: padInfo,
	    outHeight: outHeight,
	    outWidth: outWidth
	  };
	}
	function get3DPadAndOutInfo(pad, inDepth, inHeight, inWidth, strideDepth, strideHeight, strideWidth, filterDepth, filterHeight, filterWidth, roundingMode) {
	  var padInfo;
	  var outDepth;
	  var outHeight;
	  var outWidth;
	  if (pad === 'valid') {
	    pad = 0;
	  }
	  if (typeof pad === 'number') {
	    var padType = pad === 0 ? 'VALID' : 'NUMBER';
	    padInfo = {
	      top: pad,
	      bottom: pad,
	      left: pad,
	      right: pad,
	      front: pad,
	      back: pad,
	      type: padType
	    };
	    var outShape = computeOutputShape4D([inDepth, inHeight, inWidth, 1], [filterDepth, filterHeight, filterWidth], 1, [strideDepth, strideHeight, strideWidth], pad, roundingMode);
	    outDepth = outShape[0];
	    outHeight = outShape[1];
	    outWidth = outShape[2];
	  } else if (pad === 'same') {
	    outDepth = Math.ceil(inDepth / strideDepth);
	    outHeight = Math.ceil(inHeight / strideHeight);
	    outWidth = Math.ceil(inWidth / strideWidth);
	    var padAlongDepth = (outDepth - 1) * strideDepth + filterDepth - inDepth;
	    var padAlongHeight = (outHeight - 1) * strideHeight + filterHeight - inHeight;
	    var padAlongWidth = (outWidth - 1) * strideWidth + filterWidth - inWidth;
	    var front = Math.floor(padAlongDepth / 2);
	    var back = padAlongDepth - front;
	    var top = Math.floor(padAlongHeight / 2);
	    var bottom = padAlongHeight - top;
	    var left = Math.floor(padAlongWidth / 2);
	    var right = padAlongWidth - left;
	    padInfo = {
	      top: top,
	      bottom: bottom,
	      left: left,
	      right: right,
	      front: front,
	      back: back,
	      type: 'SAME'
	    };
	  } else {
	    throw Error("Unknown padding parameter: ".concat(pad));
	  }
	  return {
	    padInfo: padInfo,
	    outDepth: outDepth,
	    outHeight: outHeight,
	    outWidth: outWidth
	  };
	}
	/**
	 * Rounds a value depending on the rounding mode
	 * @param value
	 * @param roundingMode A string from: 'ceil', 'round', 'floor'. If none is
	 *     provided, it will default to truncate.
	 */
	function round$3(value, roundingMode) {
	  if (!roundingMode) {
	    return Math.trunc(value);
	  }
	  switch (roundingMode) {
	    case 'round':
	      // used for Caffe Conv
	      return Math.round(value);
	    case 'ceil':
	      // used for Caffe Pool
	      return Math.ceil(value);
	    case 'floor':
	      return Math.floor(value);
	    default:
	      throw new Error("Unknown roundingMode ".concat(roundingMode));
	  }
	}
	function tupleValuesAreOne(param) {
	  var _parseTupleParam7 = parseTupleParam(param),
	    _parseTupleParam8 = _slicedToArray(_parseTupleParam7, 3),
	    dimA = _parseTupleParam8[0],
	    dimB = _parseTupleParam8[1],
	    dimC = _parseTupleParam8[2];
	  return dimA === 1 && dimB === 1 && dimC === 1;
	}
	function eitherStridesOrDilationsAreOne(strides, dilations) {
	  return tupleValuesAreOne(strides) || tupleValuesAreOne(dilations);
	}
	function stridesOrDilationsArePositive(values) {
	  return parseTupleParam(values).every(function (value) {
	    return value > 0;
	  });
	}
	/**
	 * Convert Conv2D dataFormat from 'NHWC'|'NCHW' to
	 *    'channelsLast'|'channelsFirst'
	 * @param dataFormat in 'NHWC'|'NCHW' mode
	 * @return dataFormat in 'channelsLast'|'channelsFirst' mode
	 * @throws unknown dataFormat
	 */
	function convertConv2DDataFormat(dataFormat) {
	  if (dataFormat === 'NHWC') {
	    return 'channelsLast';
	  } else if (dataFormat === 'NCHW') {
	    return 'channelsFirst';
	  } else {
	    throw new Error("Unknown dataFormat ".concat(dataFormat));
	  }
	}
	/**
	 * Check validity of pad when using dimRoundingMode.
	 * @param opDesc A string of op description
	 * @param pad The type of padding algorithm.
	 *   - `same` and stride 1: output will be of same size as input,
	 *       regardless of filter size.
	 *   - `valid` output will be smaller than input if filter is larger
	 *       than 1x1.
	 *   - For more info, see this guide:
	 *     [https://www.tensorflow.org/api_docs/python/tf/nn/convolution](
	 *          https://www.tensorflow.org/api_docs/python/tf/nn/convolution)
	 * @param dimRoundingMode A string from: 'ceil', 'round', 'floor'. If none is
	 *     provided, it will default to truncate.
	 * @throws unknown padding parameter
	 */
	function checkPadOnDimRoundingMode(opDesc, pad, dimRoundingMode) {
	  if (dimRoundingMode != null) {
	    if (typeof pad === 'string') {
	      throw Error("Error in ".concat(opDesc, ": pad must be an integer when using ") + "dimRoundingMode ".concat(dimRoundingMode, " but got pad ").concat(pad, "."));
	    } else if (typeof pad === 'number') {
	      assert$1(isInt(pad), function () {
	        return "Error in ".concat(opDesc, ": pad must be an integer when using ") + "dimRoundingMode ".concat(dimRoundingMode, " but got pad ").concat(pad, ".");
	      });
	    } else if (_typeof(pad) === 'object') {
	      pad.forEach(function (p) {
	        p.forEach(function (v) {
	          assert$1(isInt(v), function () {
	            return "Error in ".concat(opDesc, ": pad must be an integer when using ") + "dimRoundingMode ".concat(dimRoundingMode, " but got pad ").concat(v, ".");
	          });
	        });
	      });
	    } else {
	      throw Error("Error in ".concat(opDesc, ": Unknown padding parameter: ").concat(pad));
	    }
	  }
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Reshapes a `tf.Tensor` to a given shape.
	 *
	 * Given an input tensor, returns a new tensor with the same values as the
	 * input tensor with shape `shape`.
	 *
	 * If one component of shape is the special value -1, the size of that
	 * dimension is computed so that the total size remains constant. In
	 * particular, a shape of [-1] flattens into 1-D. At most one component of
	 * shape can be -1.
	 *
	 * If shape is 1-D or higher, then the operation returns a tensor with shape
	 * shape filled with the values of tensor. In this case, the number of
	 * elements implied by shape must be the same as the number of elements in
	 * tensor.
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3, 4]);
	 * x.reshape([2, 2]).print();
	 * ```
	 *
	 * @param x The input tensor to be reshaped.
	 * @param shape An array of integers defining the output tensor shape.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Transformations'}
	 */
	function reshape_(x, shape) {
	  var $x = convertToTensor(x, 'x', 'reshape', 'string_or_numeric');
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    shape: shape
	  };
	  return ENGINE.runKernel(Reshape$1, inputs, attrs);
	}
	var reshape$3 = /* @__PURE__ */op({
	  reshape_: reshape_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the 2D average pooling of an image.
	 *
	 * @param x The input tensor, of rank 4 or rank 3 of shape
	 *     `[batch, height, width, inChannels]`. If rank 3, batch of 1 is assumed.
	 * @param filterSize The filter size: `[filterHeight, filterWidth]`. If
	 *     `filterSize` is a single number, then `filterHeight == filterWidth`.
	 * @param strides The strides of the pooling: `[strideHeight, strideWidth]`. If
	 *     `strides` is a single number, then `strideHeight == strideWidth`.
	 * @param pad The type of padding algorithm:
	 *    - `same` and stride 1: output will be of same size as input,
	 *       regardless of filter size.
	 *    - `valid`: output will be smaller than input if filter is larger
	 *       than 1x1.
	 *    - For more info, see this guide:
	 *     [https://www.tensorflow.org/api_docs/python/tf/nn/convolution](
	 *         https://www.tensorflow.org/api_docs/python/tf/nn/convolution)
	 * @param dimRoundingMode A string from: 'ceil', 'round', 'floor'. If none is
	 *     provided, it will default to truncate.
	 *
	 * @doc {heading: 'Operations', subheading: 'Convolution'}
	 */
	function avgPool_(x, filterSize, strides, pad, dimRoundingMode) {
	  var $x = convertToTensor(x, 'x', 'avgPool', 'float32');
	  var dilations = 1;
	  assert$1(eitherStridesOrDilationsAreOne(strides, dilations), function () {
	    return 'Error in avgPool: Either strides or dilations must be 1. ' + "Got strides ".concat(strides, " and dilations '").concat(dilations, "'");
	  });
	  var x4D = $x;
	  var reshapedTo4D = false;
	  if ($x.rank === 3) {
	    reshapedTo4D = true;
	    x4D = reshape$3($x, [1, $x.shape[0], $x.shape[1], $x.shape[2]]);
	  }
	  assert$1(x4D.rank === 4, function () {
	    return "Error in avgPool: x must be rank 4 but got rank ".concat(x4D.rank, ".");
	  });
	  checkPadOnDimRoundingMode('avgPool', pad, dimRoundingMode);
	  var inputs = {
	    x: x4D
	  };
	  var attrs = {
	    filterSize: filterSize,
	    strides: strides,
	    pad: pad,
	    dimRoundingMode: dimRoundingMode
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var res = ENGINE.runKernel(AvgPool, inputs, attrs);
	  res = cast$3(res, $x.dtype);
	  if (reshapedTo4D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3]]);
	  }
	  return res;
	}
	var avgPool$2 = /* @__PURE__ */op({
	  avgPool_: avgPool_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the 3D average pooling.
	 *
	 * ```js
	 * const x = tf.tensor5d([1, 2, 3, 4, 5, 6, 7, 8], [1, 2, 2, 2, 1]);
	 * const result = tf.avgPool3d(x, 2, 1, 'valid');
	 * result.print();
	 * ```
	 *
	 * @param x The input tensor, of rank 5 or rank 4 of shape
	 *     `[batch, depth, height, width, inChannels]`.
	 * @param filterSize The filter size:
	 *     `[filterDepth, filterHeight, filterWidth]`.
	 *     If `filterSize` is a single number,
	 *     then `filterDepth == filterHeight == filterWidth`.
	 * @param strides The strides of the pooling:
	 *     `[strideDepth, strideHeight, strideWidth]`.
	 *     If `strides` is a single number,
	 *     then `strideDepth == strideHeight == strideWidth`.
	 * @param pad The type of padding algorithm.
	 *    - `same` and stride 1: output will be of same size as input,
	 *       regardless of filter size.
	 *    - `valid`: output will be smaller than input if filter is larger
	 *       than 1*1x1.
	 *    - For more info, see this guide:
	 *     [https://www.tensorflow.org/api_docs/python/tf/nn/convolution](
	 *          https://www.tensorflow.org/api_docs/python/tf/nn/convolution)
	 * @param dimRoundingMode A string from: 'ceil', 'round', 'floor'. If none is
	 *     provided, it will default to truncate.
	 * @param dataFormat An optional string from: "NDHWC", "NCDHW". Defaults to
	 *     "NDHWC". Specify the data format of the input and output data. With the
	 *     default format "NDHWC", the data is stored in the order of: [batch,
	 *     depth, height, width, channels]. Only "NDHWC" is currently supported.
	 *
	 * @doc {heading: 'Operations', subheading: 'Convolution'}
	 */
	function avgPool3d_(x, filterSize, strides, pad, dimRoundingMode) {
	  var dataFormat = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : 'NDHWC';
	  var $x = convertToTensor(x, 'x', 'avgPool3d', 'float32');
	  var x5D = $x;
	  var reshapedTo5D = false;
	  if ($x.rank === 4) {
	    reshapedTo5D = true;
	    x5D = reshape$3($x, [1, $x.shape[0], $x.shape[1], $x.shape[2], $x.shape[3]]);
	  }
	  assert$1(x5D.rank === 5, function () {
	    return "Error in avgPool3d: x must be rank 5 but got rank ".concat(x5D.rank, ".");
	  });
	  assert$1(dataFormat === 'NDHWC', function () {
	    return "Error in avgPool3d: Only NDHWC is currently supported, " + "but got dataFormat of ".concat(dataFormat);
	  });
	  assert$1(typeof strides === 'number' && strides > 0 || Array.isArray(strides) && strides[0] > 0 && strides[1] > 0 && strides[2] > 0, function () {
	    return "Error in avgPool3d: Stride must be > 0, but got '".concat(strides, "'");
	  });
	  checkPadOnDimRoundingMode('avgPool3d', pad, dimRoundingMode);
	  var inputs = {
	    x: x5D
	  };
	  var attrs = {
	    filterSize: filterSize,
	    strides: strides,
	    pad: pad,
	    dimRoundingMode: dimRoundingMode,
	    dataFormat: dataFormat
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var res = ENGINE.runKernel(AvgPool3D, inputs, attrs);
	  res = cast$3(res, x5D.dtype);
	  if (reshapedTo5D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3], res.shape[4]]);
	  }
	  return res;
	}
	var avgPool3d$1 = /* @__PURE__ */op({
	  avgPool3d_: avgPool3d_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Concatenates a list of `tf.Tensor`s along a given axis.
	 *
	 * The tensors ranks and types must match, and their sizes must match in all
	 * dimensions except `axis`.
	 *
	 * Also available are stricter rank-specific methods that assert that
	 * `tensors` are of the given rank:
	 *   - `tf.concat1d`
	 *   - `tf.concat2d`
	 *   - `tf.concat3d`
	 *   - `tf.concat4d`
	 *
	 * Except `tf.concat1d` (which does not have axis param), all methods have
	 * same signature as this method.
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 2]);
	 * const b = tf.tensor1d([3, 4]);
	 * a.concat(b).print();  // or a.concat(b)
	 * ```
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 2]);
	 * const b = tf.tensor1d([3, 4]);
	 * const c = tf.tensor1d([5, 6]);
	 * tf.concat([a, b, c]).print();
	 * ```
	 *
	 * ```js
	 * const a = tf.tensor2d([[1, 2], [10, 20]]);
	 * const b = tf.tensor2d([[3, 4], [30, 40]]);
	 * const axis = 1;
	 * tf.concat([a, b], axis).print();
	 * ```
	 * @param tensors A list of tensors to concatenate.
	 * @param axis The axis to concatenate along. Defaults to 0 (the first dim).
	 *
	 * @doc {heading: 'Tensors', subheading: 'Slicing and Joining'}
	 */
	function concat_(tensors) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
	  assert$1(tensors.length >= 1, function () {
	    return 'Pass at least one tensor to concat';
	  });
	  var $tensors = convertToTensorArray(tensors, 'tensors', 'concat', 'string_or_numeric');
	  if ($tensors[0].dtype === 'complex64') {
	    $tensors.forEach(function (tensor) {
	      if (tensor.dtype !== 'complex64') {
	        throw new Error("Cannot concatenate complex64 tensors with a tensor\n          with dtype ".concat(tensor.dtype, ". "));
	      }
	    });
	  }
	  if ($tensors.length === 1) {
	    return clone($tensors[0]);
	  }
	  var inputs = $tensors;
	  var attr = {
	    axis: axis
	  };
	  return ENGINE.runKernel(Concat, inputs, attr);
	}
	var concat$2 = /* @__PURE__ */op({
	  concat_: concat_
	});

	/**
	 * Computes the dot product of two matrices, A * B. These must be matrices.
	 *
	 * ```js
	 * const a = tf.tensor2d([1, 2], [1, 2]);
	 * const b = tf.tensor2d([1, 2, 3, 4], [2, 2]);
	 *
	 * a.matMul(b).print();  // or tf.matMul(a, b)
	 * ```
	 * @param a First matrix in dot product operation.
	 * @param b Second matrix in dot product operation.
	 * @param transposeA If true, `a` is transposed before multiplication.
	 * @param transposeB If true, `b` is transposed before multiplication.
	 *
	 * @doc {heading: 'Operations', subheading: 'Matrices'}
	 */
	function matMul_(a, b) {
	  var transposeA = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  var transposeB = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var $a = convertToTensor(a, 'a', 'matMul');
	  var $b = convertToTensor(b, 'b', 'matMul');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  var attrs = {
	    transposeA: transposeA,
	    transposeB: transposeB
	  };
	  return ENGINE.runKernel(BatchMatMul, inputs, attrs);
	}
	var matMul$1 = /* @__PURE__ */op({
	  matMul_: matMul_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes sigmoid element-wise, `1 / (1 + exp(-x))`
	 *
	 * ```js
	 * const x = tf.tensor1d([0, -1, 2, -3]);
	 *
	 * x.sigmoid().print();  // or tf.sigmoid(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function sigmoid_(x) {
	  var $x = convertToTensor(x, 'x', 'sigmoid', 'float32');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Sigmoid$1, inputs);
	}
	var sigmoid$2 = /* @__PURE__ */op({
	  sigmoid_: sigmoid_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Extracts a slice from a `tf.Tensor` starting at coordinates `begin`
	 * and is of size `size`.
	 *
	 * Also available are stricter rank-specific methods with the same signature
	 * as this method that assert that `x` is of the given rank:
	 *   - `tf.slice1d`
	 *   - `tf.slice2d`
	 *   - `tf.slice3d`
	 *   - `tf.slice4d`
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3, 4]);
	 *
	 * x.slice([1], [2]).print();
	 * ```
	 *
	 * ```js
	 * const x = tf.tensor2d([1, 2, 3, 4], [2, 2]);
	 *
	 * x.slice([1, 0], [1, 2]).print();
	 * ```
	 * @param x The input `tf.Tensor` to slice from.
	 * @param begin The coordinates to start the slice from. The length can be
	 *     less than the rank of x - the rest of the axes will have implicit 0 as
	 *     start. Can also be a single number, in which case it specifies the
	 *     first axis.
	 * @param size The size of the slice. The length can be less than the rank of
	 *     x - the rest of the axes will have implicit -1. A value of -1 requests
	 *     the rest of the dimensions in the axis. Can also be a single number,
	 *     in which case it specifies the size of the first axis.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Slicing and Joining'}
	 */
	function slice_(x, begin, size) {
	  var $x = convertToTensor(x, 'x', 'slice', 'string_or_numeric');
	  if ($x.rank === 0) {
	    throw new Error('Slicing scalar is not possible');
	  }
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    begin: begin,
	    size: size
	  };
	  return ENGINE.runKernel(Slice, inputs, attrs);
	}
	var slice$2 = /* @__PURE__ */op({
	  slice_: slice_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes hyperbolic tangent of the input `tf.Tensor` element-wise: `tanh(x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([0, 1, -1, 70]);
	 *
	 * x.tanh().print();  // or tf.tanh(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function tanh_(x) {
	  var $x = convertToTensor(x, 'x', 'tanh', 'float32');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Tanh$1, inputs);
	}
	var tanh$2 = /* @__PURE__ */op({
	  tanh_: tanh_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the next state and output of a BasicLSTMCell.
	 *
	 * Returns `[newC, newH]`.
	 *
	 * Derived from tf.contrib.rnn.BasicLSTMCell.
	 *
	 * @param forgetBias Forget bias for the cell.
	 * @param lstmKernel The weights for the cell.
	 * @param lstmBias The bias for the cell.
	 * @param data The input to the cell.
	 * @param c Previous cell state.
	 * @param h Previous cell output.
	 *
	 * @doc {heading: 'Operations', subheading: 'RNN'}
	 */
	function basicLSTMCell_(forgetBias, lstmKernel, lstmBias, data, c, h) {
	  var $forgetBias = convertToTensor(forgetBias, 'forgetBias', 'basicLSTMCell');
	  var $lstmKernel = convertToTensor(lstmKernel, 'lstmKernel', 'basicLSTMCell');
	  var $lstmBias = convertToTensor(lstmBias, 'lstmBias', 'basicLSTMCell');
	  var $data = convertToTensor(data, 'data', 'basicLSTMCell');
	  var $c = convertToTensor(c, 'c', 'basicLSTMCell');
	  var $h = convertToTensor(h, 'h', 'basicLSTMCell');
	  var combined = concat$2([$data, $h], 1);
	  var weighted = matMul$1(combined, $lstmKernel);
	  var res = add$3(weighted, $lstmBias);
	  // i = input_gate, j = new_input, f = forget_gate, o = output_gate
	  var batchSize = res.shape[0];
	  var sliceCols = res.shape[1] / 4;
	  var sliceSize = [batchSize, sliceCols];
	  var i = slice$2(res, [0, 0], sliceSize);
	  var j = slice$2(res, [0, sliceCols], sliceSize);
	  var f = slice$2(res, [0, sliceCols * 2], sliceSize);
	  var o = slice$2(res, [0, sliceCols * 3], sliceSize);
	  var newC = add$3(mul(sigmoid$2(i), tanh$2(j)), mul($c, sigmoid$2(add$3($forgetBias, f))));
	  var newH = mul(tanh$2(newC), sigmoid$2(o));
	  return [newC, newH];
	}
	var basicLSTMCell = /* @__PURE__ */op({
	  basicLSTMCell_: basicLSTMCell_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * This operation reshapes the "batch" dimension 0 into `M + 1` dimensions of
	 * shape `blockShape + [batch]`, interleaves these blocks back into the grid
	 * defined by the spatial dimensions `[1, ..., M]`, to obtain a result with
	 * the same rank as the input. The spatial dimensions of this intermediate
	 * result are then optionally cropped according to `crops` to produce the
	 * output. This is the reverse of `tf.spaceToBatchND`. See below for a precise
	 * description.
	 *
	 * ```js
	 * const x = tf.tensor4d([1, 2, 3, 4], [4, 1, 1, 1]);
	 * const blockShape = [2, 2];
	 * const crops = [[0, 0], [0, 0]];
	 *
	 * x.batchToSpaceND(blockShape, crops).print();
	 * ```
	 *
	 * @param x A `tf.Tensor`. N-D with `x.shape` = `[batch] + spatialShape +
	 * remainingShape`, where spatialShape has `M` dimensions.
	 * @param blockShape A 1-D array. Must have shape `[M]`, all values must
	 * be >= 1.
	 * @param crops A 2-D array.  Must have shape `[M, 2]`, all values must be >= 0.
	 * `crops[i] = [cropStart, cropEnd]` specifies the amount to crop from input
	 * dimension `i + 1`, which corresponds to spatial dimension `i`. It is required
	 * that `cropStart[i] + cropEnd[i] <= blockShape[i] * inputShape[i + 1]`
	 *
	 * This operation is equivalent to the following steps:
	 *
	 * 1. Reshape `x` to `reshaped` of shape: `[blockShape[0], ...,
	 * blockShape[M-1], batch / prod(blockShape), x.shape[1], ...,
	 * x.shape[N-1]]`
	 *
	 * 2. Permute dimensions of `reshaped` to produce `permuted` of shape `[batch /
	 * prod(blockShape),x.shape[1], blockShape[0], ..., x.shape[M],
	 * blockShape[M-1],x.shape[M+1], ..., x.shape[N-1]]`
	 *
	 * 3. Reshape `permuted` to produce `reshapedPermuted` of shape `[batch /
	 * prod(blockShape),x.shape[1] * blockShape[0], ..., x.shape[M] *
	 * blockShape[M-1],x.shape[M+1], ..., x.shape[N-1]]`
	 *
	 * 4. Crop the start and end of dimensions `[1, ..., M]` of `reshapedPermuted`
	 * according to `crops` to produce the output of shape: `[batch /
	 * prod(blockShape),x.shape[1] * blockShape[0] - crops[0,0] - crops[0,1],
	 * ..., x.shape[M] * blockShape[M-1] - crops[M-1,0] -
	 * crops[M-1,1],x.shape[M+1], ..., x.shape[N-1]]`
	 *
	 * @doc {heading: 'Tensors', subheading: 'Transformations'}
	 */
	function batchToSpaceND_(x, blockShape, crops) {
	  var $x = convertToTensor(x, 'x', 'batchToSpaceND');
	  var prod = blockShape.reduce(function (a, b) {
	    return a * b;
	  });
	  assert$1($x.rank >= 1 + blockShape.length, function () {
	    return "input rank is ".concat($x.rank, " but should be > than blockShape.length ").concat(blockShape.length);
	  });
	  assert$1(crops.length === blockShape.length, function () {
	    return "crops.length is ".concat(crops.length, " but should be equal to blockShape.length  ").concat(blockShape.length);
	  });
	  assert$1($x.shape[0] % prod === 0, function () {
	    return "input tensor batch is ".concat($x.shape[0], " but is not divisible by the product of ") + "the elements of blockShape ".concat(blockShape.join(' * '), " === ").concat(prod);
	  });
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    blockShape: blockShape,
	    crops: crops
	  };
	  return ENGINE.runKernel(BatchToSpaceND, inputs, attrs);
	}
	var batchToSpaceND$2 = /* @__PURE__ */op({
	  batchToSpaceND_: batchToSpaceND_
	});

	function xAs4D(x) {
	  var x4D;
	  if (x.rank === 0 || x.rank === 1) {
	    x4D = reshape$3(x, [1, 1, 1, x.size]);
	  } else if (x.rank === 2) {
	    x4D = reshape$3(x, [1, 1, x.shape[0], x.shape[1]]);
	  } else if (x.rank === 3) {
	    x4D = reshape$3(x, [1, x.shape[0], x.shape[1], x.shape[2]]);
	  } else {
	    x4D = x;
	  }
	  return x4D;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Batch normalization.
	 *
	 * As described in
	 * [http://arxiv.org/abs/1502.03167](http://arxiv.org/abs/1502.03167).
	 *
	 * Mean, variance, scale, and offset can be of two shapes:
	 *   - The same shape as the input.
	 *   - In the common case, the depth dimension is the last dimension of x, so
	 *     the values would be a `tf.Tensor1D` of shape [depth].
	 *
	 * Also available are stricter rank-specific methods with the same signature
	 * as this method that assert that parameters passed are of given rank
	 *   - `tf.batchNorm2d`
	 *   - `tf.batchNorm3d`
	 *   - `tf.batchNorm4d`
	 *
	 * @param x The input Tensor.
	 * @param mean A mean Tensor.
	 * @param variance A variance Tensor.
	 * @param offset An offset Tensor.
	 * @param scale A scale Tensor.
	 * @param varianceEpsilon A small float number to avoid dividing by 0.
	 *
	 * @doc {heading: 'Operations', subheading: 'Normalization'}
	 */
	function batchNorm_(x, mean, variance, offset, scale, varianceEpsilon) {
	  if (varianceEpsilon == null) {
	    varianceEpsilon = 0.001;
	  }
	  var $x = convertToTensor(x, 'x', 'batchNorm');
	  var $mean = convertToTensor(mean, 'mean', 'batchNorm');
	  var $variance = convertToTensor(variance, 'variance', 'batchNorm');
	  var $scale;
	  if (scale != null) {
	    $scale = convertToTensor(scale, 'scale', 'batchNorm');
	  }
	  var $offset;
	  if (offset != null) {
	    $offset = convertToTensor(offset, 'offset', 'batchNorm');
	  }
	  assert$1($mean.rank === $variance.rank, function () {
	    return 'Batch normalization gradient requires mean and variance to have ' + 'equal ranks.';
	  });
	  assert$1($offset == null || $mean.rank === $offset.rank, function () {
	    return 'Batch normalization gradient requires mean and offset to have ' + 'equal ranks.';
	  });
	  assert$1($scale == null || $mean.rank === $scale.rank, function () {
	    return 'Batch normalization gradient requires mean and scale to have ' + 'equal ranks.';
	  });
	  var x4D = xAs4D($x);
	  var inputs = {
	    x: x4D,
	    scale: $scale,
	    offset: $offset,
	    mean: $mean,
	    variance: $variance
	  };
	  var attrs = {
	    varianceEpsilon: varianceEpsilon
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var res = ENGINE.runKernel(FusedBatchNorm, inputs, attrs);
	  return reshape$3(res, $x.shape);
	}
	var batchNorm$2 = /* @__PURE__ */op({
	  batchNorm_: batchNorm_
	});

	/**
	 * Batch normalization, strictly for 2D. For the more relaxed version, see
	 * `tf.batchNorm`.
	 *
	 * @param x The input Tensor.
	 * @param mean A mean Tensor.
	 * @param variance A variance Tensor.
	 * @param offset An offset Tensor.
	 * @param scale A scale Tensor.
	 * @param varianceEpsilon A small float number to avoid dividing by 0.
	 */
	function batchNorm2d_(x, mean, variance, offset, scale, varianceEpsilon) {
	  var $x = convertToTensor(x, 'x', 'batchNorm');
	  var $mean = convertToTensor(mean, 'mean', 'batchNorm');
	  var $variance = convertToTensor(variance, 'variance', 'batchNorm');
	  var $scale;
	  if (scale != null) {
	    $scale = convertToTensor(scale, 'scale', 'batchNorm');
	  }
	  var $offset;
	  if (offset != null) {
	    $offset = convertToTensor(offset, 'offset', 'batchNorm');
	  }
	  assert$1($x.rank === 2, function () {
	    return "Error in batchNorm2D: x must be rank 2 but got rank " + "".concat($x.rank, ".");
	  });
	  assert$1($mean.rank === 2 || $mean.rank === 1, function () {
	    return "Error in batchNorm2D: mean must be rank 2 or rank 1 but " + "got rank ".concat($mean.rank, ".");
	  });
	  assert$1($variance.rank === 2 || $variance.rank === 1, function () {
	    return "Error in batchNorm2D: variance must be rank 2 or rank 1 " + "but got rank ".concat($variance.rank, ".");
	  });
	  if ($scale != null) {
	    assert$1($scale.rank === 2 || $scale.rank === 1, function () {
	      return "Error in batchNorm2D: scale must be rank 2 or rank 1 " + "but got rank ".concat($scale.rank, ".");
	    });
	  }
	  if ($offset != null) {
	    assert$1($offset.rank === 2 || $offset.rank === 1, function () {
	      return "Error in batchNorm2D: offset must be rank 2 or rank 1 " + "but got rank ".concat($offset.rank, ".");
	    });
	  }
	  return batchNorm$2($x, $mean, $variance, $offset, $scale, varianceEpsilon);
	}
	var batchNorm2d = /* @__PURE__ */op({
	  batchNorm2d_: batchNorm2d_
	});

	/**
	 * Batch normalization, strictly for 3D. For the more relaxed version, see
	 * `tf.batchNorm`.
	 *
	 * @param x The input Tensor.
	 * @param mean A mean Tensor.
	 * @param variance A variance Tensor.
	 * @param offset An offset Tensor.
	 * @param scale A scale Tensor.
	 * @param varianceEpsilon A small float number to avoid dividing by 0.
	 */
	function batchNorm3d_(x, mean, variance, offset, scale, varianceEpsilon) {
	  var $x = convertToTensor(x, 'x', 'batchNorm');
	  var $mean = convertToTensor(mean, 'mean', 'batchNorm');
	  var $variance = convertToTensor(variance, 'variance', 'batchNorm');
	  var $scale;
	  if (scale != null) {
	    $scale = convertToTensor(scale, 'scale', 'batchNorm');
	  }
	  var $offset;
	  if (offset != null) {
	    $offset = convertToTensor(offset, 'offset', 'batchNorm');
	  }
	  assert$1($x.rank === 3, function () {
	    return "Error in batchNorm3D: x must be rank 3 but got rank " + "".concat($x.rank, ".");
	  });
	  assert$1($mean.rank === 3 || $mean.rank === 1, function () {
	    return "Error in batchNorm3D: mean must be rank 3 or rank 1 but " + "got rank ".concat($mean.rank, ".");
	  });
	  assert$1($variance.rank === 3 || $variance.rank === 1, function () {
	    return "Error in batchNorm3D: variance must be rank 3 or rank 1 " + "but got rank ".concat($variance.rank, ".");
	  });
	  if ($scale != null) {
	    assert$1($scale.rank === 3 || $scale.rank === 1, function () {
	      return "Error in batchNorm3D: scale must be rank 3 or rank 1 " + "but got rank ".concat($scale.rank, ".");
	    });
	  }
	  if ($offset != null) {
	    assert$1($offset.rank === 3 || $offset.rank === 1, function () {
	      return "Error in batchNorm3D: offset must be rank 3 or rank 1 " + "but got rank ".concat($offset.rank, ".");
	    });
	  }
	  return batchNorm$2($x, $mean, $variance, $offset, $scale, varianceEpsilon);
	}
	var batchNorm3d = /* @__PURE__ */op({
	  batchNorm3d_: batchNorm3d_
	});

	/**
	 * Batch normalization, strictly for 4D. For the more relaxed version, see
	 * `tf.batchNorm`.
	 *
	 * @param x The input Tensor.
	 * @param mean A mean Tensor.
	 * @param variance A variance Tensor.
	 * @param offset An offset Tensor.
	 * @param scale A scale Tensor.
	 * @param varianceEpsilon A small float number to avoid dividing by 0.
	 */
	function batchNorm4d_(x, mean, variance, offset, scale, varianceEpsilon) {
	  var $x = convertToTensor(x, 'x', 'batchNorm');
	  var $mean = convertToTensor(mean, 'mean', 'batchNorm');
	  var $variance = convertToTensor(variance, 'variance', 'batchNorm');
	  var $scale;
	  if (scale != null) {
	    $scale = convertToTensor(scale, 'scale', 'batchNorm');
	  }
	  var $offset;
	  if (offset != null) {
	    $offset = convertToTensor(offset, 'offset', 'batchNorm');
	  }
	  assert$1($x.rank === 4, function () {
	    return "Error in batchNorm4D: x must be rank 4 but got rank " + "".concat($x.rank, ".");
	  });
	  assert$1($mean.rank === 4 || $mean.rank === 1, function () {
	    return "Error in batchNorm4D: mean must be rank 4 or rank 1 but " + "got rank ".concat($mean.rank, ".");
	  });
	  assert$1($variance.rank === 4 || $variance.rank === 1, function () {
	    return "Error in batchNorm4D: variance must be rank 4 or rank 1 " + "but got rank ".concat($variance.rank, ".");
	  });
	  if ($scale != null) {
	    assert$1($scale.rank === 4 || $scale.rank === 1, function () {
	      return "Error in batchNorm4D: scale must be rank 4 or rank 1 " + "but got rank ".concat($scale.rank, ".");
	    });
	  }
	  if ($offset != null) {
	    assert$1($offset.rank === 4 || $offset.rank === 1, function () {
	      return "Error in batchNorm4D: offset must be rank 4 or rank 1 " + "but got rank ".concat($offset.rank, ".");
	    });
	  }
	  return batchNorm$2($x, $mean, $variance, $offset, $scale, varianceEpsilon);
	}
	var batchNorm4d = /* @__PURE__ */op({
	  batchNorm4d_: batchNorm4d_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Outputs a vector with length `size` and the same dtype as `weights`.
	 *
	 * If `weights` are empty, then index `i` stores the number of times the value
	 * `i` is counted in `x`. If `weights` are non-empty, then index `i` stores the
	 * sum of the value in `weights` at each index where the corresponding value in
	 * `x` is `i`.
	 *
	 * Values in `x` outside of the range [0, size) are ignored.
	 *
	 * @param x The input int tensor, rank 1.
	 * @param weights The weights tensor, must have the same shape as x, or a
	 *     length-0 Tensor, in which case it acts as all weights equal to 1.
	 * @param size Non-negative integer.
	 *
	 * @doc {heading: 'Operations', subheading: 'Reduction'}
	 */
	function bincount_(x, weights, size) {
	  var $x = convertToTensor(x, 'x', 'bincount');
	  var $weights = convertToTensor(weights, 'weights', 'bincount');
	  assert$1($x.dtype === 'int32', function () {
	    return "Error in bincount: input " + "dtype must be int32, but got ".concat($x.dtype);
	  });
	  assert$1(size >= 0, function () {
	    return "size must be non-negative, but got ".concat(size, ".");
	  });
	  assert$1($weights.size === $x.size || $weights.size === 0, function () {
	    return "Error in bincount: weights must have the same size as input or" + "0-length, but got input shape: ".concat($x.shape, ", weights shape: ") + "".concat($weights.shape, ".");
	  });
	  var inputs = {
	    x: $x,
	    weights: $weights
	  };
	  var attrs = {
	    size: size
	  };
	  return ENGINE.runKernel(Bincount, inputs, attrs);
	}
	var bincount$2 = /* @__PURE__ */op({
	  bincount_: bincount_
	});

	/**
	 * @license
	 * Copyright 2023 Google LLC.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Bitwise `AND` operation for input tensors.
	 *
	 * Given two input tensors, returns a new tensor
	 * with the `AND` calculated values.
	 *
	 * The method supports int32 values
	 *
	 *
	 * ```js
	 * const x = tf.tensor1d([0, 5, 3, 14], 'int32');
	 * const y = tf.tensor1d([5, 0, 7, 11], 'int32');
	 * tf.bitwiseAnd(x, y).print();
	 * ```
	 *
	 * @param x The input tensor to be calculated.
	 * @param y The input tensor to be calculated.
	 *
	 * @doc {heading: 'Operations', subheading: 'Logical'}
	 */
	function bitwiseAnd_(x, y) {
	  var $x = convertToTensor(x, 'x', 'bitwiseAnd');
	  var $y = convertToTensor(y, 'y', 'bitwiseAnd');
	  if (!arraysEqual($x.shape, $y.shape)) {
	    throw new Error("BitwiseAnd: Tensors must have the same shape. x: ".concat($x.shape, ", y: ").concat($y.shape));
	  }
	  if ($x.dtype !== 'int32' || $y.dtype !== 'int32') {
	    throw new Error("BitwiseAnd: Only supports 'int32' values in tensor, found type of x: ".concat($x.dtype, " and type of y: ").concat($y.dtype));
	  }
	  var inputs = {
	    a: $x,
	    b: $y
	  };
	  return ENGINE.runKernel(BitwiseAnd, inputs);
	}
	var bitwiseAnd$2 = /* @__PURE__ */op({
	  bitwiseAnd_: bitwiseAnd_
	});

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Return the shape of s0 op s1 with broadcast.
	 *
	 * compute r0, the broadcasted shape as a tensor.
	 * s0, s1 and r0 are all integer vectors.
	 *
	 * This function returns the shape of the result of an operation between
	 * two tensors of size s0 and s1 performed with broadcast.
	 *
	 * @param s0 A tensor representing a shape
	 * @param s1 A tensor representing a shape
	 *
	 * @doc {heading: 'Tensors', subheading: 'Transformations'}
	 */
	function broadcastArgs_(s0, s1) {
	  var shape1Input = convertToTensor(s0, 's0', 'broadcastArgs', 'int32');
	  var shape2Input = convertToTensor(s1, 's1', 'broadcastArgs', 'int32');
	  if (shape1Input.rank !== 1) {
	    throw new Error('broadcastArgs(): first input must be a vector (rank=1). ' + "Has rank ".concat(shape1Input.rank));
	  }
	  if (shape2Input.rank !== 1) {
	    throw new Error('broadcastArgs(): second input must be a vector (rank=1). ' + "Has rank ".concat(shape2Input.rank));
	  }
	  var inputs = {
	    s0: shape1Input,
	    s1: shape2Input
	  };
	  return ENGINE.runKernel(BroadcastArgs, inputs);
	}
	var broadcastArgs$2 = /* @__PURE__ */op({
	  broadcastArgs_: broadcastArgs_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Broadcast an array to a compatible shape NumPy-style.
	 *
	 * The tensor's shape is compared to the broadcast shape from end to beginning.
	 * Ones are prepended to the tensor's shape until it has the same length as
	 * the broadcast shape. If input.shape[i]==shape[i], the (i+1)-th axis is
	 * already broadcast-compatible. If input.shape[i]==1 and shape[i]==N, then
	 * the input tensor is tiled N times along that axis (using tf.tile).
	 *
	 * @param input The tensor that is to be broadcasted.
	 * @param shape The input is to be broadcast to this shape.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Transformations'}
	 */
	function broadcastTo_(x, shape) {
	  var input = convertToTensor(x, 'broadcastTo', 'x');
	  var xShape = input.shape;
	  assertNonNegativeIntegerDimensions(shape);
	  if (shape.length < input.rank) {
	    throw new Error("broadcastTo(): shape.length=".concat(shape.length, " < input.rank=").concat(input.rank, "."));
	  }
	  if (shape.length > input.rank) {
	    var newShape = input.shape.slice();
	    while (newShape.length < shape.length) {
	      newShape.unshift(1);
	    }
	    input = reshape$3(input, newShape);
	  }
	  var inputShape = input.shape;
	  var reps = Array.from(shape);
	  for (var i = shape.length - 1; i >= 0; i--) {
	    if (inputShape[i] === shape[i]) {
	      reps[i] = 1;
	    } else if (input.shape[i] !== 1) {
	      throw new Error("broadcastTo(): [".concat(xShape, "] cannot be broadcast to [").concat(shape, "]."));
	    }
	  }
	  var axes = reps.map(function (n, i) {
	    return n > 1 ? i : -1;
	  }).filter(function (i) {
	    return i >= 0;
	  });
	  if (axes.length === 0) {
	    return clone(input);
	  }
	  // TODO call broadcastTo kernel directly once backends implement broadcstTo
	  var inputs = {
	    x: input
	  };
	  var attrs = {
	    reps: reps
	  };
	  return ENGINE.runKernel(Tile, inputs, attrs);
	}
	var broadcastTo = /* @__PURE__ */op({
	  broadcastTo_: broadcastTo_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes ceiling of input `tf.Tensor` element-wise: `ceil(x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([.6, 1.1, -3.3]);
	 *
	 * x.ceil().print();  // or tf.ceil(x)
	 * ```
	 * @param x The input Tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function ceil_(x) {
	  var $x = convertToTensor(x, 'x', 'ceil', 'float32');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Ceil, inputs);
	}
	var ceil$2 = /* @__PURE__ */op({
	  ceil_: ceil_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a `tf.Tensor` filled with a scalar value.
	 *
	 * ```js
	 * tf.fill([2, 2], 4).print();
	 * ```
	 *
	 * @param shape An array of integers defining the output tensor shape.
	 * @param value The scalar value to fill the tensor with.
	 * @param dtype The type of an element in the resulting tensor. Defaults to
	 *     'float32' if the given param value is a number, otherwise 'string'.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function fill$2(shape, value, dtype) {
	  assertNonNegativeIntegerDimensions(shape);
	  dtype = dtype || inferDtype(value);
	  var attrs = {
	    shape: shape,
	    value: value,
	    dtype: dtype
	  };
	  return ENGINE.runKernel(Fill, {}, attrs);
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Clips values element-wise. `max(min(x, clipValueMax), clipValueMin)`
	 *
	 * ```js
	 * const x = tf.tensor1d([-1, 2, -3, 4]);
	 *
	 * x.clipByValue(-2, 3).print();  // or tf.clipByValue(x, -2, 3)
	 * ```
	 * @param x The input tensor.
	 * @param clipValueMin Lower bound of range to be clipped to.
	 * @param clipValueMax Upper bound of range to be clipped to.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function clipByValue_(x, clipValueMin, clipValueMax) {
	  var $x = convertToTensor(x, 'x', 'clipByValue');
	  assert$1(clipValueMin <= clipValueMax, function () {
	    return "Error in clip: min (".concat(clipValueMin, ") must be ") + "less than or equal to max (".concat(clipValueMax, ").");
	  });
	  if (clipValueMin === clipValueMax) {
	    return fill$2($x.shape, clipValueMin, $x.dtype);
	  }
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    clipValueMin: clipValueMin,
	    clipValueMax: clipValueMax
	  };
	  return ENGINE.runKernel(ClipByValue, inputs, attrs);
	}
	var clipByValue$2 = /* @__PURE__ */op({
	  clipByValue_: clipByValue_
	});

	/**
	 * Concatenates a list of`tf.Tensor1D`s along an axis. See `concat` for details.
	 *
	 * For example, if:
	 * A: shape(3) = |r1, g1, b1|
	 * B: shape(2) = |r2, g2|
	 * C = tf.concat1d([A, B]) == |r1, g1, b1, r2, g2|
	 *
	 * @param tensors A list of`tf.Tensor`s to concatenate.
	 * @return The concatenated array.
	 */
	function concat1d_(tensors) {
	  return concat$2(tensors, 0 /* axis */);
	}

	var concat1d = /* @__PURE__ */op({
	  concat1d_: concat1d_
	});

	/**
	 * Concatenates a list of`tf.Tensor2D`s along an axis. See `concat` for details.
	 *
	 * For example, if:
	 * A: shape(2, 3) = | r1, g1, b1 |
	 *                  | r2, g2, b2 |
	 *
	 * B: shape(2, 3) = | r3, g3, b3 |
	 *                  | r4, g4, b4 |
	 *
	 * C = tf.concat2d([A, B], axis)
	 *
	 * if axis = 0:
	 * C: shape(4, 3) = | r1, g1, b1 |
	 *                  | r2, g2, b2 |
	 *                  | r3, g3, b3 |
	 *                  | r4, g4, b4 |
	 *
	 * if axis = 1:
	 * C = shape(2, 6) = | r1, g1, b1, r3, g3, b3 |
	 *                   | r2, g2, b2, r4, g4, b4 |
	 *
	 *
	 * @param tensors A list of `tf.Tensor`s to concatenate.
	 * @param axis The axis to concatenate along.
	 * @return The concatenated array.
	 */
	function concat2d_(tensors, axis) {
	  return concat$2(tensors, axis);
	}
	var concat2d = /* @__PURE__ */op({
	  concat2d_: concat2d_
	});

	/**
	 * Concatenates a list of `tf.Tensor3D`s along an axis.
	 * See `concat` for details.
	 *
	 * For example, if:
	 * A: shape(2, 1, 3) = | r1, g1, b1 |
	 *                     | r2, g2, b2 |
	 *
	 * B: shape(2, 1, 3) = | r3, g3, b3 |
	 *                     | r4, g4, b4 |
	 *
	 * C = tf.concat3d([A, B], axis)
	 *
	 * if axis = 0:
	 * C: shape(4, 1, 3) = | r1, g1, b1 |
	 *                     | r2, g2, b2 |
	 *                     | r3, g3, b3 |
	 *                     | r4, g4, b4 |
	 *
	 * if axis = 1:
	 * C: shape(2, 2, 3) = | r1, g1, b1, r3, g3, b3 |
	 *                     | r2, g2, b2, r4, g4, b4 |
	 *
	 * if axis = 2:
	 * C = shape(2, 1, 6) = | r1, g1, b1, r3, g3, b3 |
	 *                      | r2, g2, b2, r4, g4, b4 |
	 *
	 * @param tensors A list of`tf.Tensor`s to concatenate.
	 * @param axis The axis to concate along.
	 * @return The concatenated array.
	 */
	function concat3d_(tensors, axis) {
	  return concat$2(tensors, axis);
	}
	var concat3d = /* @__PURE__ */op({
	  concat3d_: concat3d_
	});

	/**
	 * Concatenates a list of `tf.Tensor4D`s along an axis.
	 * See `concat` for details.
	 *
	 * @param tensors A list of `tf.Tensor`s to concatenate.
	 * @param axis The axis to concate along.
	 * @return The concatenated array.
	 */
	function concat4d_(tensors, axis) {
	  return concat$2(tensors, axis);
	}
	var concat4d = /* @__PURE__ */op({
	  concat4d_: concat4d_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes a 2D convolution over the input x.
	 *
	 * @param x The input tensor, of rank 4 or rank 3, of shape
	 *     `[batch, height, width, inChannels]`. If rank 3, batch of 1 is
	 * assumed.
	 * @param filter The filter, rank 4, of shape
	 *     `[filterHeight, filterWidth, inDepth, outDepth]`.
	 * @param strides The strides of the convolution: `[strideHeight,
	 * strideWidth]`.
	 * @param pad The type of padding algorithm.
	 *    - `same` and stride 1: output will be of same size as input,
	 *       regardless of filter size.
	 *    - `valid`: output will be smaller than input if filter is larger
	 *       than 1x1.
	 *   - For more info, see this guide:
	 *     [https://www.tensorflow.org/api_docs/python/tf/nn/convolution](
	 *          https://www.tensorflow.org/api_docs/python/tf/nn/convolution)
	 * @param dataFormat: An optional string from: "NHWC", "NCHW". Defaults to
	 *     "NHWC". Specify the data format of the input and output data. With the
	 *     default format "NHWC", the data is stored in the order of: [batch,
	 *     height, width, channels].
	 * @param dilations The dilation rates: `[dilationHeight, dilationWidth]`
	 *     in which we sample input values across the height and width dimensions
	 *     in atrous convolution. Defaults to `[1, 1]`. If `dilations` is a single
	 *     number, then `dilationHeight == dilationWidth`. If it is greater than
	 *     1, then all values of `strides` must be 1.
	 * @param dimRoundingMode A string from: 'ceil', 'round', 'floor'. If none is
	 *     provided, it will default to truncate.
	 *
	 * @doc {heading: 'Operations', subheading: 'Convolution'}
	 */
	function conv2d_(x, filter, strides, pad) {
	  var dataFormat = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 'NHWC';
	  var dilations = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : [1, 1];
	  var dimRoundingMode = arguments.length > 6 ? arguments[6] : undefined;
	  var $x = convertToTensor(x, 'x', 'conv2d', 'float32');
	  var $filter = convertToTensor(filter, 'filter', 'conv2d', 'float32');
	  var x4D = $x;
	  var reshapedTo4D = false;
	  if ($x.rank === 3) {
	    reshapedTo4D = true;
	    x4D = reshape$3($x, [1, $x.shape[0], $x.shape[1], $x.shape[2]]);
	  }
	  assert$1(x4D.rank === 4, function () {
	    return "Error in conv2d: input must be rank 4, but got rank ".concat(x4D.rank, ".");
	  });
	  assert$1($filter.rank === 4, function () {
	    return "Error in conv2d: filter must be rank 4, but got rank " + "".concat($filter.rank, ".");
	  });
	  checkPadOnDimRoundingMode('conv2d', pad, dimRoundingMode);
	  var inDepth = dataFormat === 'NHWC' ? x4D.shape[3] : x4D.shape[1];
	  assert$1(inDepth === $filter.shape[2], function () {
	    return "Error in conv2d: depth of input (".concat(inDepth, ") must match ") + "input depth for filter ".concat($filter.shape[2], ".");
	  });
	  assert$1(eitherStridesOrDilationsAreOne(strides, dilations), function () {
	    return 'Error in conv2D: Either strides or dilations must be 1. ' + "Got strides ".concat(strides, " and dilations '").concat(dilations, "'");
	  });
	  assert$1(stridesOrDilationsArePositive(dilations), function () {
	    return 'Error in conv2D: Dilated rates should be larger than 0.';
	  });
	  assert$1(stridesOrDilationsArePositive(strides), function () {
	    return 'Error in conv2D: Strides should be larger than 0.';
	  });
	  var inputs = {
	    x: x4D,
	    filter: $filter
	  };
	  var attrs = {
	    strides: strides,
	    pad: pad,
	    dataFormat: dataFormat,
	    dilations: dilations,
	    dimRoundingMode: dimRoundingMode
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var res = ENGINE.runKernel(Conv2D$1, inputs, attrs);
	  if (reshapedTo4D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3]]);
	  }
	  return res;
	}
	var conv2d$4 = /* @__PURE__ */op({
	  conv2d_: conv2d_
	});

	/**
	 * Computes a 1D convolution over the input x.
	 *
	 * @param x The input tensor, of rank 3 or rank 2, of shape
	 *     `[batch, width, inChannels]`. If rank 2, batch of 1 is assumed.
	 * @param filter The filter, rank 3, of shape
	 *     `[filterWidth, inDepth, outDepth]`.
	 * @param stride The number of entries by which the filter is moved right at
	 *     each step.
	 * @param pad The type of padding algorithm.
	 *    - `same` and stride 1: output will be of same size as input,
	 *       regardless of filter size.
	 *    - `valid`: output will be smaller than input if filter is larger
	 *       than 1x1.
	 *   - For more info, see this guide:
	 *     [https://www.tensorflow.org/api_docs/python/tf/nn/convolution](
	 *          https://www.tensorflow.org/api_docs/python/tf/nn/convolution)
	 * @param dataFormat An optional string from "NWC", "NCW". Defaults to "NWC",
	 *     the data is stored in the order of [batch, in_width, in_channels]. Only
	 *     "NWC" is currently supported.
	 * @param dilation The dilation rate in which we sample input values in
	 *     atrous convolution. Defaults to `1`. If it is greater than 1, then
	 *     stride must be `1`.
	 * @param dimRoundingMode A string from: 'ceil', 'round', 'floor'. If none is
	 *     provided, it will default to truncate.
	 *
	 * @doc {heading: 'Operations', subheading: 'Convolution'}
	 */
	function conv1d_(x, filter, stride, pad) {
	  var dataFormat = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 'NWC';
	  var dilation = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : 1;
	  var dimRoundingMode = arguments.length > 6 ? arguments[6] : undefined;
	  var $x = convertToTensor(x, 'x', 'conv1d');
	  var $filter = convertToTensor(filter, 'filter', 'conv1d');
	  var x3D = $x;
	  var reshapedTo3D = false;
	  if ($x.rank === 2) {
	    reshapedTo3D = true;
	    x3D = reshape$3($x, [1, $x.shape[0], $x.shape[1]]);
	  }
	  assert$1(x3D.rank === 3, function () {
	    return "Error in conv1d: input must be rank 3, but got rank ".concat(x3D.rank, ".");
	  });
	  assert$1($filter.rank === 3, function () {
	    return "Error in conv1d: filter must be rank 3, but got rank " + "".concat($filter.rank, ".");
	  });
	  checkPadOnDimRoundingMode('conv1d', pad, dimRoundingMode);
	  assert$1(x3D.shape[2] === $filter.shape[1], function () {
	    return "Error in conv1d: depth of input (".concat(x3D.shape[2], ") must match ") + "input depth for filter ".concat($filter.shape[1], ".");
	  });
	  assert$1(eitherStridesOrDilationsAreOne(stride, dilation), function () {
	    return 'Error in conv1D: Either stride or dilation must be 1. ' + "Got stride ".concat(stride, " and dilation '").concat(dilation, "'");
	  });
	  assert$1(stridesOrDilationsArePositive(dilation), function () {
	    return 'Error in conv1D: Dilated rates should be larger than 0.';
	  });
	  assert$1(stridesOrDilationsArePositive(stride), function () {
	    return 'Error in conv1D: Stride should be larger than 0.';
	  });
	  assert$1(dataFormat === 'NWC', function () {
	    return "Error in conv1d: got dataFormat of ".concat(dataFormat, " but only NWC is currently supported.");
	  });
	  var filter4D = reshape$3($filter, [1, $filter.shape[0], $filter.shape[1], $filter.shape[2]]);
	  var input4D = reshape$3(x3D, [x3D.shape[0], 1, x3D.shape[1], x3D.shape[2]]);
	  var strides = [1, stride];
	  var dilations = [1, dilation];
	  var conv2dDataFormat = 'NHWC';
	  var res = conv2d$4(input4D, filter4D, strides, pad, conv2dDataFormat, dilations, dimRoundingMode);
	  if (reshapedTo3D) {
	    return reshape$3(res, [res.shape[2], res.shape[3]]);
	  }
	  return reshape$3(res, [res.shape[0], res.shape[2], res.shape[3]]);
	}
	var conv1d$2 = /* @__PURE__ */op({
	  conv1d_: conv1d_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the derivative of the input of a 2D convolution.
	 *
	 * @param xShape The shape of the input: [batch, height, width, inDepth].
	 * If length of 3, batch of 1 is assumed.
	 * @param dy The derivative of the output, of rank 4 or rank 3 of shape
	 *   `[batch, outHeight, outWidth, outDepth]`. If rank 3, batch of 1 is
	 * assumed.
	 * @param filter The filter, rank 4, of shape
	 *     `[filterHeight, filterWidth, inDepth, outDepth]`.
	 * @param strides The strides of the convolution: `[strideHeight,
	 * strideWidth]`.
	 * @param pad The type of padding algorithm used:
	 *    - `same` and stride 1: output will be of same size as input,
	 *       regardless of filter size.
	 *    - `valid`: output will be smaller than input if filter is larger
	 *       than 1x1.
	 * @param dataFormat: An optional string from: "NHWC", "NCHW". Defaults to
	 *     "NHWC". Specify the data format of the input and output data. With the
	 *     default format "NHWC", the data is stored in the order of: [batch,
	 *     height, width, channels].
	 * @param dimRoundingMode A string from: 'ceil', 'round', 'floor'. If none is
	 *     provided, it will default to truncate.
	 */
	function conv2DBackpropInput_(xShape, dy, filter, strides, pad) {
	  var dataFormat = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : 'NHWC';
	  var dimRoundingMode = arguments.length > 6 ? arguments[6] : undefined;
	  assert$1(xShape.length === dy.rank, function () {
	    return "Length of inShape " + "(".concat(xShape.length, ") and rank of dy (").concat(dy.rank, ") must match");
	  });
	  var xShape4D = xShape;
	  var dy4D = dy;
	  var reshapedTo4D = false;
	  if (dy.rank === 3) {
	    reshapedTo4D = true;
	    dy4D = reshape$3(dy, [1, dy.shape[0], dy.shape[1], dy.shape[2]]);
	    xShape4D = [1, xShape[0], xShape[1], xShape[2]];
	  }
	  assert$1(xShape4D.length === 4, function () {
	    return "Error in conv2dDerInput: inShape must be length 4, but got length " + "".concat(xShape4D.length, ".");
	  });
	  assert$1(dy4D.rank === 4, function () {
	    return "Error in conv2dDerInput: dy must be rank 4, but got " + "rank ".concat(dy4D.rank);
	  });
	  assert$1(filter.rank === 4, function () {
	    return "Error in conv2dDerInput: filter must be rank 4, but got " + "rank ".concat(filter.rank);
	  });
	  var inDepth = dataFormat === 'NHWC' ? xShape4D[3] : xShape4D[1];
	  var outDepth = dataFormat === 'NHWC' ? dy4D.shape[3] : dy4D.shape[1];
	  assert$1(inDepth === filter.shape[2], function () {
	    return "Error in conv2dDerInput: depth of input (".concat(inDepth, ") must ") + "match input depth for filter ".concat(filter.shape[2], ".");
	  });
	  assert$1(outDepth === filter.shape[3], function () {
	    return "Error in conv2dDerInput: depth of output (".concat(outDepth, ") must ") + "match output depth for filter ".concat(filter.shape[3], ".");
	  });
	  checkPadOnDimRoundingMode('conv2dDerInput', pad, dimRoundingMode);
	  var inputs = {
	    dy: dy4D,
	    filter: filter
	  };
	  var attrs = {
	    strides: strides,
	    pad: pad,
	    dataFormat: dataFormat,
	    dimRoundingMode: dimRoundingMode,
	    inputShape: xShape4D
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var res = ENGINE.runKernel(Conv2DBackpropInput, inputs, attrs);
	  if (reshapedTo4D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3]]);
	  }
	  return res;
	}
	var conv2DBackpropInput$2 = /* @__PURE__ */op({
	  conv2DBackpropInput_: conv2DBackpropInput_
	});

	/**
	 * Computes the transposed 2D convolution of an image, also known as a
	 * deconvolution.
	 *
	 * @param x The input image, of rank 4 or rank 3, of shape
	 *   `[batch, height, width, inDepth]`. If rank 3, batch of 1 is assumed.
	 * @param filter The filter, rank 4, of shape
	 *     `[filterHeight, filterWidth, outDepth, inDepth]`.
	 *     `inDepth` must match `inDepth` in `x`.
	 * @param outputShape Output shape, of rank 4 or rank 3:
	 *     `[batch, height, width, outDepth]`. If rank 3, batch of 1 is assumed.
	 * @param strides The strides of the original convolution:
	 *     `[strideHeight, strideWidth]`.
	 * @param pad  The type of padding algorithm used in the non-transpose version
	 *    of the op.
	 * @param dimRoundingMode A string from: 'ceil', 'round', 'floor'. If none is
	 *     provided, it will default to truncate.
	 *
	 * @doc {heading: 'Operations', subheading: 'Convolution'}
	 */
	function conv2dTranspose_(x, filter, outputShape, strides, pad, dimRoundingMode) {
	  var $x = convertToTensor(x, 'x', 'conv2dTranspose');
	  var $filter = convertToTensor(filter, 'filter', 'conv2dTranspose');
	  return conv2DBackpropInput$2(outputShape, $x, $filter, strides, pad, 'NHWC', dimRoundingMode);
	}
	var conv2dTranspose$1 = /* @__PURE__ */op({
	  conv2dTranspose_: conv2dTranspose_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes a 3D convolution over the input x.
	 *
	 * @param x The input tensor, of rank 5 or rank 4, of shape
	 *     `[batch, depth, height, width, channels]`. If rank 4,
	 * batch of 1 is assumed.
	 * @param filter The filter, rank 5, of shape
	 *     `[filterDepth, filterHeight, filterWidth, inChannels, outChannels]`.
	 *      inChannels must match between input and filter.
	 * @param strides The strides of the convolution: `[strideDepth, strideHeight,
	 * strideWidth]`.
	 * @param pad The type of padding algorithm.
	 *    - `same` and stride 1: output will be of same size as input,
	 *       regardless of filter size.
	 *    - `valid`: output will be smaller than input if filter is larger
	 *       than 1x1.
	 *   - For more info, see this guide:
	 *     [https://www.tensorflow.org/api_docs/python/tf/nn/convolution](
	 *          https://www.tensorflow.org/api_docs/python/tf/nn/convolution)
	 * @param dataFormat: An optional string from: "NDHWC", "NCDHW". Defaults to
	 *     "NDHWC". Specify the data format of the input and output data. With the
	 *     default format "NDHWC", the data is stored in the order of: [batch,
	 *     depth, height, width, channels]. Only "NDHWC" is currently supported.
	 * @param dilations The dilation rates: `[dilationDepth, dilationHeight,
	 *     dilationWidth]` in which we sample input values across the height
	 *     and width dimensions in atrous convolution. Defaults to `[1, 1, 1]`.
	 *     If `dilations` is a single number, then
	 *     `dilationDepth == dilationHeight == dilationWidth`. If it is greater
	 *     than 1, then all values of `strides` must be 1.
	 *
	 * @doc {heading: 'Operations', subheading: 'Convolution'}
	 */
	function conv3d_(x, filter, strides, pad) {
	  var dataFormat = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 'NDHWC';
	  var dilations = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : [1, 1, 1];
	  var $x = convertToTensor(x, 'x', 'conv3d');
	  var $filter = convertToTensor(filter, 'filter', 'conv3d');
	  var x5D = $x;
	  var reshapedTo5D = false;
	  if ($x.rank === 4) {
	    reshapedTo5D = true;
	    x5D = reshape$3($x, [1, $x.shape[0], $x.shape[1], $x.shape[2], $x.shape[3]]);
	  }
	  assert$1(x5D.rank === 5, function () {
	    return "Error in conv3d: input must be rank 5, but got rank ".concat(x5D.rank, ".");
	  });
	  assert$1($filter.rank === 5, function () {
	    return "Error in conv3d: filter must be rank 5, but got rank " + "".concat($filter.rank, ".");
	  });
	  assert$1(x5D.shape[4] === $filter.shape[3], function () {
	    return "Error in conv3d: depth of input (".concat(x5D.shape[4], ") must match ") + "input depth for filter ".concat($filter.shape[3], ".");
	  });
	  assert$1(eitherStridesOrDilationsAreOne(strides, dilations), function () {
	    return 'Error in conv3D: Either strides or dilations must be 1. ' + "Got strides ".concat(strides, " and dilations '").concat(dilations, "'");
	  });
	  assert$1(dataFormat === 'NDHWC', function () {
	    return "Error in conv3d: got dataFormat of ".concat(dataFormat, " but only NDHWC is currently supported.");
	  });
	  assert$1(stridesOrDilationsArePositive(dilations), function () {
	    return 'Error in conv3D: Dilated rates should be larger than 0.';
	  });
	  assert$1(stridesOrDilationsArePositive(strides), function () {
	    return 'Error in conv3D: Strides should be larger than 0.';
	  });
	  var inputs = {
	    x: x5D,
	    filter: $filter
	  };
	  var attrs = {
	    strides: strides,
	    pad: pad,
	    dataFormat: dataFormat,
	    dilations: dilations
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var res = ENGINE.runKernel(Conv3D$1, inputs, attrs);
	  if (reshapedTo5D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3], res.shape[4]]);
	  }
	  return res;
	}
	var conv3d$2 = /* @__PURE__ */op({
	  conv3d_: conv3d_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the derivative of the input of a 3D convolution.
	 *
	 * @param xShape The shape of the input: [batch, depth, height, width,
	 * in_channels]. If length of 4, batch of 1 is assumed.
	 * @param dy The derivative of the output, of rank 5 or rank 4 of shape
	 *   `[batch, outDepth, outHeight, outWidth, in_channels]`.
	 * If rank 4, batch of 1 is assumed.
	 * @param filter The filter, rank 5, of shape
	 *     `[filterDepth, filterHeight, filterWidth, inDepth, outDepth]`.
	 * @param strides The strides of the convolution: `[strideDepth, strideHeight,
	 * strideWidth]`.
	 * @param pad The type of padding algorithm used:
	 *    - `same` and stride 1: output will be of same size as input,
	 *       regardless of filter size.
	 *    - `valid`: output will be smaller than input if filter is larger
	 *       than 1x1.
	 */
	function conv3DBackpropInput_(xShape, dy, filter, strides, pad) {
	  assert$1(xShape.length === dy.rank, function () {
	    return "Length of inShape " + "(".concat(xShape.length, ") and rank of dy (").concat(dy.rank, ") must match");
	  });
	  var xShape5D = xShape;
	  var dy5D = dy;
	  var reshapedTo5D = false;
	  if (dy.rank === 4) {
	    reshapedTo5D = true;
	    dy5D = reshape$3(dy, [1, dy.shape[0], dy.shape[1], dy.shape[2], dy.shape[3]]);
	    xShape5D = [1, xShape[0], xShape[1], xShape[2], xShape[3]];
	  }
	  var inDepth = xShape5D[4];
	  var outDepth = dy5D.shape[4];
	  assert$1(xShape5D.length === 5, function () {
	    return "Error in conv3dDerInput: inShape must be length 5, but got length " + "".concat(xShape5D.length, ".");
	  });
	  assert$1(dy5D.rank === 5, function () {
	    return "Error in conv3dDerInput: dy must be rank 5, but got " + "rank ".concat(dy5D.rank);
	  });
	  assert$1(filter.rank === 5, function () {
	    return "Error in conv3dDerInput: filter must be rank 5, but got " + "rank ".concat(filter.rank);
	  });
	  assert$1(inDepth === filter.shape[3], function () {
	    return "Error in conv3dDerInput: depth of input (".concat(inDepth, ") must ") + "match input depth for filter ".concat(filter.shape[3], ".");
	  });
	  assert$1(outDepth === filter.shape[4], function () {
	    return "Error in conv3dDerInput: depth of output (".concat(outDepth, ") must ") + "match output depth for filter ".concat(filter.shape[4], ".");
	  });
	  var inputs = {
	    dy: dy5D,
	    filter: filter
	  };
	  var attrs = {
	    pad: pad,
	    strides: strides,
	    inputShape: xShape5D
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var res = ENGINE.runKernel(Conv3DBackpropInputV2, inputs, attrs);
	  if (reshapedTo5D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3], res.shape[4]]);
	  }
	  return res;
	}
	var conv3DBackpropInput$1 = /* @__PURE__ */op({
	  conv3DBackpropInput_: conv3DBackpropInput_
	});

	/**
	 * Computes the transposed 3D convolution of a volume, also known as a
	 * deconvolution.
	 *
	 * @param x The input image, of rank 5 or rank 4, of shape
	 *   `[batch, depth, height, width, inDepth]`. If rank 4, batch of 1 is assumed.
	 * @param filter The filter, rank 4, of shape
	 *     `[depth, filterHeight, filterWidth, outDepth, inDepth]`.
	 *     `inDepth` must match `inDepth` in `x`.
	 * @param outputShape Output shape, of rank 5 or rank 4:
	 *     `[batch, depth, height, width, outDepth]`. If rank 3, batch of 1 is
	 *    assumed.
	 * @param strides The strides of the original convolution:
	 *     `[strideDepth, strideHeight, strideWidth]`.
	 * @param pad  The type of padding algorithm used in the non-transpose version
	 *    of the op.
	 *
	 * @doc {heading: 'Operations', subheading: 'Convolution'}
	 */
	function conv3dTranspose_(x, filter, outputShape, strides, pad) {
	  var $x = convertToTensor(x, 'x', 'conv3dTranspose');
	  var $filter = convertToTensor(filter, 'filter', 'conv3dTranspose');
	  return conv3DBackpropInput$1(outputShape, $x, $filter, strides, pad);
	}
	var conv3dTranspose$1 = /* @__PURE__ */op({
	  conv3dTranspose_: conv3dTranspose_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes cos of the input `tf.Tensor` element-wise: `cos(x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([0, Math.PI / 2, Math.PI * 3 / 4]);
	 *
	 * x.cos().print();  // or tf.cos(x)
	 * ```
	 * @param x The input tensor. Must be float32 type.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function cos_(x) {
	  var $x = convertToTensor(x, 'x', 'cos', 'float32');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Cos, inputs);
	}
	var cos$2 = /* @__PURE__ */op({
	  cos_: cos_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes hyperbolic cos of the input `tf.Tensor` element-wise: `cosh(x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([0, 1, -1, .7]);
	 *
	 * x.cosh().print();  // or tf.cosh(x)
	 * ```
	 * @param x The input tensor. Must be float32 type.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function cosh_(x) {
	  var $x = convertToTensor(x, 'x', 'cosh', 'float32');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Cosh, inputs);
	}
	var cosh$2 = /* @__PURE__ */op({
	  cosh_: cosh_
	});

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the 'License');
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an 'AS IS' BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the cumulative product of a `tf.Tensor` along `axis`.
	 *
	 * ```js
	 * const x = tf.tensor([1, 2, 3, 4]);
	 * x.cumprod().print();
	 * ```
	 * ```js
	 * const x = tf.tensor([[1, 2], [3, 4]]);
	 * x.cumprod().print();
	 * ```
	 *
	 * @param x The input tensor to cumulatively multiply.
	 * @param axis The axis along which to multiply. Optional. Defaults to 0.
	 * @param exclusive Whether to perform exclusive cumulative product. Optional.
	 *     Defaults to false. If set to true then the product of each tensor entry
	 *     does not include its own value, but only the values previous to it
	 *     along the specified axis.
	 * @param reverse Whether to multiply in the opposite direction. Optional.
	 *     Defaults to false.
	 *
	 * @doc {heading: 'Operations', subheading: 'Scan'}
	 */
	function cumprod_(x) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
	  var exclusive = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  var reverse = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var $x = convertToTensor(x, 'x', 'cumprod');
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    axis: axis,
	    exclusive: exclusive,
	    reverse: reverse
	  };
	  return ENGINE.runKernel(Cumprod, inputs, attrs);
	}
	var cumprod$2 = /* @__PURE__ */op({
	  cumprod_: cumprod_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the cumulative sum of a `tf.Tensor` along `axis`.
	 *
	 * ```js
	 * const x = tf.tensor([1, 2, 3, 4]);
	 * x.cumsum().print();
	 * ```
	 * ```js
	 * const x = tf.tensor([[1, 2], [3, 4]]);
	 * x.cumsum().print();
	 * ```
	 *
	 * @param x The input tensor to be summed.
	 * @param axis The axis along which to sum. Optional. Defaults to 0.
	 * @param exclusive Whether to perform exclusive cumulative sum. Optional.
	 *     Defaults to false. If set to true then the sum of each tensor entry
	 *     does not include its own value, but only the values previous to it
	 *     along the specified axis.
	 * @param reverse Whether to sum in the opposite direction. Optional.
	 *     Defaults to false.
	 *
	 * @doc {heading: 'Operations', subheading: 'Scan'}
	 */
	function cumsum_(x) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
	  var exclusive = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  var reverse = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var $x = convertToTensor(x, 'x', 'cumsum');
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    axis: axis,
	    exclusive: exclusive,
	    reverse: reverse
	  };
	  return ENGINE.runKernel(Cumsum, inputs, attrs);
	}
	var cumsum$2 = /* @__PURE__ */op({
	  cumsum_: cumsum_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Outputs a vector with length `size` and the same dtype as `weights`.
	 *
	 * If `weights` are empty, then index `i` stores the number of times the value
	 * `i` is counted in `x`. If `weights` are non-empty, then index `i` stores the
	 * sum of the value in `weights` at each index where the corresponding value in
	 * `x` is `i`.
	 *
	 * Values in `x` outside of the range [0, size) are ignored.
	 *
	 * @param x The input int tensor, rank 1 or rank 2.
	 * @param weights The weights tensor, must have the same shape as x, or a
	 *     length-0 Tensor, in which case it acts as all weights equal to 1.
	 * @param size Non-negative integer.
	 * @param binaryOutput Optional. Whether the kernel should count the appearance
	 *     or number of occurrences. Defaults to False.
	 *
	 * @doc {heading: 'Operations', subheading: 'Reduction'}
	 */
	function denseBincount_(x, weights, size) {
	  var binaryOutput = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var $x = convertToTensor(x, 'x', 'denseBincount');
	  var $weights = convertToTensor(weights, 'weights', 'denseBincount');
	  assert$1($x.dtype === 'int32', function () {
	    return "Error in denseBincount: input " + "dtype must be int32, but got ".concat($x.dtype);
	  });
	  assert$1($x.rank <= 2, function () {
	    return "Error in denseBincount: input must be at most rank 2, but got " + "rank ".concat($x.rank, ".");
	  });
	  assert$1(size >= 0, function () {
	    return "size must be non-negative, but got ".concat(size, ".");
	  });
	  assert$1($weights.size === $x.size || $weights.size === 0, function () {
	    return "Error in denseBincount: weights must have the same shape as x or " + "0-length, but got x shape: ".concat($x.shape, ", weights shape: ") + "".concat($weights.shape, ".");
	  });
	  var inputs = {
	    x: $x,
	    weights: $weights
	  };
	  var attrs = {
	    size: size,
	    binaryOutput: binaryOutput
	  };
	  return ENGINE.runKernel(DenseBincount, inputs, attrs);
	}
	var denseBincount$2 = /* @__PURE__ */op({
	  denseBincount_: denseBincount_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Rearranges data from depth into blocks of spatial data. More specifically,
	 * this op outputs a copy of the input tensor where values from the `depth`
	 * dimension are moved in spatial blocks to the `height` and `width` dimensions.
	 * The attr `blockSize` indicates the input block size and how the data is
	 * moved.
	 *
	 *  - Chunks of data of size `blockSize * blockSize` from depth are rearranged
	 * into non-overlapping blocks of size `blockSize x blockSize`
	 *
	 *  - The width the output tensor is `inputWidth * blockSize`, whereas the
	 * height is `inputHeight * blockSize`
	 *
	 *  - The Y, X coordinates within each block of the output image are determined
	 * by the high order component of the input channel index
	 *
	 *  - The depth of the input tensor must be divisible by `blockSize *
	 * blockSize`
	 *
	 * The `dataFormat` attr specifies the layout of the input and output tensors
	 * with the following options: "NHWC": [ `batch, height, width, channels` ]
	 * "NCHW": [ `batch, channels, height, width` ]
	 *
	 * ```js
	 * const x = tf.tensor4d([1, 2, 3, 4], [1, 1, 1, 4]);
	 * const blockSize = 2;
	 * const dataFormat = "NHWC";
	 *
	 * tf.depthToSpace(x, blockSize, dataFormat).print();
	 * ```
	 *
	 * @param x The input tensor of rank 4
	 * @param blockSIze  An `int` that is `>= 2`. The size of the spatial block
	 * @param dataFormat An optional string from: "NHWC", "NCHW". Defaults to "NHWC"
	 *
	 * @doc {heading: 'Tensors', subheading: 'Transformations'}
	 */
	function depthToSpace_(x, blockSize) {
	  var dataFormat = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'NHWC';
	  var $x = convertToTensor(x, 'x', 'depthToSpace', 'float32');
	  var inputHeight = dataFormat === 'NHWC' ? $x.shape[1] : $x.shape[2];
	  var inputWidth = dataFormat === 'NHWC' ? $x.shape[2] : $x.shape[3];
	  var inputDepth = dataFormat === 'NHWC' ? $x.shape[3] : $x.shape[1];
	  assert$1(blockSize > 1, function () {
	    return "blockSize should be > 1 for depthToSpace, but was: ".concat(blockSize);
	  });
	  assert$1(inputHeight * blockSize >= 0, function () {
	    return "Negative dimension size caused by overflow when multiplying\n    ".concat(inputHeight, " and ").concat(blockSize, "  for depthToSpace with input shape\n    ").concat($x.shape);
	  });
	  assert$1(inputWidth * blockSize >= 0, function () {
	    return "Negative dimension size caused by overflow when multiplying\n    ".concat(inputWidth, " and ").concat(blockSize, " for depthToSpace with input shape\n        ").concat($x.shape);
	  });
	  assert$1(inputDepth % (blockSize * blockSize) === 0, function () {
	    return "Dimension size must be evenly divisible by ".concat(blockSize * blockSize, " but is ").concat(inputDepth, " for depthToSpace with input shape ").concat($x.shape);
	  });
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    blockSize: blockSize,
	    dataFormat: dataFormat
	  };
	  return ENGINE.runKernel(DepthToSpace, inputs, attrs);
	}
	var depthToSpace$2 = /* @__PURE__ */op({
	  depthToSpace_: depthToSpace_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Depthwise 2D convolution.
	 *
	 * Given a 4D `input` array and a `filter` array of shape
	 * `[filterHeight, filterWidth, inChannels, channelMultiplier]` containing
	 * `inChannels` convolutional filters of depth 1, this op applies a
	 * different filter to each input channel (expanding from 1 channel to
	 * `channelMultiplier` channels for each), then concatenates the results
	 * together. The output has `inChannels * channelMultiplier` channels.
	 *
	 * See
	 * [https://www.tensorflow.org/api_docs/python/tf/nn/depthwise_conv2d](
	 *     https://www.tensorflow.org/api_docs/python/tf/nn/depthwise_conv2d)
	 * for more details.
	 *
	 * @param x The input tensor, of rank 4 or rank 3, of shape
	 *     `[batch, height, width, inChannels]`. If rank 3, batch of 1 is
	 * assumed.
	 * @param filter The filter tensor, rank 4, of shape
	 *     `[filterHeight, filterWidth, inChannels, channelMultiplier]`.
	 * @param strides The strides of the convolution: `[strideHeight,
	 * strideWidth]`. If strides is a single number, then `strideHeight ==
	 * strideWidth`.
	 * @param pad The type of padding algorithm.
	 *   - `same` and stride 1: output will be of same size as input,
	 *       regardless of filter size.
	 *   - `valid`: output will be smaller than input if filter is larger
	 *       than 1x1.
	 *   - For more info, see this guide:
	 *     [https://www.tensorflow.org/api_docs/python/tf/nn/convolution](
	 *          https://www.tensorflow.org/api_docs/python/tf/nn/convolution)
	 * @param dilations The dilation rates: `[dilationHeight, dilationWidth]`
	 *     in which we sample input values across the height and width dimensions
	 *     in atrous convolution. Defaults to `[1, 1]`. If `rate` is a single
	 *     number, then `dilationHeight == dilationWidth`. If it is greater than
	 *     1, then all values of `strides` must be 1.
	 * @param dataFormat: An optional string from: "NHWC", "NCHW". Defaults to
	 *     "NHWC". Specify the data format of the input and output data. With the
	 *     default format "NHWC", the data is stored in the order of: [batch,
	 *     height, width, channels]. Only "NHWC" is currently supported.
	 * @param dimRoundingMode A string from: 'ceil', 'round', 'floor'. If none is
	 *     provided, it will default to truncate.
	 *
	 * @doc {heading: 'Operations', subheading: 'Convolution'}
	 */
	function depthwiseConv2d_(x, filter, strides, pad) {
	  var dataFormat = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 'NHWC';
	  var dilations = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : [1, 1];
	  var dimRoundingMode = arguments.length > 6 ? arguments[6] : undefined;
	  var $x = convertToTensor(x, 'x', 'depthwiseConv2d', 'float32');
	  var $filter = convertToTensor(filter, 'filter', 'depthwiseConv2d', 'float32');
	  var x4D = $x;
	  var reshapedTo4D = false;
	  if ($x.rank === 3) {
	    reshapedTo4D = true;
	    x4D = reshape$3($x, [1, $x.shape[0], $x.shape[1], $x.shape[2]]);
	  }
	  assert$1(x4D.rank === 4, function () {
	    return "Error in depthwiseConv2d: input must be rank 4, but got " + "rank ".concat(x4D.rank, ".");
	  });
	  assert$1($filter.rank === 4, function () {
	    return "Error in depthwiseConv2d: filter must be rank 4, but got rank " + "".concat($filter.rank, ".");
	  });
	  var inChannels = dataFormat === 'NHWC' ? x4D.shape[3] : x4D.shape[1];
	  assert$1(inChannels === $filter.shape[2], function () {
	    return "Error in depthwiseConv2d: number of input channels " + "(".concat(inChannels, ") must match the inChannels dimension in ") + "filter ".concat($filter.shape[2], ".");
	  });
	  checkPadOnDimRoundingMode('depthwiseConv2d', pad, dimRoundingMode);
	  var inputs = {
	    x: x4D,
	    filter: $filter
	  };
	  var attrs = {
	    strides: strides,
	    pad: pad,
	    dataFormat: dataFormat,
	    dilations: dilations,
	    dimRoundingMode: dimRoundingMode
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var res = ENGINE.runKernel(DepthwiseConv2dNative, inputs, attrs);
	  if (reshapedTo4D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3]]);
	  }
	  return res;
	}
	var depthwiseConv2d$3 = /* @__PURE__ */op({
	  depthwiseConv2d_: depthwiseConv2d_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Returns a diagonal tensor with given diagonal values.
	 *
	 * Given a diagonal, this operation returns a tensor with the diagonal and
	 * everything else padded with zeros.
	 *
	 * Assume the input has dimensions `[D1,..., Dk]`, then the output is a tensor
	 * of rank 2k with dimensions `[D1,..., Dk, D1,..., Dk]`
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3, 4]);
	 *
	 * tf.diag(x).print()
	 * ```
	 * ```js
	 * const x = tf.tensor2d([1, 2, 3, 4, 5, 6, 7, 8], [4, 2])
	 *
	 * tf.diag(x).print()
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function diag_(x) {
	  var $x = convertToTensor(x, 'x', 'diag');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Diag, inputs);
	}
	var diag$2 = /* @__PURE__ */op({
	  diag_: diag_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the grayscale dilation over the input `x`.
	 *
	 * @param x The input tensor, rank 3 or rank 4 of shape
	 *     `[batch, height, width, depth]`. If rank 3, batch of 1 is assumed.
	 * @param filter The filter tensor, rank 3, of shape
	 *     `[filterHeight, filterWidth, depth]`.
	 * @param strides The strides of the sliding window for each dimension of the
	 *     input tensor: `[strideHeight, strideWidth]`.
	 *     If `strides` is a single number,
	 *     then `strideHeight == strideWidth`.
	 * @param pad The type of padding algorithm.
	 *    - `same` and stride 1: output will be of same size as input,
	 *       regardless of filter size.
	 *    - `valid`: output will be smaller than input if filter is larger
	 *       than 1*1x1.
	 *    - For more info, see this guide:
	 *     [https://www.tensorflow.org/api_docs/python/tf/nn/convolution](
	 *          https://www.tensorflow.org/api_docs/python/tf/nn/convolution)
	 * @param dataFormat Specify the data format of the input and output data.
	 *      Defaults to 'NHWC'. Only 'NHWC' is currently supported. With the
	 *      default format "NHWC", the data is stored in the order of: [batch,
	 *      height, width, channels].
	 * @param dilations The dilation rates: `[dilationHeight, dilationWidth]`
	 *     in which we sample input values across the height and width dimensions
	 *     for atrous morphological dilation. Defaults to `[1, 1]`. If `dilations`
	 *     is a single number, then `dilationHeight == dilationWidth`. If it is
	 *     greater than 1, then all values of `strides` must be 1.
	 *
	 * @doc {heading: 'Operations', subheading: 'Convolution'}
	 */
	function dilation2d_(x, filter, strides, pad) {
	  var dilations = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : [1, 1];
	  var dataFormat = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : 'NHWC';
	  var $x = convertToTensor(x, 'x', 'dilation2d');
	  var $filter = convertToTensor(filter, 'filter', 'dilation2d');
	  assert$1($x.rank === 3 || $x.rank === 4, function () {
	    return "Error in dilation2d: input must be rank 3 or 4, but got rank " + "".concat($x.rank, ".");
	  });
	  assert$1($filter.rank === 3, function () {
	    return "Error in dilation2d: filter must be rank 3, but got rank " + "".concat($filter.rank, ".");
	  });
	  assert$1(dataFormat === 'NHWC', function () {
	    return "Error in dilation2d: Only NHWC is currently supported, " + "but got dataFormat of ".concat(dataFormat);
	  });
	  var x4D = $x;
	  var reshapedTo4D = false;
	  if ($x.rank === 3) {
	    x4D = reshape$3($x, [1, $x.shape[0], $x.shape[1], $x.shape[2]]);
	    reshapedTo4D = true;
	  }
	  assert$1(x4D.shape[3] === $filter.shape[2], function () {
	    return "Error in dilation2d:  input and filter must have the same depth: ".concat(x4D.shape[3], " vs ").concat($filter.shape[2]);
	  });
	  var inputs = {
	    x: x4D,
	    filter: $filter
	  };
	  var attrs = {
	    strides: strides,
	    pad: pad,
	    dilations: dilations
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var res = ENGINE.runKernel(Dilation2D, inputs, attrs);
	  if (reshapedTo4D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3]]);
	  }
	  return res;
	}
	var dilation2d = /* @__PURE__ */op({
	  dilation2d_: dilation2d_
	});

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Returns the dimensions in the input shape that are broadcasted to
	 * produce the provided output shape.
	 *
	 * The returned dimensions are 0-indexed and sorted. An example:
	 * inShape = [4, 1, 3]
	 * outShape = [5, 4, 3, 3]
	 * result = [1]. Dimension 1 (2nd dimension of input) gets broadcasted 1 => 3.
	 */
	function getBroadcastDims$1(inShape, outShape) {
	  var inRank = inShape.length;
	  var dims = [];
	  for (var i = 0; i < inRank; i++) {
	    var dim = inRank - 1 - i;
	    var a = inShape[dim] || 1;
	    var b = outShape[outShape.length - 1 - i] || 1;
	    if (b > 1 && a === 1) {
	      dims.unshift(dim);
	    }
	  }
	  return dims;
	}
	/**
	 * Returns the axes in the output space that should be reduced to produce
	 * the input space.
	 */
	function getReductionAxes(inShape, outShape) {
	  var result = [];
	  for (var i = 0; i < outShape.length; i++) {
	    var inDim = inShape[inShape.length - i - 1];
	    var outAxis = outShape.length - i - 1;
	    var outDim = outShape[outAxis];
	    if (inDim == null || inDim === 1 && outDim > 1) {
	      result.unshift(outAxis);
	    }
	  }
	  return result;
	}
	function assertAndGetBroadcastShape(shapeA, shapeB) {
	  var l = Math.max(shapeA.length, shapeB.length);
	  var result = new Array(l);
	  for (var i = 0; i < l; i++) {
	    var a = shapeA[shapeA.length - i - 1];
	    if (a == null) {
	      a = 1;
	    }
	    var b = shapeB[shapeB.length - i - 1];
	    if (b == null) {
	      b = 1;
	    }
	    if (a === 1) {
	      result[l - i - 1] = b;
	    } else if (b === 1) {
	      result[l - i - 1] = a;
	    } else if (a !== b) {
	      var errMsg = "Operands could not be broadcast together with shapes " + "".concat(shapeA, " and ").concat(shapeB, ".");
	      throw Error(errMsg);
	    } else {
	      result[l - i - 1] = a;
	    }
	  }
	  return result;
	}

	var broadcast_util = {
		__proto__: null,
		assertAndGetBroadcastShape: assertAndGetBroadcastShape,
		getBroadcastDims: getBroadcastDims$1,
		getReductionAxes: getReductionAxes
	};

	/**
	 * Returns the truth value of (a == b) element-wise. Supports broadcasting.
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 2, 3]);
	 * const b = tf.tensor1d([2, 2, 2]);
	 *
	 * a.equal(b).print();
	 * ```
	 *
	 * @param a The first input tensor.
	 * @param b The second input tensor. Must have the same dtype as `a`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Logical'}
	 */
	function equal_(a, b) {
	  var $a = convertToTensor(a, 'a', 'equal', 'string_or_numeric');
	  var $b = convertToTensor(b, 'b', 'equal', 'string_or_numeric');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  assertAndGetBroadcastShape($a.shape, $b.shape);
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  return ENGINE.runKernel(Equal, inputs);
	}
	var equal$2 = /* @__PURE__ */op({
	  equal_: equal_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Returns the elements, either `a` or `b` depending on the `condition`.
	 *
	 * If the condition is true, select from `a`, otherwise select from `b`.
	 *
	 * ```js
	 * const cond = tf.tensor1d([false, false, true], 'bool');
	 * const a = tf.tensor1d([1 , 2, 3]);
	 * const b = tf.tensor1d([-1, -2, -3]);
	 *
	 * a.where(cond, b).print();
	 * ```
	 *
	 * @param condition The input condition. Must be of dtype bool.
	 * @param a If `condition` is rank 1, `a` may have a higher rank but
	 *     its first dimension must match the size of `condition`.
	 * @param b A tensor with the same dtype as `a` and with shape that is
	 *     compatible with `a`.
	 * @return A tensor with same dtype as `a` and `b`, and shape that is
	 *     broadcastable from `a` and `b`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Logical'}
	 */
	function where_(condition, a, b) {
	  var $a = convertToTensor(a, 'a', 'where');
	  var $b = convertToTensor(b, 'b', 'where');
	  var $condition = convertToTensor(condition, 'condition', 'where', 'bool');
	  // TODO: move this logic to forward function when the broadcastTo op is
	  // implemented in WASM.
	  // Find the broadcastable shape for $condition, $a, and $b.
	  var broadcastShape = assertAndGetBroadcastShape(assertAndGetBroadcastShape($condition.shape, $a.shape), $b.shape);
	  var $broadcastedCondition = broadcastTo($condition, broadcastShape);
	  var $broadcastedA = broadcastTo($a, broadcastShape);
	  var $broadcastedB = broadcastTo($b, broadcastShape);
	  var inputs = {
	    condition: $broadcastedCondition,
	    t: $broadcastedA,
	    e: $broadcastedB
	  };
	  return ENGINE.runKernel(Select, inputs);
	}
	var where = /* @__PURE__ */op({
	  where_: where_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a `tf.Tensor` with all elements set to 0 with the same shape as the
	 * given tensor.
	 *
	 * ```js
	 * const x = tf.tensor([1, 2]);
	 * tf.zerosLike(x).print();
	 * ```
	 *
	 * @param x The tensor of required shape.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function zerosLike_(x) {
	  var $x = convertToTensor(x, 'x', 'zerosLike');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(ZerosLike, inputs);
	}
	var zerosLike$3 = /* @__PURE__ */op({
	  zerosLike_: zerosLike_
	});

	/**
	 * Divides two `tf.Tensor`s element-wise, A / B. Supports broadcasting. Return 0
	 * if denominator is 0.
	 *
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 4, 9, 16]);
	 * const b = tf.tensor1d([1, 2, 3, 4]);
	 * const c = tf.tensor1d([0, 0, 0, 0]);
	 *
	 * a.divNoNan(b).print();  // or tf.divNoNan(a, b)
	 * a.divNoNan(c).print();  // or tf.divNoNan(a, c)
	 * ```
	 *
	 * ```js
	 * // Broadcast div a with b.
	 * const a = tf.tensor1d([2, 4, 6, 8]);
	 * const b = tf.scalar(2);
	 * const c = tf.scalar(0);
	 *
	 * a.divNoNan(b).print();  // or tf.divNoNan(a, b)
	 * a.divNoNan(c).print();  // or tf.divNoNan(a, c)
	 * ```
	 *
	 * @param a The first tensor as the numerator.
	 * @param b The second tensor as the denominator. Must have the same dtype as
	 * `a`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Arithmetic'}
	 */
	function divNoNan_(a, b) {
	  // TODO: Make this into its own kernel.
	  var $a = convertToTensor(a, 'a', 'div');
	  var $b = convertToTensor(b, 'b', 'div');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  var divResult = div$1($a, $b);
	  var zeros = zerosLike$3(divResult);
	  var bEqualsZero = equal$2($b, zeros);
	  return where(bEqualsZero, zeros, divResult);
	}
	var divNoNan = /* @__PURE__ */op({
	  divNoNan_: divNoNan_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the dot product of two matrices and/or vectors, `t1` and `t2`.
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 2]);
	 * const b = tf.tensor2d([[1, 2], [3, 4]]);
	 * const c = tf.tensor2d([[1, 2, 3], [4, 5, 6]]);
	 *
	 * a.dot(b).print();  // or tf.dot(a, b)
	 * b.dot(a).print();
	 * b.dot(c).print();
	 * ```
	 * @param t1 The first tensor in the dot operation.
	 * @param t2 The second tensor in the dot operation.
	 *
	 * @doc {heading: 'Operations', subheading: 'Matrices'}
	 */
	function dot_(t1, t2) {
	  var $t1 = convertToTensor(t1, 't1', 'dot');
	  var $t2 = convertToTensor(t2, 't2', 'dot');
	  assert$1(($t1.rank === 1 || $t1.rank === 2) && ($t2.rank === 1 || $t2.rank === 2), function () {
	    return "Error in dot: inputs must all be rank 1 or 2, but got ranks " + "".concat($t1.rank, " and ").concat($t2.rank, ".");
	  });
	  var t1Inner = $t1.rank === 1 ? $t1.size : $t1.shape[1];
	  var t2Inner = $t2.rank === 1 ? $t2.size : $t2.shape[0];
	  assert$1(t1Inner === t2Inner, function () {
	    return "Error in dot: inner dimensions of inputs must match, but got " + "".concat(t1Inner, " and ").concat(t2Inner, ".");
	  });
	  if ($t1.rank === 1 && $t2.rank === 1) {
	    var t12D = reshape$3($t1, [1, -1]);
	    var t22D = reshape$3($t2, [-1, 1]);
	    var t1t2 = matMul$1(t12D, t22D);
	    return reshape$3(t1t2, []);
	  } else if ($t1.rank === 1 && $t2.rank === 2) {
	    var _t12D = reshape$3($t1, [1, -1]);
	    var _t22D = reshape$3($t2, [$t2.shape[0], $t2.shape[1]]);
	    var _t1t = matMul$1(_t12D, _t22D);
	    return reshape$3(_t1t, [_t1t.size]);
	  } else if ($t1.rank === 2 && $t2.rank === 1) {
	    var _t22D2 = reshape$3($t2, [-1, 1]);
	    var _t1t2 = matMul$1($t1, _t22D2);
	    return reshape$3(_t1t2, [_t1t2.size]);
	  } else {
	    var _t22D3 = reshape$3($t2, [$t2.shape[0], $t2.shape[1]]);
	    var _t1t3 = matMul$1($t1, _t22D3);
	    return _t1t3;
	  }
	}
	var dot$2 = /* @__PURE__ */op({
	  dot_: dot_
	});

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Tensor contraction over specified indices and outer product.
	 *
	 * `einsum` allows defining Tensors by defining their element-wise computation.
	 * This computation is based on
	 * [Einstein summation](https://en.wikipedia.org/wiki/Einstein_notation).
	 *
	 * Some special cases include:
	 *
	 * Matrix multiplication:
	 * ```js
	 * const x = tf.tensor2d([[1, 2, 3], [4, 5, 6]]);
	 * const y = tf.tensor2d([[0, 1], [2, 3], [4, 5]]);
	 * x.print();
	 * y.print();
	 * tf.einsum('ij,jk->ik', x, y).print();
	 * ```
	 *
	 * Dot product:
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3]);
	 * const y = tf.tensor1d([0, 1, 2]);
	 * x.print();
	 * y.print();
	 * tf.einsum('i,i->', x, y).print();
	 * ```
	 *
	 * Batch dot product:
	 * ```js
	 * const x = tf.tensor2d([[1, 2, 3], [4, 5, 6]]);
	 * const y = tf.tensor2d([[0, 1, 2], [3, 4, 5]]);
	 * x.print();
	 * y.print();
	 * tf.einsum('bi,bi->b', x, y).print();
	 * ```
	 *
	 * Outer prouduct:
	 * ```js
	 * const x = tf.tensor1d([1, 3, 5]);
	 * const y = tf.tensor1d([2, 4, 6]);
	 * x.print();
	 * y.print();
	 * tf.einsum('i,j->ij', x, y).print();
	 * ```
	 *
	 * Matrix transpose:
	 * ```js
	 * const x = tf.tensor2d([[1, 2], [3, 4]]);
	 * x.print();
	 * tf.einsum('ij->ji', x).print();
	 * ```
	 *
	 * Batch matrix transpose:
	 * ```js
	 * const x = tf.tensor3d([[[1, 2], [3, 4]], [[-1, -2], [-3, -4]]]);
	 * x.print();
	 * tf.einsum('bij->bji', x).print();
	 * ```
	 *
	 * Limitations:
	 *
	 * This implementation of einsum has the following limitations:
	 *
	 * - Does not support >2 input tensors.
	 * - Does not support duplicate axes for any given input tensor. E.g., equation
	 *   'ii->' is not supported.
	 * - The `...` notation is not supported.
	 *
	 * @param equation a string describing the contraction, in the same format as
	 * [numpy.einsum](https://numpy.org/doc/stable/reference/generated/numpy.einsum.html).
	 * @param tensors the input(s) to contract (each one a Tensor), whose shapes
	 *     should be consistent with equation.
	 * @returns The output tensor.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Matrices'}
	 */
	function einsum_(equation) {
	  for (var _len = arguments.length, tensors = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
	    tensors[_key - 1] = arguments[_key];
	  }
	  var $tensors = tensors.map(function (t, i) {
	    return convertToTensor(t, "tensors".concat(i), 'einsum');
	  });
	  var attrs = {
	    equation: equation
	  };
	  return ENGINE.runKernel(Einsum, $tensors, attrs);
	}
	var einsum$2 = /* @__PURE__ */op({
	  einsum_: einsum_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes exponential linear element-wise: `x > 0 ? x : (e ^ x) - 1`.
	 *
	 * ```js
	 * const x = tf.tensor1d([-1, 1, -3, 2]);
	 *
	 * x.elu().print();  // or tf.elu(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function elu_(x) {
	  var $x = convertToTensor(x, 'x', 'elu', 'float32');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Elu$1, inputs);
	}
	var elu$4 = /* @__PURE__ */op({
	  elu_: elu_
	});

	/**
	 * @license
	 * Copyright 2023 Google LLC.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Checks the input tensor mathes the given shape.
	 *
	 * Given an input tensor, returns a new tensor with the same values as the
	 * input tensor with shape `shape`.
	 *
	 * The method supports the null value in tensor. It will still check the shapes,
	 * and null is a placeholder.
	 *
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3, 4]);
	 * const y = tf.tensor1d([1, null, 3, 4]);
	 * const z = tf.tensor2d([1, 2, 3, 4], [2,2]);
	 * tf.ensureShape(x, [4]).print();
	 * tf.ensureShape(y, [4]).print();
	 * tf.ensureShape(z, [null, 2]).print();
	 * ```
	 *
	 * @param x The input tensor to be ensured.
	 * @param shape A TensorShape representing the shape of this tensor, an array
	 *     or null.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Transformations'}
	 */
	function ensureShape_(x, shape) {
	  var $x = convertToTensor(x, 'x', 'ensureShape', 'string_or_numeric');
	  if (!arraysEqualWithNull($x.shape, shape)) {
	    throw new Error("EnsureShape: Shape of tensor ".concat($x.shape, " is not compatible with expected shape ").concat(shape));
	  }
	  return x;
	}
	var ensureShape = /* @__PURE__ */op({
	  ensureShape_: ensureShape_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes Gauss error function of the input `tf.Tensor` element-wise:
	 * `erf(x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([0, .1, -.1, .7]);
	 *
	 * x.erf().print(); // or tf.erf(x);
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function erf_(x) {
	  var $x = convertToTensor(x, 'x', 'erf');
	  assert$1($x.dtype === 'int32' || $x.dtype === 'float32', function () {
	    return 'Input dtype must be `int32` or `float32`.';
	  });
	  if ($x.dtype === 'int32') {
	    $x = cast$3($x, 'float32');
	  }
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Erf, inputs);
	}
	var erf$2 = /* @__PURE__ */op({
	  erf_: erf_
	});

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Returns true if the axis specifies the inner most dimensions of the
	 * array.
	 */
	function axesAreInnerMostDims(axes, rank) {
	  for (var i = 0; i < axes.length; ++i) {
	    if (axes[axes.length - i - 1] !== rank - 1 - i) {
	      return false;
	    }
	  }
	  return true;
	}
	function combineLocations(outputLoc, reduceLoc, axes) {
	  var rank = outputLoc.length + reduceLoc.length;
	  var loc = [];
	  var outIdx = 0;
	  var reduceIdx = 0;
	  for (var dim = 0; dim < rank; dim++) {
	    if (axes.indexOf(dim) === -1) {
	      loc.push(outputLoc[outIdx++]);
	    } else {
	      loc.push(reduceLoc[reduceIdx++]);
	    }
	  }
	  return loc;
	}
	function computeOutAndReduceShapes(aShape, axes) {
	  var outShape = [];
	  var rank = aShape.length;
	  for (var dim = 0; dim < rank; dim++) {
	    if (axes.indexOf(dim) === -1) {
	      outShape.push(aShape[dim]);
	    }
	  }
	  var reduceShape = axes.map(function (dim) {
	    return aShape[dim];
	  });
	  return [outShape, reduceShape];
	}
	function expandShapeToKeepDim(shape, axes) {
	  var reduceSubShape = axes.map(function (x) {
	    return 1;
	  });
	  return combineLocations(shape, reduceSubShape, axes);
	}
	function assertAxesAreInnerMostDims(msg, axes, rank) {
	  assert$1(axesAreInnerMostDims(axes, rank), function () {
	    return "".concat(msg, " supports only inner-most axes for now. ") + "Got axes ".concat(axes, " and rank-").concat(rank, " input.");
	  });
	}
	/**
	 * Returns the axes permutation to be used with `tf.transpose`, if such
	 * permutation is necessary. Otherwise it returns null. This method is used by
	 * operations that operate only on inner-most axes.
	 */
	function getAxesPermutation(axes, rank) {
	  if (axesAreInnerMostDims(axes, rank)) {
	    return null;
	  }
	  var result = [];
	  for (var i = 0; i < rank; ++i) {
	    if (axes.indexOf(i) === -1) {
	      result.push(i);
	    }
	  }
	  axes.forEach(function (axis) {
	    return result.push(axis);
	  });
	  return result;
	}
	/** Returns the axes permutation that undoes the original permutation. */
	function getUndoAxesPermutation(axes) {
	  return axes.map(function (axis, i) {
	    return [i, axis];
	  }).sort(function (a, b) {
	    return a[1] - b[1];
	  }).map(function (x) {
	    return x[0];
	  });
	}
	function getInnerMostAxes(numAxes, rank) {
	  var res = [];
	  for (var i = rank - numAxes; i < rank; ++i) {
	    res.push(i);
	  }
	  return res;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the maximum of elements across dimensions of a `tf.Tensor`.
	 *
	 * Reduces the input along the dimensions given in `axes`. Unless `keepDims`
	 * is true, the rank of the `tf.Tensor` is reduced by 1 for each entry in
	 * `axes`. If `keepDims` is true, the reduced dimensions are retained with
	 * length 1. If `axes` has no entries, all dimensions are reduced, and a
	 * `tf.Tensor` with a single element is returned.
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3]);
	 *
	 * x.max().print();  // or tf.max(x)
	 * ```
	 *
	 * ```js
	 * const x = tf.tensor2d([1, 2, 3, 4], [2, 2]);
	 *
	 * const axis = 1;
	 * x.max(axis).print();  // or tf.max(x, axis)
	 * ```
	 *
	 * @param x The input tensor.
	 * @param axis The dimension(s) to reduce. By default it reduces
	 *     all dimensions.
	 * @param keepDims If true, retains reduced dimensions with size 1.
	 *
	 * @doc {heading: 'Operations', subheading: 'Reduction'}
	 */
	function max_(x) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
	  var keepDims = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  var $x = convertToTensor(x, 'x', 'max');
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    reductionIndices: axis,
	    keepDims: keepDims
	  };
	  return ENGINE.runKernel(Max, inputs, attrs);
	}
	var max$3 = /* @__PURE__ */op({
	  max_: max_
	});

	/**
	 * @license
	 * Copyright 2020 Google Inc. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the minimum value from the input.
	 *
	 * Reduces the input along the dimensions given in `axes`. Unless `keepDims`
	 * is true, the rank of the array is reduced by 1 for each entry in `axes`.
	 * If `keepDims` is true, the reduced dimensions are retained with length 1.
	 * If `axes` has no entries, all dimensions are reduced, and an array with a
	 * single element is returned.
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3]);
	 *
	 * x.min().print();  // or tf.min(x)
	 * ```
	 *
	 * ```js
	 * const x = tf.tensor2d([1, 2, 3, 4], [2, 2]);
	 *
	 * const axis = 1;
	 * x.min(axis).print();  // or tf.min(x, axis)
	 * ```
	 *
	 * @param x The input Tensor.
	 * @param axis The dimension(s) to reduce. By default it reduces
	 *     all dimensions.
	 * @param keepDims If true, retains reduced dimensions with size 1.
	 *
	 * @doc {heading: 'Operations', subheading: 'Reduction'}
	 */
	function min_(x) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
	  var keepDims = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  var $x = convertToTensor(x, 'x', 'min');
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    axis: axis,
	    keepDims: keepDims
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  return ENGINE.runKernel(Min, inputs, attrs);
	}
	var min$3 = /* @__PURE__ */op({
	  min_: min_
	});

	/**
	 * Computes the power of one `tf.Tensor` to another. Supports broadcasting.
	 *
	 * Given a `tf.Tensor` x and a `tf.Tensor` y, this operation computes x^y for
	 * corresponding elements in x and y. The result's dtype will be the upcasted
	 * type of the `base` and `exp` dtypes.
	 *
	 * ```js
	 * const a = tf.tensor([[2, 3], [4, 5]])
	 * const b = tf.tensor([[1, 2], [3, 0]]).toInt();
	 *
	 * a.pow(b).print();  // or tf.pow(a, b)
	 * ```
	 *
	 * ```js
	 * const a = tf.tensor([[1, 2], [3, 4]])
	 * const b = tf.tensor(2).toInt();
	 *
	 * a.pow(b).print();  // or tf.pow(a, b)
	 * ```
	 * We also expose `powStrict` which has the same signature as this op and
	 * asserts that `base` and `exp` are the same shape (does not broadcast).
	 *
	 * @param base The base `tf.Tensor` to pow element-wise.
	 * @param exp The exponent `tf.Tensor` to pow element-wise.
	 *
	 * @doc {heading: 'Operations', subheading: 'Arithmetic'}
	 */
	function pow_(base, exp) {
	  var $base = convertToTensor(base, 'base', 'pow');
	  var $exp = convertToTensor(exp, 'exp', 'pow');
	  var _makeTypesMatch = makeTypesMatch($base, $exp);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $base = _makeTypesMatch2[0];
	  $exp = _makeTypesMatch2[1];
	  var inputs = {
	    a: $base,
	    b: $exp
	  };
	  return ENGINE.runKernel(Pow, inputs);
	}
	var pow$3 = /* @__PURE__ */op({
	  pow_: pow_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates rank-0 `tf.Tensor` (scalar) with the provided value and dtype.
	 *
	 * The same functionality can be achieved with `tf.tensor`, but in general
	 * we recommend using `tf.scalar` as it makes the code more readable.
	 *
	 * ```js
	 * tf.scalar(3.14).print();
	 * ```
	 *
	 * @param value The value of the scalar.
	 * @param dtype The data type.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function scalar(value, dtype) {
	  if ((isTypedArray(value) && dtype !== 'string' || Array.isArray(value)) && dtype !== 'complex64') {
	    throw new Error('Error creating a new Scalar: value must be a primitive ' + '(number|boolean|string)');
	  }
	  if (dtype === 'string' && isTypedArray(value) && !(value instanceof Uint8Array)) {
	    throw new Error('When making a scalar from encoded string, ' + 'the value must be `Uint8Array`.');
	  }
	  var shape = [];
	  var inferredShape = [];
	  return makeTensor(value, shape, inferredShape, dtype);
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes square root of the input `tf.Tensor` element-wise: `y = sqrt(x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 4, -1]);
	 *
	 * x.sqrt().print();  // or tf.sqrt(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function sqrt_(x) {
	  var $x = convertToTensor(x, 'x', 'sqrt', 'float32');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Sqrt, inputs);
	}
	var sqrt$2 = /* @__PURE__ */op({
	  sqrt_: sqrt_
	});

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes square of `x` element-wise: `x ^ 2`
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, Math.sqrt(2), -1]);
	 *
	 * x.square().print();  // or tf.square(x)
	 * ```
	 * @param x The input Tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function square_(x) {
	  var $x = convertToTensor(x, 'x', 'square');
	  var attrs = {};
	  return ENGINE.runKernel('Square', {
	    x: $x
	  }, attrs);
	}
	var square$2 = /* @__PURE__ */op({
	  square_: square_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the sum of elements across dimensions of a `tf.Tensor`.
	 *
	 * Reduces the input along the dimensions given in `axes`. Unless `keepDims`
	 * is true, the rank of the `tf.Tensor` is reduced by 1 for each entry in
	 * `axes`. If `keepDims` is true, the reduced dimensions are retained with
	 * length 1. If axes has no entries, all dimensions are reduced, and a
	 * `tf.Tensor` with a single element is returned.
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3]);
	 *
	 * x.sum().print();  // or tf.sum(x)
	 * ```
	 *
	 * ```js
	 * const x = tf.tensor2d([1, 2, 3, 4], [2, 2]);
	 *
	 * const axis = 1;
	 * x.sum(axis).print();  // or tf.sum(x, axis)
	 * ```
	 *
	 * @param x The input tensor to compute the sum over. If the dtype is `bool`
	 *   it will be converted to `int32` and the output dtype will be `int32`.
	 * @param axis The dimension(s) to reduce. By default it reduces
	 *     all dimensions.
	 * @param keepDims If true, retains reduced dimensions with size 1.
	 *
	 * @doc {heading: 'Operations', subheading: 'Reduction'}
	 */
	function sum_(x) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
	  var keepDims = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  var $x = convertToTensor(x, 'x', 'sum');
	  if ($x.dtype === 'bool') {
	    $x = cast$3($x, 'int32');
	  }
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    axis: axis,
	    keepDims: keepDims
	  };
	  return ENGINE.runKernel(Sum, inputs, attrs);
	}
	var sum$3 = /* @__PURE__ */op({
	  sum_: sum_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the norm of scalar, vectors, and matrices.
	 * This function can compute several different vector norms (the 1-norm, the
	 * Euclidean or 2-norm, the inf-norm, and in general the p-norm for p > 0)
	 * and matrix norms (Frobenius, 1-norm, and inf-norm).
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3, 4]);
	 *
	 * x.norm().print();  // or tf.norm(x)
	 * ```
	 *
	 * @param x The input array.
	 * @param ord Optional. Order of the norm. Supported norm types are
	 * following:
	 *
	 *  | ord        | norm for matrices         | norm for vectors
	 *  |------------|---------------------------|---------------------
	 *  |'euclidean' |Frobenius norm             |2-norm
	 *  |'fro'       |Frobenius norm	           |
	 *  |Infinity    |max(sum(abs(x), axis=1))   |max(abs(x))
	 *  |-Infinity   |min(sum(abs(x), axis=1))   |min(abs(x))
	 *  |1           |max(sum(abs(x), axis=0))   |sum(abs(x))
	 *  |2           |                           |sum(abs(x)^2)^(1/2)
	 *
	 * @param axis Optional. If axis is null (the default), the input is
	 * considered a vector and a single vector norm is computed over the entire
	 * set of values in the Tensor, i.e. norm(x, ord) is equivalent
	 * to norm(x.reshape([-1]), ord). If axis is an integer, the input
	 * is considered a batch of vectors, and axis determines the axis in x
	 * over which to compute vector norms. If axis is a 2-tuple of integer it is
	 * considered a batch of matrices and axis determines the axes in NDArray
	 * over which to compute a matrix norm.
	 * @param keepDims Optional. If true, the norm has the same dimensionality
	 * as the input.
	 *
	 * @doc {heading: 'Operations', subheading: 'Matrices'}
	 */
	function norm_(x) {
	  var ord = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'euclidean';
	  var axis = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
	  var keepDims = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  x = convertToTensor(x, 'x', 'norm');
	  var norm = normImpl(x, ord, axis);
	  var keepDimsShape = norm.shape;
	  if (keepDims) {
	    var axes = parseAxisParam(axis, x.shape);
	    keepDimsShape = expandShapeToKeepDim(norm.shape, axes);
	  }
	  return reshape$3(norm, keepDimsShape);
	}
	function normImpl(x, p) {
	  var axis = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
	  if (x.rank === 0) {
	    return abs$2(x);
	  }
	  // consider vector when no axis is specified
	  if (x.rank !== 1 && axis === null) {
	    return normImpl(reshape$3(x, [-1]), p, axis);
	  }
	  // vector
	  if (x.rank === 1 || typeof axis === 'number' || Array.isArray(axis) && axis.length === 1) {
	    if (p === 1) {
	      return sum$3(abs$2(x), axis);
	    }
	    if (p === Infinity) {
	      return max$3(abs$2(x), axis);
	    }
	    if (p === -Infinity) {
	      return min$3(abs$2(x), axis);
	    }
	    if (p === 'euclidean' || p === 2) {
	      // norm(x, 2) = sum(abs(xi) ^ 2) ^ 1/2
	      return sqrt$2(sum$3(pow$3(abs$2(x), scalar(2, 'int32')), axis));
	    }
	    throw new Error("Error in norm: invalid ord value: ".concat(p));
	  }
	  // matrix (assumption axis[0] < axis[1])
	  if (Array.isArray(axis) && axis.length === 2) {
	    if (p === 1) {
	      return max$3(sum$3(abs$2(x), axis[0]), axis[1] - 1);
	    }
	    if (p === Infinity) {
	      return max$3(sum$3(abs$2(x), axis[1]), axis[0]);
	    }
	    if (p === -Infinity) {
	      return min$3(sum$3(abs$2(x), axis[1]), axis[0]);
	    }
	    if (p === 'fro' || p === 'euclidean') {
	      // norm(x) = sqrt(sum(pow(x, 2)))
	      return sqrt$2(sum$3(square$2(x), axis));
	    }
	    throw new Error("Error in norm: invalid ord value: ".concat(p));
	  }
	  throw new Error("Error in norm: invalid axis: ".concat(axis));
	}
	var norm = /* @__PURE__ */op({
	  norm_: norm_
	});

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the Euclidean norm of scalar, vectors, and matrices.
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3, 4]);
	 *
	 * x.euclideanNorm().print();  // or tf.euclideanNorm(x)
	 * ```
	 *
	 * @param x The input array.
	 * @param axis Optional. If axis is null (the default), the input is
	 * considered a vector and a single vector norm is computed over the entire
	 * set of values in the Tensor, i.e. euclideanNorm(x) is equivalent
	 * to euclideanNorm(x.reshape([-1])). If axis is an integer, the input
	 * is considered a batch of vectors, and axis determines the axis in x
	 * over which to compute vector norms. If axis is a 2-tuple of integer it is
	 * considered a batch of matrices and axis determines the axes in NDArray
	 * over which to compute a matrix norm.
	 * @param keepDims Optional. If true, the norm has the same dimensionality
	 * as the input.
	 *
	 * @doc {heading: 'Operations', subheading: 'Matrices'}
	 */
	function euclideanNorm_(x) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
	  var keepDims = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  return norm(x, 'euclidean', axis, keepDims);
	}
	var euclideanNorm = /* @__PURE__ */op({
	  euclideanNorm_: euclideanNorm_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes exponential of the input `tf.Tensor` element-wise. `e ^ x`
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, -3]);
	 *
	 * x.exp().print();  // or tf.exp(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function exp_(x) {
	  var $x = convertToTensor(x, 'x', 'exp');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Exp, inputs);
	}
	var exp$2 = /* @__PURE__ */op({
	  exp_: exp_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Returns a `tf.Tensor` that has expanded rank, by inserting a dimension
	 * into the tensor's shape.
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3, 4]);
	 * const axis = 1;
	 * x.expandDims(axis).print();
	 * ```
	 *
	 * @param x The input tensor whose dimensions are to be expanded.
	 * @param axis The dimension index at which to insert shape of `1`. Defaults
	 *     to 0 (the first dimension).
	 *
	 * @doc {heading: 'Tensors', subheading: 'Transformations'}
	 */
	function expandDims_(x) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
	  var $x = convertToTensor(x, 'x', 'expandDims', 'string_or_numeric');
	  assert$1(axis <= $x.rank, function () {
	    return 'Axis must be <= rank of the tensor';
	  });
	  var inputs = {
	    input: $x
	  };
	  var attrs = {
	    dim: axis
	  };
	  return ENGINE.runKernel(ExpandDims, inputs, attrs);
	}
	var expandDims$3 = /* @__PURE__ */op({
	  expandDims_: expandDims_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes exponential of the input `tf.Tensor` minus one element-wise.
	 * `e ^ x - 1`
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, -3]);
	 *
	 * x.expm1().print();  // or tf.expm1(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function expm1_(x) {
	  var $x = convertToTensor(x, 'x', 'expm1');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Expm1, inputs);
	}
	var expm1$2 = /* @__PURE__ */op({
	  expm1_: expm1_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Construct a tensor by repeating it the number of times given by reps.
	 *
	 * This operation creates a new tensor by replicating `input` `reps`
	 * times. The output tensor's `i`th dimension has `input.shape[i] *
	 * reps[i]` elements, and the values of `input` are replicated
	 * `reps[i]` times along the `i`th dimension. For example, tiling
	 * `[a, b, c, d]` by `[2]` produces `[a, b, c, d, a, b, c, d]`.
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 2]);
	 *
	 * a.tile([2]).print();    // or tf.tile(a, [2])
	 * ```
	 *
	 * ```js
	 * const a = tf.tensor2d([1, 2, 3, 4], [2, 2]);
	 *
	 * a.tile([1, 2]).print();  // or tf.tile(a, [1,2])
	 * ```
	 * @param x The tensor to tile.
	 * @param reps Determines the number of replications per dimension.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Slicing and Joining'}
	 */
	function tile_(x, reps) {
	  var $x = convertToTensor(x, 'x', 'tile', 'string_or_numeric');
	  assert$1($x.rank === reps.length, function () {
	    return "Error in transpose: rank of input ".concat($x.rank, " ") + "must match length of reps ".concat(reps, ".");
	  });
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    reps: reps
	  };
	  return ENGINE.runKernel(Tile, inputs, attrs);
	}
	var tile$3 = /* @__PURE__ */op({
	  tile_: tile_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Create an identity matrix.
	 *
	 * @param numRows Number of rows.
	 * @param numColumns Number of columns. Defaults to `numRows`.
	 * @param batchShape If provided, will add the batch shape to the beginning
	 *   of the shape of the returned `tf.Tensor` by repeating the identity
	 *   matrix.
	 * @param dtype Data type.
	 * @returns Identity matrix of the specified size and data type, possibly
	 *   with batch repetition if `batchShape` is specified.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function eye_(numRows, numColumns, batchShape) {
	  var dtype = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'float32';
	  if (numColumns == null) {
	    numColumns = numRows;
	  }
	  var buff = buffer([numRows, numColumns], dtype);
	  var n = numRows <= numColumns ? numRows : numColumns;
	  for (var i = 0; i < n; ++i) {
	    buff.set(1, i, i);
	  }
	  var out = reshape$3(buff.toTensor(), [numRows, numColumns]);
	  if (batchShape == null) {
	    return out;
	  } else {
	    if (batchShape.length === 1) {
	      return tile$3(expandDims$3(out, 0), [batchShape[0], 1, 1]);
	    } else if (batchShape.length === 2) {
	      // tslint:disable-next-line:no-unnecessary-type-assertion
	      return tile$3(expandDims$3(expandDims$3(out, 0), 0), [batchShape[0], batchShape[1], 1, 1]);
	    } else if (batchShape.length === 3) {
	      // tslint:disable-next-line:no-unnecessary-type-assertion
	      return tile$3(expandDims$3(expandDims$3(expandDims$3(out, 0), 0), 0), [batchShape[0], batchShape[1], batchShape[2], 1, 1]);
	    } else {
	      throw new Error("eye() currently supports only 1D and 2D " + // tslint:disable-next-line:no-any
	      "batchShapes, but received ".concat(batchShape.length, "D."));
	    }
	  }
	}
	var eye = /* @__PURE__ */op({
	  eye_: eye_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes floor of input `tf.Tensor` element-wise: `floor(x)`.
	 *
	 * ```js
	 * const x = tf.tensor1d([.6, 1.1, -3.3]);
	 *
	 * x.floor().print();  // or tf.floor(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function floor_(x) {
	  var $x = convertToTensor(x, 'x', 'floor', 'float32');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Floor, inputs);
	}
	var floor$2 = /* @__PURE__ */op({
	  floor_: floor_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Gather slices from tensor `x`'s axis `axis` according to `indices`.
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3, 4]);
	 * const indices = tf.tensor1d([1, 3, 3], 'int32');
	 *
	 * x.gather(indices).print();
	 * ```
	 *
	 * ```js
	 * const x = tf.tensor2d([1, 2, 3, 4], [2, 2]);
	 * const indices = tf.tensor1d([1, 1, 0], 'int32');
	 *
	 * x.gather(indices).print();
	 * ```
	 * @param x The input tensor whose slices are to be gathered.
	 * @param indices The indices of the values to extract.
	 * @param axis The axis over which to select values. Defaults to 0.
	 * @param batchDims Optional. The number of batch dimensions. It must be less
	 *     than or equal to rank(indices). Defaults to 0.
	 *     The output tensor will have shape of
	 *     `x.shape[:axis] + indices.shape[batchDims:] + x.shape[axis + 1:]`
	 *
	 * @doc {heading: 'Tensors', subheading: 'Slicing and Joining'}
	 */
	function gather_(x, indices) {
	  var axis = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
	  var batchDims = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 0;
	  var $x = convertToTensor(x, 'x', 'gather');
	  var $indices = convertToTensor(indices, 'indices', 'gather', 'int32');
	  var inputs = {
	    x: $x,
	    indices: $indices
	  };
	  var attrs = {
	    axis: axis,
	    batchDims: batchDims
	  };
	  return ENGINE.runKernel(GatherV2, inputs, attrs);
	}
	var gather$1 = /* @__PURE__ */op({
	  gather_: gather_
	});

	/**
	 * Returns the truth value of (a > b) element-wise. Supports broadcasting.
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 2, 3]);
	 * const b = tf.tensor1d([2, 2, 2]);
	 *
	 * a.greater(b).print();
	 * ```
	 *
	 * @param a The first input tensor.
	 * @param b The second input tensor. Must have the same dtype as `a`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Logical'}
	 */
	function greater_(a, b) {
	  var $a = convertToTensor(a, 'a', 'greater', 'string_or_numeric');
	  var $b = convertToTensor(b, 'b', 'greater', 'string_or_numeric');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  assertAndGetBroadcastShape($a.shape, $b.shape);
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  return ENGINE.runKernel(Greater, inputs);
	}
	var greater$3 = /* @__PURE__ */op({
	  greater_: greater_
	});

	/**
	 * Returns the truth value of (a >= b) element-wise. Supports broadcasting.
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 2, 3]);
	 * const b = tf.tensor1d([2, 2, 2]);
	 *
	 * a.greaterEqual(b).print();
	 * ```
	 *
	 * @param a The first input tensor.
	 * @param b The second input tensor. Must have the same dtype as `a`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Logical'}
	 */
	function greaterEqual_(a, b) {
	  var $a = convertToTensor(a, 'a', 'greaterEqual', 'string_or_numeric');
	  var $b = convertToTensor(b, 'b', 'greaterEqual', 'string_or_numeric');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  assertAndGetBroadcastShape($a.shape, $b.shape);
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  return ENGINE.runKernel(GreaterEqual, inputs);
	}
	var greaterEqual$2 = /* @__PURE__ */op({
	  greaterEqual_: greaterEqual_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Returns the imaginary part of a complex (or real) tensor.
	 *
	 * Given a tensor input, this operation returns a tensor of type float that is
	 * the imaginary part of each element in input considered as a complex number.
	 * If input is real, a tensor of all zeros is returned.
	 *
	 * ```js
	 * const x = tf.complex([-2.25, 3.25], [4.75, 5.75]);
	 * tf.imag(x).print();
	 * ```
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function imag_(input) {
	  var $input = convertToTensor(input, 'input', 'imag');
	  var inputs = {
	    input: $input
	  };
	  return ENGINE.runKernel(Imag, inputs);
	}
	var imag$2 = /* @__PURE__ */op({
	  imag_: imag_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Returns which elements of x are finite.
	 *
	 * ```js
	 * const x = tf.tensor1d([NaN, Infinity, -Infinity, 0, 1]);
	 *
	 * x.isFinite().print();  // or tf.isNaN(x)
	 * ```
	 * @param x The input Tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function isFinite_(x) {
	  var $x = convertToTensor(x, 'x', 'isFinite');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(IsFinite, inputs);
	}
	var isFinite$3 = /* @__PURE__ */op({
	  isFinite_: isFinite_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Returns which elements of x are Infinity or -Infinity.
	 *
	 * ```js
	 * const x = tf.tensor1d([NaN, Infinity, -Infinity, 0, 1]);
	 *
	 * x.isInf().print();  // or tf.isNaN(x)
	 * ```
	 * @param x The input Tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function isInf_(x) {
	  var $x = convertToTensor(x, 'x', 'isInf');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(IsInf, inputs);
	}
	var isInf$2 = /* @__PURE__ */op({
	  isInf_: isInf_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Returns which elements of x are NaN.
	 *
	 * ```js
	 * const x = tf.tensor1d([NaN, Infinity, -Infinity, 0, 1]);
	 *
	 * x.isNaN().print();  // or tf.isNaN(x)
	 * ```
	 * @param x The input Tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function isNaN_(x) {
	  var $x = convertToTensor(x, 'x', 'isNaN');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(IsNan, inputs);
	}
	var isNaN$3 = /* @__PURE__ */op({
	  isNaN_: isNaN_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes leaky rectified linear element-wise.
	 *
	 * See
	 * [http://web.stanford.edu/~awni/papers/relu_hybrid_icml2013_final.pdf](
	 *     http://web.stanford.edu/~awni/papers/relu_hybrid_icml2013_final.pdf)
	 *
	 * ```js
	 * const x = tf.tensor1d([-1, 2, -3, 4]);
	 *
	 * x.leakyRelu(0.1).print();  // or tf.leakyRelu(x, 0.1)
	 * ```
	 * @param x The input tensor.
	 * @param alpha The scaling factor for negative values, defaults to 0.2.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function leakyRelu_(x) {
	  var alpha = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0.2;
	  var $x = convertToTensor(x, 'x', 'leakyRelu');
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    alpha: alpha
	  };
	  return ENGINE.runKernel(LeakyRelu, inputs, attrs);
	}
	var leakyRelu$2 = /* @__PURE__ */op({
	  leakyRelu_: leakyRelu_
	});

	/**
	 * Returns the truth value of (a < b) element-wise. Supports broadcasting.
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 2, 3]);
	 * const b = tf.tensor1d([2, 2, 2]);
	 *
	 * a.less(b).print();
	 * ```
	 * @param a The first input tensor.
	 * @param b The second input tensor. Must have the same dtype as `a`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Logical'}
	 */
	function less_(a, b) {
	  var $a = convertToTensor(a, 'a', 'less', 'string_or_numeric');
	  var $b = convertToTensor(b, 'b', 'less', 'string_or_numeric');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  assertAndGetBroadcastShape($a.shape, $b.shape);
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  return ENGINE.runKernel(Less, inputs);
	}
	var less$3 = /* @__PURE__ */op({
	  less_: less_
	});

	/**
	 * Returns the truth value of (a <= b) element-wise. Supports broadcasting.
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 2, 3]);
	 * const b = tf.tensor1d([2, 2, 2]);
	 *
	 * a.lessEqual(b).print();
	 * ```
	 *
	 * @param a The first input tensor.
	 * @param b The second input tensor. Must have the same dtype as `a`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Logical'}
	 */
	function lessEqual_(a, b) {
	  var $a = convertToTensor(a, 'a', 'lessEqual', 'string_or_numeric');
	  var $b = convertToTensor(b, 'b', 'lessEqual', 'string_or_numeric');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  assertAndGetBroadcastShape($a.shape, $b.shape);
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  return ENGINE.runKernel(LessEqual, inputs);
	}
	var lessEqual$2 = /* @__PURE__ */op({
	  lessEqual_: lessEqual_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Return an evenly spaced sequence of numbers over the given interval.
	 *
	 * ```js
	 * tf.linspace(0, 9, 10).print();
	 * ```
	 * @param start The start value of the sequence.
	 * @param stop The end value of the sequence.
	 * @param num The number of values to generate.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function linspace(start, stop, num) {
	  if (num <= 0) {
	    throw new Error('The number of values should be positive.');
	  }
	  var attrs = {
	    start: start,
	    stop: stop,
	    num: num
	  };
	  return ENGINE.runKernel(LinSpace, {}, attrs);
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Normalizes the activation of a local neighborhood across or within
	 * channels.
	 *
	 * @param x The input tensor. The 4-D input tensor is treated as a 3-D array
	 *     of 1D vectors (along the last dimension), and each vector is
	 *     normalized independently.
	 * @param depthRadius The number of adjacent channels in the 1D normalization
	 *     window.
	 * @param bias A constant bias term for the basis.
	 * @param alpha A scale factor, usually positive.
	 * @param beta An exponent.
	 *
	 * @doc {heading: 'Operations', subheading: 'Normalization'}
	 */
	function localResponseNormalization_(x) {
	  var depthRadius = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 5;
	  var bias = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;
	  var alpha = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 1;
	  var beta = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 0.5;
	  var $x = convertToTensor(x, 'x', 'localResponseNormalization');
	  assert$1($x.rank === 4 || $x.rank === 3, function () {
	    return "Error in localResponseNormalization: x must be rank 3 or 4 but got\n               rank ".concat($x.rank, ".");
	  });
	  assert$1(isInt(depthRadius), function () {
	    return "Error in localResponseNormalization: depthRadius must be an " + "integer but got depthRadius ".concat(depthRadius, ".");
	  });
	  var x4D = $x;
	  var reshapedTo4D = false;
	  if ($x.rank === 3) {
	    reshapedTo4D = true;
	    x4D = reshape$3($x, [1, $x.shape[0], $x.shape[1], $x.shape[2]]);
	  }
	  var inputs = {
	    x: x4D
	  };
	  var attrs = {
	    depthRadius: depthRadius,
	    bias: bias,
	    alpha: alpha,
	    beta: beta
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var res = ENGINE.runKernel(LRN, inputs, attrs);
	  if (reshapedTo4D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3]]);
	  } else {
	    return res;
	  }
	}
	var localResponseNormalization = /* @__PURE__ */op({
	  localResponseNormalization_: localResponseNormalization_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes natural logarithm of the input `tf.Tensor` element-wise: `ln(x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, Math.E]);
	 *
	 * x.log().print();  // or tf.log(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function log_(x) {
	  var $x = convertToTensor(x, 'x', 'log', 'float32');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Log, inputs);
	}
	var log$2 = /* @__PURE__ */op({
	  log_: log_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes natural logarithm of the input `tf.Tensor` plus one
	 * element-wise: `ln(1 + x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, Math.E - 1]);
	 *
	 * x.log1p().print();  // or tf.log1p(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function log1p_(x) {
	  var $x = convertToTensor(x, 'x', 'log1p');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Log1p, inputs);
	}
	var log1p$2 = /* @__PURE__ */op({
	  log1p_: log1p_
	});

	/**
	 * Provided `f(x)`, returns another function `g(x, dy?)`, which gives the
	 * gradient of `f(x)` with respect to `x`.
	 *
	 * If `dy` is provided, the gradient of `f(x).mul(dy).sum()` with respect to
	 * `x` is computed instead. `f(x)` must take a single tensor `x` and return a
	 * single tensor `y`. If `f()` takes multiple inputs, use `tf.grads` instead.
	 *
	 * ```js
	 * // f(x) = x ^ 2
	 * const f = x => x.square();
	 * // f'(x) = 2x
	 * const g = tf.grad(f);
	 *
	 * const x = tf.tensor1d([2, 3]);
	 * g(x).print();
	 * ```
	 *
	 * ```js
	 * // f(x) = x ^ 3
	 * const f = x => x.pow(tf.scalar(3, 'int32'));
	 * // f'(x) = 3x ^ 2
	 * const g = tf.grad(f);
	 * // f''(x) = 6x
	 * const gg = tf.grad(g);
	 *
	 * const x = tf.tensor1d([2, 3]);
	 * gg(x).print();
	 * ```
	 *
	 * @param f The function f(x), to compute gradient for.
	 *
	 * @doc {heading: 'Training', subheading: 'Gradients'}
	 */
	function grad(f) {
	  assert$1(isFunction(f), function () {
	    return 'The f passed in grad(f) must be a function';
	  });
	  return function (x, dy) {
	    // x can be of any dtype, thus null as the last argument.
	    var $x = convertToTensor(x, 'x', 'tf.grad', 'string_or_numeric');
	    var $dy = dy != null ? convertToTensor(dy, 'dy', 'tf.grad') : null;
	    return ENGINE.tidy(function () {
	      var _ENGINE$gradients = ENGINE.gradients(function () {
	          return f($x);
	        }, [$x], $dy),
	        value = _ENGINE$gradients.value,
	        grads = _ENGINE$gradients.grads;
	      if ($dy != null) {
	        assertShapesMatch(value.shape, $dy.shape, 'The shape of dy passed in grad(f)(x, dy) must match the shape ' + 'returned by f(x)');
	      }
	      checkGrads(grads);
	      return grads[0];
	    });
	  };
	}
	/**
	 * Provided `f(x1, x2,...)`, returns another function `g([x1, x2,...], dy?)`,
	 * which gives an array of gradients of `f()` with respect to each input
	 * [`x1`,`x2`,...].
	 *
	 * If `dy` is passed when calling `g()`, the gradient of
	 * `f(x1,...).mul(dy).sum()` with respect to each input is computed instead.
	 * The provided `f` must take one or more tensors and return a single tensor
	 * `y`. If `f()` takes a single input, we recommend using `tf.grad` instead.
	 *
	 * ```js
	 * // f(a, b) = a * b
	 * const f = (a, b) => a.mul(b);
	 * // df / da = b, df / db = a
	 * const g = tf.grads(f);
	 *
	 * const a = tf.tensor1d([2, 3]);
	 * const b = tf.tensor1d([-2, -3]);
	 * const [da, db] = g([a, b]);
	 * console.log('da');
	 * da.print();
	 * console.log('db');
	 * db.print();
	 * ```
	 *
	 * @param f The function `f(x1, x2,...)` to compute gradients for.
	 *
	 * @doc {heading: 'Training', subheading: 'Gradients'}
	 */
	function grads(f) {
	  assert$1(isFunction(f), function () {
	    return 'The f passed in grads(f) must be a function';
	  });
	  return function (args, dy) {
	    assert$1(Array.isArray(args), function () {
	      return 'The args passed in grads(f)(args) must be an array ' + 'of `Tensor`s or `TensorLike`s';
	    });
	    // args can be of any dtype, thus null as the last argument.
	    var $args = convertToTensorArray(args, 'args', 'tf.grads', 'string_or_numeric');
	    var $dy = dy != null ? convertToTensor(dy, 'dy', 'tf.grads') : null;
	    return ENGINE.tidy(function () {
	      var _ENGINE$gradients2 = ENGINE.gradients(function () {
	          return f.apply(void 0, _toConsumableArray($args));
	        }, $args, $dy),
	        value = _ENGINE$gradients2.value,
	        grads = _ENGINE$gradients2.grads;
	      if ($dy != null) {
	        assertShapesMatch(value.shape, $dy.shape, 'The shape of dy passed in grads(f)([x1,...], dy) must ' + 'match the shape returned by f([x1,...])');
	      }
	      checkGrads(grads);
	      return grads;
	    });
	  };
	}
	/**
	 * Like `tf.grad`, but also returns the value of `f()`. Useful when `f()`
	 * returns a metric you want to show.
	 *
	 * The result is a rich object with the following properties:
	 * - grad: The gradient of `f(x)` w.r.t. `x` (result of `tf.grad`).
	 * - value: The value returned by `f(x)`.
	 *
	 * ```js
	 * // f(x) = x ^ 2
	 * const f = x => x.square();
	 * // f'(x) = 2x
	 * const g = tf.valueAndGrad(f);
	 *
	 * const x = tf.tensor1d([2, 3]);
	 * const {value, grad} = g(x);
	 *
	 * console.log('value');
	 * value.print();
	 * console.log('grad');
	 * grad.print();
	 * ```
	 *
	 * @doc {heading: 'Training', subheading: 'Gradients'}
	 */
	function valueAndGrad(f) {
	  assert$1(isFunction(f), function () {
	    return 'The f passed in valueAndGrad(f) must be a function';
	  });
	  return function (x, dy) {
	    assert$1(x instanceof Tensor, function () {
	      return 'The x passed in valueAndGrad(f)(x) must be a tensor';
	    });
	    assert$1(dy == null || dy instanceof Tensor, function () {
	      return 'The dy passed in valueAndGrad(f)(x, dy) must be a tensor';
	    });
	    var _ENGINE$gradients3 = ENGINE.gradients(function () {
	        return f(x);
	      }, [x], dy),
	      grads = _ENGINE$gradients3.grads,
	      value = _ENGINE$gradients3.value;
	    checkGrads(grads);
	    return {
	      grad: grads[0],
	      value: value
	    };
	  };
	}
	/**
	 * Like `tf.grads`, but returns also the value of `f()`. Useful when `f()`
	 * returns a metric you want to show.
	 *
	 * The result is a rich object with the following properties:
	 * - grads: The gradients of `f()` w.r.t. each input (result of `tf.grads`).
	 * - value: The value returned by `f(x)`.
	 *
	 * ```js
	 * // f(a, b) = a * b
	 * const f = (a, b) => a.mul(b);
	 * // df/da = b, df/db = a
	 * const g = tf.valueAndGrads(f);
	 *
	 * const a = tf.tensor1d([2, 3]);
	 * const b = tf.tensor1d([-2, -3]);
	 * const {value, grads} = g([a, b]);
	 *
	 * const [da, db] = grads;
	 *
	 * console.log('value');
	 * value.print();
	 *
	 * console.log('da');
	 * da.print();
	 * console.log('db');
	 * db.print();
	 * ```
	 *
	 * @doc {heading: 'Training', subheading: 'Gradients'}
	 */
	function valueAndGrads(f) {
	  assert$1(isFunction(f), function () {
	    return 'The f passed in valueAndGrads(f) must be a function';
	  });
	  return function (args, dy) {
	    assert$1(Array.isArray(args) && args.every(function (arg) {
	      return arg instanceof Tensor;
	    }), function () {
	      return 'The args passed in valueAndGrads(f)(args) must be array of ' + 'tensors';
	    });
	    assert$1(dy == null || dy instanceof Tensor, function () {
	      return 'The dy passed in valueAndGrads(f)(args, dy) must be a tensor';
	    });
	    var res = ENGINE.gradients(function () {
	      return f.apply(void 0, _toConsumableArray(args));
	    }, args, dy);
	    if (dy != null) {
	      assertShapesMatch(res.value.shape, dy.shape, 'The shape of dy passed in valueAndGrads(f)([x1,...], dy) must ' + 'match the shape returned by f([x1,...])');
	    }
	    checkGrads(res.grads);
	    return res;
	  };
	}
	/**
	 * Computes and returns the gradient of f(x) with respect to the list of
	 * trainable variables provided by `varList`. If no list is provided, it
	 * defaults to all trainable variables.
	 *
	 * ```js
	 * const a = tf.variable(tf.tensor1d([3, 4]));
	 * const b = tf.variable(tf.tensor1d([5, 6]));
	 * const x = tf.tensor1d([1, 2]);
	 *
	 * // f(a, b) = a * x ^ 2 + b * x
	 * const f = () => a.mul(x.square()).add(b.mul(x)).sum();
	 * // df/da = x ^ 2, df/db = x
	 * const {value, grads} = tf.variableGrads(f);
	 *
	 * Object.keys(grads).forEach(varName => grads[varName].print());
	 * ```
	 *
	 * @param f The function to execute. f() should return a scalar.
	 * @param varList The list of variables to compute the gradients with respect
	 *     to. Defaults to all trainable variables.
	 * @returns An object with the following keys and values:
	 *   - `value`: The value of the function `f`.
	 *   - `grads`: A map from the names of the variables to the gradients.
	 *     If the `varList` argument is provided explicitly and contains a subset of
	 *     non-trainable variables, this map in the return value will contain keys
	 *     that map the names of the non-trainable variables to `null`.
	 *
	 * @doc {heading: 'Training', subheading: 'Gradients'}
	 */
	function variableGrads(f, varList) {
	  assert$1(isFunction(f), function () {
	    return 'The f passed in variableGrads(f) must be a function';
	  });
	  assert$1(varList == null || Array.isArray(varList) && varList.every(function (v) {
	    return v instanceof Variable;
	  }), function () {
	    return 'The varList passed in variableGrads(f, varList) must be an array ' + 'of variables';
	  });
	  var specifiedVarList = varList != null;
	  if (!specifiedVarList) {
	    // Get all of the trainable variables.
	    varList = [];
	    for (var varName in ENGINE.registeredVariables) {
	      varList.push(ENGINE.registeredVariables[varName]);
	    }
	  }
	  var specifiedNonTrainable = specifiedVarList ? varList.filter(function (variable) {
	    return !variable.trainable;
	  }) : null;
	  // Prune non-trainable variables.
	  var originalVarCount = varList.length;
	  varList = varList.filter(function (variable) {
	    return variable.trainable;
	  });
	  assert$1(varList.length > 0, function () {
	    return "variableGrads() expects at least one of the input variables to " + "be trainable, but none of the ".concat(originalVarCount, " variables is ") + "trainable.";
	  });
	  var allowNoGradients = true;
	  var _ENGINE$gradients4 = ENGINE.gradients(f, varList, null, allowNoGradients),
	    value = _ENGINE$gradients4.value,
	    grads = _ENGINE$gradients4.grads;
	  assert$1(grads.some(function (g) {
	    return g != null;
	  }), function () {
	    return 'Cannot find a connection between any variable and the result of ' + 'the loss function y=f(x). Please make sure the operations that ' + 'use variables are inside the function f passed to minimize().';
	  });
	  assert$1(value.rank === 0, function () {
	    return "The f passed in variableGrads(f) must return a scalar, but it " + "returned a rank-".concat(value.rank, " tensor");
	  });
	  var namedGrads = {};
	  varList.forEach(function (v, i) {
	    if (grads[i] != null) {
	      namedGrads[v.name] = grads[i];
	    }
	  });
	  if (specifiedNonTrainable != null) {
	    // If varList is explicitly provided and contains non-trainable values,
	    // add them to the returned gradients with `null` values.
	    specifiedNonTrainable.forEach(function (v) {
	      return namedGrads[v.name] = null;
	    });
	  }
	  return {
	    value: value,
	    grads: namedGrads
	  };
	}
	/**
	 * Overrides the gradient computation of a function `f`.
	 *
	 * Takes a function
	 * `f(...inputs, save) => {value: Tensor, gradFunc: (dy, saved) => Tensor[]}`
	 * and returns another function `g(...inputs)` which takes the same inputs as
	 * `f`. When called, `g` returns `f().value`. In backward mode, custom gradients
	 * with respect to each input of `f` are computed using `f().gradFunc`.
	 *
	 * The `save` function passed to `f` should be used for saving tensors needed
	 * in the gradient. And the `saved` passed to the `gradFunc` is a
	 * `NamedTensorMap`, which contains those saved tensors.
	 *
	 * ```js
	 * const customOp = tf.customGrad((x, save) => {
	 *   // Save x to make sure it's available later for the gradient.
	 *   save([x]);
	 *   // Override gradient of our custom x ^ 2 op to be dy * abs(x);
	 *   return {
	 *     value: x.square(),
	 *     // Note `saved.x` which points to the `x` we saved earlier.
	 *     gradFunc: (dy, saved) => [dy.mul(saved[0].abs())]
	 *   };
	 * });
	 *
	 * const x = tf.tensor1d([-1, -2, 3]);
	 * const dx = tf.grad(x => customOp(x));
	 *
	 * console.log(`f(x):`);
	 * customOp(x).print();
	 * console.log(`f'(x):`);
	 * dx(x).print();
	 * ```
	 *
	 * @param f The function to evaluate in forward mode, which should return
	 *     `{value: Tensor, gradFunc: (dy, saved) => Tensor[]}`, where `gradFunc`
	 *     returns the custom gradients of `f` with respect to its inputs.
	 *
	 * @doc {heading: 'Training', subheading: 'Gradients'}
	 */
	function customGrad(f) {
	  return ENGINE.customGrad(f);
	}
	function checkGrads(grads) {
	  var numNullGradients = grads.filter(function (g) {
	    return g == null;
	  }).length;
	  if (numNullGradients > 0) {
	    throw new Error("Cannot compute gradient of y=f(x) with respect to x. Make sure that\n    the f you passed encloses all operations that lead from x to y.");
	  }
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes `-1 * x` element-wise.
	 *
	 * ```js
	 * const x = tf.tensor2d([1, 2, -2, 0], [2, 2]);
	 *
	 * x.neg().print();  // or tf.neg(x)
	 * ```
	 *
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function neg_(x) {
	  var $x = convertToTensor(x, 'x', 'neg');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Neg, inputs);
	}
	var neg$2 = /* @__PURE__ */op({
	  neg_: neg_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes softplus of the input `tf.Tensor` element-wise: `log(exp(x) + 1)`
	 *
	 * ```js
	 * const x = tf.tensor1d([0, 1, -1, .7]);
	 *
	 * x.softplus().print();  // or tf.softplus(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function softplus_(x) {
	  var $x = convertToTensor(x, 'x', 'softplus');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Softplus$1, inputs);
	}
	var softplus$2 = /* @__PURE__ */op({
	  softplus_: softplus_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes log sigmoid of the input `tf.Tensor` element-wise:
	 * `logSigmoid(x)`. For numerical stability, we use `-tf.softplus(-x)`.
	 *
	 * ```js
	 * const x = tf.tensor1d([0, 1, -1, .7]);
	 *
	 * x.logSigmoid().print();  // or tf.logSigmoid(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function logSigmoid_(x) {
	  var $x = convertToTensor(x, 'x', 'logSigmoid');
	  // Use a custom gradient to maintain previous implementation.
	  // There is no LogSigmoid kernel in TF so we can't use engine.runKernel
	  // directly
	  var customOp = customGrad(function (x) {
	    // TODO(yassogba) we can remove the chained softplus call here only
	    // after backends have modualrized softplus at which point we can call
	    // engine runKernel(..., Sotfplus, ...) directly.
	    var value = neg$2(softplus$2(neg$2(x)));
	    var gradFunc = function gradFunc(dy) {
	      var derX = mul(dy, sigmoid$2(neg$2(x)));
	      return derX;
	    };
	    return {
	      value: value,
	      gradFunc: gradFunc
	    };
	  });
	  return customOp($x);
	}
	var logSigmoid = /* @__PURE__ */op({
	  logSigmoid_: logSigmoid_
	});

	/**
	 * Subtracts two `tf.Tensor`s element-wise, A - B. Supports broadcasting.
	 *
	 * ```js
	 * const a = tf.tensor1d([10, 20, 30, 40]);
	 * const b = tf.tensor1d([1, 2, 3, 4]);
	 *
	 * a.sub(b).print();  // or tf.sub(a, b)
	 * ```
	 *
	 * ```js
	 * // Broadcast subtract a with b.
	 * const a = tf.tensor1d([10, 20, 30, 40]);
	 * const b = tf.scalar(5);
	 *
	 * a.sub(b).print();  // or tf.sub(a, b)
	 * ```
	 * @param a The first `tf.Tensor` to subtract from.
	 * @param b The second `tf.Tensor` to be subtracted. Must have the same dtype as
	 * `a`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Arithmetic'}
	 */
	function sub_(a, b) {
	  var $a = convertToTensor(a, 'a', 'sub');
	  var $b = convertToTensor(b, 'b', 'sub');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  return ENGINE.runKernel(Sub, inputs);
	}
	var sub$2 = /* @__PURE__ */op({
	  sub_: sub_
	});

	/**
	 * Computes the log softmax.
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 2, 3]);
	 *
	 * a.logSoftmax().print();  // or tf.logSoftmax(a)
	 * ```
	 *
	 * ```js
	 * const a = tf.tensor2d([2, 4, 6, 1, 2, 3], [2, 3]);
	 *
	 * a.logSoftmax().print();  // or tf.logSoftmax(a)
	 * ```
	 *
	 * @param logits The logits array.
	 * @param axis The dimension softmax would be performed on. Defaults to `-1`
	 *     which indicates the last dimension.
	 *
	 * @doc {heading: 'Operations', subheading: 'Normalization'}
	 */
	function logSoftmax_(logits) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : -1;
	  var $logits = convertToTensor(logits, 'logits', 'logSoftmax');
	  if (axis === -1) {
	    axis = $logits.rank - 1;
	  }
	  if (axis !== $logits.rank - 1) {
	    throw Error('Log Softmax along a non-last dimension is not yet supported. ' + "Logits was rank ".concat($logits.rank, " and axis was ").concat(axis));
	  }
	  // const forward: ForwardFunc<Tensor> = (backend, save) => {
	  //   const keepDims = true;
	  //   const xMax = max(logits, axis, true);
	  //   const shifted = sub(logits, xMax);
	  //   const value =
	  //       sub(cast(shifted, 'float32'), log(sum(exp(shifted), axis,
	  //       keepDims)));
	  //   save([value]);
	  //   return value;
	  // };
	  // Use a custom gradient for numerical stability.
	  var customOp = customGrad(function (logits, save) {
	    var keepDims = true;
	    var xMax = max$3(logits, axis, true);
	    var shifted = sub$2(logits, xMax);
	    var value = sub$2(cast$3(shifted, 'float32'), log$2(sum$3(exp$2(shifted), axis, keepDims)));
	    save([value]);
	    var gradFunc = function gradFunc(dy, saved) {
	      var _saved = _slicedToArray(saved, 1),
	        value = _saved[0];
	      var keepDims = true;
	      var softmax = exp$2(value);
	      return sub$2(dy, mul(sum$3(dy, axis, keepDims), softmax));
	    };
	    return {
	      value: value,
	      gradFunc: gradFunc
	    };
	  });
	  return customOp($logits);
	  // TODO Use Engine.runKernel when CPU/WebGL/WASM backends implement this.
	  // const inputs: LogSoftmaxInputs = {logits: $logits};
	  // const attrs: LogSoftmaxAttrs = {axis};
	  // return ENGINE.runKernel(
	  //            LogSoftmax, inputs as unknown as NamedTensorMap,
	  //            attrs as unknown as NamedAttrMap);
	}

	var logSoftmax = /* @__PURE__ */op({
	  logSoftmax_: logSoftmax_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the log(sum(exp(elements across the reduction dimensions))).
	 *
	 * Reduces the input along the dimensions given in `axis`. Unless `keepDims`
	 * is true, the rank of the array is reduced by 1 for each entry in `axis`.
	 * If `keepDims` is true, the reduced dimensions are retained with length 1.
	 * If `axis` has no entries, all dimensions are reduced, and an array with a
	 * single element is returned.
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3]);
	 *
	 * x.logSumExp().print();  // or tf.logSumExp(x)
	 * ```
	 *
	 * ```js
	 * const x = tf.tensor2d([1, 2, 3, 4], [2, 2]);
	 *
	 * const axis = 1;
	 * x.logSumExp(axis).print();  // or tf.logSumExp(a, axis)
	 * ```
	 * @param x The input tensor.
	 * @param axis The dimension(s) to reduce. If null (the default),
	 *     reduces all dimensions.
	 * @param keepDims If true, retains reduced dimensions with length
	 *     of 1. Defaults to false.
	 *
	 * @doc {heading: 'Operations', subheading: 'Reduction'}
	 */
	function logSumExp_(x) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
	  var keepDims = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  var $x = convertToTensor(x, 'x', 'logSumExp');
	  var axes = parseAxisParam(axis, $x.shape);
	  var xMax = max$3($x, axes, true /* keepDims */);
	  var a = sub$2($x, xMax);
	  var b = exp$2(a);
	  var c = sum$3(b, axes);
	  var d = log$2(c);
	  var res = add$3(reshape$3(xMax, d.shape), d);
	  if (keepDims) {
	    var newShape = expandShapeToKeepDim(res.shape, axes);
	    return reshape$3(res, newShape);
	  }
	  return res;
	}
	var logSumExp = /* @__PURE__ */op({
	  logSumExp_: logSumExp_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Returns the truth value of `a AND b` element-wise. Supports broadcasting.
	 *
	 * ```js
	 * const a = tf.tensor1d([false, false, true, true], 'bool');
	 * const b = tf.tensor1d([false, true, false, true], 'bool');
	 *
	 * a.logicalAnd(b).print();
	 * ```
	 *
	 * @param a The first input tensor. Must be of dtype bool.
	 * @param b The second input tensor. Must be of dtype bool.
	 *
	 * @doc {heading: 'Operations', subheading: 'Logical'}
	 */
	function logicalAnd_(a, b) {
	  var $a = convertToTensor(a, 'a', 'logicalAnd', 'bool');
	  var $b = convertToTensor(b, 'b', 'logicalAnd', 'bool');
	  assertAndGetBroadcastShape($a.shape, $b.shape);
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  return ENGINE.runKernel(LogicalAnd, inputs);
	}
	var logicalAnd$2 = /* @__PURE__ */op({
	  logicalAnd_: logicalAnd_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Returns the truth value of `NOT x` element-wise.
	 *
	 * ```js
	 * const a = tf.tensor1d([false, true], 'bool');
	 *
	 * a.logicalNot().print();
	 * ```
	 *
	 * @param x The input tensor. Must be of dtype 'bool'.
	 *
	 * @doc {heading: 'Operations', subheading: 'Logical'}
	 */
	function logicalNot_(x) {
	  var $x = convertToTensor(x, 'x', 'logicalNot', 'bool');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(LogicalNot, inputs);
	}
	var logicalNot$2 = /* @__PURE__ */op({
	  logicalNot_: logicalNot_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Returns the truth value of `a OR b` element-wise. Supports broadcasting.
	 *
	 * ```js
	 * const a = tf.tensor1d([false, false, true, true], 'bool');
	 * const b = tf.tensor1d([false, true, false, true], 'bool');
	 *
	 * a.logicalOr(b).print();
	 * ```
	 * @param a The first input tensor. Must be of dtype bool.
	 * @param b The second input tensor. Must be of dtype bool.
	 *
	 * @doc {heading: 'Operations', subheading: 'Logical'}
	 */
	function logicalOr_(a, b) {
	  var $a = convertToTensor(a, 'a', 'logicalOr', 'bool');
	  var $b = convertToTensor(b, 'b', 'logicalOr', 'bool');
	  assertAndGetBroadcastShape($a.shape, $b.shape);
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  return ENGINE.runKernel(LogicalOr, inputs);
	}
	var logicalOr$2 = /* @__PURE__ */op({
	  logicalOr_: logicalOr_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Returns the truth value of `a XOR b` element-wise. Supports broadcasting.
	 *
	 * ```js
	 * const a = tf.tensor1d([false, false, true, true], 'bool');
	 * const b = tf.tensor1d([false, true, false, true], 'bool');
	 *
	 * a.logicalXor(b).print();
	 * ```
	 *
	 * @param a The first input tensor. Must be of dtype bool.
	 * @param b The second input tensor. Must be of dtype bool.
	 *
	 * @doc {heading: 'Operations', subheading: 'Logical'}
	 */
	function logicalXor_(a, b) {
	  var $a = convertToTensor(a, 'a', 'logicalXor', 'bool');
	  var $b = convertToTensor(b, 'b', 'logicalXor', 'bool');
	  assertAndGetBroadcastShape($a.shape, $b.shape);
	  // x ^ y = (x | y) & ~(x & y)
	  return logicalAnd$2(logicalOr$2(a, b), logicalNot$2(logicalAnd$2(a, b)));
	}
	var logicalXor = /* @__PURE__ */op({
	  logicalXor_: logicalXor_
	});

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var INT32_MAX$1 = 2147483648;
	/**
	 * Searches for where a value would go in a sorted sequence.
	 *
	 * This is not a method for checking containment (like javascript in).
	 *
	 * The typical use case for this operation is "binning", "bucketing", or
	 * "discretizing". The values are assigned to bucket-indices based on the edges
	 * listed in 'sortedSequence'. This operation returns the bucket-index for each
	 * value.
	 *
	 * The side argument controls which index is returned if a value lands exactly
	 * on an edge.
	 *
	 * The axis is not settable for this operation. It always operates on the
	 * innermost dimension (axis=-1). The operation will accept any number of outer
	 * dimensions.
	 *
	 * Note: This operation assumes that 'sortedSequence' is sorted along the
	 * innermost axis, maybe using 'sort(..., axis=-1)'. If the sequence is not
	 * sorted no error is raised and the content of the returned tensor is not well
	 * defined.
	 *
	 * ```js
	 * const edges = tf.tensor1d([-1, 3.3, 9.1, 10.0]);
	 * let values = tf.tensor1d([0.0, 4.1, 12.0]);
	 * const result1 = tf.searchSorted(edges, values, 'left');
	 * result1.print(); // [1, 2, 4]
	 *
	 * const seq = tf.tensor1d([0, 3, 9, 10, 10]);
	 * values = tf.tensor1d([0, 4, 10]);
	 * const result2 = tf.searchSorted(seq, values, 'left');
	 * result2.print(); // [0, 2, 3]
	 * const result3 = tf.searchSorted(seq, values, 'right');
	 * result3.print(); // [1, 2, 5]
	 *
	 * const sortedSequence = tf.tensor2d([[0., 3., 8., 9., 10.],
	 *                                     [1., 2., 3., 4., 5.]]);
	 * values = tf.tensor2d([[9.8, 2.1, 4.3],
	 *                       [0.1, 6.6, 4.5, ]]);
	 * const result4 = tf.searchSorted(sortedSequence, values, 'left');
	 * result4.print(); // [[4, 1, 2], [0, 5, 4]]
	 * ```
	 * @param sortedSequence: N-D. Sorted sequence.
	 * @param values: N-D. Search values.
	 * @param side: 'left'|'right'. Defaults to 'left'. 'left' corresponds to lower
	 *     bound and 'right' to upper bound.
	 * @return An N-D int32 tensor the size of values containing the result of
	 *     applying either lower bound or upper bound (depending on side) to each
	 *     value. The result is not a global index to the entire Tensor, but the
	 *     index in the last dimension.
	 * @doc {heading: 'Operations', subheading: 'Evaluation'}
	 */
	function searchSorted_(sortedSequence, values) {
	  var side = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'left';
	  var $sortedSequence = convertToTensor(sortedSequence, 'sortedSequence', 'searchSorted');
	  var $values = convertToTensor(values, 'values', 'searchSorted');
	  var sequenceSize = $sortedSequence.shape[$sortedSequence.shape.length - 1];
	  var valuesSize = $values.shape[$values.shape.length - 1];
	  var $sortedSequence2D = reshape$3($sortedSequence, [-1, sequenceSize]);
	  var $values2D = reshape$3($values, [-1, valuesSize]);
	  if ($sortedSequence2D.rank < 2) {
	    throw new Error("Sorted input argument must be at least 2-dimensional");
	  }
	  if ($sortedSequence2D.shape[0] !== $values2D.shape[0]) {
	    throw new Error("Leading dimension of 'sortedSequence' and 'values' must match.");
	  }
	  if (sizeFromShape($values2D.shape) >= INT32_MAX$1) {
	    throw new Error("values tensor size must less than ".concat(INT32_MAX$1));
	  }
	  if ($sortedSequence2D.shape[1] >= INT32_MAX$1) {
	    throw new Error("trailing dim_size must less than ".concat(INT32_MAX$1, " for int32 output type, was ").concat($sortedSequence2D.shape[1]));
	  }
	  var inputs = {
	    sortedSequence: $sortedSequence2D,
	    values: $values2D
	  };
	  var attrs = {
	    side: side
	  };
	  return ENGINE.runKernel(SearchSorted, inputs, attrs);
	}
	var searchSorted$2 = /* @__PURE__ */op({
	  searchSorted_: searchSorted_
	});

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Searches for where a value would go in a sorted sequence.
	 *
	 * This is not a method for checking containment (like javascript in).
	 *
	 * The typical use case for this operation is "binning", "bucketing", or
	 * "discretizing". The values are assigned to bucket-indices based on the edges
	 * listed in 'sortedSequence'. This operation returns the bucket-index for each
	 * value.
	 *
	 * The index returned corresponds to the first edge greater than or equal to the
	 * value.
	 *
	 * The axis is not settable for this operation. It always operates on the
	 * innermost dimension (axis=-1). The operation will accept any number of outer
	 * dimensions.
	 *
	 * Note: This operation assumes that 'lowerBound' is sorted along the
	 * innermost axis, maybe using 'sort(..., axis=-1)'. If the sequence is not
	 * sorted no error is raised and the content of the returned tensor is not well
	 * defined.
	 *
	 * ```js
	 * const edges = tf.tensor1d([-1, 3.3, 9.1, 10.0]);
	 * let values = tf.tensor1d([0.0, 4.1, 12.0]);
	 * const result1 = tf.lowerBound(edges, values);
	 * result1.print(); // [1, 2, 4]
	 *
	 * const seq = tf.tensor1d([0, 3, 9, 10, 10]);
	 * values = tf.tensor1d([0, 4, 10]);
	 * const result2 = tf.lowerBound(seq, values);
	 * result2.print(); // [0, 2, 3]
	 *
	 * const sortedSequence = tf.tensor2d([[0., 3., 8., 9., 10.],
	 *                                     [1., 2., 3., 4., 5.]]);
	 * values = tf.tensor2d([[9.8, 2.1, 4.3],
	 *                       [0.1, 6.6, 4.5, ]]);
	 * const result3 = tf.lowerBound(sortedSequence, values);
	 * result3.print(); // [[4, 1, 2], [0, 5, 4]]
	 * ```
	 * @param sortedSequence: N-D. Sorted sequence.
	 * @param values: N-D. Search values.
	 * @return An N-D int32 tensor the size of values containing the result of
	 *     applying lower bound to each value. The result is not a global index to
	 *     the entire Tensor, but the index in the last dimension.
	 * @doc {heading: 'Operations', subheading: 'Evaluation'}
	 */
	function lowerBound$1(sortedSequence, values) {
	  return searchSorted$2(sortedSequence, values, 'left');
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the 2D max pooling of an image.
	 *
	 * @param x The input tensor, of rank 4 or rank 3 of shape
	 *     `[batch, height, width, inChannels]`. If rank 3, batch of 1 is assumed.
	 * @param filterSize The filter size: `[filterHeight, filterWidth]`. If
	 *     `filterSize` is a single number, then `filterHeight == filterWidth`.
	 * @param strides The strides of the pooling: `[strideHeight, strideWidth]`. If
	 *     `strides` is a single number, then `strideHeight == strideWidth`.
	 * @param dilations The dilation rates: `[dilationHeight, dilationWidth]`
	 *     in which we sample input values across the height and width dimensions
	 *     in dilated pooling. Defaults to `[1, 1]`. If `dilations` is a single
	 *     number, then `dilationHeight == dilationWidth`. If it is greater than
	 *     1, then all values of `strides` must be 1.
	 * @param pad The type of padding algorithm.
	 *    - `same` and stride 1: output will be of same size as input,
	 *       regardless of filter size.
	 *    - `valid`: output will be smaller than input if filter is larger
	 *       than 1x1.
	 *    - For more info, see this guide:
	 *     [https://www.tensorflow.org/api_docs/python/tf/nn/convolution](
	 *          https://www.tensorflow.org/api_docs/python/tf/nn/convolution)
	 * @param dimRoundingMode A string from: 'ceil', 'round', 'floor'. If none is
	 *     provided, it will default to truncate.
	 */
	function maxPool_(x, filterSize, strides, pad, dimRoundingMode) {
	  var $x = convertToTensor(x, 'x', 'maxPool');
	  var dilations = 1;
	  var x4D = $x;
	  var reshapedTo4D = false;
	  if ($x.rank === 3) {
	    reshapedTo4D = true;
	    x4D = reshape$3($x, [1, $x.shape[0], $x.shape[1], $x.shape[2]]);
	  }
	  assert$1(x4D.rank === 4, function () {
	    return "Error in maxPool: input must be rank 4 but got rank ".concat(x4D.rank, ".");
	  });
	  assert$1(eitherStridesOrDilationsAreOne(strides, dilations), function () {
	    return 'Error in maxPool: Either strides or dilations must be 1. ' + "Got strides ".concat(strides, " and dilations '").concat(dilations, "'");
	  });
	  checkPadOnDimRoundingMode('maxPool', pad, dimRoundingMode);
	  var inputs = {
	    x: x4D
	  };
	  var attrs = {
	    filterSize: filterSize,
	    strides: strides,
	    pad: pad,
	    dimRoundingMode: dimRoundingMode
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var res = ENGINE.runKernel(MaxPool, inputs, attrs);
	  if (reshapedTo4D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3]]);
	  }
	  return res;
	}
	var maxPool$2 = /* @__PURE__ */op({
	  maxPool_: maxPool_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the 3D max pooling.
	 *
	 * ```js
	 * const x = tf.tensor5d([1, 2, 3, 4, 5, 6, 7, 8], [1, 2, 2, 2, 1]);
	 * const result = tf.maxPool3d(x, 2, 1, 'valid');
	 * result.print();
	 * ```
	 *
	 * @param x The input tensor, of rank 5 or rank 4 of shape
	 *     `[batch, depth, height, width, inChannels]`.
	 * @param filterSize The filter size:
	 *     `[filterDepth, filterHeight, filterWidth]`.
	 *     If `filterSize` is a single number,
	 *     then `filterDepth == filterHeight == filterWidth`.
	 * @param strides The strides of the pooling:
	 *     `[strideDepth, strideHeight, strideWidth]`.
	 *     If `strides` is a single number,
	 *     then `strideDepth == strideHeight == strideWidth`.
	 * @param pad The type of padding algorithm.
	 *    - `same` and stride 1: output will be of same size as input,
	 *       regardless of filter size.
	 *    - `valid`: output will be smaller than input if filter is larger
	 *       than 1*1x1.
	 *    - For more info, see this guide:
	 *     [https://www.tensorflow.org/api_docs/python/tf/nn/convolution](
	 *          https://www.tensorflow.org/api_docs/python/tf/nn/convolution)
	 * @param dimRoundingMode A string from: 'ceil', 'round', 'floor'. If none is
	 *     provided, it will default to truncate.
	 * @param dataFormat An optional string from: "NDHWC", "NCDHW". Defaults to
	 *     "NDHWC". Specify the data format of the input and output data. With the
	 *     default format "NDHWC", the data is stored in the order of: [batch,
	 *     depth, height, width, channels]. Only "NDHWC" is currently supported.
	 * @doc {heading: 'Operations', subheading: 'Convolution'}
	 */
	function maxPool3d_(x) {
	  var filterSize = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [1, 1, 1];
	  var strides = arguments.length > 2 ? arguments[2] : undefined;
	  var pad = arguments.length > 3 ? arguments[3] : undefined;
	  var dimRoundingMode = arguments.length > 4 ? arguments[4] : undefined;
	  var dataFormat = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : 'NDHWC';
	  var $x = convertToTensor(x, 'x', 'maxPool3d');
	  var x5D = $x;
	  var reshapedTo5D = false;
	  if ($x.rank === 4) {
	    reshapedTo5D = true;
	    x5D = reshape$3($x, [1, $x.shape[0], $x.shape[1], $x.shape[2], $x.shape[3]]);
	  }
	  assert$1(x5D.rank === 5, function () {
	    return "Error in maxPool3d: x must be rank 5 but got rank ".concat(x5D.rank, ".");
	  });
	  assert$1(dataFormat === 'NDHWC', function () {
	    return "Error in maxPool3d: Only NDHWC is currently supported, " + "but got dataFormat of ".concat(dataFormat);
	  });
	  checkPadOnDimRoundingMode('maxPool3d', pad, dimRoundingMode);
	  var inputs = {
	    x: x5D
	  };
	  var attrs = {
	    filterSize: filterSize,
	    strides: strides,
	    pad: pad,
	    dimRoundingMode: dimRoundingMode,
	    dataFormat: dataFormat
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var res = ENGINE.runKernel(MaxPool3D, inputs, attrs);
	  if (reshapedTo5D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3], res.shape[4]]);
	  }
	  return res;
	}
	var maxPool3d$1 = /* @__PURE__ */op({
	  maxPool3d_: maxPool3d_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the 2D max pooling of an image with Argmax index.
	 * The indices in argmax are flattened, so that a maximum value at position `[b,
	 * y, x, c]` becomes flattened index: `(y * width + x) * channels + c` if
	 * include_batch_in_index is False; `((b * height + y) * width + x) * channels
	 * +c` if include_batch_in_index is True.
	 *
	 * The indices returned are always in `[0, height) x [0, width)` before
	 * flattening.
	 *
	 * @param x The input tensor, of rank 4 or rank 3 of shape
	 *     `[batch, height, width, inChannels]`. If rank 3, batch of 1 is assumed.
	 * @param filterSize The filter size: `[filterHeight, filterWidth]`. If
	 *     `filterSize` is a single number, then `filterHeight == filterWidth`.
	 * @param strides The strides of the pooling: `[strideHeight, strideWidth]`. If
	 *     `strides` is a single number, then `strideHeight == strideWidth`.
	 * @param dataFormat An optional string from: "NDHWC", "NCDHW". Defaults to
	 *     "NDHWC". Specify the data format of the input and output data. With the
	 *     default format "NDHWC", the data is stored in the order of: [batch,
	 *     depth, height, width, channels]. Only "NDHWC" is currently supported.
	 * @param pad The type of padding algorithm.
	 *    - `same` and stride 1: output will be of same size as input,
	 *       regardless of filter size.
	 *    - `valid`: output will be smaller than input if filter is larger
	 *       than 1x1.
	 *    - For more info, see this guide:
	 *     [https://www.tensorflow.org/api_docs/python/tf/nn/convolution](
	 *          https://www.tensorflow.org/api_docs/python/tf/nn/convolution)
	 * @param includeBatchIndex Defaults to False. Whether to include batch
	 *    dimension in flattened index of argmax.
	 *
	 * @doc {heading: 'Operations', subheading: 'Convolution'}
	 */
	function maxPoolWithArgmax_(x, filterSize, strides, pad) {
	  var includeBatchInIndex = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
	  var $x = convertToTensor(x, 'x', 'maxPoolWithArgmax');
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    filterSize: filterSize,
	    strides: strides,
	    pad: pad,
	    includeBatchInIndex: includeBatchInIndex
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var result = ENGINE.runKernel(MaxPoolWithArgmax, inputs, attrs);
	  return {
	    result: result[0],
	    indexes: result[1]
	  };
	}
	var maxPoolWithArgmax = /* @__PURE__ */op({
	  maxPoolWithArgmax_: maxPoolWithArgmax_
	});

	/**
	 * Returns the max of a and b (`a > b ? a : b`) element-wise.
	 * Supports broadcasting.
	 *
	 * We also expose `tf.maximumStrict` which has the same signature as this op and
	 * asserts that `a` and `b` are the same shape (does not broadcast).
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 4, 3, 16]);
	 * const b = tf.tensor1d([1, 2, 9, 4]);
	 *
	 * a.maximum(b).print();  // or tf.maximum(a, b)
	 * ```
	 *
	 * ```js
	 * // Broadcast maximum a with b.
	 * const a = tf.tensor1d([2, 4, 6, 8]);
	 * const b = tf.scalar(5);
	 *
	 * a.maximum(b).print();  // or tf.maximum(a, b)
	 * ```
	 *
	 * @param a The first tensor.
	 * @param b The second tensor. Must have the same type as `a`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Arithmetic'}
	 */
	function maximum_(a, b) {
	  var $a = convertToTensor(a, 'a', 'maximum');
	  var $b = convertToTensor(b, 'b', 'maximum');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  if ($a.dtype === 'bool') {
	    $a = cast$3($a, 'int32');
	    $b = cast$3($b, 'int32');
	  }
	  assertAndGetBroadcastShape($a.shape, $b.shape);
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  return ENGINE.runKernel(Maximum$1, inputs);
	}
	var maximum$4 = /* @__PURE__ */op({
	  maximum_: maximum_
	});

	/**
	 * @license
	 * Copyright 2020 Google Inc. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the mean of elements across dimensions of a `tf.Tensor`.
	 *
	 * Reduces `x` along the dimensions given in `axis`. Unless `keepDims` is
	 * true, the rank of the `tf.Tensor` is reduced by 1 for each entry in `axis`.
	 * If `keepDims` is true, the reduced dimensions are retained with length 1.
	 * If `axis` has no entries, all dimensions are reduced, and a `tf.Tensor` with
	 * a single element is returned.
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3]);
	 *
	 * x.mean().print();  // or tf.mean(a)
	 * ```
	 *
	 * ```js
	 * const x = tf.tensor2d([1, 2, 3, 4], [2, 2]);
	 *
	 * const axis = 1;
	 * x.mean(axis).print();  // or tf.mean(x, axis)
	 * ```
	 *
	 * @param x The input tensor.
	 * @param axis The dimension(s) to reduce. By default it reduces
	 *     all dimensions.
	 * @param keepDims If true, retains reduced dimensions with size 1.
	 *
	 * @doc {heading: 'Operations', subheading: 'Reduction'}
	 */
	function mean_(x) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
	  var keepDims = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  var $x = convertToTensor(x, 'x', 'mean');
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    axis: axis,
	    keepDims: keepDims
	  };
	  return ENGINE.runKernel(Mean, inputs, attrs);
	}
	var mean$3 = /* @__PURE__ */op({
	  mean_: mean_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a `tf.Tensor` with all elements set to 0.
	 *
	 * ```js
	 * tf.zeros([2, 2]).print();
	 * ```
	 *
	 * @param shape An array of integers defining the output tensor shape.
	 * @param dtype The type of an element in the resulting tensor. Can
	 *     be 'float32', 'int32' or 'bool'. Defaults to 'float'.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function zeros$2(shape) {
	  var dtype = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'float32';
	  assertNonNegativeIntegerDimensions(shape);
	  if (dtype === 'complex64') {
	    var real = zeros$2(shape, 'float32');
	    var imag = zeros$2(shape, 'float32');
	    return complex$2(real, imag);
	  }
	  var values = makeZerosTypedArray(sizeFromShape(shape), dtype);
	  return ENGINE.makeTensor(values, shape, dtype);
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a `tf.Tensor` with all elements set to 1.
	 *
	 * ```js
	 * tf.ones([2, 2]).print();
	 * ```
	 *
	 * @param shape An array of integers defining the output tensor shape.
	 * @param dtype The type of an element in the resulting tensor. Defaults to
	 *     'float'.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function ones$1(shape) {
	  var dtype = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'float32';
	  assertNonNegativeIntegerDimensions(shape);
	  if (dtype === 'complex64') {
	    var real = ones$1(shape, 'float32');
	    var imag = zeros$2(shape, 'float32');
	    return complex$2(real, imag);
	  }
	  var values = makeOnesTypedArray(sizeFromShape(shape), dtype);
	  return ENGINE.makeTensor(values, shape, dtype);
	}

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Broadcasts parameters for evaluation on an N-D grid.
	 *
	 * Given N one-dimensional coordinate arrays `*args`, returns a list `outputs`
	 * of N-D coordinate arrays for evaluating expressions on an N-D grid.
	 *
	 * Notes:
	 * `meshgrid` supports cartesian ('xy') and matrix ('ij') indexing conventions.
	 * When the `indexing` argument is set to 'xy' (the default), the broadcasting
	 * instructions for the first two dimensions are swapped.
	 * Examples:
	 * Calling `const [X, Y] = meshgrid(x, y)` with the tensors
	 *
	 * ```javascript
	 * const x = [1, 2, 3];
	 * const y = [4, 5, 6];
	 * const [X, Y] = tf.meshgrid(x, y);
	 * // X = [[1, 2, 3],
	 * //      [1, 2, 3],
	 * //      [1, 2, 3]]
	 * // Y = [[4, 4, 4],
	 * //      [5, 5, 5],
	 * //      [6, 6, 6]]
	 * ```
	 *
	 * @param x Tensor with rank geq 1.
	 * @param y Tensor with rank geq 1.
	 * @param indexing
	 *
	 * @doc {heading: 'Operations', subheading: 'Slicing and Joining'}
	 */
	function meshgrid(x, y) {
	  var _ref = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {},
	    _ref$indexing = _ref.indexing,
	    indexing = _ref$indexing === void 0 ? 'xy' : _ref$indexing;
	  if (indexing !== 'xy' && indexing !== 'ij') {
	    throw new TypeError("".concat(indexing, " is not a valid third argument to meshgrid"));
	  }
	  if (x === undefined) {
	    return [];
	  }
	  var $x = convertToTensor(x, 'x', 'meshgrid', x instanceof Tensor ? x.dtype : 'float32');
	  if (y === undefined) {
	    return [$x];
	  }
	  var $y = convertToTensor(y, 'y', 'meshgrid', y instanceof Tensor ? y.dtype : 'float32');
	  var w = sizeFromShape($x.shape);
	  var h = sizeFromShape($y.shape);
	  if (indexing === 'xy') {
	    $x = reshape$3($x, [1, -1]);
	    $y = reshape$3($y, [-1, 1]);
	    return [matMul$1(ones$1([h, 1], $x.dtype), $x), matMul$1($y, ones$1([1, w], $y.dtype))];
	  }
	  $x = reshape$3($x, [-1, 1]);
	  $y = reshape$3($y, [1, -1]);
	  return [matMul$1($x, ones$1([1, h], $x.dtype)), matMul$1(ones$1([w, 1], $y.dtype), $y)];
	}

	/**
	 * Returns the min of a and b (`a < b ? a : b`) element-wise.
	 * Supports broadcasting.
	 *
	 * We also expose `minimumStrict` which has the same signature as this op and
	 * asserts that `a` and `b` are the same shape (does not broadcast).
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 4, 3, 16]);
	 * const b = tf.tensor1d([1, 2, 9, 4]);
	 *
	 * a.minimum(b).print();  // or tf.minimum(a, b)
	 * ```
	 *
	 * ```js
	 * // Broadcast minimum a with b.
	 * const a = tf.tensor1d([2, 4, 6, 8]);
	 * const b = tf.scalar(5);
	 *
	 * a.minimum(b).print();  // or tf.minimum(a, b)
	 * ```
	 *
	 * @param a The first tensor.
	 * @param b The second tensor. Must have the same type as `a`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Arithmetic'}
	 */
	function minimum_(a, b) {
	  var $a = convertToTensor(a, 'a', 'minimum');
	  var $b = convertToTensor(b, 'b', 'minimum');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  if ($a.dtype === 'bool') {
	    $a = cast$3($a, 'int32');
	    $b = cast$3($b, 'int32');
	  }
	  assertAndGetBroadcastShape($a.shape, $b.shape);
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  return ENGINE.runKernel(Minimum$1, inputs);
	}
	var minimum$4 = /* @__PURE__ */op({
	  minimum_: minimum_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Pads a `tf.Tensor` using mirror padding.
	 *
	 * This operation implements the `REFLECT` and `SYMMETRIC` modes of pad.
	 *
	 * ```js
	 * const x = tf.range(0, 9).reshape([1, 1, 3, 3]);
	 * x.mirrorPad([[0, 0], [0, 0], [2, 2], [2, 2]], 'reflect').print();
	 * ```
	 * @param x The tensor to pad.
	 * @param paddings An array of length `R` (the rank of the tensor), where
	 * each element is a length-2 tuple of ints `[padBefore, padAfter]`,
	 * specifying how much to pad along each dimension of the tensor.
	 * In "reflect" mode, the padded regions do not include the borders,
	 * while in "symmetric" mode the padded regions do include the borders.
	 * For example, if the input is `[1, 2, 3]` and paddings is `[0, 2]`,
	 * then the output is `[1, 2, 3, 2, 1]` in "reflect" mode, and
	 * `[1, 2, 3, 3, 2]` in "symmetric" mode.
	 * If `mode` is "reflect" then both `paddings[D, 0]` and `paddings[D, 1]`
	 * must be no greater than `x.shape[D] - 1`. If mode is "symmetric"
	 * then both `paddings[D, 0]` and `paddings[D, 1]` must be no greater than
	 * `x.shape[D]`
	 * @param mode String to specify padding mode. Can be `'reflect' | 'symmetric'`
	 */
	/** @doc {heading: 'Tensors', subheading: 'Transformations'} */
	function mirrorPad_(x, paddings, mode) {
	  assert$1(mode === 'reflect' || mode === 'symmetric', function () {
	    return "Invalid mode. Mode must be either reflect or symmetric. " + "Got ".concat(mode, ".");
	  });
	  var $x = convertToTensor(x, 'x', 'mirrorPad');
	  if ($x.rank === 0) {
	    throw new Error('mirrorPad(scalar) is not defined. ' + 'Pass non-scalar to mirrorPad');
	  }
	  assert$1(paddings.length === $x.rank, function () {
	    return "Padding doesn't match input. Must be ".concat($x.rank, ". ") + "Got ".concat(paddings.length, ".");
	  });
	  var shapeOffset = mode === 'reflect' ? 1 : 0;
	  var _loop = function _loop(i) {
	    assert$1(paddings[i].length === 2, function () {
	      return "Invalid number of paddings. Must be length of 2 each.";
	    });
	    assert$1(paddings[i][0] >= 0 && paddings[i][0] <= $x.shape[i] - shapeOffset && paddings[i][1] >= 0 && paddings[i][1] <= $x.shape[i] - shapeOffset, function () {
	      return "Padding in dimension ".concat(i, " cannot be greater than or equal ") + "to ".concat($x.shape[i] - shapeOffset, " or less than 0 for input of ") + "shape ".concat($x.shape);
	    });
	  };
	  for (var i = 0; i < $x.rank; i++) {
	    _loop(i);
	  }
	  var attrs = {
	    paddings: paddings,
	    mode: mode
	  };
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(MirrorPad, inputs, attrs);
	}
	var mirrorPad$1 = /* @__PURE__ */op({
	  mirrorPad_: mirrorPad_
	});

	/**
	 * Returns the mod of a and b element-wise.
	 * `floor(x / y) * y + mod(x, y) = x`
	 * Supports broadcasting.
	 *
	 * We also expose `tf.modStrict` which has the same signature as this op and
	 * asserts that `a` and `b` are the same shape (does not broadcast).
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 4, 3, 16]);
	 * const b = tf.tensor1d([1, 2, 9, 4]);
	 *
	 * a.mod(b).print();  // or tf.mod(a, b)
	 * ```
	 *
	 * ```js
	 * // Broadcast a mod b.
	 * const a = tf.tensor1d([2, 4, 6, 8]);
	 * const b = tf.scalar(5);
	 *
	 * a.mod(b).print();  // or tf.mod(a, b)
	 * ```
	 *
	 * @param a The first tensor.
	 * @param b The second tensor. Must have the same type as `a`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Arithmetic'}
	 */
	function mod_(a, b) {
	  var $a = convertToTensor(a, 'a', 'mod');
	  var $b = convertToTensor(b, 'b', 'mod');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  return ENGINE.runKernel(Mod, inputs);
	}
	var mod$2 = /* @__PURE__ */op({
	  mod_: mod_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Calculates the mean and variance of `x`. The mean and variance are
	 * calculated by aggregating the contents of `x` across `axes`. If `x` is
	 * 1-D and `axes = [0]` this is just the mean and variance of a vector.
	 *
	 * @param x The input tensor.
	 * @param axis The dimension(s) along with to compute mean and
	 *     variance. By default it reduces all dimensions.
	 * @param keepDims If true, the moments have the same dimensionality as the
	 *     input.
	 * @return An object with two keys: `mean` and `variance`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Normalization'}
	 */
	function moments_(x) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
	  var keepDims = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  x = convertToTensor(x, 'x', 'moments');
	  var axes = parseAxisParam(axis, x.shape);
	  var xMean = mean$3(x, axes, keepDims);
	  var keepDimsShape = xMean.shape;
	  if (!keepDims) {
	    keepDimsShape = expandShapeToKeepDim(xMean.shape, axes);
	  }
	  var devSquared = square$2(sub$2(cast$3(x, 'float32'), reshape$3(xMean, keepDimsShape)));
	  var variance = mean$3(devSquared, axes, keepDims);
	  return {
	    mean: xMean,
	    variance: variance
	  };
	}
	var moments = /* @__PURE__ */op({
	  moments_: moments_
	});

	/**
	 * Computes the next states and outputs of a stack of LSTMCells.
	 *
	 * Each cell output is used as input to the next cell.
	 *
	 * Returns `[cellState, cellOutput]`.
	 *
	 * Derived from tf.contrib.rn.MultiRNNCell.
	 *
	 * @param lstmCells Array of LSTMCell functions.
	 * @param data The input to the cell.
	 * @param c Array of previous cell states.
	 * @param h Array of previous cell outputs.
	 *
	 * @doc {heading: 'Operations', subheading: 'RNN'}
	 */
	function multiRNNCell_(lstmCells, data, c, h) {
	  var $data = convertToTensor(data, 'data', 'multiRNNCell');
	  var $c = convertToTensorArray(c, 'c', 'multiRNNCell');
	  var $h = convertToTensorArray(h, 'h', 'multiRNNCell');
	  var input = $data;
	  var newStates = [];
	  for (var i = 0; i < lstmCells.length; i++) {
	    var output = lstmCells[i](input, $c[i], $h[i]);
	    newStates.push(output[0]);
	    newStates.push(output[1]);
	    input = output[1];
	  }
	  var newC = [];
	  var newH = [];
	  for (var _i = 0; _i < newStates.length; _i += 2) {
	    newC.push(newStates[_i]);
	    newH.push(newStates[_i + 1]);
	  }
	  return [newC, newH];
	}
	var multiRNNCell = /* @__PURE__ */op({
	  multiRNNCell_: multiRNNCell_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a `tf.Tensor` with values drawn from a multinomial distribution.
	 *
	 * ```js
	 * const probs = tf.tensor([.75, .25]);
	 * tf.multinomial(probs, 3).print();
	 * ```
	 *
	 * @param logits 1D array with unnormalized log-probabilities, or
	 *     2D array of shape `[batchSize, numOutcomes]`. See the `normalized`
	 *     parameter.
	 * @param numSamples Number of samples to draw for each row slice.
	 * @param seed The seed number.
	 * @param normalized Whether the provided `logits` are normalized true
	 *     probabilities (sum to 1). Defaults to false.
	 * @return 1D array of shape `[numSamples]`, or 2D array of shape
	 *     `[batchSize, numSamples]`, depending on the rank of the input.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Random'}
	 */
	function multinomial_(logits, numSamples, seed) {
	  var normalized = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var $logits = convertToTensor(logits, 'logits', 'multinomial');
	  var numOutcomes = $logits.size;
	  var origRank = $logits.rank;
	  if (numOutcomes < 2) {
	    throw new Error("Error in multinomial: you need at least 2 outcomes, but got " + "".concat(numOutcomes, "."));
	  }
	  if (origRank > 2) {
	    throw new Error("Rank of probabilities must be 1 or 2, but is ".concat(origRank));
	  }
	  // TODO(lina128): Investigate correct seed behavior. The code seems not allow
	  // setting see to 0.
	  seed = seed || Math.random();
	  // The kernel only accepts (and returns) rank 2 tensors.
	  var logits2D = origRank === 1 ? reshape$3($logits, [1, -1]) : $logits;
	  var inputs = {
	    logits: logits2D
	  };
	  var attrs = {
	    numSamples: numSamples,
	    seed: seed,
	    normalized: normalized
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var res = ENGINE.runKernel(Multinomial, inputs, attrs);
	  // tslint:disable-next-line:no-unnecessary-type-assertion
	  return origRank === 1 ? reshape$3(res, [res.size]) : res;
	}
	var multinomial$2 = /* @__PURE__ */op({
	  multinomial_: multinomial_
	});

	/**
	 * Returns the truth value of (a != b) element-wise. Supports broadcasting.
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 2, 3]);
	 * const b = tf.tensor1d([0, 2, 3]);
	 *
	 * a.notEqual(b).print();
	 * ```
	 * @param a The first input tensor.
	 * @param b The second input tensor. Must have the same dtype as `a`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Logical'}
	 */
	function notEqual_(a, b) {
	  var $a = convertToTensor(a, 'a', 'notEqual', 'string_or_numeric');
	  var $b = convertToTensor(b, 'b', 'notEqual', 'string_or_numeric');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  assertAndGetBroadcastShape($a.shape, $b.shape);
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  return ENGINE.runKernel(NotEqual, inputs);
	}
	var notEqual$2 = /* @__PURE__ */op({
	  notEqual_: notEqual_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a one-hot `tf.Tensor`. The locations represented by `indices` take
	 * value `onValue` (defaults to 1), while all other locations take value
	 * `offValue` (defaults to 0). If `indices` is rank `R`, the output has rank
	 * `R+1` with the last axis of size `depth`.
	 * `indices` used to encode prediction class must start from 0. For example,
	 *  if you have 3 classes of data, class 1 should be encoded as 0, class 2
	 *  should be 1, and class 3 should be 2.
	 *
	 * ```js
	 * tf.oneHot(tf.tensor1d([0, 1], 'int32'), 3).print();
	 * ```
	 *
	 * @param indices `tf.Tensor` of indices with dtype `int32`. Indices must
	 * start from 0.
	 * @param depth The depth of the one hot dimension.
	 * @param onValue A number used to fill in the output when the index matches
	 * the location.
	 * @param offValue A number used to fill in the output when the index does
	 *     not match the location.
	 * @param dtype The dtype of the output tensor, default to 'int32'.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function oneHot_(indices, depth) {
	  var onValue = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;
	  var offValue = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 0;
	  var dtype = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 'int32';
	  if (depth < 2) {
	    throw new Error("Error in oneHot: depth must be >=2, but it is ".concat(depth));
	  }
	  var $indices = convertToTensor(indices, 'indices', 'oneHot', 'int32');
	  var inputs = {
	    indices: $indices
	  };
	  var attrs = {
	    dtype: dtype,
	    depth: depth,
	    onValue: onValue,
	    offValue: offValue
	  };
	  return ENGINE.runKernel(OneHot, inputs, attrs);
	}
	var oneHot$3 = /* @__PURE__ */op({
	  oneHot_: oneHot_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a `tf.Tensor` with all elements set to 1 with the same shape as the
	 * given tensor.
	 *
	 * ```js
	 * const x = tf.tensor([1, 2]);
	 * tf.onesLike(x).print();
	 * ```
	 * @param x A tensor.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function onesLike_(x) {
	  var $x = convertToTensor(x, 'x', 'onesLike');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(OnesLike, inputs);
	}
	var onesLike$3 = /* @__PURE__ */op({
	  onesLike_: onesLike_
	});

	/**
	 * Computes the outer product of two vectors, `v1` and `v2`.
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 2, 3]);
	 * const b = tf.tensor1d([3, 4, 5]);
	 *
	 * tf.outerProduct(a, b).print();
	 * ```
	 * @param v1 The first vector in the outer product operation.
	 * @param v2 The second vector in the outer product operation.
	 *
	 * @doc {heading: 'Operations', subheading: 'Matrices'}
	 */
	function outerProduct_(v1, v2) {
	  var $v1 = convertToTensor(v1, 'v1', 'outerProduct');
	  var $v2 = convertToTensor(v2, 'v2', 'outerProduct');
	  assert$1($v1.rank === 1 && $v2.rank === 1, function () {
	    return "Error in outerProduct: inputs must be rank 1, but got ranks " + "".concat($v1.rank, " and ").concat($v2.rank, ".");
	  });
	  var v12D = reshape$3($v1, [-1, 1]);
	  var v22D = reshape$3($v2, [1, -1]);
	  return matMul$1(v12D, v22D);
	}
	var outerProduct = /* @__PURE__ */op({
	  outerProduct_: outerProduct_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Pads a `tf.Tensor` with a given value and paddings.
	 *
	 * This operation implements `CONSTANT` mode. For `REFLECT` and `SYMMETRIC`,
	 * refer to `tf.mirrorPad`.
	 *
	 * Also available are stricter rank-specific methods with the same signature
	 * as this method that assert that `paddings` is of given length.
	 *   - `tf.pad1d`
	 *   - `tf.pad2d`
	 *   - `tf.pad3d`
	 *   - `tf.pad4d`
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3, 4]);
	 * x.pad([[1, 2]]).print();
	 * ```
	 * @param x The tensor to pad.
	 * @param paddings An array of length `R` (the rank of the tensor), where
	 * each element is a length-2 tuple of ints `[padBefore, padAfter]`,
	 * specifying how much to pad along each dimension of the tensor.
	 * @param constantValue The pad value to use. Defaults to 0.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Transformations'}
	 */
	function pad_(x, paddings) {
	  var constantValue = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
	  var $x = convertToTensor(x, 'x', 'pad');
	  if ($x.rank === 0) {
	    throw new Error('pad(scalar) is not defined. Pass non-scalar to pad');
	  }
	  var attrs = {
	    paddings: paddings,
	    constantValue: constantValue
	  };
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(PadV2, inputs, attrs);
	}
	var pad = /* @__PURE__ */op({
	  pad_: pad_
	});

	/**
	 * Pads a `tf.Tensor1D` with a given value and paddings. See `pad` for details.
	 */
	function pad1d_(x, paddings) {
	  var constantValue = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
	  assert$1(paddings.length === 2, function () {
	    return 'Invalid number of paddings. Must be length of 2.';
	  });
	  return pad(x, [paddings], constantValue);
	}
	var pad1d = /* @__PURE__ */op({
	  pad1d_: pad1d_
	});

	/**
	 * Pads a `tf.Tensor2D` with a given value and paddings. See `pad` for details.
	 */
	function pad2d_(x, paddings) {
	  var constantValue = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
	  assert$1(paddings.length === 2 && paddings[0].length === 2 && paddings[1].length === 2, function () {
	    return 'Invalid number of paddings. Must be length of 2 each.';
	  });
	  return pad(x, paddings, constantValue);
	}
	var pad2d = /* @__PURE__ */op({
	  pad2d_: pad2d_
	});

	/**
	 * Pads a `tf.Tensor3D` with a given value and paddings. See `pad` for details.
	 */
	function pad3d_(x, paddings) {
	  var constantValue = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
	  assert$1(paddings.length === 3 && paddings[0].length === 2 && paddings[1].length === 2 && paddings[2].length === 2, function () {
	    return 'Invalid number of paddings. Must be length of 2 each.';
	  });
	  return pad(x, paddings, constantValue);
	}
	var pad3d = /* @__PURE__ */op({
	  pad3d_: pad3d_
	});

	/**
	 * Pads a `tf.Tensor4D` with a given value and paddings. See `pad` for details.
	 */
	function pad4d_(x, paddings) {
	  var constantValue = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
	  assert$1(paddings.length === 4 && paddings[0].length === 2 && paddings[1].length === 2 && paddings[2].length === 2 && paddings[3].length === 2, function () {
	    return 'Invalid number of paddings. Must be length of 2 each.';
	  });
	  return pad(x, paddings, constantValue);
	}
	var pad4d = /* @__PURE__ */op({
	  pad4d_: pad4d_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * This operation divides "spatial" dimensions `[1, ..., M]` of the input into
	 * a grid of blocks of shape `blockShape`, and interleaves these blocks with
	 * the "batch" dimension (0) such that in the output, the spatial
	 * dimensions `[1, ..., M]` correspond to the position within the grid,
	 * and the batch dimension combines both the position within a spatial block
	 * and the original batch position. Prior to division into blocks,
	 * the spatial dimensions of the input are optionally zero padded
	 * according to `paddings`. See below for a precise description.
	 *
	 * ```js
	 * const x = tf.tensor4d([1, 2, 3, 4], [1, 2, 2, 1]);
	 * const blockShape = [2, 2];
	 * const paddings = [[0, 0], [0, 0]];
	 *
	 * x.spaceToBatchND(blockShape, paddings).print();
	 * ```
	 *
	 * @param x A `tf.Tensor`. N-D with `x.shape` = `[batch] + spatialShape +
	 * remainingShape`, where spatialShape has `M` dimensions.
	 * @param blockShape A 1-D array. Must have shape `[M]`, all values must
	 * be >= 1.
	 * @param paddings A 2-D array. Must have shape `[M, 2]`, all values must be >=
	 *     0. `paddings[i] = [padStart, padEnd]` specifies the amount to zero-pad
	 * from input dimension `i + 1`, which corresponds to spatial dimension `i`. It
	 * is required that
	 * `(inputShape[i + 1] + padStart + padEnd) % blockShape[i] === 0`
	 *
	 * This operation is equivalent to the following steps:
	 *
	 * 1. Zero-pad the start and end of dimensions `[1, ..., M]` of the input
	 * according to `paddings` to produce `padded` of shape paddedShape.
	 *
	 * 2. Reshape `padded` to `reshapedPadded` of shape:
	 * `[batch] + [paddedShape[1] / blockShape[0], blockShape[0], ...,
	 * paddedShape[M] / blockShape[M-1], blockShape[M-1]] + remainingShape`
	 *
	 * 3. Permute dimensions of `reshapedPadded` to produce `permutedReshapedPadded`
	 * of shape: `blockShape + [batch] + [paddedShape[1] / blockShape[0], ...,
	 * paddedShape[M] / blockShape[M-1]] + remainingShape`
	 *
	 * 4. Reshape `permutedReshapedPadded` to flatten `blockShape` into the
	 * batch dimension, producing an output tensor of shape:
	 * `[batch * prod(blockShape)] + [paddedShape[1] / blockShape[0], ...,
	 * paddedShape[M] / blockShape[M-1]] + remainingShape`
	 *
	 * @doc {heading: 'Tensors', subheading: 'Transformations'}
	 */
	function spaceToBatchND_(x, blockShape, paddings) {
	  var $x = convertToTensor(x, 'x', 'spaceToBatchND');
	  assert$1($x.rank >= 1 + blockShape.length, function () {
	    return "input rank ".concat($x.rank, " should be > than [blockShape] ").concat(blockShape.length);
	  });
	  assert$1(paddings.length === blockShape.length, function () {
	    return "paddings.shape[0] ".concat(paddings.length, " must be equal to [blockShape] ").concat(blockShape.length);
	  });
	  assert$1($x.shape.reduce(function (a, b, i) {
	    if (i > 0 && i <= blockShape.length) {
	      return a && (b + paddings[i - 1][0] + paddings[i - 1][1]) % blockShape[i - 1] === 0;
	    }
	    return a;
	  }, true), function () {
	    return "input spatial dimensions ".concat($x.shape.slice(1), " with paddings ").concat(paddings.toString(), " must be divisible by blockShapes ").concat(blockShape.toString());
	  });
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    blockShape: blockShape,
	    paddings: paddings
	  };
	  return ENGINE.runKernel(SpaceToBatchND, inputs, attrs);
	}
	var spaceToBatchND$2 = /* @__PURE__ */op({
	  spaceToBatchND_: spaceToBatchND_
	});

	/**
	 * Performs an N-D pooling operation
	 *
	 * @param input The input tensor, of rank 4 or rank 3 of shape
	 *     `[batch, height, width, inChannels]`. If rank 3, batch of 1 is assumed.
	 * @param windowShape The filter size: `[filterHeight, filterWidth]`. If
	 *     `filterSize` is a single number, then `filterHeight == filterWidth`.
	 * @param poolingType The type of pooling, either 'max' or 'avg'.
	 * @param pad The type of padding algorithm:
	 *    - `same` and stride 1: output will be of same size as input,
	 *       regardless of filter size.
	 *    - `valid`: output will be smaller than input if filter is larger
	 *       than 1x1.
	 *    - For more info, see this guide:
	 *     [https://www.tensorflow.org/api_guides/python/nn#Convolution](
	 *         https://www.tensorflow.org/api_guides/python/nn#Convolution)
	 * @param dilations The dilation rates: `[dilationHeight, dilationWidth]`
	 *     in which we sample input values across the height and width dimensions
	 *     in dilated pooling. Defaults to `[1, 1]`. If `dilationRate` is a single
	 *     number, then `dilationHeight == dilationWidth`. If it is greater than
	 *     1, then all values of `strides` must be 1.
	 * @param strides The strides of the pooling: `[strideHeight, strideWidth]`. If
	 *     `strides` is a single number, then `strideHeight == strideWidth`.
	 * @param dimRoundingMode A string from: 'ceil', 'round', 'floor'. If none is
	 *     provided, it will default to truncate.
	 *
	 * @doc {heading: 'Operations', subheading: 'Convolution'}
	 */
	function pool_(input, windowShape, poolingType, pad, dilations, strides, dimRoundingMode) {
	  if (dilations == null) {
	    dilations = [1, 1];
	  }
	  if (strides == null) {
	    strides = 1;
	  }
	  if (pad === 0) {
	    pad = 'valid';
	  }
	  var $x = convertToTensor(input, 'x', 'maxPool');
	  var x4D = $x;
	  var reshapedTo4D = false;
	  if ($x.rank === 3) {
	    reshapedTo4D = true;
	    x4D = reshape$3($x, [1, $x.shape[0], $x.shape[1], $x.shape[2]]);
	  }
	  assert$1(eitherStridesOrDilationsAreOne(strides, dilations), function () {
	    return 'Error in pool: Either strides or dilations must be 1. ' + "Got strides ".concat(strides, " and dilations '").concat(dilations, "'");
	  });
	  var convInfo = computePool2DInfo(x4D.shape, windowShape, strides, dilations, pad);
	  var dilation = [convInfo.dilationHeight, convInfo.dilationWidth];
	  // The following implementation does batchToSpace(pool(spaceToBatch(x)))
	  // whenever dilation > 1 since the TF kernels do not support dilation > 1.
	  // tslint:disable-next-line:max-line-length
	  // https://github.com/tensorflow/tensorflow/blob/50f6bb67dc98c9b74630b6047aae7a4f8a40fd02/tensorflow/python/ops/nn_ops.py#L1037
	  var basePadding;
	  if (pad === 'same') {
	    basePadding = withSpaceToBatchBasePaddings([convInfo.filterHeight, convInfo.filterWidth], dilation);
	  } else {
	    basePadding = [[0, 0], [0, 0]];
	  }
	  var isDilationOne = dilation[0] === 1 && dilation[1] === 1;
	  var _requiredSpaceToBatch = requiredSpaceToBatchPaddings([convInfo.inHeight, convInfo.inWidth], dilation, basePadding),
	    _requiredSpaceToBatch2 = _slicedToArray(_requiredSpaceToBatch, 2),
	    adjustedPadding = _requiredSpaceToBatch2[0],
	    adjustedCrops = _requiredSpaceToBatch2[1];
	  var convertedPad = isDilationOne ? pad : 'valid';
	  var convertedX = isDilationOne ? x4D : spaceToBatchND$2(x4D, dilation, adjustedPadding);
	  var forwardOp = poolingType === 'avg' ? function () {
	    return avgPool$2(convertedX, windowShape, strides, convertedPad, dimRoundingMode);
	  } : function () {
	    return maxPool$2(convertedX, windowShape, strides, convertedPad, dimRoundingMode);
	  };
	  var y = forwardOp();
	  var res = isDilationOne ? y : batchToSpaceND$2(y, dilation, adjustedCrops);
	  if (reshapedTo4D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3]]);
	  }
	  return res;
	}
	// Helper function to compute crops and paddings for pool with dilation > 1.
	// tslint:disable-next-line:max-line-length
	// https://github.com/tensorflow/tensorflow/blob/50f6bb67dc98c9b74630b6047aae7a4f8a40fd02/tensorflow/python/ops/array_ops.py#L2184
	function requiredSpaceToBatchPaddings(inputShape, blockShape, basePadding) {
	  var padStart = basePadding.map(function (b) {
	    return b[0];
	  });
	  var origPadEnd = basePadding.map(function (b) {
	    return b[1];
	  });
	  var fullInputShape = inputShape.concat(padStart, origPadEnd);
	  var padEndExtra = blockShape.map(function (b, i) {
	    return (b - fullInputShape[i] % b) % b;
	  });
	  var padEnd = origPadEnd.map(function (s, i) {
	    return s + padEndExtra[i];
	  });
	  var paddings = blockShape.map(function (_, i) {
	    return [padStart[i], padEnd[i]];
	  });
	  var crops = blockShape.map(function (_, i) {
	    return [0, padEndExtra[i]];
	  });
	  return [paddings, crops];
	}
	// Helper function to compute base paddings for pool with dilation > 1.
	// tslint:disable-next-line:max-line-length
	// https://github.com/tensorflow/tensorflow/blob/50f6bb67dc98c9b74630b6047aae7a4f8a40fd02/tensorflow/python/ops/nn_ops.py#L524
	function withSpaceToBatchBasePaddings(filterShape, dilation) {
	  // Spatial dimensions of the filters and the upsampled filters in which we
	  // introduce (rate - 1) zeros between consecutive filter values.
	  var dilatedFilterShape = filterShape.map(function (s, i) {
	    return s + (s - 1) * (dilation[i] - 1);
	  });
	  var padExtraShape = dilatedFilterShape.map(function (s) {
	    return s - 1;
	  });
	  // When padding is odd, we pad more at end, following the same
	  // convention as conv2d.
	  var padExtraStart = padExtraShape.map(function (s) {
	    return Math.floor(s / 2);
	  });
	  var padExtraEnd = padExtraShape.map(function (s, i) {
	    return s - padExtraStart[i];
	  });
	  return padExtraShape.map(function (_, i) {
	    return [padExtraStart[i], padExtraEnd[i]];
	  });
	}
	var pool$1 = /* @__PURE__ */op({
	  pool_: pool_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes leaky rectified linear element-wise with parametric alphas.
	 *
	 * `x < 0 ? alpha * x : f(x) = x`
	 *
	 * ```js
	 * const x = tf.tensor1d([-1, 2, -3, 4]);
	 * const alpha = tf.scalar(0.1);
	 *
	 * x.prelu(alpha).print();  // or tf.prelu(x, alpha)
	 * ```
	 * @param x The input tensor.
	 * @param alpha Scaling factor for negative values.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function prelu_(x, alpha) {
	  var $x = convertToTensor(x, 'x', 'prelu');
	  var $alpha = convertToTensor(alpha, 'alpha', 'prelu');
	  var inputs = {
	    x: $x,
	    alpha: $alpha
	  };
	  return ENGINE.runKernel(Prelu, inputs);
	}
	var prelu$3 = /* @__PURE__ */op({
	  prelu_: prelu_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the product of elements across dimensions of a `tf.Tensor`.
	 *
	 * Reduces the input along the dimensions given in `axes`. Unless `keepDims`
	 * is true, the rank of the `tf.Tensor` is reduced by 1 for each entry in
	 * `axes`. If `keepDims` is true, the reduced dimensions are retained with
	 * length 1. If `axes` has no entries, all dimensions are reduced, and a
	 * `tf.Tensor` with a single element is returned.
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3]);
	 *
	 * x.prod().print();  // or tf.prod(x)
	 * ```
	 *
	 * ```js
	 * const x = tf.tensor2d([1, 2, 3, 4], [2, 2]);
	 *
	 * const axis = 1;
	 * x.prod(axis).print();  // or tf.prod(x, axis)
	 * ```
	 *
	 * @param x The input tensor to compute the product over. If the dtype is `bool`
	 *   it will be converted to `int32` and the output dtype will be `int32`.
	 * @param axis The dimension(s) to reduce. By default it reduces
	 *     all dimensions.
	 * @param keepDims If true, retains reduced dimensions with size 1.
	 *
	 * @doc {heading: 'Operations', subheading: 'Reduction'}
	 */
	function prod_(x) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
	  var keepDims = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  var $x = convertToTensor(x, 'x', 'prod');
	  if ($x.dtype === 'bool') {
	    // bool is not an allowed type for the underlying kernel.
	    $x = cast$3($x, 'int32');
	  }
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    axis: axis,
	    keepDims: keepDims
	  };
	  return ENGINE.runKernel(Prod, inputs, attrs);
	}
	var prod$2 = /* @__PURE__ */op({
	  prod_: prod_
	});

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function raggedGather_(paramsNestedSplits, paramsDenseValues, indices, outputRaggedRank) {
	  var $paramsNestedSplits = paramsNestedSplits.map(function (t, i) {
	    return convertToTensor(t, "tensors".concat(i), 'raggedGather', 'int32');
	  });
	  var $paramsDenseValues = convertToTensor(paramsDenseValues, 'paramsDenseValues', 'raggedGather');
	  var $indices = convertToTensor(indices, 'indices', 'raggedGather', 'int32');
	  var inputs = {
	    paramsNestedSplits: $paramsNestedSplits,
	    paramsDenseValues: $paramsDenseValues,
	    indices: $indices
	  };
	  var attrs = {
	    outputRaggedRank: outputRaggedRank
	  };
	  var result = ENGINE.runKernel(RaggedGather, inputs, attrs);
	  return {
	    outputNestedSplits: result.slice(0, result.length - 1),
	    outputDenseValues: result[result.length - 1]
	  };
	}
	var raggedGather$2 = /* @__PURE__ */op({
	  raggedGather_: raggedGather_
	});

	/**
	 * @license
	 * Copyright 2022 Google LLC.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Returns a RaggedTensor result composed from rtDenseValues and rtNestedSplits,
	 * such that result[i] = [starts[i], starts[i] + deltas[i], ..., limits[i]]).
	 *
	 * @param starts: A Tensor. Must be one of the following types:
	 *     'float32', 'int32'. The starts of each range.
	 * @param limits: A Tensor. Must have the same type as starts. The limits of
	 *     each range.
	 * @param deltas: A Tensor. Must have the same type as starts. The deltas of
	 *     each range.
	 * @return A map with the following properties:
	 *     - rtNestedSplits: A Tensor of type 'int32'.
	 *     - rtDenseValues: A Tensor. Has the same type as starts.
	 */
	function raggedRange_(starts, limits, deltas) {
	  var $starts = convertToTensor(starts, 'starts', 'raggedRange');
	  var $limits = convertToTensor(limits, 'limits', 'raggedRange', $starts.dtype);
	  var $deltas = convertToTensor(deltas, 'deltas', 'raggedRange', $starts.dtype);
	  var inputs = {
	    starts: $starts,
	    limits: $limits,
	    deltas: $deltas
	  };
	  var result = ENGINE.runKernel(RaggedRange, inputs);
	  return {
	    rtNestedSplits: result[0],
	    rtDenseValues: result[1]
	  };
	}
	var raggedRange$2 = /* @__PURE__ */op({
	  raggedRange_: raggedRange_
	});

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Create a dense tensor from a ragged tensor, possibly altering its shape.
	 *
	 * The raggedTensorToTensor op creates a dense tensor from am array of row
	 * partition tensors, a value vector, and default values. If the shape is
	 * unspecified, the minimal shape required to contain all the elements in the
	 * ragged tensor (the natural shape) will be used. If some dimensions are left
	 * unspecified, then the size of the natural shape is used in that dimension.
	 *
	 * The defaultValue will be broadcast to the output shape. After that, the
	 * values from the ragged tensor overwrite the default values. Note that the
	 * defaultValue must have less dimensions than the value.
	 *
	 * The row partition tensors are in the order of the dimensions. At present, the
	 * types can be: "ROW_SPLITS": the row_splits tensor from the ragged tensor.
	 *   "VALUE_ROWIDS": the value_rowids tensor from the ragged tensor.
	 *   "FIRST_DIM_SIZE": if value_rowids is used for the first dimension, then it
	 * is preceded by "FIRST_DIM_SIZE".
	 * ```
	 * @param shape: A Tensor. Must be one of the following types: 'int32'. The
	 *     desired shape of the output tensor. If left unspecified (empty), the
	 *     minimal shape required to contain all the elements in the ragged tensor
	 *     (the natural shape) will be used. If some dimensions are left
	 *     unspecified, then the size of the natural shape is used in that
	 *     dimension.
	 *
	 *     Note that dense dimensions cannot be modified by the shape argument.
	 *     Trying to change the size of a dense dimension will cause the op to fail.
	 *     Examples: natural shape: [4, 5, 6] shape: -1 output shape: [4, 5, 6]
	 *
	 *     natural shape: [4, 5, 6] shape: [3, -1, 2] output shape: [3, 5, 2]
	 *
	 *     natural shape: [4, 5, 6] shape: [3, 7, 2] output shape: [3, 7, 2]
	 * @param values: A Tensor. A 1D tensor representing the values of the ragged
	 *     tensor.
	 * @param defaultValue: A Tensor. Must have the same type as values. The
	 *     defaultValue when the shape is larger than the ragged tensor. The
	 *     defaultValue is broadcast until it is the shape of the output tensor,
	 *     and then overwritten by values in the ragged tensor. The default value
	 *     must be compatible with this broadcast operation, and must have fewer
	 *     dimensions than the value tensor.
	 * @param rowPartitionTensors: A list of at least 1 Tensor objects with the same
	 *     type in: 'int32'.
	 * @param rowPartitionTypes: A list of strings. The types of the row partition
	 *     tensors. At present, these can be:
	 *     "ROW_SPLITS": the row_splits tensor from the ragged tensor.
	 *     "VALUE_ROWIDS": the value_rowids tensor from the ragged tensor.
	 *     "FIRST_DIM_SIZE": if value_rowids is used for the first dimension, then
	 *         it is preceded by "FIRST_DIM_SIZE". The tensors are in the order of
	 *         the dimensions.
	 * @return A Tensor. Has the same type as values.
	 * @doc {heading: 'Operations', subheading: 'Ragged'}
	 */
	function raggedTensorToTensor_(shape, values, defaultValue, rowPartitionTensors, rowPartitionTypes) {
	  var $shape = convertToTensor(shape, 'shape', 'raggedTensorToTensor', 'int32');
	  var $values = convertToTensor(values, 'values', 'raggedTensorToTensor');
	  var $defaultValue = convertToTensor(defaultValue, 'defaultValue', 'raggedTensorToTensor', $values.dtype);
	  var $rowPartitionTensors = rowPartitionTensors.map(function (t, i) {
	    return convertToTensor(t, "tensors".concat(i), 'raggedTensorToTensor', 'int32');
	  });
	  var inputs = {
	    shape: $shape,
	    values: $values,
	    defaultValue: $defaultValue,
	    rowPartitionTensors: $rowPartitionTensors
	  };
	  var attrs = {
	    rowPartitionTypes: rowPartitionTypes
	  };
	  return ENGINE.runKernel(RaggedTensorToTensor, inputs, attrs);
	}
	var raggedTensorToTensor$2 = /* @__PURE__ */op({
	  raggedTensorToTensor_: raggedTensorToTensor_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a `tf.Tensor` with values sampled from a random number generator
	 * function defined by the user.
	 *
	 * @param shape An array of integers defining the output tensor shape.
	 * @param randFunction A random number generator function which is called
	 * for each element in the output tensor.
	 * @param dtype The data type of the output tensor. Defaults to 'float32'.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Random'}
	 */
	function rand_(shape, randFunction, dtype) {
	  assertNonNegativeIntegerDimensions(shape);
	  var size = sizeFromShape(shape);
	  var values = null;
	  if (dtype == null || dtype === 'float32') {
	    values = new Float32Array(size);
	  } else if (dtype === 'int32') {
	    values = new Int32Array(size);
	  } else if (dtype === 'bool') {
	    values = new Uint8Array(size);
	  } else {
	    throw new Error("Unknown data type ".concat(dtype));
	  }
	  for (var i = 0; i < size; i++) {
	    values[i] = randFunction();
	  }
	  return ENGINE.makeTensor(values, shape, dtype);
	}
	var rand = /* @__PURE__ */op({
	  rand_: rand_
	});

	var alea$3 = {exports: {}};

	var alea$1 = alea$3.exports;
	(function (module) {
	  // A port of an algorithm by Johannes Baagøe <baagoe@baagoe.com>, 2010
	  // http://baagoe.com/en/RandomMusings/javascript/
	  // https://github.com/nquinlan/better-random-numbers-for-javascript-mirror
	  // Original work is under MIT license -

	  // Copyright (C) 2010 by Johannes Baagøe <baagoe@baagoe.org>
	  //
	  // Permission is hereby granted, free of charge, to any person obtaining a copy
	  // of this software and associated documentation files (the "Software"), to deal
	  // in the Software without restriction, including without limitation the rights
	  // to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
	  // copies of the Software, and to permit persons to whom the Software is
	  // furnished to do so, subject to the following conditions:
	  //
	  // The above copyright notice and this permission notice shall be included in
	  // all copies or substantial portions of the Software.
	  //
	  // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
	  // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
	  // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
	  // AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
	  // LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
	  // OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
	  // THE SOFTWARE.

	  (function (global, module, define) {
	    function Alea(seed) {
	      var me = this,
	        mash = Mash();
	      me.next = function () {
	        var t = 2091639 * me.s0 + me.c * 2.3283064365386963e-10; // 2^-32
	        me.s0 = me.s1;
	        me.s1 = me.s2;
	        return me.s2 = t - (me.c = t | 0);
	      };

	      // Apply the seeding algorithm from Baagoe.
	      me.c = 1;
	      me.s0 = mash(' ');
	      me.s1 = mash(' ');
	      me.s2 = mash(' ');
	      me.s0 -= mash(seed);
	      if (me.s0 < 0) {
	        me.s0 += 1;
	      }
	      me.s1 -= mash(seed);
	      if (me.s1 < 0) {
	        me.s1 += 1;
	      }
	      me.s2 -= mash(seed);
	      if (me.s2 < 0) {
	        me.s2 += 1;
	      }
	      mash = null;
	    }
	    function copy(f, t) {
	      t.c = f.c;
	      t.s0 = f.s0;
	      t.s1 = f.s1;
	      t.s2 = f.s2;
	      return t;
	    }
	    function impl(seed, opts) {
	      var xg = new Alea(seed),
	        state = opts && opts.state,
	        prng = xg.next;
	      prng.int32 = function () {
	        return xg.next() * 0x100000000 | 0;
	      };
	      prng.double = function () {
	        return prng() + (prng() * 0x200000 | 0) * 1.1102230246251565e-16; // 2^-53
	      };

	      prng.quick = prng;
	      if (state) {
	        if (_typeof(state) == 'object') copy(state, xg);
	        prng.state = function () {
	          return copy(xg, {});
	        };
	      }
	      return prng;
	    }
	    function Mash() {
	      var n = 0xefc8249d;
	      var mash = function mash(data) {
	        data = String(data);
	        for (var i = 0; i < data.length; i++) {
	          n += data.charCodeAt(i);
	          var h = 0.02519603282416938 * n;
	          n = h >>> 0;
	          h -= n;
	          h *= n;
	          n = h >>> 0;
	          h -= n;
	          n += h * 0x100000000; // 2^32
	        }

	        return (n >>> 0) * 2.3283064365386963e-10; // 2^-32
	      };

	      return mash;
	    }
	    if (module && module.exports) {
	      module.exports = impl;
	    } else if (define && define.amd) {
	      define(function () {
	        return impl;
	      });
	    } else {
	      this.alea = impl;
	    }
	  })(commonjsGlobal, 'object' == 'object' && module,
	  // present in node.js
	  typeof undefined == 'function' && undefined // present with an AMD loader
	  );
	})(alea$3);
	var aleaExports = alea$3.exports;
	var alea$2 = /*@__PURE__*/getDefaultExportFromCjs(aleaExports);

	var xor128$3 = {exports: {}};

	var xor128$1 = xor128$3.exports;
	(function (module) {
	  // A Javascript implementaion of the "xor128" prng algorithm by
	  // George Marsaglia.  See http://www.jstatsoft.org/v08/i14/paper

	  (function (global, module, define) {
	    function XorGen(seed) {
	      var me = this,
	        strseed = '';
	      me.x = 0;
	      me.y = 0;
	      me.z = 0;
	      me.w = 0;

	      // Set up generator function.
	      me.next = function () {
	        var t = me.x ^ me.x << 11;
	        me.x = me.y;
	        me.y = me.z;
	        me.z = me.w;
	        return me.w ^= me.w >>> 19 ^ t ^ t >>> 8;
	      };
	      if (seed === (seed | 0)) {
	        // Integer seed.
	        me.x = seed;
	      } else {
	        // String seed.
	        strseed += seed;
	      }

	      // Mix in string seed, then discard an initial batch of 64 values.
	      for (var k = 0; k < strseed.length + 64; k++) {
	        me.x ^= strseed.charCodeAt(k) | 0;
	        me.next();
	      }
	    }
	    function copy(f, t) {
	      t.x = f.x;
	      t.y = f.y;
	      t.z = f.z;
	      t.w = f.w;
	      return t;
	    }
	    function impl(seed, opts) {
	      var xg = new XorGen(seed),
	        state = opts && opts.state,
	        prng = function prng() {
	          return (xg.next() >>> 0) / 0x100000000;
	        };
	      prng.double = function () {
	        do {
	          var top = xg.next() >>> 11,
	            bot = (xg.next() >>> 0) / 0x100000000,
	            result = (top + bot) / (1 << 21);
	        } while (result === 0);
	        return result;
	      };
	      prng.int32 = xg.next;
	      prng.quick = prng;
	      if (state) {
	        if (_typeof(state) == 'object') copy(state, xg);
	        prng.state = function () {
	          return copy(xg, {});
	        };
	      }
	      return prng;
	    }
	    if (module && module.exports) {
	      module.exports = impl;
	    } else if (define && define.amd) {
	      define(function () {
	        return impl;
	      });
	    } else {
	      this.xor128 = impl;
	    }
	  })(commonjsGlobal, 'object' == 'object' && module,
	  // present in node.js
	  typeof undefined == 'function' && undefined // present with an AMD loader
	  );
	})(xor128$3);
	var xor128Exports = xor128$3.exports;
	var xor128$2 = /*@__PURE__*/getDefaultExportFromCjs(xor128Exports);

	var xorwow$3 = {exports: {}};

	var xorwow$1 = xorwow$3.exports;
	(function (module) {
	  // A Javascript implementaion of the "xorwow" prng algorithm by
	  // George Marsaglia.  See http://www.jstatsoft.org/v08/i14/paper

	  (function (global, module, define) {
	    function XorGen(seed) {
	      var me = this,
	        strseed = '';

	      // Set up generator function.
	      me.next = function () {
	        var t = me.x ^ me.x >>> 2;
	        me.x = me.y;
	        me.y = me.z;
	        me.z = me.w;
	        me.w = me.v;
	        return (me.d = me.d + 362437 | 0) + (me.v = me.v ^ me.v << 4 ^ (t ^ t << 1)) | 0;
	      };
	      me.x = 0;
	      me.y = 0;
	      me.z = 0;
	      me.w = 0;
	      me.v = 0;
	      if (seed === (seed | 0)) {
	        // Integer seed.
	        me.x = seed;
	      } else {
	        // String seed.
	        strseed += seed;
	      }

	      // Mix in string seed, then discard an initial batch of 64 values.
	      for (var k = 0; k < strseed.length + 64; k++) {
	        me.x ^= strseed.charCodeAt(k) | 0;
	        if (k == strseed.length) {
	          me.d = me.x << 10 ^ me.x >>> 4;
	        }
	        me.next();
	      }
	    }
	    function copy(f, t) {
	      t.x = f.x;
	      t.y = f.y;
	      t.z = f.z;
	      t.w = f.w;
	      t.v = f.v;
	      t.d = f.d;
	      return t;
	    }
	    function impl(seed, opts) {
	      var xg = new XorGen(seed),
	        state = opts && opts.state,
	        prng = function prng() {
	          return (xg.next() >>> 0) / 0x100000000;
	        };
	      prng.double = function () {
	        do {
	          var top = xg.next() >>> 11,
	            bot = (xg.next() >>> 0) / 0x100000000,
	            result = (top + bot) / (1 << 21);
	        } while (result === 0);
	        return result;
	      };
	      prng.int32 = xg.next;
	      prng.quick = prng;
	      if (state) {
	        if (_typeof(state) == 'object') copy(state, xg);
	        prng.state = function () {
	          return copy(xg, {});
	        };
	      }
	      return prng;
	    }
	    if (module && module.exports) {
	      module.exports = impl;
	    } else if (define && define.amd) {
	      define(function () {
	        return impl;
	      });
	    } else {
	      this.xorwow = impl;
	    }
	  })(commonjsGlobal, 'object' == 'object' && module,
	  // present in node.js
	  typeof undefined == 'function' && undefined // present with an AMD loader
	  );
	})(xorwow$3);
	var xorwowExports = xorwow$3.exports;
	var xorwow$2 = /*@__PURE__*/getDefaultExportFromCjs(xorwowExports);

	var xorshift7$3 = {exports: {}};

	var xorshift7$1 = xorshift7$3.exports;
	(function (module) {
	  // A Javascript implementaion of the "xorshift7" algorithm by
	  // François Panneton and Pierre L'ecuyer:
	  // "On the Xorgshift Random Number Generators"
	  // http://saluc.engr.uconn.edu/refs/crypto/rng/panneton05onthexorshift.pdf

	  (function (global, module, define) {
	    function XorGen(seed) {
	      var me = this;

	      // Set up generator function.
	      me.next = function () {
	        // Update xor generator.
	        var X = me.x,
	          i = me.i,
	          t,
	          v,
	          w;
	        t = X[i];
	        t ^= t >>> 7;
	        v = t ^ t << 24;
	        t = X[i + 1 & 7];
	        v ^= t ^ t >>> 10;
	        t = X[i + 3 & 7];
	        v ^= t ^ t >>> 3;
	        t = X[i + 4 & 7];
	        v ^= t ^ t << 7;
	        t = X[i + 7 & 7];
	        t = t ^ t << 13;
	        v ^= t ^ t << 9;
	        X[i] = v;
	        me.i = i + 1 & 7;
	        return v;
	      };
	      function init(me, seed) {
	        var j,
	          w,
	          X = [];
	        if (seed === (seed | 0)) {
	          // Seed state array using a 32-bit integer.
	          w = X[0] = seed;
	        } else {
	          // Seed state using a string.
	          seed = '' + seed;
	          for (j = 0; j < seed.length; ++j) {
	            X[j & 7] = X[j & 7] << 15 ^ seed.charCodeAt(j) + X[j + 1 & 7] << 13;
	          }
	        }
	        // Enforce an array length of 8, not all zeroes.
	        while (X.length < 8) X.push(0);
	        for (j = 0; j < 8 && X[j] === 0; ++j);
	        if (j == 8) w = X[7] = -1;else w = X[j];
	        me.x = X;
	        me.i = 0;

	        // Discard an initial 256 values.
	        for (j = 256; j > 0; --j) {
	          me.next();
	        }
	      }
	      init(me, seed);
	    }
	    function copy(f, t) {
	      t.x = f.x.slice();
	      t.i = f.i;
	      return t;
	    }
	    function impl(seed, opts) {
	      if (seed == null) seed = +new Date();
	      var xg = new XorGen(seed),
	        state = opts && opts.state,
	        prng = function prng() {
	          return (xg.next() >>> 0) / 0x100000000;
	        };
	      prng.double = function () {
	        do {
	          var top = xg.next() >>> 11,
	            bot = (xg.next() >>> 0) / 0x100000000,
	            result = (top + bot) / (1 << 21);
	        } while (result === 0);
	        return result;
	      };
	      prng.int32 = xg.next;
	      prng.quick = prng;
	      if (state) {
	        if (state.x) copy(state, xg);
	        prng.state = function () {
	          return copy(xg, {});
	        };
	      }
	      return prng;
	    }
	    if (module && module.exports) {
	      module.exports = impl;
	    } else if (define && define.amd) {
	      define(function () {
	        return impl;
	      });
	    } else {
	      this.xorshift7 = impl;
	    }
	  })(commonjsGlobal, 'object' == 'object' && module,
	  // present in node.js
	  typeof undefined == 'function' && undefined // present with an AMD loader
	  );
	})(xorshift7$3);
	var xorshift7Exports = xorshift7$3.exports;
	var xorshift7$2 = /*@__PURE__*/getDefaultExportFromCjs(xorshift7Exports);

	var xor4096$3 = {exports: {}};

	var xor4096$1 = xor4096$3.exports;
	(function (module) {
	  // A Javascript implementaion of Richard Brent's Xorgens xor4096 algorithm.
	  //
	  // This fast non-cryptographic random number generator is designed for
	  // use in Monte-Carlo algorithms. It combines a long-period xorshift
	  // generator with a Weyl generator, and it passes all common batteries
	  // of stasticial tests for randomness while consuming only a few nanoseconds
	  // for each prng generated.  For background on the generator, see Brent's
	  // paper: "Some long-period random number generators using shifts and xors."
	  // http://arxiv.org/pdf/1004.3115v1.pdf
	  //
	  // Usage:
	  //
	  // var xor4096 = require('xor4096');
	  // random = xor4096(1);                        // Seed with int32 or string.
	  // assert.equal(random(), 0.1520436450538547); // (0, 1) range, 53 bits.
	  // assert.equal(random.int32(), 1806534897);   // signed int32, 32 bits.
	  //
	  // For nonzero numeric keys, this impelementation provides a sequence
	  // identical to that by Brent's xorgens 3 implementaion in C.  This
	  // implementation also provides for initalizing the generator with
	  // string seeds, or for saving and restoring the state of the generator.
	  //
	  // On Chrome, this prng benchmarks about 2.1 times slower than
	  // Javascript's built-in Math.random().

	  (function (global, module, define) {
	    function XorGen(seed) {
	      var me = this;

	      // Set up generator function.
	      me.next = function () {
	        var w = me.w,
	          X = me.X,
	          i = me.i,
	          t,
	          v;
	        // Update Weyl generator.
	        me.w = w = w + 0x61c88647 | 0;
	        // Update xor generator.
	        v = X[i + 34 & 127];
	        t = X[i = i + 1 & 127];
	        v ^= v << 13;
	        t ^= t << 17;
	        v ^= v >>> 15;
	        t ^= t >>> 12;
	        // Update Xor generator array state.
	        v = X[i] = v ^ t;
	        me.i = i;
	        // Result is the combination.
	        return v + (w ^ w >>> 16) | 0;
	      };
	      function init(me, seed) {
	        var t,
	          v,
	          i,
	          j,
	          w,
	          X = [],
	          limit = 128;
	        if (seed === (seed | 0)) {
	          // Numeric seeds initialize v, which is used to generates X.
	          v = seed;
	          seed = null;
	        } else {
	          // String seeds are mixed into v and X one character at a time.
	          seed = seed + '\0';
	          v = 0;
	          limit = Math.max(limit, seed.length);
	        }
	        // Initialize circular array and weyl value.
	        for (i = 0, j = -32; j < limit; ++j) {
	          // Put the unicode characters into the array, and shuffle them.
	          if (seed) v ^= seed.charCodeAt((j + 32) % seed.length);
	          // After 32 shuffles, take v as the starting w value.
	          if (j === 0) w = v;
	          v ^= v << 10;
	          v ^= v >>> 15;
	          v ^= v << 4;
	          v ^= v >>> 13;
	          if (j >= 0) {
	            w = w + 0x61c88647 | 0; // Weyl.
	            t = X[j & 127] ^= v + w; // Combine xor and weyl to init array.
	            i = 0 == t ? i + 1 : 0; // Count zeroes.
	          }
	        }
	        // We have detected all zeroes; make the key nonzero.
	        if (i >= 128) {
	          X[(seed && seed.length || 0) & 127] = -1;
	        }
	        // Run the generator 512 times to further mix the state before using it.
	        // Factoring this as a function slows the main generator, so it is just
	        // unrolled here.  The weyl generator is not advanced while warming up.
	        i = 127;
	        for (j = 4 * 128; j > 0; --j) {
	          v = X[i + 34 & 127];
	          t = X[i = i + 1 & 127];
	          v ^= v << 13;
	          t ^= t << 17;
	          v ^= v >>> 15;
	          t ^= t >>> 12;
	          X[i] = v ^ t;
	        }
	        // Storing state as object members is faster than using closure variables.
	        me.w = w;
	        me.X = X;
	        me.i = i;
	      }
	      init(me, seed);
	    }
	    function copy(f, t) {
	      t.i = f.i;
	      t.w = f.w;
	      t.X = f.X.slice();
	      return t;
	    }
	    ;
	    function impl(seed, opts) {
	      if (seed == null) seed = +new Date();
	      var xg = new XorGen(seed),
	        state = opts && opts.state,
	        prng = function prng() {
	          return (xg.next() >>> 0) / 0x100000000;
	        };
	      prng.double = function () {
	        do {
	          var top = xg.next() >>> 11,
	            bot = (xg.next() >>> 0) / 0x100000000,
	            result = (top + bot) / (1 << 21);
	        } while (result === 0);
	        return result;
	      };
	      prng.int32 = xg.next;
	      prng.quick = prng;
	      if (state) {
	        if (state.X) copy(state, xg);
	        prng.state = function () {
	          return copy(xg, {});
	        };
	      }
	      return prng;
	    }
	    if (module && module.exports) {
	      module.exports = impl;
	    } else if (define && define.amd) {
	      define(function () {
	        return impl;
	      });
	    } else {
	      this.xor4096 = impl;
	    }
	  })(commonjsGlobal,
	  // window object or global
	  'object' == 'object' && module,
	  // present in node.js
	  typeof undefined == 'function' && undefined // present with an AMD loader
	  );
	})(xor4096$3);
	var xor4096Exports = xor4096$3.exports;
	var xor4096$2 = /*@__PURE__*/getDefaultExportFromCjs(xor4096Exports);

	var tychei$3 = {exports: {}};

	var tychei$1 = tychei$3.exports;
	(function (module) {
	  // A Javascript implementaion of the "Tyche-i" prng algorithm by
	  // Samuel Neves and Filipe Araujo.
	  // See https://eden.dei.uc.pt/~sneves/pubs/2011-snfa2.pdf

	  (function (global, module, define) {
	    function XorGen(seed) {
	      var me = this,
	        strseed = '';

	      // Set up generator function.
	      me.next = function () {
	        var b = me.b,
	          c = me.c,
	          d = me.d,
	          a = me.a;
	        b = b << 25 ^ b >>> 7 ^ c;
	        c = c - d | 0;
	        d = d << 24 ^ d >>> 8 ^ a;
	        a = a - b | 0;
	        me.b = b = b << 20 ^ b >>> 12 ^ c;
	        me.c = c = c - d | 0;
	        me.d = d << 16 ^ c >>> 16 ^ a;
	        return me.a = a - b | 0;
	      };

	      /* The following is non-inverted tyche, which has better internal
	       * bit diffusion, but which is about 25% slower than tyche-i in JS.
	      me.next = function() {
	        var a = me.a, b = me.b, c = me.c, d = me.d;
	        a = (me.a + me.b | 0) >>> 0;
	        d = me.d ^ a; d = d << 16 ^ d >>> 16;
	        c = me.c + d | 0;
	        b = me.b ^ c; b = b << 12 ^ d >>> 20;
	        me.a = a = a + b | 0;
	        d = d ^ a; me.d = d = d << 8 ^ d >>> 24;
	        me.c = c = c + d | 0;
	        b = b ^ c;
	        return me.b = (b << 7 ^ b >>> 25);
	      }
	      */

	      me.a = 0;
	      me.b = 0;
	      me.c = 2654435769 | 0;
	      me.d = 1367130551;
	      if (seed === Math.floor(seed)) {
	        // Integer seed.
	        me.a = seed / 0x100000000 | 0;
	        me.b = seed | 0;
	      } else {
	        // String seed.
	        strseed += seed;
	      }

	      // Mix in string seed, then discard an initial batch of 64 values.
	      for (var k = 0; k < strseed.length + 20; k++) {
	        me.b ^= strseed.charCodeAt(k) | 0;
	        me.next();
	      }
	    }
	    function copy(f, t) {
	      t.a = f.a;
	      t.b = f.b;
	      t.c = f.c;
	      t.d = f.d;
	      return t;
	    }
	    ;
	    function impl(seed, opts) {
	      var xg = new XorGen(seed),
	        state = opts && opts.state,
	        prng = function prng() {
	          return (xg.next() >>> 0) / 0x100000000;
	        };
	      prng.double = function () {
	        do {
	          var top = xg.next() >>> 11,
	            bot = (xg.next() >>> 0) / 0x100000000,
	            result = (top + bot) / (1 << 21);
	        } while (result === 0);
	        return result;
	      };
	      prng.int32 = xg.next;
	      prng.quick = prng;
	      if (state) {
	        if (_typeof(state) == 'object') copy(state, xg);
	        prng.state = function () {
	          return copy(xg, {});
	        };
	      }
	      return prng;
	    }
	    if (module && module.exports) {
	      module.exports = impl;
	    } else if (define && define.amd) {
	      define(function () {
	        return impl;
	      });
	    } else {
	      this.tychei = impl;
	    }
	  })(commonjsGlobal, 'object' == 'object' && module,
	  // present in node.js
	  typeof undefined == 'function' && undefined // present with an AMD loader
	  );
	})(tychei$3);
	var tycheiExports = tychei$3.exports;
	var tychei$2 = /*@__PURE__*/getDefaultExportFromCjs(tycheiExports);

	var seedrandom$3 = {exports: {}};

	var seedrandom$1 = seedrandom$3.exports;
	(function (module) {
	  (function (global, pool, math) {
	    //
	    // The following constants are related to IEEE 754 limits.
	    //

	    var width = 256,
	      // each RC4 output is 0 <= x < 256
	      chunks = 6,
	      // at least six RC4 outputs for each double
	      digits = 52,
	      // there are 52 significant digits in a double
	      rngname = 'random',
	      // rngname: name for Math.random and Math.seedrandom
	      startdenom = math.pow(width, chunks),
	      significance = math.pow(2, digits),
	      overflow = significance * 2,
	      mask = width - 1,
	      nodecrypto; // node.js crypto module, initialized at the bottom.

	    //
	    // seedrandom()
	    // This is the seedrandom function described above.
	    //
	    function seedrandom(seed, options, callback) {
	      var key = [];
	      options = options == true ? {
	        entropy: true
	      } : options || {};

	      // Flatten the seed string or build one from local entropy if needed.
	      var shortseed = mixkey(flatten(options.entropy ? [seed, tostring(pool)] : seed == null ? autoseed() : seed, 3), key);

	      // Use the seed to initialize an ARC4 generator.
	      var arc4 = new ARC4(key);

	      // This function returns a random double in [0, 1) that contains
	      // randomness in every bit of the mantissa of the IEEE 754 value.
	      var prng = function prng() {
	        var n = arc4.g(chunks),
	          // Start with a numerator n < 2 ^ 48
	          d = startdenom,
	          //   and denominator d = 2 ^ 48.
	          x = 0; //   and no 'extra last byte'.
	        while (n < significance) {
	          // Fill up all significant digits by
	          n = (n + x) * width; //   shifting numerator and
	          d *= width; //   denominator and generating a
	          x = arc4.g(1); //   new least-significant-byte.
	        }

	        while (n >= overflow) {
	          // To avoid rounding up, before adding
	          n /= 2; //   last byte, shift everything
	          d /= 2; //   right using integer math until
	          x >>>= 1; //   we have exactly the desired bits.
	        }

	        return (n + x) / d; // Form the number within [0, 1).
	      };

	      prng.int32 = function () {
	        return arc4.g(4) | 0;
	      };
	      prng.quick = function () {
	        return arc4.g(4) / 0x100000000;
	      };
	      prng.double = prng;

	      // Mix the randomness into accumulated entropy.
	      mixkey(tostring(arc4.S), pool);

	      // Calling convention: what to return as a function of prng, seed, is_math.
	      return (options.pass || callback || function (prng, seed, is_math_call, state) {
	        if (state) {
	          // Load the arc4 state from the given state if it has an S array.
	          if (state.S) {
	            copy(state, arc4);
	          }
	          // Only provide the .state method if requested via options.state.
	          prng.state = function () {
	            return copy(arc4, {});
	          };
	        }

	        // If called as a method of Math (Math.seedrandom()), mutate
	        // Math.random because that is how seedrandom.js has worked since v1.0.
	        if (is_math_call) {
	          math[rngname] = prng;
	          return seed;
	        }

	        // Otherwise, it is a newer calling convention, so return the
	        // prng directly.
	        else return prng;
	      })(prng, shortseed, 'global' in options ? options.global : this == math, options.state);
	    }

	    //
	    // ARC4
	    //
	    // An ARC4 implementation.  The constructor takes a key in the form of
	    // an array of at most (width) integers that should be 0 <= x < (width).
	    //
	    // The g(count) method returns a pseudorandom integer that concatenates
	    // the next (count) outputs from ARC4.  Its return value is a number x
	    // that is in the range 0 <= x < (width ^ count).
	    //
	    function ARC4(key) {
	      var t,
	        keylen = key.length,
	        me = this,
	        i = 0,
	        j = me.i = me.j = 0,
	        s = me.S = [];

	      // The empty key [] is treated as [0].
	      if (!keylen) {
	        key = [keylen++];
	      }

	      // Set up S using the standard key scheduling algorithm.
	      while (i < width) {
	        s[i] = i++;
	      }
	      for (i = 0; i < width; i++) {
	        s[i] = s[j = mask & j + key[i % keylen] + (t = s[i])];
	        s[j] = t;
	      }

	      // The "g" method returns the next (count) outputs as one number.
	      (me.g = function (count) {
	        // Using instance members instead of closure state nearly doubles speed.
	        var t,
	          r = 0,
	          i = me.i,
	          j = me.j,
	          s = me.S;
	        while (count--) {
	          t = s[i = mask & i + 1];
	          r = r * width + s[mask & (s[i] = s[j = mask & j + t]) + (s[j] = t)];
	        }
	        me.i = i;
	        me.j = j;
	        return r;
	        // For robust unpredictability, the function call below automatically
	        // discards an initial batch of values.  This is called RC4-drop[256].
	        // See http://google.com/search?q=rsa+fluhrer+response&btnI
	      })(width);
	    }

	    //
	    // copy()
	    // Copies internal state of ARC4 to or from a plain object.
	    //
	    function copy(f, t) {
	      t.i = f.i;
	      t.j = f.j;
	      t.S = f.S.slice();
	      return t;
	    }
	    ;

	    //
	    // flatten()
	    // Converts an object tree to nested arrays of strings.
	    //
	    function flatten(obj, depth) {
	      var result = [],
	        typ = _typeof(obj),
	        prop;
	      if (depth && typ == 'object') {
	        for (prop in obj) {
	          try {
	            result.push(flatten(obj[prop], depth - 1));
	          } catch (e) {}
	        }
	      }
	      return result.length ? result : typ == 'string' ? obj : obj + '\0';
	    }

	    //
	    // mixkey()
	    // Mixes a string seed into a key that is an array of integers, and
	    // returns a shortened string seed that is equivalent to the result key.
	    //
	    function mixkey(seed, key) {
	      var stringseed = seed + '',
	        smear,
	        j = 0;
	      while (j < stringseed.length) {
	        key[mask & j] = mask & (smear ^= key[mask & j] * 19) + stringseed.charCodeAt(j++);
	      }
	      return tostring(key);
	    }

	    //
	    // autoseed()
	    // Returns an object for autoseeding, using window.crypto and Node crypto
	    // module if available.
	    //
	    function autoseed() {
	      try {
	        var out;
	        if (nodecrypto && (out = nodecrypto.randomBytes)) {
	          // The use of 'out' to remember randomBytes makes tight minified code.
	          out = out(width);
	        } else {
	          out = new Uint8Array(width);
	          (global.crypto || global.msCrypto).getRandomValues(out);
	        }
	        return tostring(out);
	      } catch (e) {
	        var browser = global.navigator,
	          plugins = browser && browser.plugins;
	        return [+new Date(), global, plugins, global.screen, tostring(pool)];
	      }
	    }

	    //
	    // tostring()
	    // Converts an array of charcodes to a string
	    //
	    function tostring(a) {
	      return String.fromCharCode.apply(0, a);
	    }

	    //
	    // When seedrandom.js is loaded, we immediately mix a few bits
	    // from the built-in RNG into the entropy pool.  Because we do
	    // not want to interfere with deterministic PRNG state later,
	    // seedrandom will not call math.random on its own again after
	    // initialization.
	    //
	    mixkey(math.random(), pool);

	    //
	    // Nodejs and AMD support: export the implementation as a module using
	    // either convention.
	    //
	    if ('object' == 'object' && module.exports) {
	      module.exports = seedrandom;
	      // When in node.js, try using crypto package for autoseeding.
	      try {
	        nodecrypto = require('crypto');
	      } catch (ex) {}
	    } else if (typeof undefined == 'function' && undefined.amd) {
	      undefined(function () {
	        return seedrandom;
	      });
	    } else {
	      // When included as a plain script, set up Math.seedrandom global.
	      math['seed' + rngname] = seedrandom;
	    }

	    // End anonymous scope, and pass initial values.
	  })(
	  // global: `self` in browsers (including strict mode and web workers),
	  // otherwise `this` in Node and other environments
	  typeof self !== 'undefined' ? self : commonjsGlobal, [],
	  // pool: entropy pool starts empty
	  Math // math: package containing random, pow, and seedrandom
	  );
	})(seedrandom$3);
	var seedrandomExports = seedrandom$3.exports;
	var seedrandom$2 = /*@__PURE__*/getDefaultExportFromCjs(seedrandomExports);

	// A library of seedable RNGs implemented in Javascript.
	//
	// Usage:
	//
	// var seedrandom = require('seedrandom');
	// var random = seedrandom(1); // or any seed.
	// var x = random();       // 0 <= x < 1.  Every bit is random.
	// var x = random.quick(); // 0 <= x < 1.  32 bits of randomness.

	// alea, a 53-bit multiply-with-carry generator by Johannes Baagøe.
	// Period: ~2^116
	// Reported to pass all BigCrush tests.
	var alea = aleaExports;

	// xor128, a pure xor-shift generator by George Marsaglia.
	// Period: 2^128-1.
	// Reported to fail: MatrixRank and LinearComp.
	var xor128 = xor128Exports;

	// xorwow, George Marsaglia's 160-bit xor-shift combined plus weyl.
	// Period: 2^192-2^32
	// Reported to fail: CollisionOver, SimpPoker, and LinearComp.
	var xorwow = xorwowExports;

	// xorshift7, by François Panneton and Pierre L'ecuyer, takes
	// a different approach: it adds robustness by allowing more shifts
	// than Marsaglia's original three.  It is a 7-shift generator
	// with 256 bits, that passes BigCrush with no systmatic failures.
	// Period 2^256-1.
	// No systematic BigCrush failures reported.
	var xorshift7 = xorshift7Exports;

	// xor4096, by Richard Brent, is a 4096-bit xor-shift with a
	// very long period that also adds a Weyl generator. It also passes
	// BigCrush with no systematic failures.  Its long period may
	// be useful if you have many generators and need to avoid
	// collisions.
	// Period: 2^4128-2^32.
	// No systematic BigCrush failures reported.
	var xor4096 = xor4096Exports;

	// Tyche-i, by Samuel Neves and Filipe Araujo, is a bit-shifting random
	// number generator derived from ChaCha, a modern stream cipher.
	// https://eden.dei.uc.pt/~sneves/pubs/2011-snfa2.pdf
	// Period: ~2^127
	// No systematic BigCrush failures reported.
	var tychei = tycheiExports;

	// The original ARC4-based prng included in this library.
	// Period: ~2^1600
	var sr = seedrandomExports;
	sr.alea = alea;
	sr.xor128 = xor128;
	sr.xorwow = xorwow;
	sr.xorshift7 = xorshift7;
	sr.xor4096 = xor4096;
	sr.tychei = tychei;
	var seedrandom = sr;
	var index$1 = /*@__PURE__*/getDefaultExportFromCjs(seedrandom);

	var TEST_EPSILON_FLOAT32 = 1e-3;
	var TEST_EPSILON_FLOAT16 = 1e-1;
	function expectArraysClose(actual, expected, epsilon) {
	  if (epsilon == null) {
	    epsilon = testEpsilon();
	  }
	  return expectArraysPredicate(actual, expected, function (a, b) {
	    return areClose(a, b, epsilon);
	  });
	}
	function testEpsilon() {
	  return ENGINE.backend.floatPrecision() === 32 ? TEST_EPSILON_FLOAT32 : TEST_EPSILON_FLOAT16;
	}
	function expectArraysPredicate(actual, expected, predicate) {
	  var checkClassType = true;
	  if (isTypedArray(actual) || isTypedArray(expected)) {
	    checkClassType = false;
	  }
	  if (isTypedArray(actual) && isTypedArray(expected)) {
	    checkClassType = true;
	  }
	  if (checkClassType) {
	    var aType = actual.constructor.name;
	    var bType = expected.constructor.name;
	    if (aType !== bType) {
	      throw new Error("Arrays are of different type. Actual: ".concat(aType, ". ") + "Expected: ".concat(bType));
	    }
	  }
	  if (Array.isArray(actual) && Array.isArray(expected)) {
	    var actualShape = inferShape(actual);
	    var expectedShape = inferShape(expected);
	    if (!arraysEqual(actualShape, expectedShape)) {
	      throw new Error("Arrays have different shapes. " + "Actual: [".concat(actualShape, "]. Expected: [").concat(expectedShape, "]"));
	    }
	  }
	  var actualFlat = isTypedArray(actual) ? actual : flatten$2(actual);
	  var expectedFlat = isTypedArray(expected) ? expected : flatten$2(expected);
	  if (actualFlat.length !== expectedFlat.length) {
	    throw new Error("Arrays have different lengths actual: ".concat(actualFlat.length, " vs ") + "expected: ".concat(expectedFlat.length, ".\n") + "Actual:   ".concat(actualFlat, ".\n") + "Expected: ".concat(expectedFlat, "."));
	  }
	  for (var i = 0; i < expectedFlat.length; ++i) {
	    var a = actualFlat[i];
	    var e = expectedFlat[i];
	    if (!predicate(a, e)) {
	      throw new Error("Arrays differ: actual[".concat(i, "] = ").concat(a, ", expected[").concat(i, "] = ").concat(e, ".\n") + "Actual:   ".concat(actualFlat, ".\n") + "Expected: ".concat(expectedFlat, "."));
	    }
	  }
	  if (typeof expect !== 'undefined') {
	    expect().nothing();
	  }
	}
	function expectPromiseToFail(fn, done) {
	  fn().then(function () {
	    return done.fail();
	  }, function () {
	    return done();
	  });
	  if (typeof expect !== 'undefined') {
	    expect().nothing();
	  }
	}
	function expectArraysEqual(actual, expected) {
	  var exp = typeof expected === 'string' || typeof expected === 'number' || typeof expected === 'boolean' ? [expected] : expected;
	  if (isString(actual) || isString(actual[0]) || isString(expected) || isString(expected[0])) {
	    // tslint:disable-next-line: triple-equals
	    return expectArraysPredicate(actual, exp, function (a, b) {
	      return a == b;
	    });
	  }
	  return expectArraysPredicate(actual, expected, function (a, b) {
	    return areClose(a, b, 0);
	  });
	}
	function expectNumbersClose(a, e, epsilon) {
	  if (epsilon == null) {
	    epsilon = testEpsilon();
	  }
	  if (!areClose(a, e, epsilon)) {
	    throw new Error("Numbers differ: actual === ".concat(a, ", expected === ").concat(e));
	  }
	  if (typeof expect !== 'undefined') {
	    expect().nothing();
	  }
	}
	function areClose(a, e, epsilon) {
	  if (!isFinite(a) && !isFinite(e)) {
	    return true;
	  }
	  if (isNaN(a) || isNaN(e) || Math.abs(a - e) > epsilon) {
	    return false;
	  }
	  return true;
	}
	function expectValuesInRange(actual, low, high) {
	  for (var i = 0; i < actual.length; i++) {
	    if (actual[i] < low || actual[i] > high) {
	      throw new Error("Value out of range:".concat(actual[i], " low: ").concat(low, ", high: ").concat(high));
	    }
	  }
	}
	function expectArrayBuffersEqual(actual, expected) {
	  // Safari does not like comparing ArrayBuffers directly. Wrapping in
	  // a Float32Array solves this issue.
	  var actualArray = new Float32Array(actual);
	  var expectedArray = new Float32Array(expected);
	  if (actualArray.length !== expectedArray.length) {
	    throw new Error('Expected ArrayBuffer to be of length ' + "".concat(expectedArray.length, ", but it was ").concat(actualArray.length));
	  }
	  for (var i = 0; i < expectedArray.length; i++) {
	    if (actualArray[i] !== expectedArray[i]) {
	      throw new Error("Expected ArrayBuffer value at ".concat(i, " to be ") + "".concat(expectedArray[i], " but got ").concat(actualArray[i], " instead"));
	    }
	  }
	}
	/** Encodes strings into utf-8 bytes. */
	function encodeStrings(a) {
	  for (var i = 0; i < a.length; i++) {
	    var val = a[i];
	    if (Array.isArray(val)) {
	      encodeStrings(val);
	    } else {
	      a[i] = encodeString(val);
	    }
	  }
	  return a;
	}
	/** Creates an HTMLVideoElement with autoplay-friendly default settings. */
	function createVideoElement(source) {
	  var video = document.createElement('video');
	  if ('playsInline' in video) {
	    // tslint:disable-next-line:no-any
	    video.playsInline = true;
	  }
	  video.muted = true;
	  video.loop = true;
	  video.style.position = 'fixed';
	  video.style.left = '0px';
	  video.style.top = '0px';
	  video.preload = 'auto';
	  video.appendChild(source);
	  return new Promise(function (resolve) {
	    video.addEventListener('loadeddata', function (_) {
	      return resolve(video);
	    });
	    video.load();
	  });
	}
	function play(_x) {
	  return _play.apply(this, arguments);
	}
	function _play() {
	  _play = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(video) {
	    return _regeneratorRuntime().wrap(function _callee$(_context) {
	      while (1) switch (_context.prev = _context.next) {
	        case 0:
	          _context.next = 2;
	          return video.play();
	        case 2:
	          if (!('requestVideoFrameCallback' in video)) {
	            _context.next = 5;
	            break;
	          }
	          _context.next = 5;
	          return new Promise(function (resolve) {
	            // tslint:disable-next-line:no-any
	            video.requestVideoFrameCallback(resolve);
	          });
	        case 5:
	        case "end":
	          return _context.stop();
	      }
	    }, _callee);
	  }));
	  return _play.apply(this, arguments);
	}

	var test_util = {
		__proto__: null,
		TEST_EPSILON_FLOAT16: TEST_EPSILON_FLOAT16,
		createVideoElement: createVideoElement,
		encodeStrings: encodeStrings,
		expectArrayBuffersEqual: expectArrayBuffersEqual,
		expectArraysClose: expectArraysClose,
		expectArraysEqual: expectArraysEqual,
		expectNumbersClose: expectNumbersClose,
		expectPromiseToFail: expectPromiseToFail,
		expectValuesInRange: expectValuesInRange,
		play: play,
		testEpsilon: testEpsilon
	};

	// https://en.wikipedia.org/wiki/Marsaglia_polar_method
	var MPRandGauss = /*#__PURE__*/function () {
	  function MPRandGauss(mean, stdDeviation, dtype, truncated, seed) {
	    _classCallCheck(this, MPRandGauss);
	    this.mean = mean;
	    this.stdDev = stdDeviation;
	    this.dtype = dtype;
	    this.nextVal = NaN;
	    this.truncated = truncated;
	    if (this.truncated) {
	      this.upper = this.mean + this.stdDev * 2;
	      this.lower = this.mean - this.stdDev * 2;
	    }
	    var seedValue = seed ? seed : Math.random();
	    this.random = seedrandom.alea(seedValue.toString());
	  }
	  /** Returns next sample from a Gaussian distribution. */
	  _createClass(MPRandGauss, [{
	    key: "nextValue",
	    value: function nextValue() {
	      if (!isNaN(this.nextVal)) {
	        var value = this.nextVal;
	        this.nextVal = NaN;
	        return value;
	      }
	      var resultX, resultY;
	      var isValid = false;
	      while (!isValid) {
	        var v1 = void 0,
	          v2 = void 0,
	          s = void 0;
	        do {
	          v1 = 2 * this.random() - 1;
	          v2 = 2 * this.random() - 1;
	          s = v1 * v1 + v2 * v2;
	        } while (s >= 1 || s === 0);
	        var mul = Math.sqrt(-2.0 * Math.log(s) / s);
	        resultX = this.mean + this.stdDev * v1 * mul;
	        resultY = this.mean + this.stdDev * v2 * mul;
	        if (!this.truncated || this.isValidTruncated(resultX)) {
	          isValid = true;
	        }
	      }
	      if (!this.truncated || this.isValidTruncated(resultY)) {
	        this.nextVal = this.convertValue(resultY);
	      }
	      return this.convertValue(resultX);
	    }
	    /** Handles proper rounding for non-floating-point numbers. */
	  }, {
	    key: "convertValue",
	    value: function convertValue(value) {
	      if (this.dtype == null || this.dtype === 'float32') {
	        return value;
	      }
	      return Math.round(value);
	    }
	    /** Returns true if less than 2-standard-deviations from the mean. */
	  }, {
	    key: "isValidTruncated",
	    value: function isValidTruncated(value) {
	      return value <= this.upper && value >= this.lower;
	    }
	  }]);
	  return MPRandGauss;
	}();
	// Marsaglia, George, and Wai Wan Tsang. 2000. "A Simple Method for Generating
	// Gamma Variables."
	var RandGamma = /*#__PURE__*/function () {
	  function RandGamma(alpha, beta, dtype, seed) {
	    _classCallCheck(this, RandGamma);
	    this.alpha = alpha;
	    this.beta = 1 / beta; // convert rate to scale parameter
	    this.dtype = dtype;
	    var seedValue = seed ? seed : Math.random();
	    this.randu = seedrandom.alea(seedValue.toString());
	    this.randn = new MPRandGauss(0, 1, dtype, false, this.randu());
	    if (alpha < 1) {
	      this.d = alpha + 2 / 3;
	    } else {
	      this.d = alpha - 1 / 3;
	    }
	    this.c = 1 / Math.sqrt(9 * this.d);
	  }
	  /** Returns next sample from a gamma distribution. */
	  _createClass(RandGamma, [{
	    key: "nextValue",
	    value: function nextValue() {
	      var x2, v0, v1, x, u, v;
	      while (true) {
	        do {
	          x = this.randn.nextValue();
	          v = 1 + this.c * x;
	        } while (v <= 0);
	        v *= v * v;
	        x2 = x * x;
	        v0 = 1 - 0.331 * x2 * x2;
	        v1 = 0.5 * x2 + this.d * (1 - v + Math.log(v));
	        u = this.randu();
	        if (u < v0 || Math.log(u) < v1) {
	          break;
	        }
	      }
	      v = 1 / this.beta * this.d * v;
	      if (this.alpha < 1) {
	        v *= Math.pow(this.randu(), 1 / this.alpha);
	      }
	      return this.convertValue(v);
	    }
	    /** Handles proper rounding for non-floating-point numbers. */
	  }, {
	    key: "convertValue",
	    value: function convertValue(value) {
	      if (this.dtype === 'float32') {
	        return value;
	      }
	      return Math.round(value);
	    }
	  }]);
	  return RandGamma;
	}();
	var UniformRandom = /*#__PURE__*/function () {
	  function UniformRandom() {
	    var _this = this;
	    var min = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
	    var max = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
	    var dtype = arguments.length > 2 ? arguments[2] : undefined;
	    var seed = arguments.length > 3 ? arguments[3] : undefined;
	    _classCallCheck(this, UniformRandom);
	    /** Handles proper rounding for non floating point numbers. */
	    this.canReturnFloat = function () {
	      return _this.dtype == null || _this.dtype === 'float32';
	    };
	    this.min = min;
	    this.range = max - min;
	    this.dtype = dtype;
	    if (seed == null) {
	      seed = Math.random();
	    }
	    if (typeof seed === 'number') {
	      seed = seed.toString();
	    }
	    if (!this.canReturnFloat() && this.range <= 1) {
	      throw new Error("The difference between ".concat(min, " - ").concat(max, " <= 1 and dtype is not float"));
	    }
	    this.random = seedrandom.alea(seed);
	  }
	  _createClass(UniformRandom, [{
	    key: "convertValue",
	    value: function convertValue(value) {
	      if (this.canReturnFloat()) {
	        return value;
	      }
	      return Math.round(value);
	    }
	  }, {
	    key: "nextValue",
	    value: function nextValue() {
	      return this.convertValue(this.min + this.range * this.random());
	    }
	  }]);
	  return UniformRandom;
	}();
	function jarqueBeraNormalityTest(values) {
	  // https://en.wikipedia.org/wiki/Jarque%E2%80%93Bera_test
	  var n = values.length;
	  var s = skewness(values);
	  var k = kurtosis(values);
	  var jb = n / 6 * (Math.pow(s, 2) + 0.25 * Math.pow(k - 3, 2));
	  // JB test requires 2-degress of freedom from Chi-Square @ 0.95:
	  // http://www.itl.nist.gov/div898/handbook/eda/section3/eda3674.htm
	  var CHI_SQUARE_2DEG = 5.991;
	  if (jb > CHI_SQUARE_2DEG) {
	    throw new Error("Invalid p-value for JB: ".concat(jb));
	  }
	}
	function expectArrayInMeanStdRange(actual, expectedMean, expectedStdDev, epsilon) {
	  if (epsilon == null) {
	    epsilon = testEpsilon();
	  }
	  var actualMean = mean$2(actual);
	  expectNumbersClose(actualMean, expectedMean, epsilon);
	  expectNumbersClose(standardDeviation(actual, actualMean), expectedStdDev, epsilon);
	}
	function mean$2(values) {
	  var sum = 0;
	  for (var i = 0; i < values.length; i++) {
	    sum += values[i];
	  }
	  return sum / values.length;
	}
	function standardDeviation(values, mean) {
	  var squareDiffSum = 0;
	  for (var i = 0; i < values.length; i++) {
	    var diff = values[i] - mean;
	    squareDiffSum += diff * diff;
	  }
	  return Math.sqrt(squareDiffSum / values.length);
	}
	function kurtosis(values) {
	  // https://en.wikipedia.org/wiki/Kurtosis
	  var valuesMean = mean$2(values);
	  var n = values.length;
	  var sum2 = 0;
	  var sum4 = 0;
	  for (var i = 0; i < n; i++) {
	    var v = values[i] - valuesMean;
	    sum2 += Math.pow(v, 2);
	    sum4 += Math.pow(v, 4);
	  }
	  return 1 / n * sum4 / Math.pow(1 / n * sum2, 2);
	}
	function skewness(values) {
	  // https://en.wikipedia.org/wiki/Skewness
	  var valuesMean = mean$2(values);
	  var n = values.length;
	  var sum2 = 0;
	  var sum3 = 0;
	  for (var i = 0; i < n; i++) {
	    var v = values[i] - valuesMean;
	    sum2 += Math.pow(v, 2);
	    sum3 += Math.pow(v, 3);
	  }
	  return 1 / n * sum3 / Math.pow(1 / (n - 1) * sum2, 3 / 2);
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a `tf.Tensor` with values sampled from a gamma distribution.
	 *
	 * ```js
	 * tf.randomGamma([2, 2], 1).print();
	 * ```
	 *
	 * @param shape An array of integers defining the output tensor shape.
	 * @param alpha The shape parameter of the gamma distribution.
	 * @param beta The inverse scale parameter of the gamma distribution. Defaults
	 *     to 1.
	 * @param dtype The data type of the output. Defaults to float32.
	 * @param seed The seed for the random number generator.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Random'}
	 */
	function randomGamma_(shape, alpha) {
	  var beta = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;
	  var dtype = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'float32';
	  var seed = arguments.length > 4 ? arguments[4] : undefined;
	  assertNonNegativeIntegerDimensions(shape);
	  if (beta == null) {
	    beta = 1;
	  }
	  if (dtype == null) {
	    dtype = 'float32';
	  }
	  if (dtype !== 'float32' && dtype !== 'int32') {
	    throw new Error("Unsupported data type ".concat(dtype));
	  }
	  var rgamma = new RandGamma(alpha, beta, dtype, seed);
	  var res = buffer(shape, dtype);
	  for (var i = 0; i < res.values.length; i++) {
	    res.values[i] = rgamma.nextValue();
	  }
	  return res.toTensor();
	}
	var randomGamma = /* @__PURE__ */op({
	  randomGamma_: randomGamma_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a `tf.Tensor` with values sampled from a normal distribution.
	 *
	 * ```js
	 * tf.randomNormal([2, 2]).print();
	 * ```
	 *
	 * @param shape An array of integers defining the output tensor shape.
	 * @param mean The mean of the normal distribution.
	 * @param stdDev The standard deviation of the normal distribution.
	 * @param dtype The data type of the output.
	 * @param seed The seed for the random number generator.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Random'}
	 */
	function randomNormal_(shape) {
	  var mean = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
	  var stdDev = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;
	  var dtype = arguments.length > 3 ? arguments[3] : undefined;
	  var seed = arguments.length > 4 ? arguments[4] : undefined;
	  assertNonNegativeIntegerDimensions(shape);
	  if (dtype != null && dtype === 'bool') {
	    throw new Error("Unsupported data type ".concat(dtype));
	  }
	  var randGauss = new MPRandGauss(mean, stdDev, dtype, false /* truncated */, seed);
	  var res = buffer(shape, dtype);
	  for (var i = 0; i < res.values.length; i++) {
	    res.values[i] = randGauss.nextValue();
	  }
	  return res.toTensor();
	}
	var randomNormal$2 = /* @__PURE__ */op({
	  randomNormal_: randomNormal_
	});

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a `tf.Tensor` with values sampled from a normal distribution.
	 *
	 * The generated values will have mean 0 and standard deviation 1.
	 *
	 * ```js
	 * tf.randomStandardNormal([2, 2]).print();
	 * ```
	 *
	 * @param shape An array of integers defining the output tensor shape.
	 * @param dtype The data type of the output.
	 * @param seed The seed for the random number generator.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Random'}
	 */
	function randomStandardNormal_(shape, dtype, seed) {
	  if (dtype != null && dtype === 'bool') {
	    throw new Error("Unsupported data type ".concat(dtype));
	  }
	  return randomNormal$2(shape, 0, 1, dtype, seed);
	}
	var randomStandardNormal = /* @__PURE__ */op({
	  randomStandardNormal_: randomStandardNormal_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a `tf.Tensor` with values sampled from a uniform distribution.
	 *
	 * The generated values follow a uniform distribution in the range [minval,
	 * maxval). The lower bound minval is included in the range, while the upper
	 * bound maxval is excluded.
	 *
	 * ```js
	 * tf.randomUniform([2, 2]).print();
	 * ```
	 *
	 * @param shape An array of integers defining the output tensor shape.
	 * @param minval The lower bound on the range of random values to generate.
	 *   Defaults to 0.
	 * @param maxval The upper bound on the range of random values to generate.
	 *   Defaults to 1.
	 * @param dtype The data type of the output tensor. Defaults to 'float32'.
	 * @param seed An optional int. Defaults to 0. If seed is set to be non-zero,
	 *   the random number generator is seeded by the given seed. Otherwise, it is
	 *   seeded by a random seed.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Random'}
	 */
	function randomUniform_(shape) {
	  var minval = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
	  var maxval = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;
	  var dtype = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'float32';
	  var seed = arguments.length > 4 ? arguments[4] : undefined;
	  assertNonNegativeIntegerDimensions(shape);
	  var res = buffer(shape, dtype);
	  var random = new UniformRandom(minval, maxval, null, seed);
	  for (var i = 0; i < res.values.length; i++) {
	    res.values[i] = random.nextValue();
	  }
	  return res.toTensor();
	}
	var randomUniform$1 = /* @__PURE__ */op({
	  randomUniform_: randomUniform_
	});

	/**
	 * @license
	 * Copyright 2023 Google LLC.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a `tf.Tensor` with integers sampled from a uniform distribution.
	 *
	 * The generated values are uniform integers in the range [minval, maxval). The
	 * lower bound minval is included in the range, while the upper bound maxval is
	 * excluded.
	 *
	 * ```js
	 * tf.randomUniformInt([2, 2], 0, 10).print();
	 * ```
	 *
	 * @param shape An array of integers defining the output tensor shape.
	 * @param minval Inclusive lower bound on the generated integers.
	 * @param maxval Exclusive upper bound on the generated integers.
	 * @param seed An optional int. Defaults to 0. If seed is set to be non-zero,
	 *   the random number generator is seeded by the given seed. Otherwise, it is
	 *   seeded by a random seed.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Random'}
	 */
	function randomUniformInt_(shape, minval, maxval, seed) {
	  // TODO(mattsoulanille): Handle optional seed2 input.
	  return randomUniform$1(shape, minval, maxval, 'int32', seed);
	}
	var randomUniformInt = /* @__PURE__ */op({
	  randomUniformInt_: randomUniformInt_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a new `tf.Tensor1D` filled with the numbers in the range provided.
	 *
	 * The tensor is a half-open interval meaning it includes start, but
	 * excludes stop. Decrementing ranges and negative step values are also
	 * supported.
	 *
	 *
	 * ```js
	 * tf.range(0, 9, 2).print();
	 * ```
	 *
	 * @param start An integer start value
	 * @param stop An integer stop value
	 * @param step An integer increment (will default to 1 or -1)
	 * @param dtype The data type of the output tensor. Defaults to 'float32'.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function range$3(start, stop) {
	  var step = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;
	  var dtype = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'float32';
	  if (step === 0) {
	    throw new Error('Cannot have a step of zero');
	  }
	  var attrs = {
	    start: start,
	    stop: stop,
	    step: step,
	    dtype: dtype
	  };
	  return ENGINE.runKernel(Range, {} /* inputs */, attrs);
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Returns the real part of a complex (or real) tensor.
	 *
	 * Given a tensor input, this operation returns a tensor of type float that is
	 * the real part of each element in input considered as a complex number.
	 *
	 * If the input is real, it simply makes a clone.
	 *
	 * ```js
	 * const x = tf.complex([-2.25, 3.25], [4.75, 5.75]);
	 * tf.real(x).print();
	 * ```
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function real_(input) {
	  var $input = convertToTensor(input, 'input', 'real');
	  var inputs = {
	    input: $input
	  };
	  return ENGINE.runKernel(Real, inputs);
	}
	var real$2 = /* @__PURE__ */op({
	  real_: real_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes reciprocal of x element-wise: `1 / x`
	 *
	 * ```js
	 * const x = tf.tensor1d([0, 1, 2]);
	 *
	 * x.reciprocal().print();  // or tf.reciprocal(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function reciprocal_(x) {
	  var $x = convertToTensor(x, 'x', 'reciprocal');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Reciprocal, inputs);
	}
	var reciprocal$2 = /* @__PURE__ */op({
	  reciprocal_: reciprocal_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes rectified linear element-wise: `max(x, 0)`.
	 *
	 * ```js
	 * const x = tf.tensor1d([-1, 2, -3, 4]);
	 *
	 * x.relu().print();  // or tf.relu(x)
	 * ```
	 * @param x The input tensor. If the dtype is `bool`, the output dtype will be
	 *     `int32`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function relu_(x) {
	  var $x = convertToTensor(x, 'x', 'relu');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Relu$1, inputs);
	}
	var relu$2 = /* @__PURE__ */op({
	  relu_: relu_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes rectified linear 6 element-wise: `min(max(x, 0), 6)`.
	 *
	 * ```js
	 * const x = tf.tensor1d([-1, 2, -3, 8]);
	 *
	 * x.relu6().print();  // or tf.relu6(x)
	 * ```
	 * @param x The input tensor. If the dtype is `bool`, the output dtype will be
	 *     `int32`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function relu6_(x) {
	  var $x = convertToTensor(x, 'x', 'relu6');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Relu6$1, inputs);
	}
	var relu6$2 = /* @__PURE__ */op({
	  relu6_: relu6_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Reverses a `tf.Tensor` along a specified axis.
	 *
	 * Also available are stricter rank-specific methods that assert that `x` is
	 * of the given rank:
	 *   - `tf.reverse1d`
	 *   - `tf.reverse2d`
	 *   - `tf.reverse3d`
	 *   - `tf.reverse4d`
	 *
	 * Except `tf.reverse1d` (which does not have axis param), all methods have
	 * same signature as this method.
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3, 4]);
	 *
	 * x.reverse().print();
	 * ```
	 *
	 * ```js
	 * const x = tf.tensor2d([1, 2, 3, 4], [2, 2]);
	 *
	 * const axis = 1;
	 * x.reverse(axis).print();
	 * ```
	 * @param x The input tensor to be reversed.
	 * @param axis The set of dimensions to reverse. Must be in the
	 *     range [-rank(x), rank(x)). Defaults to all axes.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Slicing and Joining'}
	 */
	function reverse_(x, axis) {
	  var $x = convertToTensor(x, 'x', 'reverse');
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    dims: axis
	  };
	  return ENGINE.runKernel(Reverse, inputs, attrs);
	}
	var reverse$2 = /* @__PURE__ */op({
	  reverse_: reverse_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Reverses a `tf.Tensor1D`.
	 *
	 * @param x The input tensor.
	 */
	function reverse1d_(x) {
	  var $x = convertToTensor(x, 'x', 'reverse');
	  assert$1($x.rank === 1, function () {
	    return "Error in reverse1D: x must be rank 1 but got rank ".concat($x.rank, ".");
	  });
	  return reverse$2($x, 0);
	}
	var reverse1d = /* @__PURE__ */op({
	  reverse1d_: reverse1d_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Reverses a `tf.Tensor2D` along a specified axis.
	 *
	 * @param x The input tensor.
	 * @param axis The set of dimensions to reverse. Must be in the
	 *     range [-rank(x), rank(x)). Defaults to all axes.
	 */
	function reverse2d_(x, axis) {
	  var $x = convertToTensor(x, 'x', 'reverse');
	  assert$1($x.rank === 2, function () {
	    return "Error in reverse2D: x must be rank 2 but got rank ".concat($x.rank, ".");
	  });
	  return reverse$2($x, axis);
	}
	var reverse2d = /* @__PURE__ */op({
	  reverse2d_: reverse2d_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Reverses a `tf.Tensor3D` along a specified axis.
	 *
	 * @param x The input tensor.
	 * @param axis The set of dimensions to reverse. Must be in the
	 *     range [-rank(x), rank(x)). Defaults to all axes.
	 */
	function reverse3d_(x, axis) {
	  var $x = convertToTensor(x, 'x', 'reverse');
	  assert$1($x.rank === 3, function () {
	    return "Error in reverse3D: x must be rank 3 but got rank ".concat($x.rank, ".");
	  });
	  return reverse$2($x, axis);
	}
	var reverse3d = /* @__PURE__ */op({
	  reverse3d_: reverse3d_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Reverses a `tf.Tensor4D` along a specified axis.
	 *
	 * @param x The input tensor.
	 * @param axis The set of dimensions to reverse. Must be in the
	 *     range [-rank(x), rank(x)). Defaults to all axes.
	 */
	function reverse4d_(x, axis) {
	  var $x = convertToTensor(x, 'x', 'reverse');
	  assert$1($x.rank === 4, function () {
	    return "Error in reverse4D: x must be rank 4 but got rank ".concat($x.rank, ".");
	  });
	  return reverse$2($x, axis);
	}
	var reverse4d = /* @__PURE__ */op({
	  reverse4d_: reverse4d_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes round of input `tf.Tensor` element-wise: `round(x)`.
	 * It implements banker's rounding.
	 *
	 * ```js
	 * const x = tf.tensor1d([.6, 1.1, -3.3]);
	 *
	 * x.round().print();  // or tf.round(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function round_(x) {
	  var $x = convertToTensor(x, 'x', 'round');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Round, inputs);
	}
	var round$2 = /* @__PURE__ */op({
	  round_: round_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes reciprocal of square root of the input `tf.Tensor` element-wise:
	 * `y = 1 / sqrt(x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 4, -1]);
	 *
	 * x.rsqrt().print();  // or tf.rsqrt(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function rsqrt_(x) {
	  var $x = convertToTensor(x, 'x', 'rsqrt', 'float32');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Rsqrt, inputs);
	}
	var rsqrt$2 = /* @__PURE__ */op({
	  rsqrt_: rsqrt_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes scaled exponential linear element-wise.
	 *
	 * `x < 0 ? scale * alpha * (exp(x) - 1) : scale * x`
	 *
	 * ```js
	 * const x = tf.tensor1d([-1, 2, -3, 4]);
	 *
	 * x.selu().print();  // or tf.selu(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function selu_(x) {
	  var $x = convertToTensor(x, 'x', 'selu');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Selu$1, inputs);
	}
	var selu$2 = /* @__PURE__ */op({
	  selu_: selu_
	});

	/**
	 * 2-D convolution with separable filters.
	 *
	 * Performs a depthwise convolution that acts separately on channels followed
	 * by a pointwise convolution that mixes channels. Note that this is
	 * separability between dimensions [1, 2] and 3, not spatial separability
	 * between dimensions 1 and 2.
	 *
	 * See
	 * [https://www.tensorflow.org/api_docs/python/tf/nn/separable_conv2d](
	 *     https://www.tensorflow.org/api_docs/python/tf/nn/separable_conv2d)
	 * for more details.
	 *
	 * @param x The input tensor, of rank 4 or rank 3, of shape
	 *     `[batch, height, width, inChannels]`. If rank 3, batch of 1 is
	 * assumed.
	 * @param depthwiseFilter The depthwise filter tensor, rank 4, of shape
	 *     `[filterHeight, filterWidth, inChannels, channelMultiplier]`. This is
	 *     the filter used in the first step.
	 * @param pointwiseFilter The pointwise filter tensor, rank 4, of shape
	 *     `[1, 1, inChannels * channelMultiplier, outChannels]`. This is
	 *     the filter used in the second step.
	 * @param strides The strides of the convolution: `[strideHeight,
	 * strideWidth]`. If strides is a single number, then `strideHeight ==
	 * strideWidth`.
	 * @param pad The type of padding algorithm.
	 *   - `same` and stride 1: output will be of same size as input,
	 *       regardless of filter size.
	 *   - `valid`: output will be smaller than input if filter is larger
	 *       than 1x1.
	 *   - For more info, see this guide:
	 *     [https://www.tensorflow.org/api_docs/python/tf/nn/convolution](
	 *          https://www.tensorflow.org/api_docs/python/tf/nn/convolution)
	 * @param dilations The dilation rates: `[dilationHeight, dilationWidth]`
	 *     in which we sample input values across the height and width dimensions
	 *     in atrous convolution. Defaults to `[1, 1]`. If `rate` is a single
	 *     number, then `dilationHeight == dilationWidth`. If it is greater than
	 *     1, then all values of `strides` must be 1.
	 * @param dataFormat: An optional string from: "NHWC", "NCHW". Defaults to
	 *     "NHWC". Specify the data format of the input and output data. With the
	 *     default format "NHWC", the data is stored in the order of: [batch,
	 *     height, width, channels]. Only "NHWC" is currently supported.
	 *
	 * @doc {heading: 'Operations', subheading: 'Convolution'}
	 */
	function separableConv2d_(x, depthwiseFilter, pointwiseFilter, strides, pad) {
	  var dilation = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : [1, 1];
	  var dataFormat = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : 'NHWC';
	  var $x = convertToTensor(x, 'x', 'separableConv2d');
	  var $depthwiseFilter = convertToTensor(depthwiseFilter, 'depthwiseFilter', 'separableConv2d');
	  var $pointwiseFilter = convertToTensor(pointwiseFilter, 'pointwiseFilter', 'separableConv2d');
	  var x4D = $x;
	  var reshapedTo4D = false;
	  if ($x.rank === 3) {
	    reshapedTo4D = true;
	    x4D = reshape$3($x, [1, $x.shape[0], $x.shape[1], $x.shape[2]]);
	  }
	  if (dataFormat === 'NCHW') {
	    throw new Error('separableConv2d currently does not support dataFormat NCHW; only ' + 'NHWC is supported');
	  }
	  assert$1(x4D.rank === 4, function () {
	    return "Error in separableConv2d: input must be rank 4, but got " + "rank ".concat(x4D.rank, ".");
	  });
	  assert$1($depthwiseFilter.rank === 4, function () {
	    return "Error in separableConv2d: depthwise filter must be rank 4, but " + "got rank ".concat($depthwiseFilter.rank, ".");
	  });
	  assert$1($pointwiseFilter.rank === 4, function () {
	    return "Error in separableConv2d: pointwise filter must be rank 4, but " + "got rank ".concat($depthwiseFilter.rank, ".");
	  });
	  assert$1($pointwiseFilter.shape[0] === 1, function () {
	    return "Error in separableConv2d: the first dimension of pointwise filter " + " must be 1, but got ".concat($pointwiseFilter.shape[0], ".");
	  });
	  assert$1($pointwiseFilter.shape[1] === 1, function () {
	    return "Error in separableConv2d: the second dimension of pointwise " + "filter must be 1, but got ".concat($pointwiseFilter.shape[1], ".");
	  });
	  var inChannels = $depthwiseFilter.shape[2];
	  var channelMultiplier = $depthwiseFilter.shape[3];
	  assert$1($pointwiseFilter.shape[2] === inChannels * channelMultiplier, function () {
	    return "Error in separableConv2d: the third dimension of pointwise filter " + "must be ".concat(inChannels * channelMultiplier, ", ") + "but got ".concat($pointwiseFilter.shape[2], ".");
	  });
	  var depthwise = depthwiseConv2d$3(x4D, $depthwiseFilter, strides, pad, dataFormat, dilation);
	  var pointwiseStride = 1;
	  var res = conv2d$4(depthwise, $pointwiseFilter, pointwiseStride, 'valid', dataFormat);
	  if (reshapedTo4D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3]]);
	  }
	  return res;
	}
	var separableConv2d$1 = /* @__PURE__ */op({
	  separableConv2d_: separableConv2d_
	});

	/**
	 * Computes the difference between two lists of numbers.
	 *
	 * Given a Tensor `x` and a Tensor `y`, this operation returns a Tensor `out`
	 * that represents all values that are in `x` but not in `y`. The returned
	 * Tensor `out` is sorted in the same order that the numbers appear in `x`
	 * (duplicates are preserved). This operation also returns a Tensor indices that
	 * represents the position of each out element in `x`. In other words:
	 *
	 * `out[i] = x[idx[i]] for i in [0, 1, ..., out.length - 1]`
	 *
	 * ```js
	 * const x = [1, 2, 3, 4, 5, 6];
	 * const y = [1, 3, 5];
	 *
	 * const [out, indices] = await tf.setdiff1dAsync(x, y);
	 * out.print(); // [2, 4, 6]
	 * indices.print(); // [1, 3, 5]
	 * ```
	 *
	 * @param x 1-D Tensor. Values to keep.
	 * @param y 1-D Tensor. Must have the same type as x. Values to exclude in the
	 *     output.
	 * @returns Promise of Tensor tuple [out, indices].
	 *  out: Tensor with the same type as x.
	 *  indices: A Tensor of type int32.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Transformations'}
	 */
	function setdiff1dAsync_(_x, _x2) {
	  return _setdiff1dAsync_.apply(this, arguments);
	}
	function _setdiff1dAsync_() {
	  _setdiff1dAsync_ = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(x, y) {
	    var $x, $y, xVals, yVals, ySet, outputSize, i, buffer, indices, _i, p;
	    return _regeneratorRuntime().wrap(function _callee$(_context) {
	      while (1) switch (_context.prev = _context.next) {
	        case 0:
	          $x = convertToTensor(x, 'x', 'setdiff1d');
	          $y = convertToTensor(y, 'y', 'setdiff1d');
	          assert$1($x.dtype === $y.dtype, function () {
	            return "x and y should have the same dtype, but got x (".concat($x.dtype, ") and y (").concat($y.dtype, ").");
	          });
	          assert$1($x.rank === 1, function () {
	            return "x should be 1D tensor, but got x (".concat($x.shape, ").");
	          });
	          assert$1($y.rank === 1, function () {
	            return "y should be 1D tensor, but got y (".concat($y.shape, ").");
	          });
	          _context.next = 7;
	          return $x.data();
	        case 7:
	          xVals = _context.sent;
	          _context.next = 10;
	          return $y.data();
	        case 10:
	          yVals = _context.sent;
	          ySet = new Set(yVals);
	          outputSize = 0;
	          for (i = 0; i < xVals.length; i++) {
	            if (!ySet.has(xVals[i])) {
	              outputSize++;
	            }
	          }
	          buffer = new TensorBuffer([outputSize], $x.dtype);
	          indices = new TensorBuffer([outputSize], 'int32');
	          for (_i = 0, p = 0; _i < xVals.length; _i++) {
	            if (!ySet.has(xVals[_i])) {
	              buffer.values[p] = xVals[_i];
	              indices.values[p] = _i;
	              p++;
	            }
	          }
	          return _context.abrupt("return", [buffer.toTensor(), indices.toTensor()]);
	        case 18:
	        case "end":
	          return _context.stop();
	      }
	    }, _callee);
	  }));
	  return _setdiff1dAsync_.apply(this, arguments);
	}
	var setdiff1dAsync = setdiff1dAsync_;

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Returns an element-wise indication of the sign of a number.
	 *
	 * ```js
	 * const x = tf.tensor1d([.6, 1.1, -3.3, NaN, 0]);
	 *
	 * x.sign().print();  // or tf.sign(x)
	 * ```
	 * @param x The input Tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function sign_(x) {
	  var $x = convertToTensor(x, 'x', 'sign');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Sign, inputs);
	}
	var sign$3 = /* @__PURE__ */op({
	  sign_: sign_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes sin of the input Tensor element-wise: `sin(x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([0, Math.PI / 2, Math.PI * 3 / 4]);
	 *
	 * x.sin().print();  // or tf.sin(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function sin_(x) {
	  var $x = convertToTensor(x, 'x', 'sin', 'float32');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Sin, inputs);
	}
	var sin$2 = /* @__PURE__ */op({
	  sin_: sin_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes hyperbolic sin of the input `tf.Tensor` element-wise: `sinh(x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([0, 1, -1, .7]);
	 *
	 * x.sinh().print();  // or tf.sinh(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function sinh_(x) {
	  var $x = convertToTensor(x, 'x', 'sinh');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Sinh, inputs);
	}
	var sinh$2 = /* @__PURE__ */op({
	  sinh_: sinh_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Extracts a 1D slice from 1D array starting at coordinates `begin` and is
	 * of length `size`. See `slice` for details.
	 */
	function slice1d_(x, begin, size) {
	  var $x = convertToTensor(x, 'x', 'slice1d');
	  assert$1($x.rank === 1, function () {
	    return "slice1d expects a rank-1 tensor, but got a rank-".concat($x.rank, " tensor");
	  });
	  return slice$2($x, [begin], [size]);
	}
	var slice1d = /* @__PURE__ */op({
	  slice1d_: slice1d_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Extracts a 2D slice from a 2D array starting at coordinates `begin` and
	 * is of size `size`. See `slice` for details.
	 */
	function slice2d_(x, begin, size) {
	  var $x = convertToTensor(x, 'x', 'slice2d');
	  assert$1($x.rank === 2, function () {
	    return "slice2d expects a rank-2 tensor, but got a rank-".concat($x.rank, " tensor");
	  });
	  return slice$2($x, begin, size);
	}
	var slice2d = /* @__PURE__ */op({
	  slice2d_: slice2d_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Extracts a 3D slice from a 3D array starting at coordinates `begin` and
	 * is of size `size`. See `slice` for details.
	 */
	function slice3d_(x, begin, size) {
	  var $x = convertToTensor(x, 'x', 'slice3d');
	  assert$1($x.rank === 3, function () {
	    return "slice3d expects a rank-3 tensor, but got a rank-".concat($x.rank, " tensor");
	  });
	  return slice$2($x, begin, size);
	}
	var slice3d = /* @__PURE__ */op({
	  slice3d_: slice3d_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Extracts a 4D slice from a 4D array starting at coordinates `begin` and
	 * is of size `size`. See `slice` for details.
	 */
	function slice4d_(x, begin, size) {
	  var $x = convertToTensor(x, 'x', 'slice4d');
	  assert$1($x.rank === 4, function () {
	    return "slice4d expects a rank-4 tensor, but got a rank-".concat($x.rank, " tensor");
	  });
	  return slice$2($x, begin, size);
	}
	var slice4d = /* @__PURE__ */op({
	  slice4d_: slice4d_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the softmax normalized vector given the logits.
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 2, 3]);
	 *
	 * a.softmax().print();  // or tf.softmax(a)
	 * ```
	 *
	 * ```js
	 * const a = tf.tensor2d([2, 4, 6, 1, 2, 3], [2, 3]);
	 *
	 * a.softmax().print();  // or tf.softmax(a)
	 * ```
	 *
	 * @param logits The logits array.
	 * @param dim The dimension softmax would be performed on. Defaults to `-1`
	 *     which indicates the last dimension.
	 *
	 * @doc {heading: 'Operations', subheading: 'Normalization'}
	 */
	function softmax_(logits) {
	  var dim = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : -1;
	  var $logits = convertToTensor(logits, 'logits', 'softmax', 'float32');
	  if (dim === -1) {
	    dim = $logits.rank - 1;
	  }
	  if (dim !== $logits.rank - 1) {
	    throw Error('Softmax along a non-last dimension is not yet supported. ' + "Logits was rank ".concat($logits.rank, " and dim was ").concat(dim));
	  }
	  var inputs = {
	    logits: $logits
	  };
	  var attrs = {
	    dim: dim
	  };
	  return ENGINE.runKernel(Softmax$2, inputs, attrs);
	}
	var softmax$3 = /* @__PURE__ */op({
	  softmax_: softmax_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Fast Fourier transform.
	 *
	 * Computes the 1-dimensional discrete Fourier transform over the inner-most
	 * dimension of input.
	 *
	 * ```js
	 * const real = tf.tensor1d([1, 2, 3]);
	 * const imag = tf.tensor1d([1, 2, 3]);
	 * const x = tf.complex(real, imag);
	 *
	 * x.fft().print();  // tf.spectral.fft(x).print();
	 * ```
	 * @param input The complex input to compute an fft over.
	 *
	 * @doc {heading: 'Operations', subheading: 'Spectral', namespace: 'spectral'}
	 */
	function fft_(input) {
	  assert$1(input.dtype === 'complex64', function () {
	    return "The dtype for tf.spectral.fft() must be complex64 " + "but got ".concat(input.dtype, ".");
	  });
	  var inputs = {
	    input: input
	  };
	  return ENGINE.runKernel(FFT, inputs);
	}
	var fft$2 = /* @__PURE__ */op({
	  fft_: fft_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Inverse fast Fourier transform.
	 *
	 * Computes the inverse 1-dimensional discrete Fourier transform over the
	 * inner-most dimension of input.
	 *
	 * ```js
	 * const real = tf.tensor1d([1, 2, 3]);
	 * const imag = tf.tensor1d([1, 2, 3]);
	 * const x = tf.complex(real, imag);
	 *
	 * x.ifft().print();  // tf.spectral.ifft(x).print();
	 * ```
	 * @param input The complex input to compute an ifft over.
	 *
	 * @doc {heading: 'Operations', subheading: 'Spectral', namespace: 'spectral'}
	 */
	function ifft_(input) {
	  assert$1(input.dtype === 'complex64', function () {
	    return "The dtype for tf.spectral.ifft() must be complex64 " + "but got ".concat(input.dtype, ".");
	  });
	  var inputs = {
	    input: input
	  };
	  return ENGINE.runKernel(IFFT, inputs);
	}
	var ifft$2 = /* @__PURE__ */op({
	  ifft_: ifft_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Inversed real value input fast Fourier transform.
	 *
	 * Computes the 1-dimensional inversed discrete Fourier transform over the
	 * inner-most dimension of the real input.
	 *
	 * ```js
	 * const real = tf.tensor1d([1, 2, 3]);
	 * const imag = tf.tensor1d([0, 0, 0]);
	 * const x = tf.complex(real, imag);
	 *
	 * x.irfft().print();
	 * ```
	 * @param input The real value input to compute an irfft over.
	 *
	 * @doc {heading: 'Operations', subheading: 'Spectral', namespace: 'spectral'}
	 */
	function irfft_(input) {
	  var innerDimensionSize = input.shape[input.shape.length - 1];
	  var batch = input.size / innerDimensionSize;
	  var ret;
	  if (innerDimensionSize <= 2) {
	    var complexInput = reshape$3(input, [batch, innerDimensionSize]);
	    ret = ifft$2(complexInput);
	  } else {
	    // The length of unique components of the DFT of a real-valued signal
	    // is 2 * (input_len - 1)
	    var outputShape = [batch, 2 * (innerDimensionSize - 1)];
	    var realInput = reshape$3(real$2(input), [batch, innerDimensionSize]);
	    var imagInput = reshape$3(imag$2(input), [batch, innerDimensionSize]);
	    var realConjugate = reverse$2(slice$2(realInput, [0, 1], [batch, innerDimensionSize - 2]), 1);
	    var imagConjugate = mul(reverse$2(slice$2(imagInput, [0, 1], [batch, innerDimensionSize - 2]), 1), scalar(-1));
	    var r = concat$2([realInput, realConjugate], 1);
	    var i = concat$2([imagInput, imagConjugate], 1);
	    var _complexInput = reshape$3(complex$2(r, i), [outputShape[0], outputShape[1]]);
	    ret = ifft$2(_complexInput);
	  }
	  ret = real$2(ret);
	  // reshape the result if the input is 3D tensor.
	  if (input.rank === 3 && input.shape[0] !== 0) {
	    var temp = ret;
	    var _batch = input.shape[0];
	    ret = reshape$3(ret, [_batch, ret.shape[0] / _batch, ret.shape[1]]);
	    temp.dispose();
	  }
	  return ret;
	}
	var irfft = /* @__PURE__ */op({
	  irfft_: irfft_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Splits a `tf.Tensor` into sub tensors.
	 *
	 * If `numOrSizeSplits` is a number, splits `x` along dimension `axis`
	 * into `numOrSizeSplits` smaller tensors.
	 * Requires that `numOrSizeSplits` evenly divides `x.shape[axis]`.
	 *
	 * If `numOrSizeSplits` is a number array, splits `x` into
	 * `numOrSizeSplits.length` pieces. The shape of the `i`-th piece has the
	 * same size as `x` except along dimension `axis` where the size is
	 * `numOrSizeSplits[i]`.
	 *
	 * ```js
	 * const x = tf.tensor2d([1, 2, 3, 4, 5, 6, 7, 8], [2, 4]);
	 * const [a, b] = tf.split(x, 2, 1);
	 * a.print();
	 * b.print();
	 *
	 * const [c, d, e] = tf.split(x, [1, 2, 1], 1);
	 * c.print();
	 * d.print();
	 * e.print();
	 * ```
	 *
	 * @param x The input tensor to split.
	 * @param numOrSizeSplits Either an integer indicating the number of
	 * splits along the axis or an array of integers containing the sizes of
	 * each output tensor along the axis. If a number then it must evenly divide
	 * `x.shape[axis]`; otherwise the sum of sizes must match `x.shape[axis]`.
	 * Can contain one -1 indicating that dimension is to be inferred.
	 * @param axis The dimension along which to split. Defaults to 0 (the first
	 * dim).
	 *
	 * @doc {heading: 'Tensors', subheading: 'Slicing and Joining'}
	 */
	function split_(x, numOrSizeSplits) {
	  var axis = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
	  var $x = convertToTensor(x, 'x', 'split');
	  var inputs = {
	    x: $x
	  };
	  var attr = {
	    numOrSizeSplits: numOrSizeSplits,
	    axis: axis
	  };
	  return ENGINE.runKernel(SplitV, inputs, attr);
	}
	var split$3 = /* @__PURE__ */op({
	  split_: split_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Real value input fast Fourier transform.
	 *
	 * Computes the 1-dimensional discrete Fourier transform over the
	 * inner-most dimension of the real input.
	 *
	 * ```js
	 * const real = tf.tensor1d([1, 2, 3]);
	 *
	 * real.rfft().print();
	 * ```
	 * @param input The real value input to compute an rfft over.
	 *
	 * @doc {heading: 'Operations', subheading: 'Spectral', namespace: 'spectral'}
	 */
	function rfft_(input, fftLength) {
	  assert$1(input.dtype === 'float32', function () {
	    return "The dtype for rfft() must be real value but got ".concat(input.dtype);
	  });
	  var innerDimensionSize = input.shape[input.shape.length - 1];
	  var batch = input.size / innerDimensionSize;
	  var adjustedInput;
	  if (fftLength != null && fftLength < innerDimensionSize) {
	    // Need to crop
	    var begin = input.shape.map(function (v) {
	      return 0;
	    });
	    var size = input.shape.map(function (v) {
	      return v;
	    });
	    size[input.shape.length - 1] = fftLength;
	    adjustedInput = slice$2(input, begin, size);
	    innerDimensionSize = fftLength;
	  } else if (fftLength != null && fftLength > innerDimensionSize) {
	    // Need to pad with zeros
	    var zerosShape = input.shape.map(function (v) {
	      return v;
	    });
	    zerosShape[input.shape.length - 1] = fftLength - innerDimensionSize;
	    adjustedInput = concat$2([input, zeros$2(zerosShape)], input.shape.length - 1);
	    innerDimensionSize = fftLength;
	  } else {
	    adjustedInput = input;
	  }
	  // Complement the input with zero imaginary numbers.
	  var zerosInput = zerosLike$3(adjustedInput);
	  var complexInput = reshape$3(complex$2(adjustedInput, zerosInput), [batch, innerDimensionSize]);
	  var ret = fft$2(complexInput);
	  // Exclude complex conjugations. These conjugations are put symmetrically.
	  var half = Math.floor(innerDimensionSize / 2) + 1;
	  var realValues = real$2(ret);
	  var imagValues = imag$2(ret);
	  var realComplexConjugate = split$3(realValues, [half, innerDimensionSize - half], realValues.shape.length - 1);
	  var imagComplexConjugate = split$3(imagValues, [half, innerDimensionSize - half], imagValues.shape.length - 1);
	  var outputShape = adjustedInput.shape.slice();
	  outputShape[adjustedInput.shape.length - 1] = half;
	  return reshape$3(complex$2(realComplexConjugate[0], imagComplexConjugate[0]), outputShape);
	}
	var rfft = /* @__PURE__ */op({
	  rfft_: rfft_
	});

	/**
	 * Returns (a - b) * (a - b) element-wise.
	 * Supports broadcasting.
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 4, 3, 16]);
	 * const b = tf.tensor1d([1, 2, 9, 4]);
	 *
	 * a.squaredDifference(b).print();  // or tf.squaredDifference(a, b)
	 * ```
	 *
	 * ```js
	 * // Broadcast squared difference  a with b.
	 * const a = tf.tensor1d([2, 4, 6, 8]);
	 * const b = tf.scalar(5);
	 *
	 * a.squaredDifference(b).print();  // or tf.squaredDifference(a, b)
	 * ```
	 *
	 * @param a The first tensor.
	 * @param b The second tensor. Must have the same type as `a`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Arithmetic'}
	 */
	function squaredDifference_(a, b) {
	  var $a = convertToTensor(a, 'a', 'squaredDifference');
	  var $b = convertToTensor(b, 'b', 'squaredDifference');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  assertAndGetBroadcastShape($a.shape, $b.shape);
	  var inputs = {
	    a: $a,
	    b: $b
	  };
	  var attrs = {};
	  return ENGINE.runKernel(SquaredDifference, inputs, attrs);
	}
	var squaredDifference$2 = /* @__PURE__ */op({
	  squaredDifference_: squaredDifference_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Removes dimensions of size 1 from the shape of a `tf.Tensor`.
	 *
	 * ```js
	 * const x = tf.tensor([1, 2, 3, 4], [1, 1, 4]);
	 * x.squeeze().print();
	 * ```
	 *
	 * @param x The input tensor to be squeezed.
	 * @param axis An optional list of numbers. If specified, only
	 *     squeezes the dimensions listed. The dimension index starts at 0. It
	 * is an error to squeeze a dimension that is not 1.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Transformations'}
	 */
	function squeeze_(x, axis) {
	  var $x = convertToTensor(x, 'x', 'squeeze', 'string_or_numeric');
	  return reshape$3($x, squeezeShape($x.shape, axis).newShape);
	}
	var squeeze = /* @__PURE__ */op({
	  squeeze_: squeeze_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Stacks a list of rank-`R` `tf.Tensor`s into one rank-`(R+1)` `tf.Tensor`.
	 *
	 * ```js
	 * const a = tf.tensor1d([1, 2]);
	 * const b = tf.tensor1d([3, 4]);
	 * const c = tf.tensor1d([5, 6]);
	 * tf.stack([a, b, c]).print();
	 * ```
	 *
	 * @param tensors A list of tensor objects with the same shape and dtype.
	 * @param axis The axis to stack along. Defaults to 0 (the first dim).
	 *
	 * @doc {heading: 'Tensors', subheading: 'Slicing and Joining'}
	 */
	function stack_(tensors) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
	  var $tensors = convertToTensorArray(tensors, 'tensors', 'stack', 'string_or_numeric');
	  assert$1($tensors.length >= 1, function () {
	    return 'Pass at least one tensor to tf.stack';
	  });
	  if ($tensors.length > 0) {
	    assert$1(axis <= $tensors[0].rank, function () {
	      return 'Axis must be <= rank of the tensor';
	    });
	  }
	  var inputs = $tensors;
	  var attrs = {
	    axis: axis
	  };
	  return ENGINE.runKernel(Pack, inputs, attrs);
	}
	var stack = /* @__PURE__ */op({
	  stack_: stack_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes step of the input `tf.Tensor` element-wise: `x > 0 ? 1 : alpha`
	 *
	 * ```js
	 * const x = tf.tensor1d([0, 2, -1, -3]);
	 *
	 * x.step(.5).print();  // or tf.step(x, .5)
	 * ```
	 * @param x The input tensor.
	 * @param alpha The gradient when input is negative. Defaults to 0.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function step_(x) {
	  var alpha = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0.0;
	  var $x = convertToTensor(x, 'x', 'step');
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    alpha: alpha
	  };
	  return ENGINE.runKernel(Step, inputs, attrs);
	}
	var step$2 = /* @__PURE__ */op({
	  step_: step_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Extracts a strided slice of a tensor.
	 *
	 * Roughly speaking, this op extracts a slice of size (end-begin)/stride from
	 * the given input tensor (x). Starting at the location specified by begin the
	 * slice continues by adding stride to the index until all dimensions are not
	 * less than end. Note that a stride can be negative, which causes a reverse
	 * slice.
	 *
	 * ```js
	 * const t = tf.tensor3d([1, 1, 1 ,2, 2, 2, 3, 3, 3, 4, 4, 4, 5, 5, 5, 6, 6, 6],
	 *    [3, 2, 3]);
	 * t.stridedSlice([1, 0, 0], [2, 1, 3], [1, 1, 1]).print()  // [[[3, 3, 3]]]
	 * t.stridedSlice([1, 0, 0], [2, 2, 3], [1, 1, 1]).print()  // [[[3, 3, 3],
	 *                                                     // [4, 4, 4]]]
	 * t.stridedSlice([1, -1, 0], [2, -3, 3], [1, -1, 1]).print() // [[[4, 4, 4],
	 *                                                     // [3, 3, 3]]]
	 * ```
	 *
	 * @param x The tensor to stride slice.
	 * @param begin The coordinates to start the slice from.
	 * @param end: The coordinates to end the slice at.
	 * @param strides: The size of the slice.
	 * @param beginMask: If the ith bit of beginMask is set, begin[i] is ignored
	 *      and the fullest possible range in that dimension is used instead.
	 * @param endMask: If the ith bit of endMask is set, end[i] is ignored
	 *      and the fullest possible range in that dimension is used instead.
	 * @param shrinkAxisMask: a bitmask where bit i implies that
	 * the ith specification should shrink the dimensionality. begin and end must
	 * imply a slice of size 1 in the dimension.
	 *
	 * @doc {heading: 'Operations', subheading: 'Slicing and Joining'}
	 */
	function stridedSlice_(x, begin, end, strides) {
	  var beginMask = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 0;
	  var endMask = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : 0;
	  var ellipsisMask = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : 0;
	  var newAxisMask = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : 0;
	  var shrinkAxisMask = arguments.length > 8 && arguments[8] !== undefined ? arguments[8] : 0;
	  var $x = convertToTensor(x, 'x', 'stridedSlice', 'string_or_numeric');
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    begin: begin,
	    end: end,
	    strides: strides,
	    beginMask: beginMask,
	    endMask: endMask,
	    ellipsisMask: ellipsisMask,
	    newAxisMask: newAxisMask,
	    shrinkAxisMask: shrinkAxisMask
	  };
	  return ENGINE.runKernel(StridedSlice, inputs, attrs);
	}
	var stridedSlice$2 = /* @__PURE__ */op({
	  stridedSlice_: stridedSlice_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes tan of the input `tf.Tensor` element-wise, `tan(x)`
	 *
	 * ```js
	 * const x = tf.tensor1d([0, Math.PI / 2, Math.PI * 3 / 4]);
	 *
	 * x.tan().print();  // or tf.tan(x)
	 * ```
	 * @param x The input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Basic math'}
	 */
	function tan_(x) {
	  var $x = convertToTensor(x, 'x', 'tan', 'float32');
	  var inputs = {
	    x: $x
	  };
	  return ENGINE.runKernel(Tan, inputs);
	}
	var tan$2 = /* @__PURE__ */op({
	  tan_: tan_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates rank-1 `tf.Tensor` with the provided values, shape and dtype.
	 *
	 * The same functionality can be achieved with `tf.tensor`, but in general
	 * we recommend using `tf.tensor1d` as it makes the code more readable.
	 *
	 * ```js
	 * tf.tensor1d([1, 2, 3]).print();
	 * ```
	 *
	 * @param values The values of the tensor. Can be array of numbers,
	 *     or a `TypedArray`.
	 * @param dtype The data type.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function tensor1d(values, dtype) {
	  assertNonNull(values);
	  var inferredShape = inferShape(values, dtype);
	  if (inferredShape.length !== 1) {
	    throw new Error('tensor1d() requires values to be a flat/TypedArray');
	  }
	  var shape = null;
	  return makeTensor(values, shape, inferredShape, dtype);
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates rank-2 `tf.Tensor` with the provided values, shape and dtype.
	 *
	 * The same functionality can be achieved with `tf.tensor`, but in general
	 * we recommend using `tf.tensor2d` as it makes the code more readable.
	 *
	 *  ```js
	 * // Pass a nested array.
	 * tf.tensor2d([[1, 2], [3, 4]]).print();
	 * ```
	 * ```js
	 * // Pass a flat array and specify a shape.
	 * tf.tensor2d([1, 2, 3, 4], [2, 2]).print();
	 * ```
	 *
	 * @param values The values of the tensor. Can be nested array of numbers,
	 *     or a flat array, or a `TypedArray`.
	 * @param shape The shape of the tensor. If not provided, it is inferred from
	 *     `values`.
	 * @param dtype The data type.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function tensor2d(values, shape, dtype) {
	  assertNonNull(values);
	  if (shape != null && shape.length !== 2) {
	    throw new Error('tensor2d() requires shape to have two numbers');
	  }
	  var inferredShape = inferShape(values, dtype);
	  if (inferredShape.length !== 2 && inferredShape.length !== 1) {
	    throw new Error('tensor2d() requires values to be number[][] or flat/TypedArray');
	  }
	  if (inferredShape.length === 1 && shape == null) {
	    throw new Error('tensor2d() requires shape to be provided when `values` ' + 'are a flat/TypedArray');
	  }
	  return makeTensor(values, shape, inferredShape, dtype);
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates rank-3 `tf.Tensor` with the provided values, shape and dtype.
	 *
	 * The same functionality can be achieved with `tf.tensor`, but in general
	 * we recommend using `tf.tensor3d` as it makes the code more readable.
	 *
	 *  ```js
	 * // Pass a nested array.
	 * tf.tensor3d([[[1], [2]], [[3], [4]]]).print();
	 * ```
	 * ```js
	 * // Pass a flat array and specify a shape.
	 * tf.tensor3d([1, 2, 3, 4], [2, 2, 1]).print();
	 * ```
	 *
	 * @param values The values of the tensor. Can be nested array of numbers,
	 *     or a flat array, or a `TypedArray`.
	 * @param shape The shape of the tensor. If not provided,  it is inferred from
	 *     `values`.
	 * @param dtype The data type.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function tensor3d(values, shape, dtype) {
	  assertNonNull(values);
	  if (shape != null && shape.length !== 3) {
	    throw new Error('tensor3d() requires shape to have three numbers');
	  }
	  var inferredShape = inferShape(values, dtype);
	  if (inferredShape.length !== 3 && inferredShape.length !== 1) {
	    throw new Error('tensor3d() requires values to be number[][][] or flat/TypedArray');
	  }
	  if (inferredShape.length === 1 && shape == null) {
	    throw new Error('tensor3d() requires shape to be provided when `values` ' + 'are a flat array');
	  }
	  return makeTensor(values, shape, inferredShape, dtype);
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates rank-4 `tf.Tensor` with the provided values, shape and dtype.
	 *
	 * The same functionality can be achieved with `tf.tensor`, but in general
	 * we recommend using `tf.tensor4d` as it makes the code more readable.
	 *
	 *  ```js
	 * // Pass a nested array.
	 * tf.tensor4d([[[[1], [2]], [[3], [4]]]]).print();
	 * ```
	 * ```js
	 * // Pass a flat array and specify a shape.
	 * tf.tensor4d([1, 2, 3, 4], [1, 2, 2, 1]).print();
	 * ```
	 *
	 * @param values The values of the tensor. Can be nested array of numbers,
	 *     or a flat array, or a `TypedArray`.
	 * @param shape The shape of the tensor. Optional. If not provided,
	 *   it is inferred from `values`.
	 * @param dtype The data type.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function tensor4d(values, shape, dtype) {
	  assertNonNull(values);
	  if (shape != null && shape.length !== 4) {
	    throw new Error('tensor4d() requires shape to have four numbers');
	  }
	  var inferredShape = inferShape(values, dtype);
	  if (inferredShape.length !== 4 && inferredShape.length !== 1) {
	    throw new Error('tensor4d() requires values to be number[][][][] or flat/TypedArray');
	  }
	  if (inferredShape.length === 1 && shape == null) {
	    throw new Error('tensor4d() requires shape to be provided when `values` ' + 'are a flat array');
	  }
	  return makeTensor(values, shape, inferredShape, dtype);
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates rank-5 `tf.Tensor` with the provided values, shape and dtype.
	 *
	 * The same functionality can be achieved with `tf.tensor`, but in general
	 * we recommend using `tf.tensor5d` as it makes the code more readable.
	 *
	 *  ```js
	 * // Pass a nested array.
	 * tf.tensor5d([[[[[1],[2]],[[3],[4]]],[[[5],[6]],[[7],[8]]]]]).print();
	 * ```
	 * ```js
	 * // Pass a flat array and specify a shape.
	 * tf.tensor5d([1, 2, 3, 4, 5, 6, 7, 8], [1, 2, 2, 2, 1]).print();
	 * ```
	 *
	 * @param values The values of the tensor. Can be nested array of numbers,
	 *     or a flat array, or a `TypedArray`.
	 * @param shape The shape of the tensor. Optional. If not provided,
	 *   it is inferred from `values`.
	 * @param dtype The data type.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function tensor5d(values, shape, dtype) {
	  assertNonNull(values);
	  if (shape != null && shape.length !== 5) {
	    throw new Error('tensor5d() requires shape to have five numbers');
	  }
	  var inferredShape = inferShape(values, dtype);
	  if (inferredShape.length !== 5 && inferredShape.length !== 1) {
	    throw new Error('tensor5d() requires values to be ' + 'number[][][][][] or flat/TypedArray');
	  }
	  if (inferredShape.length === 1 && shape == null) {
	    throw new Error('tensor5d() requires shape to be provided when `values` ' + 'are a flat array');
	  }
	  return makeTensor(values, shape, inferredShape, dtype);
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates rank-6 `tf.Tensor` with the provided values, shape and dtype.
	 *
	 * The same functionality can be achieved with `tf.tensor`, but in general
	 * we recommend using `tf.tensor6d` as it makes the code more readable.
	 *
	 *  ```js
	 * // Pass a nested array.
	 * tf.tensor6d([[[[[[1],[2]],[[3],[4]]],[[[5],[6]],[[7],[8]]]]]]).print();
	 * ```
	 * ```js
	 * // Pass a flat array and specify a shape.
	 * tf.tensor6d([1, 2, 3, 4, 5, 6, 7, 8], [1, 1, 2, 2, 2, 1]).print();
	 * ```
	 *
	 * @param values The values of the tensor. Can be nested array of numbers,
	 *     or a flat array, or a `TypedArray`.
	 * @param shape The shape of the tensor. Optional. If not provided,
	 *   it is inferred from `values`.
	 * @param dtype The data type.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function tensor6d(values, shape, dtype) {
	  assertNonNull(values);
	  if (shape != null && shape.length !== 6) {
	    throw new Error('tensor6d() requires shape to have six numbers');
	  }
	  var inferredShape = inferShape(values, dtype);
	  if (inferredShape.length !== 6 && inferredShape.length !== 1) {
	    throw new Error('tensor6d() requires values to be number[][][][][][] or ' + 'flat/TypedArray');
	  }
	  if (inferredShape.length === 1 && shape == null) {
	    throw new Error('tensor6d() requires shape to be provided when `values` ' + 'are a flat array');
	  }
	  shape = shape || inferredShape;
	  return makeTensor(values, shape, inferredShape, dtype);
	}

	/**
	 * Check whether updates.shape = indices.shape[:batchDim] +
	 * shape[sliceDim:]
	 *
	 * @param x The input tensor.
	 */
	function validateUpdateShape(shape, indices, updates) {
	  var sliceDim = indices.rank > 1 ? indices.shape[indices.rank - 1] : 1;
	  var batchDim = indices.rank > 1 ? indices.rank - 1 : 1;
	  var shapeError = 'Must have updates.shape = indices.shape[:batchDim] + ' + "shape[sliceDim:], got updates.shape: ".concat(updates.shape) + ", indices.shape: ".concat(indices.shape, ", shape: ").concat(shape) + ", sliceDim: ".concat(sliceDim, ", and batchDim: ").concat(batchDim, ".");
	  if (updates.rank < batchDim) {
	    throw new Error(shapeError + " update.rank < ".concat(batchDim, ". "));
	  }
	  if (shape.length < sliceDim + (updates.rank - batchDim)) {
	    throw new Error(shapeError + " Output shape length < ".concat(sliceDim + (updates.rank - batchDim)));
	  }
	  if (updates.rank !== batchDim + shape.length - sliceDim) {
	    throw new Error(shapeError + " update.rank != ".concat(batchDim + shape.length - sliceDim));
	  }
	  for (var d = 0; d < batchDim; ++d) {
	    if (updates.shape[d] !== indices.shape[d]) {
	      throw new Error(shapeError + " updates.shape[".concat(d, "] (").concat(updates.shape[d], ") != indices.shape[").concat(d, "] (").concat(indices.shape[d], ")."));
	    }
	  }
	  for (var _d = 0; _d < updates.rank - batchDim; ++_d) {
	    if (updates.shape[_d + batchDim] !== shape[_d + sliceDim]) {
	      throw new Error(shapeError + " updates.shape[".concat(_d + batchDim, "] (").concat(updates.shape[_d + batchDim], ") != shape[").concat(_d + batchDim, "] (").concat(shape[_d + batchDim], ")"));
	    }
	  }
	}
	/**
	 * Validate scatter nd inputs.
	 *
	 * @param update The tensor contains the update values.
	 * @param indices The tensor contains the indices for the update values.
	 * @param shape The shape of the output tensor.
	 */
	function validateInput$1(updates, indices, shape) {
	  if (indices.rank < 1) {
	    throw new Error('tf.scatterND() expects the indices to be rank 1 or higher,' + " but the rank was ".concat(indices.rank, "."));
	  }
	  if (updates.rank < 1) {
	    throw new Error('tf.scatterND() expects the updates to be rank 1 or higher,' + " but the rank was ".concat(updates.rank, "."));
	  }
	  if (indices.dtype !== 'int32') {
	    throw new Error("The dtype of 'indices' should be int32, but got dtype: ".concat(indices.dtype));
	  }
	  if (shape.length < 1) {
	    throw new Error("Output rank must be greater or equal to 1, but got shape: ".concat(shape));
	  }
	  if (shape.length === 0) {
	    if (indices.size === 0) {
	      throw new Error("Indices specified for empty output. indices shape: ".concat(indices.shape));
	    }
	    if (updates.size === 0) {
	      throw new Error("Updates specified for empty output. updates shape: ".concat(updates.shape));
	    }
	  }
	  validateUpdateShape(shape, indices, updates);
	}
	/**
	 * Calculate the shape information for the output.
	 *
	 * @param update The tensor contains the update values.
	 * @param indices The tensor contains the indices for the update values.
	 * @param shape The shape of the output tensor.
	 *
	 * @returns ScatterShapeInfo
	 */
	function calculateShapes(updates, indices, shape) {
	  // Calculate the number of dimensions in indices
	  var indicesRank = indices.shape.length;
	  var sliceRank = indicesRank > 1 ? indices.shape[indicesRank - 1] : 1;
	  // Calculate the number of elements that make up each slice of our updated
	  // tensor. This allows us to work with flattened tensors and copy over whole
	  // slices at a time.
	  var totalNd = shape.length;
	  var sliceSize = 1;
	  for (var i = sliceRank; i < totalNd; ++i) {
	    sliceSize *= shape[i];
	  }
	  var safeSliceDim = sliceRank < 1 ? 1 : sliceRank;
	  var numUpdates = sizeFromShape(indices.shape) / safeSliceDim;
	  var strides = [].concat(_toConsumableArray(computeStrides(shape.slice(0, sliceRank))), [1]);
	  var outputSize = sizeFromShape(shape);
	  return {
	    sliceRank: sliceRank,
	    numUpdates: numUpdates,
	    sliceSize: sliceSize,
	    strides: strides,
	    outputSize: outputSize
	  };
	}

	var scatter_nd_util = {
		__proto__: null,
		calculateShapes: calculateShapes,
		validateInput: validateInput$1,
		validateUpdateShape: validateUpdateShape
	};

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a new tensor by applying sparse updates to individual
	 * values or slices to the passed in tensor according to
	 * indices. This operator is the similar to scatterNd op, except that the
	 * udpates are scattered on an existing tensor (as opposed to a zero-tensor).
	 *
	 * If indices contains duplicates, then we pick the last update for the index.
	 *
	 * If an out of bound index is found on CPU, an error is returned.
	 *
	 * Warning: There are some GPU specific semantics for this operation.
	 *  - If an out of bound index is found, the index is ignored.
	 *  - The order in which updates are applied is nondeterministic, so the output
	 * will be nondeterministic if indices contains duplicates.
	 * ```js
	 * const shape = [8];
	 * const tensor = tf.ones(shape);
	 * const indices = tf.tensor2d([4, 3, 1, 7], [4, 1], 'int32');
	 * const updates = tf.tensor1d([9, 10, 11, 12]);
	 *
	 * tf.tensorScatterUpdate(tensor, indices, updates).print();
	 *    //[1, 11, 1, 10, 9, 1, 1, 12]
	 * ```
	 *
	 * @param tensor A Tensor. Tensor to copy/update.
	 * @param indices The tensor contains the indices into the output tensor, must
	 *     have at least 2 axes: (num_updates, index_depth).
	 * @param updates The tensor contains the value for the indices.
	 *
	 * @doc {heading: 'Operations', subheading: 'Slicing and Joining'}
	 */
	function tensorScatterUpdate_(tensor, indices, updates) {
	  var $tensor = convertToTensor(tensor, 'tensor', 'tensorScatterupdate');
	  var $indices = convertToTensor(indices, 'indices', 'tensorScatterupdate', 'int32');
	  var $updates = convertToTensor(updates, 'updates', 'tensorScatterupdate');
	  validateInput$1($updates, $indices, $tensor.shape);
	  if ($tensor.dtype !== $updates.dtype) {
	    throw new Error("tensor and updates must have the same dtype, instead they are ".concat($tensor.dtype, " and ").concat($updates.dtype, "."));
	  }
	  var inputs = {
	    tensor: $tensor,
	    indices: $indices,
	    updates: $updates
	  };
	  var attrs = {};
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  return ENGINE.runKernel(TensorScatterUpdate, inputs, attrs);
	}
	var tensorScatterUpdate$2 = op({
	  tensorScatterUpdate_: tensorScatterUpdate_
	});

	/**
	 * Finds the values and indices of the `k` largest entries along the last
	 * dimension.
	 *
	 * If the input is a vector (rank=1), finds the k largest entries in the vector
	 * and outputs their values and indices as vectors. Thus values[j] is the j-th
	 * largest entry in input, and its index is indices[j].
	 * For higher rank inputs, computes the top k entries along the last dimension.
	 *
	 * If two elements are equal, the lower-index element appears first.
	 *
	 * ```js
	 * const a = tf.tensor2d([[1, 5], [4, 3]]);
	 * const {values, indices} = tf.topk(a);
	 * values.print();
	 * indices.print();
	 * ```
	 * @param x 1-D or higher `tf.Tensor` with last dimension being at least `k`.
	 * @param k Number of top elements to look for along the last dimension.
	 * @param sorted If true, the resulting `k` elements will be sorted by the
	 *     values in descending order.
	 *
	 * @doc {heading: 'Operations', subheading: 'Evaluation'}
	 */
	function topk_(x) {
	  var k = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
	  var sorted = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
	  var $x = convertToTensor(x, 'x', 'topk');
	  if ($x.rank === 0) {
	    throw new Error('topk() expects the input to be of rank 1 or higher');
	  }
	  var lastDim = $x.shape[$x.shape.length - 1];
	  if (k < 0) {
	    throw new Error("'k' passed to topk() must be >= 0 but got ".concat(k));
	  }
	  if (k > lastDim) {
	    throw new Error("'k' passed to topk() must be <= the last dimension (".concat(lastDim, ") ") + "but got ".concat(k));
	  }
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    k: k,
	    sorted: sorted
	  };
	  var _ENGINE$runKernel = ENGINE.runKernel(TopK, inputs, attrs),
	    _ENGINE$runKernel2 = _slicedToArray(_ENGINE$runKernel, 2),
	    values = _ENGINE$runKernel2[0],
	    indices = _ENGINE$runKernel2[1];
	  return {
	    values: values,
	    indices: indices
	  };
	}
	var topk = /* @__PURE__ */op({
	  topk_: topk_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a `tf.Tensor` with values sampled from a truncated normal
	 * distribution.
	 *
	 * ```js
	 * tf.truncatedNormal([2, 2]).print();
	 * ```
	 *
	 * The generated values follow a normal distribution with specified mean and
	 * standard deviation, except that values whose magnitude is more than 2
	 * standard deviations from the mean are dropped and re-picked.
	 *
	 * @param shape An array of integers defining the output tensor shape.
	 * @param mean The mean of the normal distribution.
	 * @param stdDev The standard deviation of the normal distribution.
	 * @param dtype The data type of the output tensor.
	 * @param seed The seed for the random number generator.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function truncatedNormal_(shape) {
	  var mean = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
	  var stdDev = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;
	  var dtype = arguments.length > 3 ? arguments[3] : undefined;
	  var seed = arguments.length > 4 ? arguments[4] : undefined;
	  assertNonNegativeIntegerDimensions(shape);
	  if (dtype != null && dtype === 'bool') {
	    throw new Error("Unsupported data type $ { dtype }");
	  }
	  var randGauss = new MPRandGauss(mean, stdDev, dtype, true /* truncated */, seed);
	  var res = buffer(shape, dtype);
	  for (var i = 0; i < res.values.length; i++) {
	    res.values[i] = randGauss.nextValue();
	  }
	  return res.toTensor();
	}
	var truncatedNormal$1 = /* @__PURE__ */op({
	  truncatedNormal_: truncatedNormal_
	});

	/**
	 * Finds unique elements along an axis of a tensor.
	 *
	 * It returns a tensor `values` containing all of the unique elements along the
	 * `axis` of the given tensor `x` in the same order that they occur along the
	 * `axis` in `x`; `x` does not need to be sorted. It also returns a tensor
	 * `indices` the same size as the number of the elements in `x` along the `axis`
	 * dimension. It contains the index in the unique output `values`.
	 *
	 * ```js
	 * // A 1-D tensor
	 * const a = tf.tensor1d([1, 1, 2, 4, 4, 4, 7, 8, 8]);
	 * const {values, indices} = tf.unique(a);
	 * values.print();   // [1, 2, 4, 7, 8,]
	 * indices.print();  // [0, 0, 1, 2, 2, 2, 3, 4, 4]
	 * ```
	 *
	 * ```js
	 * // A 2-D tensor with axis=0
	 * //
	 * // 'a' is: [[1, 0, 0],
	 * //          [1, 0, 0],
	 * //          [2, 0, 0]]
	 * const a = tf.tensor2d([[1, 0, 0], [1, 0, 0], [2, 0, 0]]);
	 * const {values, indices} = tf.unique(a, 0)
	 * values.print();   // [[1, 0, 0],
	 *                   //  [2, 0, 0]]
	 * indices.print();  // [0, 0, 1]
	 * ```
	 *
	 * ```js
	 * // A 2-D tensor with axis=1
	 * //
	 * // 'a' is: [[1, 0, 0],
	 * //          [1, 0, 0],
	 * //          [2, 0, 0]]
	 * const a = tf.tensor2d([[1, 0, 0], [1, 0, 0], [2, 0, 0]]);
	 * const {values, indices} = tf.unique(a, 1)
	 * values.print();   // [[1, 0],
	 *                   //  [1, 0],
	 *                   //  [2, 0]]
	 * indices.print();  // [0, 1, 1]
	 * ```
	 * @param x A tensor (int32, string, bool).
	 * @param axis The axis of the tensor to find the unique elements.
	 * @returns [uniqueElements, indices] (see above for details)
	 *
	 * @doc {heading: 'Operations', subheading: 'Evaluation'}
	 */
	function unique_(x) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
	  var $x = convertToTensor(x, 'x', 'unique', 'string_or_numeric');
	  assert$1($x.rank > 0, function () {
	    return 'The input tensor must be at least 1D';
	  });
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    axis: axis
	  };
	  var _ENGINE$runKernel = ENGINE.runKernel(Unique, inputs, attrs),
	    _ENGINE$runKernel2 = _slicedToArray(_ENGINE$runKernel, 2),
	    values = _ENGINE$runKernel2[0],
	    indices = _ENGINE$runKernel2[1];
	  return {
	    values: values,
	    indices: indices
	  };
	}
	var unique$3 = /* @__PURE__ */op({
	  unique_: unique_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the sum along segments of a `tf.Tensor`.
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 3, 4]);
	 * const segmentIds = tf.tensor1d([1, 2, 0, 1], 'int32');
	 * const numSegments = 3;
	 *
	 * x.unsortedSegmentSum(segmentIds, numSegments).print()
	 * //or tf.unsortedSegmentSum(x, segmentIds, numSegments)
	 * ```
	 * @param x The `tf.Tensor` that will be summed along its segments.
	 * @param segmentIds A `tf.Tensor1D` whose rank is equal to the rank of `x`'s
	 * dimension along the `axis`.  Maps each element of `x` to a segment.
	 * @param numSegments The number of distinct `segmentIds`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Segment'}
	 */
	function unsortedSegmentSum_(x, segmentIds, numSegments) {
	  var $x = convertToTensor(x, 'x', 'unsortedSegmentSum');
	  var $segmentIds = convertToTensor(segmentIds, 'segmentIds', 'unsortedSegmentSum', 'int32');
	  assert$1(isInt(numSegments), function () {
	    return 'numSegments must be of dtype int';
	  });
	  var inputs = {
	    x: $x,
	    segmentIds: $segmentIds
	  };
	  var attrs = {
	    numSegments: numSegments
	  };
	  return ENGINE.runKernel(UnsortedSegmentSum, inputs, attrs);
	}
	var unsortedSegmentSum$2 = /* @__PURE__ */op({
	  unsortedSegmentSum_: unsortedSegmentSum_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Unstacks a `tf.Tensor` of rank-`R` into a list of rank-`(R-1)` `tf.Tensor`s.
	 *
	 * ```js
	 * const a = tf.tensor2d([1, 2, 3, 4], [2, 2]);
	 *
	 * tf.unstack(a).forEach(tensor => tensor.print());
	 * ```
	 *
	 * @param x A tensor object.
	 * @param axis The axis to unstack along. Defaults to 0 (the first dim).
	 *
	 * @doc {heading: 'Tensors', subheading: 'Slicing and Joining'}
	 */
	function unstack_(x) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
	  var $x = convertToTensor(x, 'x', 'unstack', 'string_or_numeric');
	  assert$1(axis >= -$x.shape.length && axis < $x.shape.length, function () {
	    return "Axis = ".concat(axis, " is not in [-").concat($x.shape.length, ", ").concat($x.shape.length, ")");
	  });
	  var inputs = {
	    value: $x
	  };
	  var attrs = {
	    axis: axis
	  };
	  return ENGINE.runKernel(Unpack, inputs, attrs);
	}
	var unstack = /* @__PURE__ */op({
	  unstack_: unstack_
	});

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Searches for where a value would go in a sorted sequence.
	 *
	 * This is not a method for checking containment (like javascript in).
	 *
	 * The typical use case for this operation is "binning", "bucketing", or
	 * "discretizing". The values are assigned to bucket-indices based on the edges
	 * listed in 'sortedSequence'. This operation returns the bucket-index for each
	 * value.
	 *
	 * The index returned corresponds to the first edge greater than the value.
	 *
	 * The axis is not settable for this operation. It always operates on the
	 * innermost dimension (axis=-1). The operation will accept any number of outer
	 * dimensions.
	 *
	 * Note: This operation assumes that 'upperBound' is sorted along the
	 * innermost axis, maybe using 'sort(..., axis=-1)'. If the sequence is not
	 * sorted no error is raised and the content of the returned tensor is not well
	 * defined.
	 *
	 * ```js
	 * const seq = tf.tensor1d([0, 3, 9, 10, 10]);
	 * const values = tf.tensor1d([0, 4, 10]);
	 * const result = tf.upperBound(seq, values);
	 * result.print(); // [1, 2, 5]
	 * ```
	 * @param sortedSequence: N-D. Sorted sequence.
	 * @param values: N-D. Search values.
	 * @return An N-D int32 tensor the size of values containing the result of
	 *     applying upper bound to each value. The result is not a global index to
	 *     the entire Tensor, but the index in the last dimension.
	 * @doc {heading: 'Operations', subheading: 'Evaluation'}
	 */
	function upperBound$1(sortedSequence, values) {
	  return searchSorted$2(sortedSequence, values, 'right');
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a new variable with the provided initial value.
	 * ```js
	 * const x = tf.variable(tf.tensor([1, 2, 3]));
	 * x.assign(tf.tensor([4, 5, 6]));
	 *
	 * x.print();
	 * ```
	 *
	 * @param initialValue Initial value for the tensor.
	 * @param trainable If true, optimizers are allowed to update it.
	 * @param name Name of the variable. Defaults to a unique id.
	 * @param dtype If set, initialValue will be converted to the given type.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Creation'}
	 */
	function variable$1(initialValue) {
	  var trainable = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
	  var name = arguments.length > 2 ? arguments[2] : undefined;
	  var dtype = arguments.length > 3 ? arguments[3] : undefined;
	  return ENGINE.makeVariable(initialValue, trainable, name, dtype);
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function whereImpl$2(condShape, condVals) {
	  var indices = [];
	  for (var i = 0; i < condVals.length; i++) {
	    if (condVals[i]) {
	      indices.push(i);
	    }
	  }
	  var inBuffer = buffer(condShape, 'int32');
	  var out = buffer([indices.length, condShape.length], 'int32');
	  for (var _i = 0; _i < indices.length; _i++) {
	    var loc = inBuffer.indexToLoc(indices[_i]);
	    var offset = _i * condShape.length;
	    out.values.set(loc, offset);
	  }
	  return out.toTensor();
	}

	/**
	 * Returns the coordinates of true elements of condition.
	 *
	 * The coordinates are returned in a 2-D tensor where the first dimension (rows)
	 * represents the number of true elements, and the second dimension (columns)
	 * represents the coordinates of the true elements. Keep in mind, the shape of
	 * the output tensor can vary depending on how many true values there are in
	 * input. Indices are output in row-major order. The resulting tensor has the
	 * shape `[numTrueElems, condition.rank]`.
	 *
	 * This is analogous to calling the python `tf.where(cond)` without an x or y.
	 *
	 * ```js
	 * const cond = tf.tensor1d([false, false, true], 'bool');
	 * const result = await tf.whereAsync(cond);
	 * result.print();
	 * ```
	 *
	 * @doc {heading: 'Operations', subheading: 'Logical'}
	 */
	function whereAsync_(_x) {
	  return _whereAsync_.apply(this, arguments);
	}
	function _whereAsync_() {
	  _whereAsync_ = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(condition) {
	    var $condition, vals, res;
	    return _regeneratorRuntime().wrap(function _callee$(_context) {
	      while (1) switch (_context.prev = _context.next) {
	        case 0:
	          $condition = convertToTensor(condition, 'condition', 'whereAsync', 'bool');
	          _context.next = 3;
	          return $condition.data();
	        case 3:
	          vals = _context.sent;
	          res = whereImpl$2($condition.shape, vals);
	          if (condition !== $condition) {
	            $condition.dispose();
	          }
	          return _context.abrupt("return", res);
	        case 7:
	        case "end":
	          return _context.stop();
	      }
	    }, _callee);
	  }));
	  return _whereAsync_.apply(this, arguments);
	}
	var whereAsync = whereAsync_;

	/**
	 * Apply boolean mask to tensor.
	 *
	 * ```js
	 * const tensor = tf.tensor2d([1, 2, 3, 4, 5, 6], [3, 2]);
	 * const mask = tf.tensor1d([1, 0, 1], 'bool');
	 * const result = await tf.booleanMaskAsync(tensor, mask);
	 * result.print();
	 * ```
	 *
	 * @param tensor N-D tensor.
	 * @param mask K-D boolean tensor, K <= N and K must be known statically.
	 * @param axis A 0-D int Tensor representing the axis in tensor to mask from.
	 *     By default, axis is 0 which will mask from the first dimension.
	 *     Otherwise K + axis <= N.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Slicing and Joining'}
	 */
	function booleanMaskAsync_(_x, _x2, _x3) {
	  return _booleanMaskAsync_.apply(this, arguments);
	}
	function _booleanMaskAsync_() {
	  _booleanMaskAsync_ = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(tensor, mask, axis) {
	    var $tensor, $mask, axisFrom, maskDim, tensorShape, leadingSize, i, targetTensorShape, reshapedTensor, reshapedMask, positivePositions, indices, res;
	    return _regeneratorRuntime().wrap(function _callee$(_context) {
	      while (1) switch (_context.prev = _context.next) {
	        case 0:
	          $tensor = convertToTensor(tensor, 'tensor', 'boolMask');
	          $mask = convertToTensor(mask, 'mask', 'boolMask', 'bool');
	          axisFrom = axis == null ? 0 : axis;
	          maskDim = $mask.rank;
	          tensorShape = $tensor.shape;
	          assert$1(maskDim > 0, function () {
	            return 'mask cannot be scalar';
	          });
	          assertShapesMatch(tensorShape.slice(axisFrom, axisFrom + maskDim), $mask.shape, "mask's shape must match the first K dimensions of tensor's shape,");
	          leadingSize = 1;
	          for (i = axisFrom; i < axisFrom + maskDim; i++) {
	            leadingSize *= tensorShape[i];
	          }
	          targetTensorShape = tensorShape.slice(0, axisFrom).concat([leadingSize], tensorShape.slice(axisFrom + maskDim));
	          reshapedTensor = reshape$3($tensor, targetTensorShape);
	          reshapedMask = reshape$3($mask, [-1]);
	          _context.next = 14;
	          return whereAsync(reshapedMask);
	        case 14:
	          positivePositions = _context.sent;
	          indices = squeeze(positivePositions, [1]);
	          res = gather$1(reshapedTensor, indices, axisFrom); // Ensure no memory leak.
	          if (tensor !== $tensor) {
	            $tensor.dispose();
	          }
	          if (mask !== $mask) {
	            $mask.dispose();
	          }
	          indices.dispose();
	          reshapedTensor.dispose();
	          reshapedMask.dispose();
	          positivePositions.dispose();
	          return _context.abrupt("return", res);
	        case 24:
	        case "end":
	          return _context.stop();
	      }
	    }, _callee);
	  }));
	  return _booleanMaskAsync_.apply(this, arguments);
	}
	var booleanMaskAsync = booleanMaskAsync_;

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Transposes the `tf.Tensor`. Permutes the dimensions according to `perm`.
	 *
	 * The returned `tf.Tensor`'s dimension `i` will correspond to the input
	 * dimension `perm[i]`. If `perm` is not given, it is set to `[n-1...0]`,
	 * where `n` is the rank of the input `tf.Tensor`. Hence by default, this
	 * operation performs a regular matrix transpose on 2-D input `tf.Tensor`s.
	 *
	 * ```js
	 * const a = tf.tensor2d([1, 2, 3, 4, 5, 6], [2, 3]);
	 *
	 * a.transpose().print();  // or tf.transpose(a)
	 * ```
	 *
	 * @param x The tensor to transpose.
	 * @param perm The permutation of the dimensions of a.
	 * @param conjugate Will conjugate complex input if true.
	 *
	 * @doc {heading: 'Operations', subheading: 'Matrices'}
	 */
	function transpose_(x, perm, conjugate) {
	  var $x = convertToTensor(x, 'x', 'transpose');
	  if (perm == null) {
	    perm = $x.shape.map(function (s, i) {
	      return i;
	    }).reverse();
	  }
	  assert$1($x.rank === perm.length, function () {
	    return "Error in transpose: rank of input ".concat($x.rank, " ") + "must match length of perm ".concat(perm, ".");
	  });
	  perm.forEach(function (axis) {
	    assert$1(axis >= 0 && axis < $x.rank, function () {
	      return "All entries in 'perm' must be between 0 and ".concat($x.rank - 1) + " but got ".concat(perm);
	    });
	  });
	  if ($x.rank <= 1) {
	    return $x.clone();
	  }
	  var inputs = {
	    x: $x
	  };
	  var attrs = {
	    perm: perm
	  };
	  if ($x.dtype === 'complex64') {
	    return tidy(function () {
	      var $real = real$2($x);
	      var $imag = imag$2($x);
	      $real = ENGINE.runKernel(Transpose, {
	        x: $real
	      }, attrs);
	      $imag = ENGINE.runKernel(Transpose, {
	        x: $imag
	      }, attrs);
	      if (conjugate) {
	        $imag = neg$2($imag);
	      }
	      return complex$2($real, $imag);
	    });
	  }
	  return ENGINE.runKernel(Transpose, inputs, attrs);
	}
	var transpose$2 = /* @__PURE__ */op({
	  transpose_: transpose_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Compute the moving average of a variable.
	 *
	 * Without zeroDebias, the moving average operation is defined by:
	 *   `v += delta`
	 * where
	 *   `delta = (1 - decay) * (x - v)`
	 *
	 * With zeroDebias (default), the `delta` term is scaled to debias the
	 * effect of the (assumed) zero-initialization of `v`.
	 *   `delta /= (1 - decay ^ step)`
	 *
	 * For more details on the zero-debiasing algorithm, see:
	 *   https://arxiv.org/abs/1412.6980
	 *
	 * Note that this function is completely stateless and does not keep track of
	 * step count. The step count needs to be maintained by the caller and passed
	 * in as `step`.
	 *
	 * @param v The current moving average value.
	 * @param x New input value, must have the same shape and dtype as `v`.
	 * @param decay The decay factor. Typical values are 0.95 and 0.99.
	 * @param step Step count.
	 * @param zeroDebias: Whether zeroDebias is to be performed (default: `true`).
	 * @returns The new moving average value.
	 *
	 * @doc {heading: 'Operations', subheading: 'Moving Average'}
	 */
	function movingAverage_(v, x, decay, step) {
	  var zeroDebias = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : true;
	  var $v = convertToTensor(v, 'v', 'movingAverage');
	  var $x = convertToTensor(x, 'x', 'movingAverage');
	  var $decay = convertToTensor(decay, 'decay', 'movingAverage');
	  assertTypesMatch($v, $x);
	  assert$1(arraysEqual($v.shape, $x.shape), function () {
	    return 'Shape mismatch in v and x';
	  });
	  var one = scalar(1);
	  var oneMinusDecay = sub$2(one, $decay);
	  var update = mul(sub$2($x, $v), oneMinusDecay);
	  if (zeroDebias) {
	    assert$1(step != null, function () {
	      return 'When using zeroDebias: true, step is required.';
	    });
	    var $step = convertToTensor(step, 'step', 'movingAverage');
	    update = div$1(update, sub$2(one, pow$3($decay, $step)));
	  }
	  return add$3($v, update);
	}
	var movingAverage = /* @__PURE__ */op({
	  movingAverage_: movingAverage_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates a new tensor by applying sparse updates to individual
	 * values or slices within a zero tensor of the given shape tensor according to
	 * indices. This operator is the inverse of the `tf.gatherND` operator which
	 * extracts values or slices from a given tensor.
	 *
	 * ```js
	 * const indices = tf.tensor2d([4, 3, 1, 7], [4, 1], 'int32');
	 * const updates = tf.tensor1d([9, 10, 11, 12]);
	 * const shape = [8];
	 * tf.scatterND(indices, updates, shape).print() //[0, 11, 0, 10, 9, 0, 0, 12]
	 * ```
	 *
	 * @param indices The tensor contains the indices into the output tensor.
	 * @param updates The tensor contains the value for the indices.
	 * @param shape: The shape of the output tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Slicing and Joining'}
	 */
	function scatterND_(indices, updates, shape) {
	  assertNonNegativeIntegerDimensions(shape);
	  var $indices = convertToTensor(indices, 'indices', 'scatterND', 'int32');
	  var $updates = convertToTensor(updates, 'updates', 'scatterND');
	  validateInput$1($updates, $indices, shape);
	  var inputs = {
	    indices: $indices,
	    updates: $updates
	  };
	  var attrs = {
	    shape: shape
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  return ENGINE.runKernel(ScatterNd, inputs, attrs);
	}
	var scatterND = /* @__PURE__ */op({
	  scatterND_: scatterND_
	});

	/**
	 * Validate sparseToDense inputs.
	 *
	 * @param sparseIndices A 0-D, 1-D, or 2-D Tensor of type int32.
	 * sparseIndices[i] contains the complete index where sparseValues[i] will be
	 * placed.
	 * @param sparseValues A 0-D or 1-D Tensor. Values
	 * corresponding to each row of sparseIndices, or a scalar value to be used for
	 * all sparse indices.
	 * @param outputShape number[]. Shape of the dense output tensor.
	 * @param validateIndices boolean. indice validation is not supported, error
	 * will be thrown if it is set.
	 */
	function validateInput(sparseIndices, sparseValues, outputShape, defaultValues) {
	  if (sparseIndices.dtype !== 'int32') {
	    throw new Error('tf.sparseToDense() expects the indices to be int32 type,' + " but the dtype was ".concat(sparseIndices.dtype, "."));
	  }
	  if (sparseIndices.rank > 2) {
	    throw new Error('sparseIndices should be a scalar, vector, or matrix,' + " but got shape ".concat(sparseIndices.shape, "."));
	  }
	  var numElems = sparseIndices.rank > 0 ? sparseIndices.shape[0] : 1;
	  var numDims = sparseIndices.rank > 1 ? sparseIndices.shape[1] : 1;
	  if (outputShape.length !== numDims) {
	    throw new Error('outputShape has incorrect number of elements:,' + " ".concat(outputShape.length, ", should be: ").concat(numDims, "."));
	  }
	  var numValues = sparseValues.size;
	  if (!(sparseValues.rank === 0 || sparseValues.rank === 1 && numValues === numElems)) {
	    throw new Error('sparseValues has incorrect shape ' + "".concat(sparseValues.shape, ", should be [] or [").concat(numElems, "]"));
	  }
	  if (sparseValues.dtype !== defaultValues.dtype) {
	    throw new Error('sparseValues.dtype must match defaultValues.dtype');
	  }
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Converts a sparse representation into a dense tensor.
	 *
	 * Builds an array dense with shape outputShape such that:
	 *
	 * // If sparseIndices is scalar
	 * dense[i] = (i == sparseIndices ? sparseValues : defaultValue)
	 *
	 * // If sparseIndices is a vector, then for each i
	 * dense[sparseIndices[i]] = sparseValues[i]
	 *
	 * // If sparseIndices is an n by d matrix, then for each i in [0, n)
	 * dense[sparseIndices[i][0], ..., sparseIndices[i][d-1]] = sparseValues[i]
	 * All other values in dense are set to defaultValue. If sparseValues is a
	 * scalar, all sparse indices are set to this single value.
	 *
	 * If indices are repeated the final value is summed over all values for those
	 * indices.
	 *
	 * ```js
	 * const indices = tf.tensor1d([4, 5, 6, 1, 2, 3], 'int32');
	 * const values = tf.tensor1d([10, 11, 12, 13, 14, 15], 'float32');
	 * const shape = [8];
	 * tf.sparseToDense(indices, values, shape).print();
	 * ```
	 *
	 * @param sparseIndices A 0-D, 1-D, or 2-D Tensor of type int32.
	 * sparseIndices[i] contains the complete index where sparseValues[i] will be
	 * placed.
	 * @param sparseValues A 0-D or 1-D Tensor. Values
	 * corresponding to each row of sparseIndices, or a scalar value to be used for
	 * all sparse indices.
	 * @param outputShape Shape of the dense output tensor. The type is inferred.
	 * @param defaultValue Scalar. Value to set for indices not specified in
	 * sparseIndices. Defaults to zero.
	 *
	 * @doc {heading: 'Operations', subheading: 'Normalization'}
	 */
	function sparseToDense_(sparseIndices, sparseValues, outputShape) {
	  var defaultValue = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 0;
	  assertNonNegativeIntegerDimensions(outputShape);
	  var $sparseIndices = convertToTensor(sparseIndices, 'sparseIndices', 'sparseToDense', 'int32');
	  var $sparseValues = convertToTensor(sparseValues, 'sparseValues', 'sparseToDense', 'string_or_numeric');
	  var $defaultValue = convertToTensor(defaultValue, 'defaultValue', 'sparseToDense', $sparseValues.dtype);
	  validateInput($sparseIndices, $sparseValues, outputShape, $defaultValue);
	  var inputs = {
	    sparseIndices: $sparseIndices,
	    sparseValues: $sparseValues,
	    defaultValue: $defaultValue
	  };
	  var attrs = {
	    outputShape: outputShape
	  };
	  return ENGINE.runKernel(SparseToDense, inputs, attrs);
	}
	var sparseToDense$2 = /* @__PURE__ */op({
	  sparseToDense_: sparseToDense_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Gather slices from input tensor into a Tensor with shape specified by
	 * `indices`.
	 *
	 * `indices` is a K-dimensional integer tensor, best thought of as a
	 * (K-1)-dimensional tensor of indices into input, where each element defines a
	 * slice of input:
	 * output[\\(i_0, ..., i_{K-2}\\)] = input[indices[\\(i_0, ..., i_{K-2}\\)]]
	 *
	 * Whereas in `tf.gather`, `indices` defines slices into the first dimension of
	 * input, in `tf.gatherND`, `indices` defines slices into the first N dimensions
	 * of input, where N = indices.shape[-1].
	 *
	 * The last dimension of indices can be at most the rank of input:
	 * indices.shape[-1] <= input.rank
	 *
	 * The last dimension of `indices` corresponds to elements
	 * (if indices.shape[-1] == input.rank) or slices
	 * (if indices.shape[-1] < input.rank) along dimension indices.shape[-1] of
	 * input.
	 * The output tensor has shape
	 * indices.shape[:-1] + input.shape[indices.shape[-1]:]
	 *
	 * Note that on CPU, if an out of bound index is found, an error is returned. On
	 * GPU, if an out of bound index is found, a 0 is stored in the corresponding
	 * output value.
	 *
	 * ```js
	 * const indices = tf.tensor2d([0, 1, 1, 0], [2,2], 'int32');
	 * const input = tf.tensor2d([9, 10, 11, 12], [2, 2]);
	 * tf.gatherND(input, indices).print() // [10, 11]
	 * ```
	 *
	 * @param x The tensor from which to gather values.
	 * @param indices Index tensor, must be of type int32.
	 *
	 * @doc {heading: 'Operations', subheading: 'Slicing and Joining'}
	 */
	function gatherND_(x, indices) {
	  var $indices = convertToTensor(indices, 'indices', 'gatherND', 'int32');
	  var $x = convertToTensor(x, 'x', 'gatherND', 'string_or_numeric');
	  var inputs = {
	    params: $x,
	    indices: $indices
	  };
	  return ENGINE.runKernel(GatherNd, inputs);
	}
	var gatherND = /* @__PURE__ */op({
	  gatherND_: gatherND_
	});

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Normalize noise shape based on provided tensor and noise shape.
	 *
	 * @param x Tensor.
	 * @param noiseShape The shape for the randomly generated keep/drop flags, as
	 *   an array of numbers. Optional.
	 * @returns Normalized noise shape.
	 */
	function getNoiseShape(x, noiseShape) {
	  if (noiseShape == null) {
	    return x.shape.slice();
	  }
	  if (arraysEqual(x.shape, noiseShape)) {
	    return noiseShape;
	  }
	  if (x.shape.length === noiseShape.length) {
	    var newDimension = [];
	    for (var i = 0; i < x.shape.length; i++) {
	      if (noiseShape[i] == null && x.shape[i] != null) {
	        newDimension.push(x.shape[i]);
	      } else {
	        newDimension.push(noiseShape[i]);
	      }
	    }
	    return newDimension;
	  }
	  return noiseShape;
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes dropout.
	 *
	 * ```js
	 * const x = tf.tensor1d([1, 2, 2, 1]);
	 * const rate = 0.75;
	 * const output = tf.dropout(x, rate);
	 * output.print();
	 * ```
	 *
	 * @param x A floating point Tensor or TensorLike.
	 * @param rate A float in the range [0, 1). The probability that each element
	 *   of x is discarded.
	 * @param noiseShape An array of numbers of type int32, representing the
	 * shape for randomly generated keep/drop flags. If the noiseShape has null
	 * value, it will be automatically replaced with the x's relative dimension
	 * size. Optional.
	 * @param seed Used to create random seeds. Optional.
	 * @returns A Tensor of the same shape of x.
	 *
	 * @doc {heading: 'Operations', subheading: 'Dropout'}
	 */
	function dropout_(x, rate, noiseShape, seed) {
	  var $x = convertToTensor(x, 'x', 'dropout');
	  assert$1($x.dtype === 'float32', function () {
	    return "x has to be a floating point tensor since it's going to be " + "scaled, but got a ".concat($x.dtype, " tensor instead.");
	  });
	  assert$1(rate >= 0 && rate < 1, function () {
	    return "rate must be a float in the range [0, 1), but got ".concat(rate, ".");
	  });
	  if (rate === 0) {
	    return x instanceof Tensor ? $x.clone() : $x;
	  }
	  var $noiseShape = getNoiseShape($x, noiseShape);
	  var keepProb = 1 - rate;
	  var multiplier = div$1(floor$2(add$3(randomUniform$1($noiseShape, 0, 1, 'float32', seed), keepProb)), keepProb);
	  return mul($x, multiplier);
	}
	var dropout$2 = /* @__PURE__ */op({
	  dropout_: dropout_
	});

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function enclosingPowerOfTwo(value) {
	  // Return 2**N for integer N such that 2**N >= value.
	  return Math.floor(Math.pow(2, Math.ceil(Math.log(value) / Math.log(2.0))));
	}
	function cosineWindow(windowLength, a, b) {
	  var even = 1 - windowLength % 2;
	  var newValues = new Float32Array(windowLength);
	  for (var i = 0; i < windowLength; ++i) {
	    var cosArg = 2.0 * Math.PI * i / (windowLength + even - 1);
	    newValues[i] = a - b * Math.cos(cosArg);
	  }
	  return tensor1d(newValues, 'float32');
	}

	/**
	 * Returns whether the targets are in the top K predictions.
	 *
	 * ```js
	 * const predictions = tf.tensor2d([[20, 10, 40, 30], [30, 50, -20, 10]]);
	 * const targets = tf.tensor1d([2, 0]);
	 * const precision = await tf.inTopKAsync(predictions, targets);
	 * precision.print();
	 * ```
	 * @param predictions 2-D or higher `tf.Tensor` with last dimension being
	 *     at least `k`.
	 * @param targets 1-D or higher `tf.Tensor`.
	 * @param k Optional Number of top elements to look at for computing precision,
	 *     default to 1.
	 *
	 * @doc {heading: 'Operations', subheading: 'Evaluation'}
	 */
	function inTopKAsync_(_x, _x2) {
	  return _inTopKAsync_.apply(this, arguments);
	}
	function _inTopKAsync_() {
	  _inTopKAsync_ = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(predictions, targets) {
	    var k,
	      $predictions,
	      $targets,
	      lastDim,
	      predictionsVals,
	      targetsVals,
	      batch,
	      size,
	      precision,
	      b,
	      offset,
	      vals,
	      valAndInd,
	      i,
	      _i,
	      _args = arguments;
	    return _regeneratorRuntime().wrap(function _callee$(_context) {
	      while (1) switch (_context.prev = _context.next) {
	        case 0:
	          k = _args.length > 2 && _args[2] !== undefined ? _args[2] : 1;
	          $predictions = convertToTensor(predictions, 'predictions', 'inTopK');
	          $targets = convertToTensor(targets, 'targets', 'inTopK');
	          assert$1($predictions.rank > 1, function () {
	            return 'inTopK() expects the predictions to be of rank 2 or higher, ' + "but got ".concat($predictions.rank);
	          });
	          assert$1($predictions.rank - 1 === $targets.rank, function () {
	            return "predictions rank should be 1 larger than " + "targets rank, but got predictions rank " + "".concat($predictions.rank, " and targets rank ").concat($targets.rank);
	          });
	          assertShapesMatch($predictions.shape.slice(0, $predictions.shape.length - 1), $targets.shape, "predictions's shape should be align with the targets' shape, " + 'except the last dimension.');
	          lastDim = $predictions.shape[$predictions.shape.length - 1];
	          assert$1(k > 0 && k <= lastDim, function () {
	            return "'k' passed to inTopK() must be > 0 && <= the predictions last " + "dimension (".concat(lastDim, "), but got ").concat(k);
	          });
	          _context.next = 10;
	          return $predictions.data();
	        case 10:
	          predictionsVals = _context.sent;
	          _context.next = 13;
	          return $targets.data();
	        case 13:
	          targetsVals = _context.sent;
	          // Reshape predictionsVals into a 2d tensor [batch, lastDim]
	          // and look up topK along lastDim.
	          batch = predictionsVals.length / lastDim, size = lastDim;
	          precision = getTypedArrayFromDType('bool', batch);
	          b = 0;
	        case 17:
	          if (!(b < batch)) {
	            _context.next = 35;
	            break;
	          }
	          offset = b * size;
	          vals = predictionsVals.subarray(offset, offset + size);
	          valAndInd = [];
	          for (i = 0; i < vals.length; i++) {
	            valAndInd.push({
	              value: vals[i],
	              index: i
	            });
	          }
	          valAndInd.sort(function (a, b) {
	            return b.value - a.value;
	          });
	          precision[b] = 0;
	          _i = 0;
	        case 25:
	          if (!(_i < k)) {
	            _context.next = 32;
	            break;
	          }
	          if (!(valAndInd[_i].index === targetsVals[b])) {
	            _context.next = 29;
	            break;
	          }
	          precision[b] = 1;
	          return _context.abrupt("break", 32);
	        case 29:
	          _i++;
	          _context.next = 25;
	          break;
	        case 32:
	          b++;
	          _context.next = 17;
	          break;
	        case 35:
	          if (predictions !== $predictions) {
	            $predictions.dispose();
	          }
	          if (targets !== $targets) {
	            $targets.dispose();
	          }
	          // Output precision has the same shape as targets.
	          return _context.abrupt("return", tensor(precision, $targets.shape, 'bool'));
	        case 38:
	        case "end":
	          return _context.stop();
	      }
	    }, _callee);
	  }));
	  return _inTopKAsync_.apply(this, arguments);
	}
	var inTopKAsync = inTopKAsync_;

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the derivative of the filter of a 2D convolution.
	 *
	 * @param x The input tensor, of rank 4 or rank 3 of shape
	 *     [batch, height, width, inChannels]. If rank 3, batch of 1 is assumed.
	 * @param dy The dy image, of rank 4 or rank 3, of shape
	 *     [batch, height, width, outDepth]. If rank 3, batch of 1 is assumed.
	 * @param filterShape The shape of the filter, length 4,
	 *     [filterHeight, filterWidth, inDepth, outDepth].
	 * @param strides The strides of the convolution: [strideHeight,
	 * strideWidth].
	 * @param pad A string from: 'same', 'valid'. The type of padding algorithm
	 *     used in the forward prop of the op.
	 * @param dataFormat: An optional string from: "NHWC", "NCHW". Defaults to
	 *     "NHWC". Specify the data format of the input and output data. With the
	 *     default format "NHWC", the data is stored in the order of: [batch,
	 *     height, width, channels].
	 * @param dimRoundingMode A string from: 'ceil', 'round', 'floor'. If none is
	 *     provided, it will default to truncate.
	 */
	function conv2DBackpropFilter_(x, dy, filterShape, strides, pad) {
	  var dataFormat = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : 'NHWC';
	  var dimRoundingMode = arguments.length > 6 ? arguments[6] : undefined;
	  var x4D = x;
	  if (x.rank === 3) {
	    x4D = reshape$3(x, [1, x.shape[0], x.shape[1], x.shape[2]]);
	  }
	  var dy4D = dy;
	  if (dy4D.rank === 3) {
	    dy4D = reshape$3(dy, [1, dy.shape[0], dy.shape[1], dy.shape[2]]);
	  }
	  assert$1(x4D.rank === 4, function () {
	    return "Error in conv2dDerFilter: input must be rank 4, but got shape " + "".concat(x4D.shape, ".");
	  });
	  assert$1(dy4D.rank === 4, function () {
	    return "Error in conv2dDerFilter: dy must be rank 4, but got shape " + "".concat(dy4D.shape, ".");
	  });
	  assert$1(filterShape.length === 4, function () {
	    return "Error in conv2dDerFilter: filterShape must be length 4, but got " + "".concat(filterShape, ".");
	  });
	  var inDepth = dataFormat === 'NHWC' ? x4D.shape[3] : x4D.shape[1];
	  var outDepth = dataFormat === 'NHWC' ? dy4D.shape[3] : dy4D.shape[1];
	  assert$1(inDepth === filterShape[2], function () {
	    return "Error in conv2dDerFilter: depth of input ".concat(inDepth, ") must ") + "match input depth in filter (".concat(filterShape[2], ".");
	  });
	  assert$1(outDepth === filterShape[3], function () {
	    return "Error in conv2dDerFilter: depth of dy (".concat(outDepth, ") must ") + "match output depth for filter (".concat(filterShape[3], ").");
	  });
	  checkPadOnDimRoundingMode('conv2dDerFilter', pad, dimRoundingMode);
	  var inputs = {
	    x: x4D,
	    dy: dy4D
	  };
	  var attrs = {
	    strides: strides,
	    pad: pad,
	    dataFormat: dataFormat,
	    dimRoundingMode: dimRoundingMode,
	    filterShape: filterShape
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  return ENGINE.runKernel(Conv2DBackpropFilter, inputs, attrs);
	}
	var conv2DBackpropFilter$2 = /* @__PURE__ */op({
	  conv2DBackpropFilter_: conv2DBackpropFilter_
	});

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	// Returns gradient for fused activation.
	function getFusedDyActivation(dy, y, activation) {
	  if (activation == null || activation === 'linear') {
	    return dy;
	  }
	  if (activation === 'relu') {
	    return mul(dy, step$2(y));
	  }
	  throw new Error("Cannot compute gradient for fused activation ".concat(activation, "."));
	}
	// Returns gradient for fused bias.
	function getFusedBiasGradient(bias, dyActivation) {
	  var res = dyActivation;
	  var reduceAxes = getReductionAxes(bias.shape, dyActivation.shape);
	  if (reduceAxes.length > 0) {
	    res = sum$3(res, reduceAxes);
	  }
	  return reshape$3(res, bias.shape);
	}
	function applyActivation$1(x, activation, preluActivationWeights, leakyreluAlpha) {
	  if (activation === 'linear') {
	    return x;
	  } else if (activation === 'relu') {
	    return relu$2(x);
	  } else if (activation === 'elu') {
	    return elu$4(x);
	  } else if (activation === 'relu6') {
	    return relu6$2(x);
	  } else if (activation === 'prelu') {
	    return prelu$3(x, preluActivationWeights);
	  } else if (activation === 'leakyrelu') {
	    return leakyRelu$2(x, leakyreluAlpha);
	  } else if (activation === 'sigmoid') {
	    return sigmoid$2(x);
	  }
	  throw new Error("Unknown fused activation ".concat(activation, "."));
	}
	// Whether we should call fused ops.
	var shouldFuse = function shouldFuse(gradientDepth, activation) {
	  var gradientMode = gradientDepth > 0;
	  return !gradientMode || activation === 'linear';
	};

	/**
	 * Computes a 2D convolution over the input x, optionally fused with adding a
	 * bias and applying an activation.
	 *
	 * ```js
	 * const inputDepth = 2;
	 * const inShape = [2, 2, 2, inputDepth];
	 * const outputDepth = 2;
	 * const fSize = 1;
	 * const pad = 0;
	 * const strides = 1;
	 *
	 * const x = tf.tensor4d( [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15,
	 * 16], inShape);
	 * const w = tf.tensor4d([-1, 1, -2, 0.5], [fSize, fSize, inputDepth,
	 * outputDepth]);
	 *
	 * tf.fused.conv2d({ x, filter: w, strides, pad, dataFormat: 'NHWC',
	 * dilations: [1, 1], bias: tf.scalar(5), activation: 'relu' }).print();
	 * ```
	 *
	 * @param obj An object with the following properties:
	 * @param x The input tensor, of rank 4 or rank 3, of shape
	 *     `[batch, height, width, inChannels]`. If rank 3, batch of 1 is
	 * assumed.
	 * @param filter The filter, rank 4, of shape
	 *     `[filterHeight, filterWidth, inDepth, outDepth]`.
	 * @param strides The strides of the convolution: `[strideHeight,
	 * strideWidth]`.
	 * @param pad The type of padding algorithm.
	 *   - `same` and stride 1: output will be of same size as input,
	 *       regardless of filter size.
	 *   - `valid` output will be smaller than input if filter is larger
	 *       than 1x1.
	 *   - For more info, see this guide:
	 *     [https://www.tensorflow.org/api_docs/python/tf/nn/convolution](
	 *          https://www.tensorflow.org/api_docs/python/tf/nn/convolution)
	 * @param dataFormat An optional string from: "NHWC", "NCHW". Defaults to
	 *     "NHWC". Specify the data format of the input and output data. With the
	 *     default format "NHWC", the data is stored in the order of: [batch,
	 *     height, width, channels]. Only "NHWC" is currently supported.
	 * @param dilations The dilation rates: `[dilationHeight, dilationWidth]`
	 *     in which we sample input values across the height and width dimensions
	 *     in atrous convolution. Defaults to `[1, 1]`. If `dilations` is a single
	 *     number, then `dilationHeight == dilationWidth`. If it is greater than
	 *     1, then all values of `strides` must be 1.
	 * @param dimRoundingMode A string from: 'ceil', 'round', 'floor'. If none is
	 *     provided, it will default to truncate.
	 * @param bias Tensor to be added to the result.
	 * @param activation Name of activation kernel (defaults to `linear`) to be
	 *     applied
	 *      after biasAdd.
	 * @param preluActivationWeights Tensor of prelu weights to be applied as part
	 *     of a `prelu` activation, typically the same shape as `x`.
	 * @param leakyreluAlpha Optional. Alpha to be applied as part of a `leakyrelu`
	 *     activation.
	 */
	function fusedConv2d_(_ref) {
	  var x = _ref.x,
	    filter = _ref.filter,
	    strides = _ref.strides,
	    pad = _ref.pad,
	    _ref$dataFormat = _ref.dataFormat,
	    dataFormat = _ref$dataFormat === void 0 ? 'NHWC' : _ref$dataFormat,
	    _ref$dilations = _ref.dilations,
	    dilations = _ref$dilations === void 0 ? [1, 1] : _ref$dilations,
	    dimRoundingMode = _ref.dimRoundingMode,
	    bias = _ref.bias,
	    _ref$activation = _ref.activation,
	    activation = _ref$activation === void 0 ? 'linear' : _ref$activation,
	    preluActivationWeights = _ref.preluActivationWeights,
	    leakyreluAlpha = _ref.leakyreluAlpha;
	  activation = activation || 'linear';
	  if (shouldFuse(ENGINE.state.gradientDepth, activation) === false) {
	    // TODO: Transpose bias and preluActivationWeights properly for NCHW
	    // format before computation.
	    assert$1(dataFormat === 'NHWC', function () {
	      return "Error in fused conv2d: got dataFormat of ".concat(dataFormat, " but ") + "only NHWC is currently supported for the case of gradient depth " + "is 0 and the activation is not linear.";
	    });
	    var result = conv2d$4(x, filter, strides, pad, dataFormat, dilations, dimRoundingMode);
	    if (bias != null) {
	      result = add$3(result, bias);
	    }
	    return applyActivation$1(result, activation, preluActivationWeights, leakyreluAlpha);
	  }
	  var $x = convertToTensor(x, 'x', 'conv2d', 'float32');
	  var $filter = convertToTensor(filter, 'filter', 'conv2d', 'float32');
	  var x4D = $x;
	  var reshapedTo4D = false;
	  if ($x.rank === 3) {
	    reshapedTo4D = true;
	    x4D = reshape$3($x, [1, $x.shape[0], $x.shape[1], $x.shape[2]]);
	  }
	  assert$1(x4D.rank === 4, function () {
	    return "Error in fused conv2d: input must be rank 4, but got rank " + "".concat(x4D.rank, ".");
	  });
	  assert$1($filter.rank === 4, function () {
	    return "Error in fused conv2d: filter must be rank 4, but got rank " + "".concat($filter.rank, ".");
	  });
	  checkPadOnDimRoundingMode('fused conv2d', pad, dimRoundingMode);
	  var inputChannels = dataFormat === 'NHWC' ? x4D.shape[3] : x4D.shape[1];
	  assert$1($filter.shape[2] === inputChannels, function () {
	    return "Error in conv2d: depth of input (".concat(inputChannels, ") must match ") + "input depth for filter ".concat($filter.shape[2], ".");
	  });
	  assert$1(eitherStridesOrDilationsAreOne(strides, dilations), function () {
	    return 'Error in conv2D: Either strides or dilations must be 1. ' + "Got strides ".concat(strides, " and dilations '").concat(dilations, "'");
	  });
	  var convInfo = computeConv2DInfo(x4D.shape, $filter.shape, strides, dilations, pad, dimRoundingMode);
	  var $bias;
	  if (bias != null) {
	    $bias = convertToTensor(bias, 'bias', 'fused conv2d');
	    var _makeTypesMatch = makeTypesMatch($bias, $x);
	    var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 1);
	    $bias = _makeTypesMatch2[0];
	    // According to TensorFlow, the bias is supposed be a 1-D tensor or a
	    // scalar.
	    //
	    // 3-D or 4-D bias is not disabled for NHWC format, because they are
	    // currently being used in some cases. For examplem in our code base,
	    // https://github.com/tensorflow/tfjs/blob/b53bd47e880367ae57493f0ea628abaf08db2d5d/tfjs-core/src/ops/fused/fused_conv2d_test.ts#L1972.
	    if (dataFormat === 'NHWC') {
	      assertAndGetBroadcastShape(convInfo.outShape, $bias.shape);
	    } else {
	      assert$1($bias.shape.length <= 1, function () {
	        return "Error in fused conv2d: only supports scalar or 1-D Tensor " + "bias for NCHW format but got the bias of " + "rank-".concat($bias.shape.length, ".");
	      });
	      assert$1($bias.shape.length === 0 || $bias.shape[0] === convInfo.outChannels || $bias.shape[0] === 1, function () {
	        return "Error in fused conv2d: bias shape (".concat($bias.shape, ") is not ") + "compatible with the number of output channels " + "(".concat(convInfo.outChannels, ")");
	      });
	    }
	  }
	  var $preluActivationWeights;
	  if (preluActivationWeights != null) {
	    // PReLU's activation weights could be a scalar, a 1-D tensor or a 3-D
	    // tensor.
	    var alphaShape = preluActivationWeights.shape;
	    assert$1(alphaShape.length <= 1 || alphaShape.length === 3, function () {
	      return "Error in fused conv2d: only supports scalar, 1-D Tensor or " + "3-D Tensor PReLU activation weights but got a tensor of " + "rank-".concat(alphaShape.length, ".");
	    });
	    if (alphaShape.length === 1) {
	      // Whether the data format is NCHW or NHWC, the 1-D PReLU activation
	      // weights tensor should be aligned with the output channels of conv2d
	      // result.
	      assert$1(alphaShape[0] === 1 || alphaShape[0] === convInfo.outChannels, function () {
	        return "Error in fused conv2d: PReLU activation weights " + "(".concat(alphaShape, ") is not compatible with the number of output ") + "channels (".concat(convInfo.outChannels, ").");
	      });
	    } else if (alphaShape.length === 3) {
	      // Whether the data format is NCHW or NHWC, the PReLU activation weights
	      // tensor should has the compatible shape with the result of conv2d.
	      try {
	        assertAndGetBroadcastShape(alphaShape, convInfo.outShape);
	      } catch (e) {
	        var errMsg = "Error in fused conv2d: PReLU activation weights (".concat(alphaShape, ") ") + "is not compatible with the output shape of the conv2d " + "(".concat(convInfo.outShape, ").");
	        throw Error(errMsg);
	      }
	    }
	    $preluActivationWeights = convertToTensor(preluActivationWeights, 'prelu weights', 'fused conv2d');
	  }
	  var grad = function grad(dy, saved) {
	    assert$1(dataFormat === 'NHWC', function () {
	      return "Error in gradient of fused conv2D: got dataFormat of ".concat(dataFormat, " but only NHWC is currently supported.");
	    });
	    var _saved = _slicedToArray(saved, 4),
	      $filter = _saved[0],
	      x4D = _saved[1],
	      y = _saved[2],
	      $bias = _saved[3];
	    var dyActivation = getFusedDyActivation(dy, y, activation);
	    assert$1(tupleValuesAreOne(dilations), function () {
	      return 'Error in gradient of fused conv2D: ' + "dilation rates greater than 1 " + "are not yet supported in gradients. Got dilations '".concat(dilations, "'");
	    });
	    var xDer = conv2DBackpropInput$2(x4D.shape, dyActivation, $filter, strides, pad);
	    var filterDer = conv2DBackpropFilter$2(x4D, dyActivation, $filter.shape, strides, pad);
	    var der = [xDer, filterDer];
	    if ($bias != null) {
	      var biasDer = getFusedBiasGradient($bias, dyActivation);
	      der.push(biasDer);
	    }
	    return der;
	  };
	  var inputs = {
	    x: x4D,
	    filter: $filter,
	    bias: $bias,
	    preluActivationWeights: $preluActivationWeights
	  };
	  var attrs = {
	    strides: strides,
	    pad: pad,
	    dataFormat: dataFormat,
	    dilations: dilations,
	    dimRoundingMode: dimRoundingMode,
	    activation: activation,
	    leakyreluAlpha: leakyreluAlpha
	  };
	  // Depending on the the params passed in we will have different number of
	  // inputs and thus a a different number of elements in the gradient.
	  if (bias == null) {
	    var customOp = customGrad(function (x4D, filter, save) {
	      var res =
	      // tslint:disable-next-line: no-unnecessary-type-assertion
	      ENGINE.runKernel(FusedConv2D, inputs, attrs);
	      save([filter, x4D, res]);
	      if (reshapedTo4D) {
	        // tslint:disable-next-line: no-unnecessary-type-assertion
	        res = reshape$3(res, [res.shape[1], res.shape[2], res.shape[3]]);
	      }
	      return {
	        value: res,
	        gradFunc: grad
	      };
	    });
	    return customOp(x4D, $filter);
	  } else {
	    var customOpWithBias = customGrad(function (x4D, filter, bias, save) {
	      var res = ENGINE.runKernel(FusedConv2D, inputs, attrs);
	      save([filter, x4D, res, bias]);
	      if (reshapedTo4D) {
	        // tslint:disable-next-line: no-unnecessary-type-assertion
	        res = reshape$3(res, [res.shape[1], res.shape[2], res.shape[3]]);
	      }
	      return {
	        value: res,
	        gradFunc: grad
	      };
	    });
	    return customOpWithBias(x4D, $filter, $bias);
	  }
	}
	var conv2d$3 = /* @__PURE__ */op({
	  fusedConv2d_: fusedConv2d_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function depthwiseConv2dNativeBackpropFilter_(x, dy, filterShape, strides, pad) {
	  var dilations = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : [1, 1];
	  var dimRoundingMode = arguments.length > 6 ? arguments[6] : undefined;
	  var x4D = x;
	  if (x.rank === 3) {
	    x4D = reshape$3(x, [1, x.shape[0], x.shape[1], x.shape[2]]);
	  }
	  var dy4D = dy;
	  if (dy4D.rank === 3) {
	    dy4D = reshape$3(dy, [1, dy.shape[0], dy.shape[1], dy.shape[2]]);
	  }
	  var inputs = {
	    x: x4D,
	    dy: dy4D
	  };
	  var attrs = {
	    strides: strides,
	    pad: pad,
	    dimRoundingMode: dimRoundingMode,
	    dilations: dilations,
	    filterShape: filterShape
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  return ENGINE.runKernel(DepthwiseConv2dNativeBackpropFilter, inputs, attrs);
	}
	var depthwiseConv2dNativeBackpropFilter$2 = op({
	  depthwiseConv2dNativeBackpropFilter_: depthwiseConv2dNativeBackpropFilter_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function depthwiseConv2dNativeBackpropInput_(xShape, dy, filter, strides, pad) {
	  var dilations = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : [1, 1];
	  var dimRoundingMode = arguments.length > 6 ? arguments[6] : undefined;
	  var dy4D = dy;
	  var reshapedTo4D = false;
	  if (dy.rank === 3) {
	    reshapedTo4D = true;
	    dy4D = reshape$3(dy, [1, dy.shape[0], dy.shape[1], dy.shape[2]]);
	  }
	  var inputs = {
	    dy: dy4D,
	    filter: filter
	  };
	  var attrs = {
	    strides: strides,
	    pad: pad,
	    dimRoundingMode: dimRoundingMode,
	    dilations: dilations,
	    inputShape: xShape
	  };
	  var res =
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  ENGINE.runKernel(DepthwiseConv2dNativeBackpropInput, inputs, attrs);
	  if (reshapedTo4D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3]]);
	  }
	  return res;
	}
	var depthwiseConv2dNativeBackpropInput$2 = op({
	  depthwiseConv2dNativeBackpropInput_: depthwiseConv2dNativeBackpropInput_
	});

	/**
	 * Computes depthwise 2D convolution, optionally fused with adding a
	 * bias and applying an activation.
	 *
	 * Given a 4D `input` array and a `filter` array of shape
	 * `[filterHeight, filterWidth, inChannels, channelMultiplier]` containing
	 * `inChannels` convolutional filters of depth 1, this op applies a
	 * different filter to each input channel (expanding from 1 channel to
	 * `channelMultiplier` channels for each), then concatenates the results
	 * together. The output has `inChannels * channelMultiplier` channels.
	 *
	 * See
	 * [https://www.tensorflow.org/api_docs/python/tf/nn/depthwise_conv2d](
	 *     https://www.tensorflow.org/api_docs/python/tf/nn/depthwise_conv2d)
	 * for more details.
	 *
	 * @param obj An object with the following properties:
	 * @param x The input tensor, of rank 4 or rank 3, of shape
	 *     `[batch, height, width, inChannels]`. If rank 3, batch of 1 is
	 * assumed.
	 * @param filter The filter tensor, rank 4, of shape
	 *     `[filterHeight, filterWidth, inChannels, channelMultiplier]`.
	 * @param strides The strides of the convolution: `[strideHeight,
	 * strideWidth]`. If strides is a single number, then `strideHeight ==
	 * strideWidth`.
	 * @param pad The type of padding algorithm.
	 *   - `same` and stride 1: output will be of same size as input,
	 *       regardless of filter size.
	 *   - `valid`: output will be smaller than input if filter is larger
	 *       than 1x1.
	 *   - For more info, see this guide:
	 *     [https://www.tensorflow.org/api_docs/python/tf/nn/convolution](
	 *          https://www.tensorflow.org/api_docs/python/tf/nn/convolution)
	 * @param dilations The dilation rates: `[dilationHeight, dilationWidth]`
	 *     in which we sample input values across the height and width dimensions
	 *     in atrous convolution. Defaults to `[1, 1]`. If `rate` is a single
	 *     number, then `dilationHeight == dilationWidth`. If it is greater than
	 *     1, then all values of `strides` must be 1.
	 * @param dataFormat: An optional string from: "NHWC", "NCHW". Defaults to
	 *     "NHWC". Specify the data format of the input and output data. With the
	 *     default format "NHWC", the data is stored in the order of: [batch,
	 *     height, width, channels]. Only "NHWC" is currently supported.
	 * @param dimRoundingMode A string from: 'ceil', 'round', 'floor'. If none is
	 *     provided, it will default to truncate.
	 * @param bias Tensor to be added to the result.
	 * @param activation Name of activation kernel (defaults to `linear`).
	 * @param preluActivationWeights Tensor of prelu weights to be applied as part
	 *     of a `prelu` activation, typically the same shape as `x`.
	 * @param leakyreluAlpha Optional. Alpha to be applied as part of a `leakyrelu`
	 *     activation.
	 */
	function fusedDepthwiseConv2d_(_ref) {
	  var x = _ref.x,
	    filter = _ref.filter,
	    strides = _ref.strides,
	    pad = _ref.pad,
	    _ref$dataFormat = _ref.dataFormat,
	    dataFormat = _ref$dataFormat === void 0 ? 'NHWC' : _ref$dataFormat,
	    _ref$dilations = _ref.dilations,
	    dilations = _ref$dilations === void 0 ? [1, 1] : _ref$dilations,
	    dimRoundingMode = _ref.dimRoundingMode,
	    bias = _ref.bias,
	    _ref$activation = _ref.activation,
	    activation = _ref$activation === void 0 ? 'linear' : _ref$activation,
	    preluActivationWeights = _ref.preluActivationWeights,
	    leakyreluAlpha = _ref.leakyreluAlpha;
	  if (shouldFuse(ENGINE.state.gradientDepth, activation) === false) {
	    var result = depthwiseConv2d$3(x, filter, strides, pad, dataFormat, dilations, dimRoundingMode);
	    if (bias != null) {
	      result = add$3(result, bias);
	    }
	    return applyActivation$1(result, activation, preluActivationWeights, leakyreluAlpha);
	  }
	  var $x = convertToTensor(x, 'x', 'depthwiseConv2d', 'float32');
	  var $filter = convertToTensor(filter, 'filter', 'depthwiseConv2d', 'float32');
	  var x4D = $x;
	  var reshapedTo4D = false;
	  if ($x.rank === 3) {
	    reshapedTo4D = true;
	    x4D = reshape$3($x, [1, $x.shape[0], $x.shape[1], $x.shape[2]]);
	  }
	  assert$1(x4D.rank === 4, function () {
	    return "Error in fused depthwiseConv2d: input must be rank 4, but got " + "rank ".concat(x4D.rank, ".");
	  });
	  assert$1($filter.rank === 4, function () {
	    return "Error in fused depthwiseConv2d: filter must be rank 4, " + "but got rank ".concat($filter.rank, ".");
	  });
	  assert$1(x4D.shape[3] === $filter.shape[2], function () {
	    return "Error in fused depthwiseConv2d: number of input channels " + "(".concat(x4D.shape[3], ") must match the inChannels dimension in ") + "filter ".concat($filter.shape[2], ".");
	  });
	  if (dilations == null) {
	    dilations = [1, 1];
	  }
	  assert$1(eitherStridesOrDilationsAreOne(strides, dilations), function () {
	    return 'Error in fused depthwiseConv2d: Either strides or dilations must ' + "be 1. Got strides ".concat(strides, " and dilations '").concat(dilations, "'");
	  });
	  checkPadOnDimRoundingMode('fused depthwiseConv2d', pad, dimRoundingMode);
	  var convInfo = computeConv2DInfo(x4D.shape, $filter.shape, strides, dilations, pad, dimRoundingMode, true /* depthwise */);
	  var $bias;
	  if (bias != null) {
	    $bias = convertToTensor(bias, 'bias', 'fused conv2d');
	    var _makeTypesMatch = makeTypesMatch($bias, $x);
	    var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 1);
	    $bias = _makeTypesMatch2[0];
	    assertAndGetBroadcastShape(convInfo.outShape, $bias.shape);
	  }
	  var $preluActivationWeights;
	  if (preluActivationWeights != null) {
	    $preluActivationWeights = convertToTensor(preluActivationWeights, 'prelu weights', 'fused depthwiseConv2d');
	  }
	  var grad = function grad(dy, saved) {
	    assert$1(tupleValuesAreOne(dilations), function () {
	      return 'Error in gradient of fused depthwiseConv2d: dilation rates ' + "greater than 1 are not yet supported. Got dilations " + "'".concat(dilations, "'");
	    });
	    var _saved = _slicedToArray(saved, 4),
	      $filter = _saved[0],
	      x4D = _saved[1],
	      y = _saved[2],
	      bias = _saved[3];
	    var dyActivation = getFusedDyActivation(dy, y, activation);
	    var xDer = depthwiseConv2dNativeBackpropInput$2(x4D.shape, dyActivation, $filter, strides, pad, dilations, dimRoundingMode);
	    var filterDer = depthwiseConv2dNativeBackpropFilter$2(x4D, dyActivation, $filter.shape, strides, pad, dilations, dimRoundingMode);
	    if (bias != null) {
	      var biasDer = getFusedBiasGradient($bias, dyActivation);
	      return [xDer, filterDer, biasDer];
	    }
	    return [xDer, filterDer];
	  };
	  var inputs = {
	    x: x4D,
	    filter: $filter,
	    bias: $bias,
	    preluActivationWeights: $preluActivationWeights
	  };
	  var attrs = {
	    strides: strides,
	    pad: pad,
	    dataFormat: dataFormat,
	    dilations: dilations,
	    dimRoundingMode: dimRoundingMode,
	    activation: activation,
	    leakyreluAlpha: leakyreluAlpha
	  };
	  // Depending on the the params passed in we will have different number of
	  // inputs and thus a a different number of elements in the gradient.
	  if (bias == null) {
	    var customOp = customGrad(function (x4D, filter, save) {
	      // tslint:disable-next-line: no-unnecessary-type-assertion
	      var res = ENGINE.runKernel(FusedDepthwiseConv2D, inputs, attrs);
	      save([filter, x4D, res]);
	      if (reshapedTo4D) {
	        // tslint:disable-next-line: no-unnecessary-type-assertion
	        res = reshape$3(res, [res.shape[1], res.shape[2], res.shape[3]]);
	      }
	      return {
	        value: res,
	        gradFunc: grad
	      };
	    });
	    return customOp(x4D, $filter);
	  } else {
	    var customOpWithBias = customGrad(function (x4D, filter, bias, save) {
	      // tslint:disable-next-line: no-unnecessary-type-assertion
	      var res = ENGINE.runKernel(FusedDepthwiseConv2D, inputs, attrs);
	      save([filter, x4D, res, bias]);
	      if (reshapedTo4D) {
	        // tslint:disable-next-line: no-unnecessary-type-assertion
	        res = reshape$3(res, [res.shape[1], res.shape[2], res.shape[3]]);
	      }
	      return {
	        value: res,
	        gradFunc: grad
	      };
	    });
	    return customOpWithBias(x4D, $filter, $bias);
	  }
	}
	var depthwiseConv2d$2 = /* @__PURE__ */op({
	  fusedDepthwiseConv2d_: fusedDepthwiseConv2d_
	});

	/**
	 * Computes the dot product of two matrices with optional activation and bias.
	 *
	 * ```js
	 * const a = tf.tensor2d([-1, -2], [1, 2]);
	 * const b = tf.tensor2d([1, 2, 3, 4], [2, 2]);
	 * const bias = tf.tensor2d([1, 2], [1, 2]);
	 *
	 * tf.fused.matMul({a, b, bias, activation: 'relu'}).print();
	 * ```
	 *
	 * @param obj An object with the following properties:
	 * - `a` First matrix in dot product operation.
	 * - `b` Second matrix in dot product operation.
	 * - `transposeA` If true, `a` is transposed before multiplication.
	 * - `transposeB` If true, `b` is transposed before multiplication.
	 * - `bias` Matrix to be added to the result.
	 * - `activation` Name of activation kernel (defaults to `linear`).
	 * - `preluActivationWeights` Tensor of prelu weights.
	 * - `leakyreluAlpha` Alpha of leakyrelu.
	 */
	function fusedMatMul_(_ref) {
	  var a = _ref.a,
	    b = _ref.b,
	    _ref$transposeA = _ref.transposeA,
	    transposeA = _ref$transposeA === void 0 ? false : _ref$transposeA,
	    _ref$transposeB = _ref.transposeB,
	    transposeB = _ref$transposeB === void 0 ? false : _ref$transposeB,
	    bias = _ref.bias,
	    _ref$activation = _ref.activation,
	    activation = _ref$activation === void 0 ? 'linear' : _ref$activation,
	    preluActivationWeights = _ref.preluActivationWeights,
	    _ref$leakyreluAlpha = _ref.leakyreluAlpha,
	    leakyreluAlpha = _ref$leakyreluAlpha === void 0 ? 0.2 : _ref$leakyreluAlpha;
	  if (shouldFuse(ENGINE.state.gradientDepth, activation) === false) {
	    var result = matMul$1(a, b, transposeA, transposeB);
	    if (bias != null) {
	      result = add$3(result, bias);
	    }
	    return applyActivation$1(result, activation, preluActivationWeights, leakyreluAlpha);
	  }
	  var $a = convertToTensor(a, 'a', 'fused matMul');
	  var $b = convertToTensor(b, 'b', 'fused matMul');
	  var _makeTypesMatch = makeTypesMatch($a, $b);
	  var _makeTypesMatch2 = _slicedToArray(_makeTypesMatch, 2);
	  $a = _makeTypesMatch2[0];
	  $b = _makeTypesMatch2[1];
	  var innerShapeA = transposeA ? $a.shape[$a.rank - 2] : $a.shape[$a.rank - 1];
	  var innerShapeB = transposeB ? $b.shape[$b.rank - 1] : $b.shape[$b.rank - 2];
	  var outerShapeA = transposeA ? $a.shape[$a.rank - 1] : $a.shape[$a.rank - 2];
	  var outerShapeB = transposeB ? $b.shape[$b.rank - 2] : $b.shape[$b.rank - 1];
	  var outerDimsA = $a.shape.slice(0, -2);
	  var outerDimsB = $b.shape.slice(0, -2);
	  var batchDimA = sizeFromShape(outerDimsA);
	  var batchDimB = sizeFromShape(outerDimsB);
	  assert$1(innerShapeA === innerShapeB, function () {
	    return "Error in fused matMul: inner shapes (".concat(innerShapeA, ") and (") + "".concat(innerShapeB, ") of Tensors with shapes ").concat($a.shape, " and ") + "".concat($b.shape, " and transposeA=").concat(transposeA) + " and transposeB=".concat(transposeB, " must match.");
	  });
	  var outShapeOuterDims = assertAndGetBroadcastShape($a.shape.slice(0, -2), $b.shape.slice(0, -2));
	  var outShape = outShapeOuterDims.concat([outerShapeA, outerShapeB]);
	  var a3D = transposeA ? reshape$3($a, [batchDimA, innerShapeA, outerShapeA]) : reshape$3($a, [batchDimA, outerShapeA, innerShapeA]);
	  var b3D = transposeB ? reshape$3($b, [batchDimB, outerShapeB, innerShapeB]) : reshape$3($b, [batchDimB, innerShapeB, outerShapeB]);
	  var $bias;
	  if (bias != null) {
	    $bias = convertToTensor(bias, 'bias', 'fused matMul');
	    var _makeTypesMatch3 = makeTypesMatch($bias, $a);
	    var _makeTypesMatch4 = _slicedToArray(_makeTypesMatch3, 1);
	    $bias = _makeTypesMatch4[0];
	    assertAndGetBroadcastShape(outShape, $bias.shape);
	  }
	  var $preluActivationWeights;
	  if (preluActivationWeights != null) {
	    $preluActivationWeights = convertToTensor(preluActivationWeights, 'prelu weights', 'fused matMul');
	  }
	  var grad = function grad(dy, saved) {
	    var _saved = _slicedToArray(saved, 4),
	      a3D = _saved[0],
	      b3D = _saved[1],
	      y = _saved[2],
	      $bias = _saved[3];
	    // we reshape dy because the result of the forward is not
	    // necessarily going to be a 3d tensor due to a reshape done at the end of
	    // the customOp.
	    var dyActivation = getFusedDyActivation(reshape$3(dy, y.shape), y, activation);
	    var aDer;
	    var bDer;
	    if (!transposeA && !transposeB) {
	      aDer = matMul$1(dyActivation, b3D, false, true);
	      bDer = matMul$1(a3D, dyActivation, true, false);
	    } else if (!transposeA && transposeB) {
	      aDer = matMul$1(dyActivation, b3D, false, false);
	      bDer = matMul$1(dyActivation, a3D, true, false);
	    } else if (transposeA && !transposeB) {
	      aDer = matMul$1(b3D, dyActivation, false, true);
	      bDer = matMul$1(a3D, dyActivation, false, false);
	    } else {
	      aDer = matMul$1(b3D, dyActivation, true, true);
	      bDer = matMul$1(dyActivation, a3D, true, true);
	    }
	    if (bias != null) {
	      var biasDer = getFusedBiasGradient($bias, dyActivation);
	      return [aDer, bDer, biasDer];
	    } else {
	      return [aDer, bDer];
	    }
	  };
	  var inputs = {
	    a: a3D,
	    b: b3D,
	    bias: $bias,
	    preluActivationWeights: $preluActivationWeights
	  };
	  var attrs = {
	    transposeA: transposeA,
	    transposeB: transposeB,
	    activation: activation,
	    leakyreluAlpha: leakyreluAlpha
	  };
	  // Depending on the the params passed in we will have different number of
	  // inputs and thus a a different number of elements in the gradient.
	  if (bias == null) {
	    var customOp = customGrad(function (a3D, b3D, save) {
	      var res =
	      // tslint:disable-next-line: no-unnecessary-type-assertion
	      ENGINE.runKernel(_FusedMatMul, inputs, attrs);
	      save([a3D, b3D, res]);
	      return {
	        value: reshape$3(res, outShape),
	        gradFunc: grad
	      };
	    });
	    return customOp(a3D, b3D);
	  } else {
	    var customOpWithBias = customGrad(function (a3D, b3D, $bias, save) {
	      var res =
	      // tslint:disable-next-line: no-unnecessary-type-assertion
	      ENGINE.runKernel(_FusedMatMul, inputs, attrs);
	      save([a3D, b3D, res, $bias]);
	      return {
	        value: reshape$3(res, outShape),
	        gradFunc: grad
	      };
	    });
	    return customOpWithBias(a3D, b3D, $bias);
	  }
	}
	var matMul = /* @__PURE__ */op({
	  fusedMatMul_: fusedMatMul_
	});

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */

	var fused_ops = {
		__proto__: null,
		conv2d: conv2d$3,
		depthwiseConv2d: depthwiseConv2d$2,
		matMul: matMul
	};

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Generate a hamming window.
	 *
	 * See: https://en.wikipedia.org/wiki/Window_function#Hann_and_Hamming_windows
	 *
	 * ```js
	 * tf.signal.hammingWindow(10).print();
	 * ```
	 * @param The length of window
	 *
	 * @doc {heading: 'Operations', subheading: 'Signal', namespace: 'signal'}
	 */
	function hammingWindow_(windowLength) {
	  return cosineWindow(windowLength, 0.54, 0.46);
	}
	var hammingWindow = /* @__PURE__ */op({
	  hammingWindow_: hammingWindow_
	});

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Generate a Hann window.
	 *
	 * See: https://en.wikipedia.org/wiki/Window_function#Hann_and_Hamming_windows
	 *
	 * ```js
	 * tf.signal.hannWindow(10).print();
	 * ```
	 * @param The length of window
	 *
	 * @doc {heading: 'Operations', subheading: 'Signal', namespace: 'signal'}
	 */
	function hannWindow_(windowLength) {
	  return cosineWindow(windowLength, 0.5, 0.5);
	}
	var hannWindow = /* @__PURE__ */op({
	  hannWindow_: hannWindow_
	});

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Expands input into frames of frameLength.
	 * Slides a window size with frameStep.
	 *
	 * ```js
	 * tf.signal.frame([1, 2, 3], 2, 1).print();
	 * ```
	 * @param signal The input tensor to be expanded
	 * @param frameLength Length of each frame
	 * @param frameStep The frame hop size in samples.
	 * @param padEnd Whether to pad the end of signal with padValue.
	 * @param padValue A number to use where the input signal does
	 *     not exist when padEnd is True.
	 *
	 * @doc {heading: 'Operations', subheading: 'Signal', namespace: 'signal'}
	 */
	function frame_(signal, frameLength, frameStep) {
	  var padEnd = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var padValue = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 0;
	  var start = 0;
	  var output = [];
	  while (start + frameLength <= signal.size) {
	    output.push(slice$2(signal, start, frameLength));
	    start += frameStep;
	  }
	  if (padEnd) {
	    while (start < signal.size) {
	      var padLen = start + frameLength - signal.size;
	      var pad = concat$2([slice$2(signal, start, frameLength - padLen), fill$2([padLen], padValue)]);
	      output.push(pad);
	      start += frameStep;
	    }
	  }
	  if (output.length === 0) {
	    return tensor2d([], [0, frameLength]);
	  }
	  return reshape$3(concat$2(output), [output.length, frameLength]);
	}
	var frame = /* @__PURE__ */op({
	  frame_: frame_
	});

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the Short-time Fourier Transform of signals
	 * See: https://en.wikipedia.org/wiki/Short-time_Fourier_transform
	 *
	 * ```js
	 * const input = tf.tensor1d([1, 1, 1, 1, 1])
	 * tf.signal.stft(input, 3, 1).print();
	 * ```
	 * @param signal 1-dimensional real value tensor.
	 * @param frameLength The window length of samples.
	 * @param frameStep The number of samples to step.
	 * @param fftLength The size of the FFT to apply.
	 * @param windowFn A callable that takes a window length and returns 1-d tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'Signal', namespace: 'signal'}
	 */
	function stft_(signal, frameLength, frameStep, fftLength) {
	  var windowFn = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : hannWindow;
	  if (fftLength == null) {
	    fftLength = enclosingPowerOfTwo(frameLength);
	  }
	  var framedSignal = frame(signal, frameLength, frameStep);
	  var windowedSignal = mul(framedSignal, windowFn(frameLength));
	  return rfft(windowedSignal, fftLength);
	}
	var stft = /* @__PURE__ */op({
	  stft_: stft_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Extracts crops from the input image tensor and resizes them using bilinear
	 * sampling or nearest neighbor sampling (possibly with aspect ratio change)
	 * to a common output size specified by cropSize.
	 *
	 * @param image 4d tensor of shape `[batch,imageHeight,imageWidth, depth]`,
	 *     where imageHeight and imageWidth must be positive, specifying the
	 *     batch of images from which to take crops
	 * @param boxes 2d float32 tensor of shape `[numBoxes, 4]`. Each entry is
	 *     `[y1, x1, y2, x2]`, where `(y1, x1)` and `(y2, x2)` are the normalized
	 *     coordinates of the box in the `boxInd[i]`th image in the batch
	 * @param boxInd 1d int32 tensor of shape `[numBoxes]` with values in range
	 *     `[0, batch)` that specifies the image that the `i`-th box refers to.
	 * @param cropSize 1d int32 tensor of 2 elements `[cropHeigh, cropWidth]`
	 *     specifying the size to which all crops are resized to.
	 * @param method Optional string from `'bilinear' | 'nearest'`,
	 *     defaults to bilinear, which specifies the sampling method for resizing
	 * @param extrapolationValue A threshold for deciding when to remove boxes based
	 *     on score. Defaults to 0.
	 * @return A 4D tensor of the shape `[numBoxes,cropHeight,cropWidth,depth]`
	 *
	 * @doc {heading: 'Operations', subheading: 'Images', namespace: 'image'}
	 */
	function cropAndResize_(image, boxes, boxInd, cropSize) {
	  var method = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 'bilinear';
	  var extrapolationValue = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : 0;
	  var $image = convertToTensor(image, 'image', 'cropAndResize');
	  var $boxes = convertToTensor(boxes, 'boxes', 'cropAndResize', 'float32');
	  var $boxInd = convertToTensor(boxInd, 'boxInd', 'cropAndResize', 'int32');
	  var numBoxes = $boxes.shape[0];
	  assert$1($image.rank === 4, function () {
	    return 'Error in cropAndResize: image must be rank 4,' + "but got rank ".concat($image.rank, ".");
	  });
	  assert$1($boxes.rank === 2 && $boxes.shape[1] === 4, function () {
	    return "Error in cropAndResize: boxes must be have size [".concat(numBoxes, ",4] ") + "but had shape ".concat($boxes.shape, ".");
	  });
	  assert$1($boxInd.rank === 1 && $boxInd.shape[0] === numBoxes, function () {
	    return "Error in cropAndResize: boxInd must be have size [".concat(numBoxes, "] ") + "but had shape ".concat($boxes.shape, ".");
	  });
	  assert$1(cropSize.length === 2, function () {
	    return "Error in cropAndResize: cropSize must be of length 2, but got " + "length ".concat(cropSize.length, ".");
	  });
	  assert$1(cropSize[0] >= 1 && cropSize[1] >= 1, function () {
	    return "cropSize must be atleast [1,1], but was ".concat(cropSize);
	  });
	  assert$1(method === 'bilinear' || method === 'nearest', function () {
	    return "method must be bilinear or nearest, but was ".concat(method);
	  });
	  var inputs = {
	    image: $image,
	    boxes: $boxes,
	    boxInd: $boxInd
	  };
	  var attrs = {
	    method: method,
	    extrapolationValue: extrapolationValue,
	    cropSize: cropSize
	  };
	  var res = ENGINE.runKernel(CropAndResize, inputs, attrs);
	  return res;
	}
	var cropAndResize$3 = /* @__PURE__ */op({
	  cropAndResize_: cropAndResize_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Flips the image left to right. Currently available in the CPU, WebGL, and
	 * WASM backends.
	 *
	 * @param image 4d tensor of shape `[batch, imageHeight, imageWidth, depth]`.
	 */
	/** @doc {heading: 'Operations', subheading: 'Images', namespace: 'image'} */
	function flipLeftRight_(image) {
	  var $image = convertToTensor(image, 'image', 'flipLeftRight', 'float32');
	  assert$1($image.rank === 4, function () {
	    return 'Error in flipLeftRight: image must be rank 4,' + "but got rank ".concat($image.rank, ".");
	  });
	  var inputs = {
	    image: $image
	  };
	  var res = ENGINE.runKernel(FlipLeftRight, inputs, {});
	  return res;
	}
	var flipLeftRight = /* @__PURE__ */op({
	  flipLeftRight_: flipLeftRight_
	});

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Converts images from grayscale to RGB format.
	 *
	 * @param image A grayscale tensor to convert. The `image`'s last dimension must
	 *     be size 1 with at least a two-dimensional shape.
	 *
	 * @doc {heading: 'Operations', subheading: 'Images', namespace: 'image'}
	 */
	function grayscaleToRGB_(image) {
	  var $image = convertToTensor(image, 'image', 'grayscaleToRGB');
	  var lastDimsIdx = $image.rank - 1;
	  var lastDims = $image.shape[lastDimsIdx];
	  assert$1($image.rank >= 2, function () {
	    return 'Error in grayscaleToRGB: images must be at least rank 2, ' + "but got rank ".concat($image.rank, ".");
	  });
	  assert$1(lastDims === 1, function () {
	    return 'Error in grayscaleToRGB: last dimension of a grayscale image ' + "should be size 1, but got size ".concat(lastDims, ".");
	  });
	  var reps = new Array($image.rank);
	  reps.fill(1, 0, lastDimsIdx);
	  reps[lastDimsIdx] = 3;
	  return tile$3($image, reps);
	}
	var grayscaleToRGB = /* @__PURE__ */op({
	  grayscaleToRGB_: grayscaleToRGB_
	});

	/**
	 * @license
	 * Copyright 2023 Google LLC.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Converts images from RGB format to grayscale.
	 *
	 * @param image A RGB tensor to convert. The `image`'s last dimension must
	 *     be size 3 with at least a two-dimensional shape.
	 *
	 * @doc {heading: 'Operations', subheading: 'Images', namespace: 'image'}
	 */
	function rgbToGrayscale_(image) {
	  var $image = convertToTensor(image, 'image', 'RGBToGrayscale');
	  var lastDimsIdx = $image.rank - 1;
	  var lastDims = $image.shape[lastDimsIdx];
	  assert$1($image.rank >= 2, function () {
	    return 'Error in RGBToGrayscale: images must be at least rank 2, ' + "but got rank ".concat($image.rank, ".");
	  });
	  assert$1(lastDims === 3, function () {
	    return 'Error in RGBToGrayscale: last dimension of an RGB image ' + "should be size 3, but got size ".concat(lastDims, ".");
	  });
	  // Remember original dtype so we can convert back if needed
	  var origDtype = $image.dtype;
	  var fltImage = cast$3($image, 'float32');
	  var rgbWeights = tensor1d([0.2989, 0.5870, 0.1140]);
	  var grayFloat;
	  switch ($image.rank) {
	    case 2:
	      grayFloat = einsum$2('ij,j->i', fltImage, rgbWeights);
	      break;
	    case 3:
	      grayFloat = einsum$2('ijk,k->ij', fltImage, rgbWeights);
	      break;
	    case 4:
	      grayFloat = einsum$2('ijkl,l->ijk', fltImage, rgbWeights);
	      break;
	    case 5:
	      grayFloat = einsum$2('ijklm,m->ijkl', fltImage, rgbWeights);
	      break;
	    case 6:
	      grayFloat = einsum$2('ijklmn,n->ijklm', fltImage, rgbWeights);
	      break;
	    default:
	      throw new Error('Not a valid tensor rank.');
	  }
	  grayFloat = expandDims$3(grayFloat, -1);
	  return cast$3(grayFloat, origDtype);
	}
	var rgbToGrayscale = /* @__PURE__ */op({
	  rgbToGrayscale_: rgbToGrayscale_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Rotates the input image tensor counter-clockwise with an optional offset
	 * center of rotation. Currently available in the CPU, WebGL, and WASM backends.
	 *
	 * @param image 4d tensor of shape `[batch, imageHeight, imageWidth, depth]`.
	 * @param radians The amount of rotation.
	 * @param fillValue The value to fill in the empty space leftover
	 *     after rotation. Can be either a single grayscale value (0-255), or an
	 *     array of three numbers `[red, green, blue]` specifying the red, green,
	 *     and blue channels. Defaults to `0` (black).
	 * @param center The center of rotation. Can be either a single value (0-1), or
	 *     an array of two numbers `[centerX, centerY]`. Defaults to `0.5` (rotates
	 *     the image around its center).
	 *
	 * @doc {heading: 'Operations', subheading: 'Images', namespace: 'image'}
	 */
	function rotateWithOffset_(image, radians) {
	  var fillValue = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
	  var center = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 0.5;
	  var $image = convertToTensor(image, 'image', 'rotateWithOffset', 'float32');
	  assert$1($image.rank === 4, function () {
	    return 'Error in rotateWithOffset: image must be rank 4,' + "but got rank ".concat($image.rank, ".");
	  });
	  var inputs = {
	    image: $image
	  };
	  var attrs = {
	    radians: radians,
	    fillValue: fillValue,
	    center: center
	  };
	  var res = ENGINE.runKernel(RotateWithOffset, inputs, attrs);
	  return res;
	}
	var rotateWithOffset = /* @__PURE__ */op({
	  rotateWithOffset_: rotateWithOffset_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function nonMaxSuppSanityCheck(boxes, scores, maxOutputSize, iouThreshold, scoreThreshold, softNmsSigma) {
	  if (iouThreshold == null) {
	    iouThreshold = 0.5;
	  }
	  if (scoreThreshold == null) {
	    scoreThreshold = Number.NEGATIVE_INFINITY;
	  }
	  if (softNmsSigma == null) {
	    softNmsSigma = 0.0;
	  }
	  var numBoxes = boxes.shape[0];
	  maxOutputSize = Math.min(maxOutputSize, numBoxes);
	  assert$1(0 <= iouThreshold && iouThreshold <= 1, function () {
	    return "iouThreshold must be in [0, 1], but was '".concat(iouThreshold, "'");
	  });
	  assert$1(boxes.rank === 2, function () {
	    return "boxes must be a 2D tensor, but was of rank '".concat(boxes.rank, "'");
	  });
	  assert$1(boxes.shape[1] === 4, function () {
	    return "boxes must have 4 columns, but 2nd dimension was ".concat(boxes.shape[1]);
	  });
	  assert$1(scores.rank === 1, function () {
	    return 'scores must be a 1D tensor';
	  });
	  assert$1(scores.shape[0] === numBoxes, function () {
	    return "scores has incompatible shape with boxes. Expected ".concat(numBoxes, ", ") + "but was ".concat(scores.shape[0]);
	  });
	  assert$1(0 <= softNmsSigma && softNmsSigma <= 1, function () {
	    return "softNmsSigma must be in [0, 1], but was '".concat(softNmsSigma, "'");
	  });
	  return {
	    maxOutputSize: maxOutputSize,
	    iouThreshold: iouThreshold,
	    scoreThreshold: scoreThreshold,
	    softNmsSigma: softNmsSigma
	  };
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Performs non maximum suppression of bounding boxes based on
	 * iou (intersection over union).
	 *
	 * @param boxes a 2d tensor of shape `[numBoxes, 4]`. Each entry is
	 *     `[y1, x1, y2, x2]`, where `(y1, x1)` and `(y2, x2)` are the corners of
	 *     the bounding box.
	 * @param scores a 1d tensor providing the box scores of shape `[numBoxes]`.
	 * @param maxOutputSize The maximum number of boxes to be selected.
	 * @param iouThreshold A float representing the threshold for deciding whether
	 *     boxes overlap too much with respect to IOU. Must be between [0, 1].
	 *     Defaults to 0.5 (50% box overlap).
	 * @param scoreThreshold A threshold for deciding when to remove boxes based
	 *     on score. Defaults to -inf, which means any score is accepted.
	 * @return A 1D tensor with the selected box indices.
	 *
	 * @doc {heading: 'Operations', subheading: 'Images', namespace: 'image'}
	 */
	function nonMaxSuppression_(boxes, scores, maxOutputSize) {
	  var iouThreshold = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 0.5;
	  var scoreThreshold = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : Number.NEGATIVE_INFINITY;
	  var $boxes = convertToTensor(boxes, 'boxes', 'nonMaxSuppression', 'float32');
	  var $scores = convertToTensor(scores, 'scores', 'nonMaxSuppression', 'float32');
	  var inputs = nonMaxSuppSanityCheck($boxes, $scores, maxOutputSize, iouThreshold, scoreThreshold);
	  maxOutputSize = inputs.maxOutputSize;
	  iouThreshold = inputs.iouThreshold;
	  scoreThreshold = inputs.scoreThreshold;
	  var attrs = {
	    maxOutputSize: maxOutputSize,
	    iouThreshold: iouThreshold,
	    scoreThreshold: scoreThreshold
	  };
	  return ENGINE.runKernel(NonMaxSuppressionV3, {
	    boxes: $boxes,
	    scores: $scores
	  }, attrs);
	}
	var nonMaxSuppression = /* @__PURE__ */op({
	  nonMaxSuppression_: nonMaxSuppression_
	});

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Inserts a value into a sorted array. This method allows duplicate, meaning it
	 * allows inserting duplicate value, in which case, the element will be inserted
	 * at the lowest index of the value.
	 * @param arr The array to modify.
	 * @param element The element to insert.
	 * @param comparator Optional. If no comparator is specified, elements are
	 * compared using array_util.defaultComparator, which is suitable for Strings
	 * and Numbers in ascending arrays. If the array contains multiple instances of
	 * the target value, the left-most instance will be returned. To provide a
	 * comparator, it should take 2 arguments to compare and return a negative,
	 * zero, or a positive number.
	 */
	function binaryInsert(arr, element, comparator) {
	  var index = binarySearch(arr, element, comparator);
	  var insertionPoint = index < 0 ? -(index + 1) : index;
	  arr.splice(insertionPoint, 0, element);
	}
	/**
	 * Searches the array for the target using binary search, returns the index
	 * of the found element, or position to insert if element not found. If no
	 * comparator is specified, elements are compared using array_
	 * util.defaultComparator, which is suitable for Strings and Numbers in
	 * ascending arrays. If the array contains multiple instances of the target
	 * value, the left-most instance will be returned.
	 * @param arr The array to be searched in.
	 * @param target The target to be searched for.
	 * @param comparator Should take 2 arguments to compare and return a negative,
	 *    zero, or a positive number.
	 * @return Lowest index of the target value if found, otherwise the insertion
	 *    point where the target should be inserted, in the form of
	 *    (-insertionPoint - 1).
	 */
	function binarySearch(arr, target, comparator) {
	  return binarySearch_(arr, target, comparator || defaultComparator);
	}
	/**
	 * Compares its two arguments for order.
	 * @param a The first element to be compared.
	 * @param b The second element to be compared.
	 * @return A negative number, zero, or a positive number as the first
	 *     argument is less than, equal to, or greater than the second.
	 */
	function defaultComparator(a, b) {
	  return a > b ? 1 : a < b ? -1 : 0;
	}
	function binarySearch_(arr, target, comparator) {
	  var left = 0;
	  var right = arr.length;
	  var middle = 0;
	  var found = false;
	  while (left < right) {
	    middle = left + (right - left >>> 1);
	    var compareResult = comparator(target, arr[middle]);
	    if (compareResult > 0) {
	      left = middle + 1;
	    } else {
	      right = middle;
	      // If compareResult is 0, the value is found. We record it is found,
	      // and then keep looking because there may be duplicate.
	      found = !compareResult;
	    }
	  }
	  return found ? left : -left - 1;
	}

	function nonMaxSuppressionV3Impl$2(boxes, scores, maxOutputSize, iouThreshold, scoreThreshold) {
	  return nonMaxSuppressionImpl_(boxes, scores, maxOutputSize, iouThreshold, scoreThreshold, 0 /* softNmsSigma */);
	}

	function nonMaxSuppressionV4Impl$2(boxes, scores, maxOutputSize, iouThreshold, scoreThreshold, padToMaxOutputSize) {
	  return nonMaxSuppressionImpl_(boxes, scores, maxOutputSize, iouThreshold, scoreThreshold, 0 /* softNmsSigma */, false /* returnScoresTensor */, padToMaxOutputSize /* padToMaxOutputSize */, true
	  /* returnValidOutputs */);
	}

	function nonMaxSuppressionV5Impl$2(boxes, scores, maxOutputSize, iouThreshold, scoreThreshold, softNmsSigma) {
	  return nonMaxSuppressionImpl_(boxes, scores, maxOutputSize, iouThreshold, scoreThreshold, softNmsSigma, true /* returnScoresTensor */);
	}

	function nonMaxSuppressionImpl_(boxes, scores, maxOutputSize, iouThreshold, scoreThreshold, softNmsSigma) {
	  var returnScoresTensor = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : false;
	  var padToMaxOutputSize = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : false;
	  var returnValidOutputs = arguments.length > 8 && arguments[8] !== undefined ? arguments[8] : false;
	  // The list is sorted in ascending order, so that we can always pop the
	  // candidate with the largest score in O(1) time.
	  var candidates = [];
	  for (var i = 0; i < scores.length; i++) {
	    if (scores[i] > scoreThreshold) {
	      candidates.push({
	        score: scores[i],
	        boxIndex: i,
	        suppressBeginIndex: 0
	      });
	    }
	  }
	  candidates.sort(ascendingComparator);
	  // If softNmsSigma is 0, the outcome of this algorithm is exactly same as
	  // before.
	  var scale = softNmsSigma > 0 ? -0.5 / softNmsSigma : 0.0;
	  var selectedIndices = [];
	  var selectedScores = [];
	  while (selectedIndices.length < maxOutputSize && candidates.length > 0) {
	    var candidate = candidates.pop();
	    var originalScore = candidate.score,
	      boxIndex = candidate.boxIndex,
	      suppressBeginIndex = candidate.suppressBeginIndex;
	    if (originalScore < scoreThreshold) {
	      break;
	    }
	    // Overlapping boxes are likely to have similar scores, therefore we
	    // iterate through the previously selected boxes backwards in order to
	    // see if candidate's score should be suppressed. We use
	    // suppressBeginIndex to track and ensure a candidate can be suppressed
	    // by a selected box no more than once. Also, if the overlap exceeds
	    // iouThreshold, we simply ignore the candidate.
	    var ignoreCandidate = false;
	    for (var j = selectedIndices.length - 1; j >= suppressBeginIndex; --j) {
	      var iou = intersectionOverUnion(boxes, boxIndex, selectedIndices[j]);
	      if (iou >= iouThreshold) {
	        ignoreCandidate = true;
	        break;
	      }
	      candidate.score = candidate.score * suppressWeight(iouThreshold, scale, iou);
	      if (candidate.score <= scoreThreshold) {
	        break;
	      }
	    }
	    // At this point, if `candidate.score` has not dropped below
	    // `scoreThreshold`, then we know that we went through all of the
	    // previous selections and can safely update `suppressBeginIndex` to the
	    // end of the selected array. Then we can re-insert the candidate with
	    // the updated score and suppressBeginIndex back in the candidate list.
	    // If on the other hand, `candidate.score` has dropped below the score
	    // threshold, we will not add it back to the candidates list.
	    candidate.suppressBeginIndex = selectedIndices.length;
	    if (!ignoreCandidate) {
	      // Candidate has passed all the tests, and is not suppressed, so
	      // select the candidate.
	      if (candidate.score === originalScore) {
	        selectedIndices.push(boxIndex);
	        selectedScores.push(candidate.score);
	      } else if (candidate.score > scoreThreshold) {
	        // Candidate's score is suppressed but is still high enough to be
	        // considered, so add back to the candidates list.
	        binaryInsert(candidates, candidate, ascendingComparator);
	      }
	    }
	  }
	  // NonMaxSuppressionV4 feature: padding output to maxOutputSize.
	  var validOutputs = selectedIndices.length;
	  var elemsToPad = maxOutputSize - validOutputs;
	  if (padToMaxOutputSize && elemsToPad > 0) {
	    selectedIndices.push.apply(selectedIndices, _toConsumableArray(new Array(elemsToPad).fill(0)));
	    selectedScores.push.apply(selectedScores, _toConsumableArray(new Array(elemsToPad).fill(0.0)));
	  }
	  var result = {
	    selectedIndices: selectedIndices
	  };
	  if (returnScoresTensor) {
	    result['selectedScores'] = selectedScores;
	  }
	  if (returnValidOutputs) {
	    result['validOutputs'] = validOutputs;
	  }
	  return result;
	}
	function intersectionOverUnion(boxes, i, j) {
	  var iCoord = boxes.subarray(i * 4, i * 4 + 4);
	  var jCoord = boxes.subarray(j * 4, j * 4 + 4);
	  var yminI = Math.min(iCoord[0], iCoord[2]);
	  var xminI = Math.min(iCoord[1], iCoord[3]);
	  var ymaxI = Math.max(iCoord[0], iCoord[2]);
	  var xmaxI = Math.max(iCoord[1], iCoord[3]);
	  var yminJ = Math.min(jCoord[0], jCoord[2]);
	  var xminJ = Math.min(jCoord[1], jCoord[3]);
	  var ymaxJ = Math.max(jCoord[0], jCoord[2]);
	  var xmaxJ = Math.max(jCoord[1], jCoord[3]);
	  var areaI = (ymaxI - yminI) * (xmaxI - xminI);
	  var areaJ = (ymaxJ - yminJ) * (xmaxJ - xminJ);
	  if (areaI <= 0 || areaJ <= 0) {
	    return 0.0;
	  }
	  var intersectionYmin = Math.max(yminI, yminJ);
	  var intersectionXmin = Math.max(xminI, xminJ);
	  var intersectionYmax = Math.min(ymaxI, ymaxJ);
	  var intersectionXmax = Math.min(xmaxI, xmaxJ);
	  var intersectionArea = Math.max(intersectionYmax - intersectionYmin, 0.0) * Math.max(intersectionXmax - intersectionXmin, 0.0);
	  return intersectionArea / (areaI + areaJ - intersectionArea);
	}
	// A Gaussian penalty function, this method always returns values in [0, 1].
	// The weight is a function of similarity, the more overlap two boxes are, the
	// smaller the weight is,meaning highly overlapping boxes will be significantly
	// penalized. On the other hand, a non-overlapping box will not be penalized.
	function suppressWeight(iouThreshold, scale, iou) {
	  var weight = Math.exp(scale * iou * iou);
	  return iou <= iouThreshold ? weight : 0.0;
	}
	function ascendingComparator(c1, c2) {
	  // For objects with same scores, we make the object with the larger index go
	  // first. In an array that pops from the end, this means that the object with
	  // the smaller index will be popped first. This ensures the same output as
	  // the TensorFlow python version.
	  return c1.score - c2.score || c1.score === c2.score && c2.boxIndex - c1.boxIndex;
	}

	/**
	 * Performs non maximum suppression of bounding boxes based on
	 * iou (intersection over union).
	 *
	 * This is the async version of `nonMaxSuppression`
	 *
	 * @param boxes a 2d tensor of shape `[numBoxes, 4]`. Each entry is
	 *     `[y1, x1, y2, x2]`, where `(y1, x1)` and `(y2, x2)` are the corners of
	 *     the bounding box.
	 * @param scores a 1d tensor providing the box scores of shape `[numBoxes]`.
	 * @param maxOutputSize The maximum number of boxes to be selected.
	 * @param iouThreshold A float representing the threshold for deciding whether
	 *     boxes overlap too much with respect to IOU. Must be between [0, 1].
	 *     Defaults to 0.5 (50% box overlap).
	 * @param scoreThreshold A threshold for deciding when to remove boxes based
	 *     on score. Defaults to -inf, which means any score is accepted.
	 * @return A 1D tensor with the selected box indices.
	 *
	 * @doc {heading: 'Operations', subheading: 'Images', namespace: 'image'}
	 */
	function nonMaxSuppressionAsync_(_x, _x2, _x3) {
	  return _nonMaxSuppressionAsync_.apply(this, arguments);
	}
	function _nonMaxSuppressionAsync_() {
	  _nonMaxSuppressionAsync_ = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(boxes, scores, maxOutputSize) {
	    var iouThreshold,
	      scoreThreshold,
	      $boxes,
	      $scores,
	      inputs,
	      boxesAndScores,
	      boxesVals,
	      scoresVals,
	      _nonMaxSuppressionV3I,
	      selectedIndices,
	      _args = arguments;
	    return _regeneratorRuntime().wrap(function _callee$(_context) {
	      while (1) switch (_context.prev = _context.next) {
	        case 0:
	          iouThreshold = _args.length > 3 && _args[3] !== undefined ? _args[3] : 0.5;
	          scoreThreshold = _args.length > 4 && _args[4] !== undefined ? _args[4] : Number.NEGATIVE_INFINITY;
	          $boxes = convertToTensor(boxes, 'boxes', 'nonMaxSuppressionAsync');
	          $scores = convertToTensor(scores, 'scores', 'nonMaxSuppressionAsync');
	          inputs = nonMaxSuppSanityCheck($boxes, $scores, maxOutputSize, iouThreshold, scoreThreshold);
	          maxOutputSize = inputs.maxOutputSize;
	          iouThreshold = inputs.iouThreshold;
	          scoreThreshold = inputs.scoreThreshold;
	          _context.next = 10;
	          return Promise.all([$boxes.data(), $scores.data()]);
	        case 10:
	          boxesAndScores = _context.sent;
	          boxesVals = boxesAndScores[0];
	          scoresVals = boxesAndScores[1]; // We call a cpu based impl directly with the typedarray data  here rather
	          // than a kernel because all kernels are synchronous (and thus cannot await
	          // .data()).
	          _nonMaxSuppressionV3I = nonMaxSuppressionV3Impl$2(boxesVals, scoresVals, maxOutputSize, iouThreshold, scoreThreshold), selectedIndices = _nonMaxSuppressionV3I.selectedIndices;
	          if ($boxes !== boxes) {
	            $boxes.dispose();
	          }
	          if ($scores !== scores) {
	            $scores.dispose();
	          }
	          return _context.abrupt("return", tensor1d(selectedIndices, 'int32'));
	        case 17:
	        case "end":
	          return _context.stop();
	      }
	    }, _callee);
	  }));
	  return _nonMaxSuppressionAsync_.apply(this, arguments);
	}
	var nonMaxSuppressionAsync = nonMaxSuppressionAsync_;

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Performs non maximum suppression of bounding boxes based on
	 * iou (intersection over union).
	 *
	 * This op also supports a Soft-NMS mode (cf.
	 * Bodla et al, https://arxiv.org/abs/1704.04503) where boxes reduce the score
	 * of other overlapping boxes, therefore favoring different regions of the image
	 * with high scores. To enable this Soft-NMS mode, set the `softNmsSigma`
	 * parameter to be larger than 0.
	 *
	 * @param boxes a 2d tensor of shape `[numBoxes, 4]`. Each entry is
	 *     `[y1, x1, y2, x2]`, where `(y1, x1)` and `(y2, x2)` are the corners of
	 *     the bounding box.
	 * @param scores a 1d tensor providing the box scores of shape `[numBoxes]`.
	 * @param maxOutputSize The maximum number of boxes to be selected.
	 * @param iouThreshold A float representing the threshold for deciding whether
	 *     boxes overlap too much with respect to IOU. Must be between [0, 1].
	 *     Defaults to 0.5 (50% box overlap).
	 * @param scoreThreshold A threshold for deciding when to remove boxes based
	 *     on score. Defaults to -inf, which means any score is accepted.
	 * @param softNmsSigma A float representing the sigma parameter for Soft NMS.
	 *     When sigma is 0, it falls back to nonMaxSuppression.
	 * @return A map with the following properties:
	 *     - selectedIndices: A 1D tensor with the selected box indices.
	 *     - selectedScores: A 1D tensor with the corresponding scores for each
	 *       selected box.
	 *
	 * @doc {heading: 'Operations', subheading: 'Images', namespace: 'image'}
	 */
	function nonMaxSuppressionWithScore_(boxes, scores, maxOutputSize) {
	  var iouThreshold = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 0.5;
	  var scoreThreshold = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : Number.NEGATIVE_INFINITY;
	  var softNmsSigma = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : 0.0;
	  var $boxes = convertToTensor(boxes, 'boxes', 'nonMaxSuppression');
	  var $scores = convertToTensor(scores, 'scores', 'nonMaxSuppression');
	  var params = nonMaxSuppSanityCheck($boxes, $scores, maxOutputSize, iouThreshold, scoreThreshold, softNmsSigma);
	  maxOutputSize = params.maxOutputSize;
	  iouThreshold = params.iouThreshold;
	  scoreThreshold = params.scoreThreshold;
	  softNmsSigma = params.softNmsSigma;
	  var inputs = {
	    boxes: $boxes,
	    scores: $scores
	  };
	  var attrs = {
	    maxOutputSize: maxOutputSize,
	    iouThreshold: iouThreshold,
	    scoreThreshold: scoreThreshold,
	    softNmsSigma: softNmsSigma
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var result = ENGINE.runKernel(NonMaxSuppressionV5, inputs, attrs);
	  return {
	    selectedIndices: result[0],
	    selectedScores: result[1]
	  };
	}
	var nonMaxSuppressionWithScore = /* @__PURE__ */op({
	  nonMaxSuppressionWithScore_: nonMaxSuppressionWithScore_
	});

	/**
	 * Asynchronously performs non maximum suppression of bounding boxes based on
	 * iou (intersection over union).
	 *
	 * This op also supports a Soft-NMS mode (cf.
	 * Bodla et al, https://arxiv.org/abs/1704.04503) where boxes reduce the score
	 * of other overlapping boxes, therefore favoring different regions of the image
	 * with high scores. To enable this Soft-NMS mode, set the `softNmsSigma`
	 * parameter to be larger than 0.
	 *
	 * @param boxes a 2d tensor of shape `[numBoxes, 4]`. Each entry is
	 *     `[y1, x1, y2, x2]`, where `(y1, x1)` and `(y2, x2)` are the corners of
	 *     the bounding box.
	 * @param scores a 1d tensor providing the box scores of shape `[numBoxes]`.
	 * @param maxOutputSize The maximum number of boxes to be selected.
	 * @param iouThreshold A float representing the threshold for deciding whether
	 *     boxes overlap too much with respect to IOU. Must be between [0, 1].
	 *     Defaults to 0.5 (50% box overlap).
	 * @param scoreThreshold A threshold for deciding when to remove boxes based
	 *     on score. Defaults to -inf, which means any score is accepted.
	 * @param softNmsSigma A float representing the sigma parameter for Soft NMS.
	 *     When sigma is 0, it falls back to nonMaxSuppression.
	 * @return A map with the following properties:
	 *     - selectedIndices: A 1D tensor with the selected box indices.
	 *     - selectedScores: A 1D tensor with the corresponding scores for each
	 *       selected box.
	 *
	 * @doc {heading: 'Operations', subheading: 'Images', namespace: 'image'}
	 */
	function nonMaxSuppressionWithScoreAsync_(_x, _x2, _x3) {
	  return _nonMaxSuppressionWithScoreAsync_.apply(this, arguments);
	}
	function _nonMaxSuppressionWithScoreAsync_() {
	  _nonMaxSuppressionWithScoreAsync_ = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(boxes, scores, maxOutputSize) {
	    var iouThreshold,
	      scoreThreshold,
	      softNmsSigma,
	      $boxes,
	      $scores,
	      params,
	      boxesAndScores,
	      boxesVals,
	      scoresVals,
	      _nonMaxSuppressionV5I,
	      selectedIndices,
	      selectedScores,
	      _args = arguments;
	    return _regeneratorRuntime().wrap(function _callee$(_context) {
	      while (1) switch (_context.prev = _context.next) {
	        case 0:
	          iouThreshold = _args.length > 3 && _args[3] !== undefined ? _args[3] : 0.5;
	          scoreThreshold = _args.length > 4 && _args[4] !== undefined ? _args[4] : Number.NEGATIVE_INFINITY;
	          softNmsSigma = _args.length > 5 && _args[5] !== undefined ? _args[5] : 0.0;
	          $boxes = convertToTensor(boxes, 'boxes', 'nonMaxSuppressionAsync');
	          $scores = convertToTensor(scores, 'scores', 'nonMaxSuppressionAsync');
	          params = nonMaxSuppSanityCheck($boxes, $scores, maxOutputSize, iouThreshold, scoreThreshold, softNmsSigma);
	          maxOutputSize = params.maxOutputSize;
	          iouThreshold = params.iouThreshold;
	          scoreThreshold = params.scoreThreshold;
	          softNmsSigma = params.softNmsSigma;
	          _context.next = 12;
	          return Promise.all([$boxes.data(), $scores.data()]);
	        case 12:
	          boxesAndScores = _context.sent;
	          boxesVals = boxesAndScores[0];
	          scoresVals = boxesAndScores[1]; // We call a cpu based impl directly with the typedarray data  here rather
	          // than a kernel because all kernels are synchronous (and thus cannot await
	          // .data()).
	          _nonMaxSuppressionV5I = nonMaxSuppressionV5Impl$2(boxesVals, scoresVals, maxOutputSize, iouThreshold, scoreThreshold, softNmsSigma), selectedIndices = _nonMaxSuppressionV5I.selectedIndices, selectedScores = _nonMaxSuppressionV5I.selectedScores;
	          if ($boxes !== boxes) {
	            $boxes.dispose();
	          }
	          if ($scores !== scores) {
	            $scores.dispose();
	          }
	          return _context.abrupt("return", {
	            selectedIndices: tensor1d(selectedIndices, 'int32'),
	            selectedScores: tensor1d(selectedScores)
	          });
	        case 19:
	        case "end":
	          return _context.stop();
	      }
	    }, _callee);
	  }));
	  return _nonMaxSuppressionWithScoreAsync_.apply(this, arguments);
	}
	var nonMaxSuppressionWithScoreAsync = nonMaxSuppressionWithScoreAsync_;

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Asynchronously performs non maximum suppression of bounding boxes based on
	 * iou (intersection over union), with an option to pad results.
	 *
	 * @param boxes a 2d tensor of shape `[numBoxes, 4]`. Each entry is
	 *     `[y1, x1, y2, x2]`, where `(y1, x1)` and `(y2, x2)` are the corners of
	 *     the bounding box.
	 * @param scores a 1d tensor providing the box scores of shape `[numBoxes]`.
	 * @param maxOutputSize The maximum number of boxes to be selected.
	 * @param iouThreshold A float representing the threshold for deciding whether
	 *     boxes overlap too much with respect to IOU. Must be between [0, 1].
	 *     Defaults to 0.5 (50% box overlap).
	 * @param scoreThreshold A threshold for deciding when to remove boxes based
	 *     on score. Defaults to -inf, which means any score is accepted.
	 * @param padToMaxOutputSize Defaults to false. If true, size of output
	 *     `selectedIndices` is padded to maxOutputSize.
	 * @return A map with the following properties:
	 *     - selectedIndices: A 1D tensor with the selected box indices.
	 *     - validOutputs: A scalar denoting how many elements in `selectedIndices`
	 *       are valid. Valid elements occur first, then padding.
	 *
	 * @doc {heading: 'Operations', subheading: 'Images', namespace: 'image'}
	 */
	function nonMaxSuppressionPadded_(boxes, scores, maxOutputSize) {
	  var iouThreshold = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 0.5;
	  var scoreThreshold = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : Number.NEGATIVE_INFINITY;
	  var padToMaxOutputSize = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : false;
	  var $boxes = convertToTensor(boxes, 'boxes', 'nonMaxSuppression');
	  var $scores = convertToTensor(scores, 'scores', 'nonMaxSuppression');
	  var params = nonMaxSuppSanityCheck($boxes, $scores, maxOutputSize, iouThreshold, scoreThreshold, null /* softNmsSigma */);
	  var $maxOutputSize = params.maxOutputSize;
	  var $iouThreshold = params.iouThreshold;
	  var $scoreThreshold = params.scoreThreshold;
	  var inputs = {
	    boxes: $boxes,
	    scores: $scores
	  };
	  var attrs = {
	    maxOutputSize: $maxOutputSize,
	    iouThreshold: $iouThreshold,
	    scoreThreshold: $scoreThreshold,
	    padToMaxOutputSize: padToMaxOutputSize
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var result = ENGINE.runKernel(NonMaxSuppressionV4, inputs, attrs);
	  return {
	    selectedIndices: result[0],
	    validOutputs: result[1]
	  };
	}
	var nonMaxSuppressionPadded = /* @__PURE__ */op({
	  nonMaxSuppressionPadded_: nonMaxSuppressionPadded_
	});

	/**
	 * Asynchronously performs non maximum suppression of bounding boxes based on
	 * iou (intersection over union), with an option to pad results.
	 *
	 * @param boxes a 2d tensor of shape `[numBoxes, 4]`. Each entry is
	 *     `[y1, x1, y2, x2]`, where `(y1, x1)` and `(y2, x2)` are the corners of
	 *     the bounding box.
	 * @param scores a 1d tensor providing the box scores of shape `[numBoxes]`.
	 * @param maxOutputSize The maximum number of boxes to be selected.
	 * @param iouThreshold A float representing the threshold for deciding whether
	 *     boxes overlap too much with respect to IOU. Must be between [0, 1].
	 *     Defaults to 0.5 (50% box overlap).
	 * @param scoreThreshold A threshold for deciding when to remove boxes based
	 *     on score. Defaults to -inf, which means any score is accepted.
	 * @param padToMaxOutputSize Defaults to false. If true, size of output
	 *     `selectedIndices` is padded to maxOutputSize.
	 * @return A map with the following properties:
	 *     - selectedIndices: A 1D tensor with the selected box indices.
	 *     - validOutputs: A scalar denoting how many elements in `selectedIndices`
	 *       are valid. Valid elements occur first, then padding.
	 *
	 * @doc {heading: 'Operations', subheading: 'Images', namespace: 'image'}
	 */
	function nonMaxSuppressionPaddedAsync_(_x, _x2, _x3) {
	  return _nonMaxSuppressionPaddedAsync_.apply(this, arguments);
	}
	function _nonMaxSuppressionPaddedAsync_() {
	  _nonMaxSuppressionPaddedAsync_ = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(boxes, scores, maxOutputSize) {
	    var iouThreshold,
	      scoreThreshold,
	      padToMaxOutputSize,
	      $boxes,
	      $scores,
	      params,
	      $maxOutputSize,
	      $iouThreshold,
	      $scoreThreshold,
	      _yield$Promise$all,
	      _yield$Promise$all2,
	      boxesVals,
	      scoresVals,
	      _nonMaxSuppressionV4I,
	      selectedIndices,
	      validOutputs,
	      _args = arguments;
	    return _regeneratorRuntime().wrap(function _callee$(_context) {
	      while (1) switch (_context.prev = _context.next) {
	        case 0:
	          iouThreshold = _args.length > 3 && _args[3] !== undefined ? _args[3] : 0.5;
	          scoreThreshold = _args.length > 4 && _args[4] !== undefined ? _args[4] : Number.NEGATIVE_INFINITY;
	          padToMaxOutputSize = _args.length > 5 && _args[5] !== undefined ? _args[5] : false;
	          $boxes = convertToTensor(boxes, 'boxes', 'nonMaxSuppressionAsync');
	          $scores = convertToTensor(scores, 'scores', 'nonMaxSuppressionAsync');
	          params = nonMaxSuppSanityCheck($boxes, $scores, maxOutputSize, iouThreshold, scoreThreshold, null /* softNmsSigma */);
	          $maxOutputSize = params.maxOutputSize;
	          $iouThreshold = params.iouThreshold;
	          $scoreThreshold = params.scoreThreshold;
	          _context.next = 11;
	          return Promise.all([$boxes.data(), $scores.data()]);
	        case 11:
	          _yield$Promise$all = _context.sent;
	          _yield$Promise$all2 = _slicedToArray(_yield$Promise$all, 2);
	          boxesVals = _yield$Promise$all2[0];
	          scoresVals = _yield$Promise$all2[1];
	          // We call a cpu based impl directly with the typedarray data here rather
	          // than a kernel because all kernels are synchronous (and thus cannot await
	          // .data()).
	          _nonMaxSuppressionV4I = nonMaxSuppressionV4Impl$2(boxesVals, scoresVals, $maxOutputSize, $iouThreshold, $scoreThreshold, padToMaxOutputSize), selectedIndices = _nonMaxSuppressionV4I.selectedIndices, validOutputs = _nonMaxSuppressionV4I.validOutputs;
	          if ($boxes !== boxes) {
	            $boxes.dispose();
	          }
	          if ($scores !== scores) {
	            $scores.dispose();
	          }
	          return _context.abrupt("return", {
	            selectedIndices: tensor1d(selectedIndices, 'int32'),
	            validOutputs: scalar(validOutputs, 'int32')
	          });
	        case 19:
	        case "end":
	          return _context.stop();
	      }
	    }, _callee);
	  }));
	  return _nonMaxSuppressionPaddedAsync_.apply(this, arguments);
	}
	var nonMaxSuppressionPaddedAsync = nonMaxSuppressionPaddedAsync_;

	/**
	 * Bilinear resize a single 3D image or a batch of 3D images to a new shape.
	 *
	 * @param images The images, of rank 4 or rank 3, of shape
	 *     `[batch, height, width, inChannels]`. If rank 3, batch of 1 is assumed.
	 * @param size The new shape `[newHeight, newWidth]` to resize the
	 *     images to. Each channel is resized individually.
	 * @param alignCorners Defaults to `false`. If true, rescale
	 *     input by `(new_height - 1) / (height - 1)`, which exactly aligns the 4
	 *     corners of images and resized images. If false, rescale by
	 *     `new_height / height`. Treat similarly the width dimension.
	 * @param halfPixelCenters Defaults to `false`. Whether to assume pixel centers
	 *     are at 0.5, which would make the floating point coordinates of the top
	 *     left pixel 0.5, 0.5.
	 *
	 * @doc {heading: 'Operations', subheading: 'Images', namespace: 'image'}
	 */
	function resizeBilinear_(images, size) {
	  var alignCorners = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  var halfPixelCenters = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var $images = convertToTensor(images, 'images', 'resizeBilinear');
	  assert$1($images.rank === 3 || $images.rank === 4, function () {
	    return "Error in resizeBilinear: x must be rank 3 or 4, but got " + "rank ".concat($images.rank, ".");
	  });
	  assert$1(size.length === 2, function () {
	    return "Error in resizeBilinear: new shape must 2D, but got shape " + "".concat(size, ".");
	  });
	  assert$1(halfPixelCenters === false || alignCorners === false, function () {
	    return "Error in resizeBilinear: If halfPixelCenters is true, " + "alignCorners must be false.";
	  });
	  var batchImages = $images;
	  var reshapedTo4D = false;
	  if ($images.rank === 3) {
	    reshapedTo4D = true;
	    batchImages = reshape$3($images, [1, $images.shape[0], $images.shape[1], $images.shape[2]]);
	  }
	  var _size = _slicedToArray(size, 0);
	  var inputs = {
	    images: batchImages
	  };
	  var attrs = {
	    alignCorners: alignCorners,
	    halfPixelCenters: halfPixelCenters,
	    size: size
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var res = ENGINE.runKernel(ResizeBilinear, inputs, attrs);
	  if (reshapedTo4D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3]]);
	  }
	  return res;
	}
	var resizeBilinear$3 = /* @__PURE__ */op({
	  resizeBilinear_: resizeBilinear_
	});

	/**
	 * NearestNeighbor resize a batch of 3D images to a new shape.
	 *
	 * @param images The images, of rank 4 or rank 3, of shape
	 *     `[batch, height, width, inChannels]`. If rank 3, batch of 1 is assumed.
	 * @param size The new shape `[newHeight, newWidth]` to resize the
	 *     images to. Each channel is resized individually.
	 * @param alignCorners Defaults to False. If true, rescale
	 *     input by `(new_height - 1) / (height - 1)`, which exactly aligns the 4
	 *     corners of images and resized images. If false, rescale by
	 *     `new_height / height`. Treat similarly the width dimension.
	 * @param halfPixelCenters Defaults to `false`. Whether to assume pixels are of
	 *      half the actual dimensions, and yield more accurate resizes. This flag
	 *      would also make the floating point coordinates of the top left pixel
	 *      0.5, 0.5.
	 *
	 * @doc {heading: 'Operations', subheading: 'Images', namespace: 'image'}
	 */
	function resizeNearestNeighbor_(images, size) {
	  var alignCorners = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  var halfPixelCenters = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var $images = convertToTensor(images, 'images', 'resizeNearestNeighbor');
	  assert$1($images.rank === 3 || $images.rank === 4, function () {
	    return "Error in resizeNearestNeighbor: x must be rank 3 or 4, but got " + "rank ".concat($images.rank, ".");
	  });
	  assert$1(size.length === 2, function () {
	    return "Error in resizeNearestNeighbor: new shape must 2D, but got shape " + "".concat(size, ".");
	  });
	  assert$1($images.dtype === 'float32' || $images.dtype === 'int32', function () {
	    return '`images` must have `int32` or `float32` as dtype';
	  });
	  assert$1(halfPixelCenters === false || alignCorners === false, function () {
	    return "Error in resizeNearestNeighbor: If halfPixelCenters is true, " + "alignCorners must be false.";
	  });
	  var batchImages = $images;
	  var reshapedTo4D = false;
	  if ($images.rank === 3) {
	    reshapedTo4D = true;
	    batchImages = reshape$3($images, [1, $images.shape[0], $images.shape[1], $images.shape[2]]);
	  }
	  var _size = _slicedToArray(size, 0);
	  var inputs = {
	    images: batchImages
	  };
	  var attrs = {
	    alignCorners: alignCorners,
	    halfPixelCenters: halfPixelCenters,
	    size: size
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var res = ENGINE.runKernel(ResizeNearestNeighbor, inputs, attrs);
	  if (reshapedTo4D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3]]);
	  }
	  return res;
	}
	var resizeNearestNeighbor$2 = /* @__PURE__ */op({
	  resizeNearestNeighbor_: resizeNearestNeighbor_
	});

	/**
	 * Performs image binarization with corresponding threshold
	 * (depends on the method)value, which creates a binary image from a grayscale.
	 * @param image 3d tensor of shape [imageHeight,imageWidth, depth],
	 * where imageHeight and imageWidth must be positive.The image color
	 * range should be [0, 255].
	 * @param method Optional string from `'binary' | 'otsu'`
	 * which specifies the method for thresholding. Defaults to 'binary'.
	 * @param inverted Optional boolean whichspecifies
	 * if colours should be inverted. Defaults to false.
	 * @param threshValue Optional number which defines threshold value from 0 to 1.
	 * Defaults to 0.5.
	 * @return A 3d tensor of shape [imageHeight,imageWidth, depth], which
	 * contains binarized image.
	 */
	function threshold_(image) {
	  var method = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'binary';
	  var inverted = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  var threshValue = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 0.5;
	  var $image = convertToTensor(image, 'image', 'threshold');
	  /* 0.2989, 0.5870, 0.1140 are represent luma coefficients in CCIR601.
	  Reference for converting between RGB and grayscale: https://en.wikipedia.org/wiki/Luma_%28video%29  */
	  var RED_INTENCITY_COEF = 0.2989;
	  var GREEN_INTENCITY_COEF = 0.5870;
	  var BLUE_INTENCITY_COEF = 0.1140;
	  var totalPixelsInImage = $image.shape[0] * $image.shape[1];
	  var $threshold = mul(tensor1d([threshValue]), 255);
	  var r, g, b, grayscale;
	  assert$1($image.rank === 3, function () {
	    return 'Error in threshold: image must be rank 3,' + "but got rank ".concat($image.rank, ".");
	  });
	  assert$1($image.shape[2] === 3 || $image.shape[2] === 1, function () {
	    return 'Error in threshold: ' + 'image color channel must be equal to 3 or 1' + "but got ".concat($image.shape[2], ".");
	  });
	  assert$1($image.dtype === 'int32' || $image.dtype === 'float32', function () {
	    return 'Error in dtype: image dtype must be int32 or float32,' + "but got dtype ".concat($image.dtype, ".");
	  });
	  assert$1(method === 'otsu' || method === 'binary', function () {
	    return "Method must be binary or otsu, but was ".concat(method);
	  });
	  if ($image.shape[2] === 3) {
	    var _split = split$3($image, [1, 1, 1], -1);
	    var _split2 = _slicedToArray(_split, 3);
	    r = _split2[0];
	    g = _split2[1];
	    b = _split2[2];
	    var $r = mul(r, RED_INTENCITY_COEF);
	    var $g = mul(g, GREEN_INTENCITY_COEF);
	    var $b = mul(b, BLUE_INTENCITY_COEF);
	    grayscale = add$3(add$3($r, $g), $b);
	  } else {
	    grayscale = image;
	  }
	  if (method === 'otsu') {
	    var $histogram = bincount$2(cast$3(round$2(grayscale), 'int32'), tensor([]), 256);
	    $threshold = otsu($histogram, totalPixelsInImage);
	  }
	  var invCondition = inverted ? lessEqual$2(grayscale, $threshold) : greater$3(grayscale, $threshold);
	  var result = cast$3(mul(invCondition, 255), 'int32');
	  return result;
	}
	function otsu(histogram, total) {
	  var bestThresh = tensor1d([-1]);
	  var bestInBetVar = tensor1d([0]);
	  var cInBetVar = tensor1d([0]);
	  var classFirst, classSecond, meanFirst, meanSec, weightForeground, weightBack;
	  for (var index = 0; index < histogram.size - 1; index++) {
	    classFirst = slice$2(histogram, 0, index + 1);
	    classSecond = slice$2(histogram, index + 1);
	    weightForeground = div$1(sum$3(classFirst), total);
	    weightBack = div$1(sum$3(classSecond), total);
	    var meanFirstDivA = sum$3(mul(classFirst, range$3(0, classFirst.size)));
	    meanFirst = div$1(meanFirstDivA, sum$3(classFirst));
	    var meanSecFill = fill$2(classSecond.shape, classFirst.size);
	    var meanSecAdd = add$3(range$3(0, classSecond.size), meanSecFill);
	    var meanSecMul = mul(classSecond, meanSecAdd);
	    meanSec = div$1(sum$3(meanSecMul), sum$3(classSecond));
	    var cInBetVarSubA = sub$2(meanFirst, meanSec);
	    var cInBetVarSubB = sub$2(meanFirst, meanSec);
	    var cInBetVarMul = mul(weightForeground, weightBack);
	    cInBetVar = mul(mul(cInBetVarMul, cInBetVarSubA), cInBetVarSubB);
	    var condition = greater$3(cInBetVar, bestInBetVar);
	    bestInBetVar = where(condition, cInBetVar, bestInBetVar);
	    bestThresh = where(condition, tensor1d([index]), bestThresh);
	  }
	  return bestThresh;
	}
	var threshold$1 = /* @__PURE__ */op({
	  threshold_: threshold_
	});

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Applies the given transform(s) to the image(s).
	 *
	 * @param image 4d tensor of shape `[batch, imageHeight, imageWidth, depth]`.
	 * @param transforms Projective transform matrix/matrices. A tensor1d of length
	 *     8 or tensor of size N x 8. If one row of transforms is [a0, a1, a2, b0,
	 *     b1, b2, c0, c1], then it maps the output point (x, y) to a transformed
	 *     input point (x', y') = ((a0 x + a1 y + a2) / k, (b0 x + b1 y + b2) / k),
	 *     where k = c0 x + c1 y + 1. The transforms are inverted compared to the
	 *     transform mapping input points to output points.
	 * @param interpolation Interpolation mode.
	 *     Supported values: 'nearest', 'bilinear'. Default to 'nearest'.
	 * @param fillMode Points outside the boundaries of the input are filled
	 *     according to the given mode, one of 'constant', 'reflect', 'wrap',
	 *     'nearest'. Default to 'constant'.
	 *     'reflect': (d c b a | a b c d | d c b a ) The input is extended by
	 *     reflecting about the edge of the last pixel.
	 *     'constant': (k k k k | a b c d | k k k k) The input is extended by
	 *     filling all values beyond the edge with the same constant value k.
	 *     'wrap': (a b c d | a b c d | a b c d) The input is extended by
	 *     wrapping around to the opposite edge.
	 *     'nearest': (a a a a | a b c d | d d d d) The input is extended by
	 *     the nearest pixel.
	 * @param fillValue A float represents the value to be filled outside the
	 *     boundaries when fillMode is 'constant'.
	 * @param Output dimension after the transform, [height, width]. If undefined,
	 *     output is the same size as input image.
	 *
	 * @doc {heading: 'Operations', subheading: 'Images', namespace: 'image'}
	 */
	function transform_(image, transforms) {
	  var interpolation = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'nearest';
	  var fillMode = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'constant';
	  var fillValue = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 0;
	  var outputShape = arguments.length > 5 ? arguments[5] : undefined;
	  var $image = convertToTensor(image, 'image', 'transform', 'float32');
	  var $transforms = convertToTensor(transforms, 'transforms', 'transform', 'float32');
	  assert$1($image.rank === 4, function () {
	    return 'Error in transform: image must be rank 4,' + "but got rank ".concat($image.rank, ".");
	  });
	  assert$1($transforms.rank === 2 && ($transforms.shape[0] === $image.shape[0] || $transforms.shape[0] === 1) && $transforms.shape[1] === 8, function () {
	    return "Error in transform: Input transform should be batch x 8 or 1 x 8";
	  });
	  assert$1(outputShape == null || outputShape.length === 2, function () {
	    return 'Error in transform: outputShape must be [height, width] or null, ' + "but got ".concat(outputShape, ".");
	  });
	  var inputs = {
	    image: $image,
	    transforms: $transforms
	  };
	  var attrs = {
	    interpolation: interpolation,
	    fillMode: fillMode,
	    fillValue: fillValue,
	    outputShape: outputShape
	  };
	  return ENGINE.runKernel(Transform, inputs, attrs);
	}
	var transform$2 = /* @__PURE__ */op({
	  transform_: transform_
	});

	/**
	 * Copy a tensor setting everything outside a central band in each innermost
	 * matrix to zero.
	 *
	 * The band part is computed as follows: Assume input has `k` dimensions
	 * `[I, J, K, ..., M, N]`, then the output is a tensor with the same shape where
	 * `band[i, j, k, ..., m, n] = in_band(m, n) * input[i, j, k, ..., m, n]`.
	 * The indicator function
	 * `in_band(m, n) = (num_lower < 0 || (m-n) <= num_lower)`
	 * `&& (num_upper < 0 || (n-m) <= num_upper)`
	 *
	 * ```js
	 * const x = tf.tensor2d([[ 0,  1,  2, 3],
	 *                        [-1,  0,  1, 2],
	 *                        [-2, -1,  0, 1],
	 *                        [-3, -2, -1, 0]]);
	 * let y = tf.linalg.bandPart(x, 1, -1);
	 * y.print(); // [[ 0,  1,  2, 3],
	 *            //  [-1,  0,  1, 2],
	 *            //  [ 0, -1,  0, 1],
	 *            //  [ 0, 0 , -1, 0]]
	 * let z = tf.linalg.bandPart(x, 2, 1);
	 * z.print(); // [[ 0,  1,  0, 0],
	 *            //  [-1,  0,  1, 0],
	 *            //  [-2, -1,  0, 1],
	 *            //  [ 0, -2, -1, 0]]
	 * ```
	 *
	 * @param x Rank `k` tensor
	 * @param numLower Number of subdiagonals to keep.
	 *   If negative, keep entire lower triangle.
	 * @param numUpper Number of subdiagonals to keep.
	 *   If negative, keep entire upper triangle.
	 * @returns Rank `k` tensor of the same shape as input.
	 *   The extracted banded tensor.
	 *
	 * @doc {heading:'Operations', subheading:'Linear Algebra', namespace:'linalg'}
	 */
	function bandPart_(a, numLower, numUpper) {
	  var $a = convertToTensor(a, 'a', 'bandPart');
	  assert$1($a.rank >= 2, function () {
	    return "bandPart(): Rank must be at least 2, got ".concat($a.rank, ".");
	  });
	  var shape = $a.shape;
	  var _$a$shape$slice = $a.shape.slice(-2),
	    _$a$shape$slice2 = _slicedToArray(_$a$shape$slice, 2),
	    M = _$a$shape$slice2[0],
	    N = _$a$shape$slice2[1];
	  var $numLower;
	  var $numUpper;
	  if (typeof numLower === 'number') {
	    assert$1(numLower % 1 === 0, function () {
	      return "bandPart(): numLower must be an integer, got ".concat(numLower, ".");
	    });
	    assert$1(numLower <= M, function () {
	      return "bandPart(): numLower (".concat(numLower, ")") + " must not be greater than the number of rows (".concat(M, ").");
	    });
	    $numLower = convertToTensor(numLower < 0 ? M : numLower, 'numLower', 'bandPart');
	  } else {
	    assert$1(numLower.dtype === 'int32', function () {
	      return "bandPart(): numLower's dtype must be an int32.";
	    });
	    // If numLower is a Scalar, checking `numLower <= M` could hurt performance,
	    // but minimum(numLower, M) could avoid unexpected results.
	    $numLower = where(less$3(numLower, 0), M, minimum$4(numLower, M));
	  }
	  if (typeof numUpper === 'number') {
	    assert$1(numUpper % 1 === 0, function () {
	      return "bandPart(): numUpper must be an integer, got ".concat(numUpper, ".");
	    });
	    assert$1(numUpper <= N, function () {
	      return "bandPart(): numUpper (".concat(numUpper, ")") + " must not be greater than the number of columns (".concat(N, ").");
	    });
	    $numUpper = convertToTensor(numUpper < 0 ? N : numUpper, 'numUpper', 'bandPart');
	  } else {
	    assert$1(numUpper.dtype === 'int32', function () {
	      return "bandPart(): numUpper's dtype must be an int32.";
	    });
	    $numUpper = where(less$3(numUpper, 0), N, minimum$4(numUpper, N));
	  }
	  var i = reshape$3(range$3(0, M, 1, 'int32'), [-1, 1]);
	  var j = range$3(0, N, 1, 'int32');
	  var ij = sub$2(i, j);
	  var inBand = logicalAnd$2(lessEqual$2(ij, $numLower), greaterEqual$2(ij, neg$2($numUpper)));
	  var zero = zeros$2([M, N], $a.dtype);
	  return reshape$3(stack(unstack(reshape$3($a, [-1, M, N])).map(function (mat) {
	    return where(inBand, mat, zero);
	  })), shape);
	}
	var bandPart = /* @__PURE__ */op({
	  bandPart_: bandPart_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Gram-Schmidt orthogonalization.
	 *
	 * ```js
	 * const x = tf.tensor2d([[1, 2], [3, 4]]);
	 * let y = tf.linalg.gramSchmidt(x);
	 * y.print();
	 * console.log('Orthogonalized:');
	 * y.dot(y.transpose()).print();  // should be nearly the identity matrix.
	 * console.log('First row direction maintained:');
	 * const data = await y.array();
	 * console.log(data[0][1] / data[0][0]);  // should be nearly 2.
	 * ```
	 *
	 * @param xs The vectors to be orthogonalized, in one of the two following
	 *   formats:
	 *   - An Array of `tf.Tensor1D`.
	 *   - A `tf.Tensor2D`, i.e., a matrix, in which case the vectors are the rows
	 *     of `xs`.
	 *   In each case, all the vectors must have the same length and the length
	 *   must be greater than or equal to the number of vectors.
	 * @returns The orthogonalized and normalized vectors or matrix.
	 *   Orthogonalization means that the vectors or the rows of the matrix
	 *   are orthogonal (zero inner products). Normalization means that each
	 *   vector or each row of the matrix has an L2 norm that equals `1`.
	 *
	 * @doc {heading:'Operations', subheading:'Linear Algebra', namespace:'linalg'}
	 */
	function gramSchmidt_(xs) {
	  var inputIsTensor2D;
	  if (Array.isArray(xs)) {
	    inputIsTensor2D = false;
	    assert$1(xs != null && xs.length > 0, function () {
	      return 'Gram-Schmidt process: input must not be null, undefined, or ' + 'empty';
	    });
	    var dim = xs[0].shape[0];
	    var _loop = function _loop(i) {
	      assert$1(xs[i].shape[0] === dim, function () {
	        return 'Gram-Schmidt: Non-unique lengths found in the input vectors: ' + "(".concat(xs[i].shape[0], " vs. ").concat(dim, ")");
	      });
	    };
	    for (var i = 1; i < xs.length; ++i) {
	      _loop(i);
	    }
	  } else {
	    inputIsTensor2D = true;
	    xs = split$3(xs, xs.shape[0], 0).map(function (x) {
	      return squeeze(x, [0]);
	    });
	  }
	  assert$1(xs.length <= xs[0].shape[0], function () {
	    return "Gram-Schmidt: Number of vectors (".concat(xs.length, ") exceeds ") + "number of dimensions (".concat(xs[0].shape[0], ").");
	  });
	  var ys = [];
	  var xs1d = xs;
	  var _loop2 = function _loop2(_i) {
	    ys.push(ENGINE.tidy(function () {
	      var x = xs1d[_i];
	      if (_i > 0) {
	        for (var j = 0; j < _i; ++j) {
	          var proj = mul(sum$3(mul(ys[j], x)), ys[j]);
	          x = sub$2(x, proj);
	        }
	      }
	      return div$1(x, norm(x, 'euclidean'));
	    }));
	  };
	  for (var _i = 0; _i < xs.length; ++_i) {
	    _loop2(_i);
	  }
	  if (inputIsTensor2D) {
	    return stack(ys, 0);
	  } else {
	    return ys;
	  }
	}
	var gramSchmidt = /* @__PURE__ */op({
	  gramSchmidt_: gramSchmidt_
	});

	/**
	 * Compute QR decomposition of m-by-n matrix using Householder transformation.
	 *
	 * Implementation based on
	 *   [http://www.cs.cornell.edu/~bindel/class/cs6210-f09/lec18.pdf]
	 * (http://www.cs.cornell.edu/~bindel/class/cs6210-f09/lec18.pdf)
	 *
	 * ```js
	 * const a = tf.tensor2d([[1, 2], [3, 4]]);
	 * let [q, r] = tf.linalg.qr(a);
	 * console.log('Q');
	 * q.print();
	 * console.log('R');
	 * r.print();
	 * console.log('Orthogonalized');
	 * q.dot(q.transpose()).print()  // should be nearly the identity matrix.
	 * console.log('Reconstructed');
	 * q.dot(r).print(); // should be nearly [[1, 2], [3, 4]];
	 * ```
	 *
	 * @param x The `tf.Tensor` to be QR-decomposed. Must have rank >= 2. Suppose
	 *   it has the shape `[..., M, N]`.
	 * @param fullMatrices An optional boolean parameter. Defaults to `false`.
	 *   If `true`, compute full-sized `Q`. If `false` (the default),
	 *   compute only the leading N columns of `Q` and `R`.
	 * @returns An `Array` of two `tf.Tensor`s: `[Q, R]`. `Q` is a unitary matrix,
	 *   i.e., its columns all have unit norm and are mutually orthogonal.
	 *   If `M >= N`,
	 *     If `fullMatrices` is `false` (default),
	 *       - `Q` has a shape of `[..., M, N]`,
	 *       - `R` has a shape of `[..., N, N]`.
	 *     If `fullMatrices` is `true` (default),
	 *       - `Q` has a shape of `[..., M, M]`,
	 *       - `R` has a shape of `[..., M, N]`.
	 *   If `M < N`,
	 *     - `Q` has a shape of `[..., M, M]`,
	 *     - `R` has a shape of `[..., M, N]`.
	 * @throws If the rank of `x` is less than 2.
	 *
	 * @doc {heading:'Operations',
	 *       subheading:'Linear Algebra',
	 *       namespace:'linalg'}
	 */
	function qr_(x) {
	  var fullMatrices = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
	  assert$1(x.rank >= 2, function () {
	    return "qr() requires input tensor to have a rank >= 2, but got rank ".concat(x.rank);
	  });
	  if (x.rank === 2) {
	    return qr2d(x, fullMatrices);
	  } else {
	    // Rank > 2.
	    // TODO(cais): Below we split the input into individual 2D tensors,
	    //   perform QR decomposition on them and then stack the results back
	    //   together. We should explore whether this can be parallelized.
	    var outerDimsProd = x.shape.slice(0, x.shape.length - 2).reduce(function (value, prev) {
	      return value * prev;
	    });
	    var x2ds = unstack(reshape$3(x, [outerDimsProd, x.shape[x.shape.length - 2], x.shape[x.shape.length - 1]]), 0);
	    var q2ds = [];
	    var r2ds = [];
	    x2ds.forEach(function (x2d) {
	      var _qr2d = qr2d(x2d, fullMatrices),
	        _qr2d2 = _slicedToArray(_qr2d, 2),
	        q2d = _qr2d2[0],
	        r2d = _qr2d2[1];
	      q2ds.push(q2d);
	      r2ds.push(r2d);
	    });
	    var q = reshape$3(stack(q2ds, 0), x.shape);
	    var r = reshape$3(stack(r2ds, 0), x.shape);
	    return [q, r];
	  }
	}
	function qr2d(x) {
	  var fullMatrices = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
	  return ENGINE.tidy(function () {
	    assert$1(x.shape.length === 2, function () {
	      return "qr2d() requires a 2D Tensor, but got a ".concat(x.shape.length, "D Tensor.");
	    });
	    var m = x.shape[0];
	    var n = x.shape[1];
	    var q = eye(m); // Orthogonal transform so far.
	    var r = clone(x); // Transformed matrix so far.
	    var one2D = tensor2d([[1]], [1, 1]);
	    var w = clone(one2D);
	    var iters = m >= n ? n : m;
	    var _loop = function _loop(j) {
	      // This tidy within the for-loop ensures we clean up temporary
	      // tensors as soon as they are no longer needed.
	      var rTemp = r;
	      var wTemp = w;
	      var qTemp = q;
	      var _ENGINE$tidy = ENGINE.tidy(function () {
	        // Find H = I - tau * w * w', to put zeros below R(j, j).
	        var rjEnd1 = slice$2(r, [j, j], [m - j, 1]);
	        var normX = norm(rjEnd1);
	        var rjj = slice$2(r, [j, j], [1, 1]);
	        // The sign() function returns 0 on 0, which causes division by zero.
	        var s = where(greater$3(rjj, 0), tensor2d([[-1]]), tensor2d([[1]]));
	        var u1 = sub$2(rjj, mul(s, normX));
	        var wPre = div$1(rjEnd1, u1);
	        if (wPre.shape[0] === 1) {
	          w = clone(one2D);
	        } else {
	          w = concat$2([one2D, slice$2(wPre, [1, 0], [wPre.shape[0] - 1, wPre.shape[1]])], 0);
	        }
	        var tau = neg$2(div$1(matMul$1(s, u1), normX));
	        // -- R := HR, Q := QH.
	        var rjEndAll = slice$2(r, [j, 0], [m - j, n]);
	        var tauTimesW = mul(tau, w);
	        var wT = transpose$2(w);
	        if (j === 0) {
	          r = sub$2(rjEndAll, matMul$1(tauTimesW, matMul$1(wT, rjEndAll)));
	        } else {
	          var rTimesTau = sub$2(rjEndAll, matMul$1(tauTimesW, matMul$1(wT, rjEndAll)));
	          r = concat$2([slice$2(r, [0, 0], [j, n]), rTimesTau], 0);
	        }
	        var tawTimesWT = transpose$2(tauTimesW);
	        var qAllJEnd = slice$2(q, [0, j], [m, q.shape[1] - j]);
	        if (j === 0) {
	          q = sub$2(qAllJEnd, matMul$1(matMul$1(qAllJEnd, w), tawTimesWT));
	        } else {
	          var qTimesTau = sub$2(qAllJEnd, matMul$1(matMul$1(qAllJEnd, w), tawTimesWT));
	          q = concat$2([slice$2(q, [0, 0], [m, j]), qTimesTau], 1);
	        }
	        return [w, r, q];
	      });
	      var _ENGINE$tidy2 = _slicedToArray(_ENGINE$tidy, 3);
	      w = _ENGINE$tidy2[0];
	      r = _ENGINE$tidy2[1];
	      q = _ENGINE$tidy2[2];
	      dispose([rTemp, wTemp, qTemp]);
	    };
	    for (var j = 0; j < iters; ++j) {
	      _loop(j);
	    }
	    if (!fullMatrices && m > n) {
	      q = slice$2(q, [0, 0], [m, n]);
	      r = slice$2(r, [0, 0], [n, n]);
	    }
	    return [q, r];
	  });
	}
	var qr = /* @__PURE__ */op({
	  qr_: qr_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	exports.Reduction = void 0;
	(function (Reduction) {
	  Reduction[Reduction["NONE"] = 0] = "NONE";
	  Reduction[Reduction["MEAN"] = 1] = "MEAN";
	  Reduction[Reduction["SUM"] = 2] = "SUM";
	  Reduction[Reduction["SUM_BY_NONZERO_WEIGHTS"] = 3] = "SUM_BY_NONZERO_WEIGHTS";
	})(exports.Reduction || (exports.Reduction = {}));

	/**
	 * Computes the weighted loss between two tensors.
	 *
	 * @param losses Tensor of shape `[batch_size, d1, ..., dN]`.
	 * @param weights Tensor whose rank is either 0, or the same rank as
	 *    `losses`, and must be broadcastable to `losses` (i.e., all
	 *    dimensions must be either `1`, or the same as the corresponding
	 *    `losses` dimension).
	 *
	 * @doc {heading: 'Training', subheading: 'Losses', namespace: 'losses'}
	 */
	function computeWeightedLoss_(losses, weights) {
	  var reduction = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : exports.Reduction.SUM_BY_NONZERO_WEIGHTS;
	  var $losses = convertToTensor(losses, 'losses', 'computeWeightedLoss');
	  var $weights = null;
	  if (weights != null) {
	    $weights = convertToTensor(weights, 'weights', 'computeWeightedLoss');
	  }
	  var weightedLoss = $weights == null ? $losses : mul($losses, $weights);
	  if (reduction === exports.Reduction.NONE) {
	    return weightedLoss;
	  }
	  if (reduction === exports.Reduction.SUM) {
	    return sum$3(weightedLoss);
	  }
	  if (reduction === exports.Reduction.MEAN) {
	    if ($weights == null) {
	      return mean$3(weightedLoss);
	    } else {
	      var broadcastFactor = $losses.size / $weights.size;
	      var result = div$1(sum$3(weightedLoss), sum$3($weights));
	      return broadcastFactor > 1 ? div$1(result, scalar(broadcastFactor)) : result;
	    }
	  }
	  if (reduction === exports.Reduction.SUM_BY_NONZERO_WEIGHTS) {
	    if ($weights == null) {
	      return div$1(sum$3(weightedLoss), scalar($losses.size));
	    } else {
	      var broadcastedWeights = mul($weights, ones$1($losses.shape));
	      var numNonZeros = cast$3(sum$3(notEqual$2(broadcastedWeights, scalar(0))), 'float32');
	      return div$1(sum$3(weightedLoss), numNonZeros);
	    }
	  }
	  throw Error("Unknown reduction: ".concat(reduction));
	}
	var computeWeightedLoss$1 = /* @__PURE__ */op({
	  computeWeightedLoss_: computeWeightedLoss_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the absolute difference loss between two tensors.
	 *
	 * @param labels The ground truth output tensor, same dimensions as
	 *    'predictions'.
	 * @param predictions The predicted outputs.
	 * @param weights Tensor whose rank is either 0, or the same rank as
	 *    `labels`, and must be broadcastable to `labels` (i.e., all dimensions
	 *    must be either `1`, or the same as the corresponding `losses`
	 *    dimension).
	 * @param reduction Type of reduction to apply to loss. Should be of type
	 *    `Reduction`
	 *
	 * @doc {heading: 'Training', subheading: 'Losses', namespace: 'losses'}
	 */
	function absoluteDifference_(labels, predictions, weights) {
	  var reduction = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : exports.Reduction.SUM_BY_NONZERO_WEIGHTS;
	  var $labels = convertToTensor(labels, 'labels', 'absoluteDifference');
	  var $predictions = convertToTensor(predictions, 'predictions', 'absoluteDifference');
	  var $weights = null;
	  if (weights != null) {
	    $weights = convertToTensor(weights, 'weights', 'absoluteDifference');
	  }
	  assertShapesMatch($labels.shape, $predictions.shape, 'Error in absoluteDifference: ');
	  var losses = abs$2(sub$2($labels, $predictions));
	  return computeWeightedLoss$1(losses, $weights, reduction);
	}
	var absoluteDifference = /* @__PURE__ */op({
	  absoluteDifference_: absoluteDifference_
	});

	/**
	 * Computes the cosine distance loss between two tensors.
	 *
	 * @param labels The ground truth output tensor, same dimensions as
	 *    'predictions'.
	 * @param predictions The predicted outputs.
	 * @param axis The dimension along which the cosine distance is computed.
	 * @param weights Tensor whose rank is either 0, or the same rank as
	 *    `labels`, and must be broadcastable to `labels` (i.e., all dimensions
	 *    must be either `1`, or the same as the corresponding `losses`
	 *    dimension).
	 * @param reduction Type of reduction to apply to loss. Should be of type
	 *    `Reduction`
	 *
	 * @doc {heading: 'Training', subheading: 'Losses', namespace: 'losses'}
	 */
	function cosineDistance_(labels, predictions, axis, weights) {
	  var reduction = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : exports.Reduction.SUM_BY_NONZERO_WEIGHTS;
	  var $labels = convertToTensor(labels, 'labels', 'cosineDistance');
	  var $predictions = convertToTensor(predictions, 'predictions', 'cosineDistance');
	  var $weights = null;
	  if (weights != null) {
	    $weights = convertToTensor(weights, 'weights', 'cosineDistance');
	  }
	  assertShapesMatch($labels.shape, $predictions.shape, 'Error in cosineDistance: ');
	  var one = scalar(1);
	  var losses = sub$2(one, sum$3(mul($labels, $predictions), axis, true));
	  return computeWeightedLoss$1(losses, $weights, reduction);
	}
	var cosineDistance = /* @__PURE__ */op({
	  cosineDistance_: cosineDistance_
	});

	/**
	 * Computes the Hinge loss between two tensors.
	 *
	 * @param labels The ground truth output tensor, same dimensions as
	 *    'predictions'.
	 * @param predictions The predicted outputs.
	 * @param weights Tensor whose rank is either 0, or the same rank as
	 *    `labels`, and must be broadcastable to `labels` (i.e., all dimensions
	 *    must be either `1`, or the same as the corresponding `losses`
	 *    dimension).
	 * @param reduction Type of reduction to apply to loss. Should be of type
	 *    `Reduction`
	 *
	 * @doc {heading: 'Training', subheading: 'Losses', namespace: 'losses'}
	 */
	function hingeLoss_(labels, predictions, weights) {
	  var reduction = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : exports.Reduction.SUM_BY_NONZERO_WEIGHTS;
	  var $labels = convertToTensor(labels, 'labels', 'hingeLoss');
	  var $predictions = convertToTensor(predictions, 'predictions', 'hingeLoss');
	  var $weights = null;
	  if (weights != null) {
	    $weights = convertToTensor(weights, 'weights', 'hingeLoss');
	  }
	  assertShapesMatch($labels.shape, $predictions.shape, 'Error in hingeLoss: ');
	  var one = scalar(1);
	  // Convert binary labels to (-1, 1)
	  $labels = sub$2(mul(scalar(2), $labels), one);
	  var losses = relu$2(sub$2(one, mul($labels, $predictions)));
	  return computeWeightedLoss$1(losses, $weights, reduction);
	}
	var hingeLoss = /* @__PURE__ */op({
	  hingeLoss_: hingeLoss_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the Huber loss between two tensors.
	 *
	 * @param labels The ground truth output tensor, same dimensions as
	 *    'predictions'.
	 * @param predictions The predicted outputs.
	 * @param weights Tensor whose rank is either 0, or the same rank as
	 *    `labels`, and must be broadcastable to `labels` (i.e., all dimensions
	 *    must be either `1`, or the same as the corresponding `losses`
	 *    dimension).
	 * @param delta Point where Huber loss changes from quadratic to linear.
	 * @param reduction Type of reduction to apply to loss. Should be of type
	 *    `Reduction`.
	 *
	 * @doc {heading: 'Training', subheading: 'Losses', namespace: 'losses'}
	 */
	function huberLoss_(labels, predictions, weights) {
	  var delta = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 1.0;
	  var reduction = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : exports.Reduction.SUM_BY_NONZERO_WEIGHTS;
	  var $labels = convertToTensor(labels, 'labels', 'huberLoss');
	  var $predictions = convertToTensor(predictions, 'predictions', 'huberLoss');
	  var $weights = null;
	  if (weights != null) {
	    $weights = convertToTensor(weights, 'weights', 'huberLoss');
	  }
	  assertShapesMatch($labels.shape, $predictions.shape, 'Error in huberLoss: ');
	  var deltaScalar = scalar(delta);
	  var error = abs$2(sub$2($predictions, $labels));
	  var quadratic = minimum$4(error, deltaScalar);
	  var linear = sub$2(error, quadratic);
	  var losses = add$3(mul(scalar(0.5), square$2(quadratic)), mul(deltaScalar, linear));
	  return computeWeightedLoss$1(losses, $weights, reduction);
	}
	var huberLoss = /* @__PURE__ */op({
	  huberLoss_: huberLoss_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the log loss between two tensors.
	 *
	 * @param labels The ground truth output tensor, same dimensions as
	 *    'predictions'.
	 * @param predictions The predicted outputs.
	 * @param weights Tensor whose rank is either 0, or the same rank as
	 *    `labels`, and must be broadcastable to `labels` (i.e., all dimensions
	 *    must be either `1`, or the same as the corresponding `losses`
	 *    dimension).
	 * @param epsilon A small increment to avoid taking log of zero
	 * @param reduction Type of reduction to apply to loss. Should be of type
	 *    `Reduction`
	 *
	 * @doc {heading: 'Training', subheading: 'Losses', namespace: 'losses'}
	 */
	function logLoss_(labels, predictions, weights) {
	  var epsilon = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 1e-7;
	  var reduction = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : exports.Reduction.SUM_BY_NONZERO_WEIGHTS;
	  var $labels = convertToTensor(labels, 'labels', 'logLoss');
	  var $predictions = convertToTensor(predictions, 'predictions', 'logLoss');
	  var $weights = null;
	  if (weights != null) {
	    $weights = convertToTensor(weights, 'weights', 'logLoss');
	  }
	  assertShapesMatch($labels.shape, $predictions.shape, 'Error in logLoss: ');
	  var one = scalar(1);
	  var epsilonScalar = scalar(epsilon);
	  var l1 = neg$2(mul($labels, log$2(add$3($predictions, epsilonScalar))));
	  var l2 = mul(sub$2(one, $labels), log$2(add$3(sub$2(one, $predictions), epsilonScalar)));
	  var losses = sub$2(l1, l2);
	  return computeWeightedLoss$1(losses, $weights, reduction);
	}
	var logLoss = /* @__PURE__ */op({
	  logLoss_: logLoss_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the mean squared error between two tensors.
	 *
	 * @param labels The ground truth output tensor, same dimensions as
	 *    'predictions'.
	 * @param predictions The predicted outputs.
	 * @param weights Tensor whose rank is either 0, or the same rank as
	 *    `labels`, and must be broadcastable to `labels` (i.e., all dimensions
	 *    must be either `1`, or the same as the corresponding `losses`
	 *    dimension).
	 * @param reduction Type of reduction to apply to loss. Should be of type
	 *    `Reduction`
	 *
	 * @doc {heading: 'Training', subheading: 'Losses', namespace: 'losses'}
	 */
	function meanSquaredError_(labels, predictions, weights) {
	  var reduction = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : exports.Reduction.SUM_BY_NONZERO_WEIGHTS;
	  var $labels = convertToTensor(labels, 'labels', 'meanSquaredError');
	  var $predictions = convertToTensor(predictions, 'predictions', 'meanSquaredError');
	  var $weights = null;
	  if (weights != null) {
	    $weights = convertToTensor(weights, 'weights', 'meanSquaredError');
	  }
	  assertShapesMatch($labels.shape, $predictions.shape, 'Error in meanSquaredError: ');
	  var losses = squaredDifference$2($labels, $predictions);
	  return computeWeightedLoss$1(losses, $weights, reduction);
	}
	var meanSquaredError$2 = /* @__PURE__ */op({
	  meanSquaredError_: meanSquaredError_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function sigmoidCrossEntropyWithLogits_(labels, logits) {
	  var $labels = convertToTensor(labels, 'labels', 'sigmoidCrossEntropyWithLogits');
	  var $logits = convertToTensor(logits, 'logits', 'sigmoidCrossEntropyWithLogits');
	  assertShapesMatch($labels.shape, $logits.shape, 'Error in sigmoidCrossEntropyWithLogits: ');
	  /**
	   * Implementation Details:
	   *
	   * For brevity, let `x = logits`, `z = labels`.  The logistic loss is
	   *     z * -log(sigmoid(x)) + (1 - z) * -log(1 - sigmoid(x))
	   *   = z * -log(1 / (1 + exp(-x))) + (1 - z) * -log(exp(-x) / (1 + exp(-x)))
	   *   = z * log(1 + exp(-x)) + (1 - z) * (-log(exp(-x)) + log(1 + exp(-x)))
	   *   = z * log(1 + exp(-x)) + (1 - z) * (x + log(1 + exp(-x))
	   *   = (1 - z) * x + log(1 + exp(-x))
	   *   = x - x * z + log(1 + exp(-x))
	   *
	   *   For x < 0, to avoid overflow in exp(-x), we reformulate the above
	   *     x - x * z + log(1 + exp(-x))
	   *   = log(exp(x)) - x * z + log(1 + exp(-x))
	   *   = - x * z + log(1 + exp(x))
	   *
	   * Hence, to ensure stability and avoid overflow, the implementation uses
	   * this equivalent formulation:
	   *     max(x, 0) - x * z + log(1 + exp(-abs(x)))
	   */
	  var maxOutput = relu$2($logits);
	  var outputXTarget = mul($logits, $labels);
	  var sigmoidOutput = log1p$2(exp$2(neg$2(abs$2($logits))));
	  return add$3(sub$2(maxOutput, outputXTarget), sigmoidOutput);
	}
	/**
	 * Computes the sigmoid cross entropy loss between two tensors.
	 *
	 * If labelSmoothing is nonzero, smooth the labels towards 1/2:
	 *
	 *   newMulticlassLabels = multiclassLabels * (1 - labelSmoothing)
	 *                         + 0.5 * labelSmoothing
	 *
	 * @param multiClassLabels The ground truth output tensor of shape
	 * [batch_size, num_classes], same dimensions as 'predictions'.
	 * @param logits The predicted outputs.
	 * @param weights Tensor whose rank is either 0, or the same rank as
	 *    `labels`, and must be broadcastable to `labels` (i.e., all dimensions
	 *    must be either `1`, or the same as the corresponding `losses`
	 *    dimension).
	 * @param labelSmoothing If greater than 0, then smooth the labels.
	 * @param reduction Type of reduction to apply to loss. Should be of type
	 *    `Reduction`
	 *
	 * @doc { heading: 'Training', subheading: 'Losses', namespace: 'losses' }
	 */
	function sigmoidCrossEntropy_(multiClassLabels, logits, weights) {
	  var labelSmoothing = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 0;
	  var reduction = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : exports.Reduction.SUM_BY_NONZERO_WEIGHTS;
	  var $multiClassLabels = convertToTensor(multiClassLabels, 'multiClassLabels', 'sigmoidCrossEntropy');
	  var $logits = convertToTensor(logits, 'logits', 'sigmoidCrossEntropy');
	  var $weights = null;
	  if (weights != null) {
	    $weights = convertToTensor(weights, 'weights', 'sigmoidCrossEntropy');
	  }
	  assertShapesMatch($multiClassLabels.shape, $logits.shape, 'Error in sigmoidCrossEntropy: ');
	  if (labelSmoothing > 0) {
	    var labelSmoothingScalar = scalar(labelSmoothing);
	    var one = scalar(1);
	    var half = scalar(0.5);
	    $multiClassLabels = add$3(mul($multiClassLabels, sub$2(one, labelSmoothingScalar)), mul(half, labelSmoothingScalar));
	  }
	  var losses = sigmoidCrossEntropyWithLogits_($multiClassLabels, $logits);
	  return computeWeightedLoss$1(losses, $weights, reduction);
	}
	var sigmoidCrossEntropy = /* @__PURE__ */op({
	  sigmoidCrossEntropy_: sigmoidCrossEntropy_
	});

	/**
	 * Computes softmax cross entropy between logits and labels.
	 *
	 * Measures the probability error in discrete classification tasks in which
	 * the classes are mutually exclusive (each entry is in exactly one class).
	 * For example, each CIFAR-10 image is labeled with one and only one label: an
	 * image can be a dog or a truck, but not both.
	 *
	 * `NOTE`: While the classes are mutually exclusive, their probabilities need
	 * not be. All that is required is that each row of labels is a valid
	 * probability distribution. If they are not, the computation of the gradient
	 * will be incorrect.
	 *
	 * `WARNING`: This op expects unscaled logits, since it performs a softmax on
	 * logits internally for efficiency. Do not call this op with the output of
	 * softmax, as it will produce incorrect results.
	 *
	 * logits and labels must have the same shape, e.g. [batch_size, num_classes]
	 * and the same dtype.
	 * @param labels The labels array.
	 * @param logits The logits array.
	 * @param dim The dimension softmax would be performed on. Defaults to `-1`
	 *     which indicates the last dimension.
	 */
	function softmaxCrossEntropyWithLogits_(labels, logits) {
	  var dim = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : -1;
	  if (dim === -1) {
	    dim = logits.rank - 1;
	  }
	  if (dim !== logits.rank - 1) {
	    throw Error("Softmax cross entropy along a non-last dimension is not yet " + "supported. Labels / logits was rank ".concat(logits.rank, " ") + "and dim was ".concat(dim));
	  }
	  // Use a custom gradient for numerical stability.
	  var customOp = customGrad(function (labels, logits, save) {
	    // Reference:
	    //   1. http://cs231n.github.io/linear-classify/#softmax
	    //   2. https://blog.feedly.com/tricks-of-the-trade-logsumexp/
	    var keepDims = true;
	    var lse = logSumExp(logits, [dim], keepDims);
	    var logResult = sub$2(cast$3(logits, 'float32'), lse);
	    save([labels, logResult]);
	    var costVector = neg$2(mul(logResult, labels));
	    var value = sum$3(costVector, [dim]);
	    var gradFunc = function gradFunc(dy, saved) {
	      var _saved = _slicedToArray(saved, 2),
	        labels = _saved[0],
	        logResult = _saved[1];
	      var dyShape = expandShapeToKeepDim(dy.shape, [dim]);
	      return [mul(reshape$3(dy, dyShape), sub$2(cast$3(labels, 'float32'), exp$2(logResult))), mul(reshape$3(dy, dyShape), sub$2(exp$2(logResult), cast$3(labels, 'float32')))];
	    };
	    return {
	      value: value,
	      gradFunc: gradFunc
	    };
	  });
	  return customOp(labels, logits);
	}
	/**
	 * Computes the softmax cross entropy loss between two tensors.
	 *
	 * If labelSmoothing is nonzero, smooth the labels towards 1/2:
	 *
	 *   newOnehotLabels = onehotLabels * (1 - labelSmoothing)
	 *                         + labelSmoothing / numClasses
	 *
	 * @param onehotLabels One hot encoded labels
	 *    [batch_size, num_classes], same dimensions as 'predictions'.
	 * @param logits The predicted outputs.
	 * @param weights Tensor whose rank is either 0, or 1, and must be
	 *    broadcastable to `loss`  of shape [batch_size]
	 * @param labelSmoothing If greater than 0, then smooth the labels.
	 * @param reduction Type of reduction to apply to loss. Should be of type
	 *    `Reduction`
	 *
	 * @doc { heading: 'Training', subheading: 'Losses', namespace: 'losses' }
	 */
	function softmaxCrossEntropy_(onehotLabels, logits, weights) {
	  var labelSmoothing = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 0;
	  var reduction = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : exports.Reduction.SUM_BY_NONZERO_WEIGHTS;
	  var $onehotLabels = convertToTensor(onehotLabels, 'onehotLabels', 'softmaxCrossEntropy');
	  var $logits = convertToTensor(logits, 'logits', 'softmaxCrossEntropy');
	  var $weights = null;
	  if (weights != null) {
	    $weights = convertToTensor(weights, 'weights', 'softmaxCrossEntropy');
	  }
	  assertShapesMatch($onehotLabels.shape, $logits.shape, 'Error in softmaxCrossEntropy: ');
	  if (labelSmoothing > 0) {
	    var labelSmoothingScalar = scalar(labelSmoothing);
	    var one = scalar(1);
	    var numClasses = scalar($onehotLabels.shape[1]);
	    $onehotLabels = add$3(mul($onehotLabels, sub$2(one, labelSmoothingScalar)), div$1(labelSmoothingScalar, numClasses));
	  }
	  var losses = softmaxCrossEntropyWithLogits_($onehotLabels, $logits);
	  return computeWeightedLoss$1(losses, $weights, reduction);
	}
	var softmaxCrossEntropy = /* @__PURE__ */op({
	  softmaxCrossEntropy_: softmaxCrossEntropy_
	});

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * The input SparseTensor is represented via the map of inputs {`indices`,
	 * `values`, `denseShape`}. The output SparseTensor has the same `denseShape`
	 * but with indices `outputIndices` and values `outputValues`. This op inserts a
	 * single entry for every row that doesn't have any values. The index is created
	 * as `[row, 0, ..., 0]` and the inserted value is `defaultValue`.
	 *
	 * For example, suppose `spInput` has shape [5, 6] and non-empty values:
	 * [0, 1]: a
	 * [0, 3]: b
	 * [2, 0]: c
	 * [3, 1]: d
	 *
	 * Rows 1 and 4 are empty, so the output will be of shape [5, 6] with values:
	 * [0, 1]: a
	 * [0, 3]: b
	 * [1, 0]: `defaultValue`
	 * [2, 0]: c
	 * [3, 1]: d
	 * [4, 0]: `defaultValue`
	 *
	 * The output SparseTensor will be in row-major order and will have the same
	 * shape as the input.
	 *
	 * This op also returns an indicator vector shaped [dense_shape[0]] such that
	 * emptyRowIndicator[i] = True iff row i was an empty row.
	 *
	 * And a reverse index map vector shaped [indices.shape[0]] that is used during
	 * backpropagation, reverseIndexMap[i] = outi s.t. indices[i, j] ==
	 * outputIndices[outi, j] for all j
	 *
	 * ```js
	 * const result = tf.sparse.sparseFillEmptyRows(
	 *   [[0, 0], [1, 0], [1, 3], [1, 4], [3, 2], [3, 3]],
	 *   [0, 10, 13, 14, 32, 33], [5, 6], -1);
	 * console.log(result);
	 * result['outputIndices'].print(); // [[0, 0], [1, 0], [1, 3], [1, 4],
	 *                                  //  [2, 0], [3, 2], [3, 3], [4, 0]]
	 * result['outputValues'].print(); // [0, 10, 13, 14,-1, 32, 33, -1]
	 * result['emptyRowIndicator'].print(); // [false, false, true, false, true]
	 * result['reverseIndexMap'].print(); // [0, 1, 2, 3, 5, 6]
	 * ```
	 * @param indices: 2-D. The indices of the sparse tensor.
	 * @param values: 1-D. The values of the sparse tensor.
	 * @param denseShape: 1-D. The shape of the sparse tensor.
	 * @param defaultValue: 0-D. Default value to insert into location [row, 0, ...,
	 *     0] for rows missing from the input sparse tensor.
	 * @return A map with the following properties:
	 *     - outputIndices
	 *     - outputValues: 1-D. The values of the filled sparse tensor.
	 *     - emptyRowIndicator: 1-D. Whether the dense row was missing in the input
	 * sparse tensor.
	 *     - reverseIndexMap: 1-D. A map from the input indices to the output
	 * indices.
	 * @doc {heading: 'Operations', subheading: 'Sparse'}
	 */
	function sparseFillEmptyRows_(indices, values, denseShape, defaultValue) {
	  var $indices = convertToTensor(indices, 'indices', 'sparseFillEmptyRows', 'int32');
	  var $values = convertToTensor(values, 'values', 'sparseFillEmptyRows');
	  var $denseShape = convertToTensor(denseShape, 'denseShape', 'sparseFillEmptyRows', 'int32');
	  var $defaultValue = convertToTensor(defaultValue, 'defaultValue', 'sparseFillEmptyRows', $values.dtype);
	  if ($indices.rank !== 2) {
	    throw new Error("Indices should be Tensor2D but received shape\n        ".concat($indices.shape));
	  }
	  if ($values.rank !== 1) {
	    throw new Error("Values should be Tensor1D but received shape ".concat($values.shape));
	  }
	  if ($denseShape.rank !== 1) {
	    throw new Error("Dense shape should be Tensor1D but received shape ".concat($denseShape.shape));
	  }
	  if ($defaultValue.rank !== 0) {
	    throw new Error("Default value should be a scalar but received shape ".concat($defaultValue.shape));
	  }
	  var inputs = {
	    indices: $indices,
	    values: $values,
	    denseShape: $denseShape,
	    defaultValue: $defaultValue
	  };
	  var result = ENGINE.runKernel(SparseFillEmptyRows, inputs);
	  return {
	    outputIndices: result[0],
	    outputValues: result[1],
	    emptyRowIndicator: result[2],
	    reverseIndexMap: result[3]
	  };
	}
	var sparseFillEmptyRows$2 = /* @__PURE__ */op({
	  sparseFillEmptyRows_: sparseFillEmptyRows_
	});

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * This operation has the same semantics as reshape on the represented dense
	 * tensor. The `inputIndices` are recomputed based on the requested `newShape`.
	 * If one component of `newShape` is the special value -1, the size of that
	 * dimension is computed so that the total dense size remains constant. At most
	 * one component of `newShape` can be -1. The number of dense elements implied
	 * by `newShape` must be the same as the number of dense elements originally
	 * implied by `inputShape`. Reshaping does not affect the order of values in the
	 * SparseTensor. If the input tensor has rank R_in and N non-empty values, and
	 * `newShape` has length R_out, then `inputIndices` has shape [N, R_in],
	 * `inputShape` has length R_in, `outputIndices` has shape [N, R_out], and
	 * `outputShape` has length R_out.
	 *
	 * ```js
	 * const result = tf.sparse.sparseReshape(
	 *   [[0, 0, 0], [0, 0, 1], [0, 1, 0], [1, 0, 0], [1, 2, 3]],
	 *   [2, 3, 6], [9, -1]);
	 * console.log(result);
	 * result['outputIndices'].print(); //[[0, 0], [0, 1], [1, 2], [4, 2], [8, 1]]
	 * result['outputShape'].print(); // [9, 4]
	 * ```
	 * @param inputIndices: 2-D. N x R_in matrix with the indices of non-empty
	 * values in a SparseTensor.
	 * @param inputShape: 1-D. R_in Tensor1D with the input SparseTensor's dense
	 * shape.
	 * @param newShape: 1-D. R_out Tensor1D with the requested new dense shape.
	 * @return A map with the following properties:
	 *     - outputIndices: 2-D. N x R_out matrix with the updated indices of
	 *       non-empty values in the output SparseTensor.
	 *     - outputShape: 1-D. R_out vector with the full dense shape of the output
	 *       SparseTensor. This is the same as newShape but with any -1 dimensions
	 *        filled in.
	 * @doc {heading: 'Operations', subheading: 'Sparse'}
	 */
	function sparseReshape_(inputIndices, inputShape, newShape) {
	  var $inputIndices = convertToTensor(inputIndices, 'inputIndices', 'sparseReshape', 'int32');
	  var $inputShape = convertToTensor(inputShape, 'inputShape', 'sparseReshape', 'int32');
	  var $newShape = convertToTensor(newShape, 'newShape', 'sparseReshape', 'int32');
	  if ($inputIndices.rank !== 2) {
	    throw new Error("Input indices should be Tensor2D but received shape\n        ".concat($inputIndices.shape));
	  }
	  if ($inputShape.rank !== 1) {
	    throw new Error("Input shape should be Tensor1D but received shape ".concat($inputShape.shape));
	  }
	  if ($newShape.rank !== 1) {
	    throw new Error("New shape should be Tensor1D but received shape ".concat($newShape.shape));
	  }
	  var inputs = {
	    inputIndices: $inputIndices,
	    inputShape: $inputShape,
	    newShape: $newShape
	  };
	  var result = ENGINE.runKernel(SparseReshape, inputs);
	  return {
	    outputIndices: result[0],
	    outputShape: result[1]
	  };
	}
	var sparseReshape$2 = /* @__PURE__ */op({
	  sparseReshape_: sparseReshape_
	});

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the mean along sparse segments of a tensor.
	 *
	 * ```js
	 * const c = tf.tensor2d([[1,2,3,4], [-1,-2,-3,-4], [6,7,8,9]]);
	 * // Select two rows, one segment.
	 * const result1 = tf.sparse.sparseSegmentMean(c,
	 *                                           tf.tensor1d([0, 1], 'int32'),
	 *                                           tf.tensor1d([0, 0], 'int32'));
	 * result1.print(); // [[0, 0, 0, 0]]
	 *
	 * // Select two rows, two segments.
	 * const result2 = tf.sparse.sparseSegmentMean(c,
	 *                                             tf.tensor1d([0, 1], 'int32'),
	 *                                             tf.tensor1d([0, 1], 'int32'));
	 * result2.print(); // [[1, 2, 3, 4], [-1, -2, -3, -4]]
	 *
	 * // Select all rows, two segments.
	 * const result3 = tf.sparse.sparseSegmentMean(c,
	 *                                             tf.tensor1d([0, 1, 2], 'int32'),
	 *                                             tf.tensor1d([0, 1, 1], 'int32'));
	 * result3.print(); // [[1.0, 2.0, 3.0, 4.0], [2.5, 2.5, 2.5, 2.5]]
	 * ```
	 * @param data: A Tensor of at least one dimension with data that will be
	 *     assembled in the output.
	 * @param indices: A 1-D Tensor with indices into data. Has same rank as
	 *     segmentIds.
	 * @param segmentIds: A 1-D Tensor with indices into the output Tensor. Values
	 *     should be sorted and can be repeated.
	 * @return Has same shape as data, except for dimension 0 which has equal to
	 *         the number of segments.
	 *
	 * @doc {heading: 'Operations', subheading: 'Sparse'}
	 */
	function sparseSegmentMean_(data, indices, segmentIds) {
	  var $data = convertToTensor(data, 'data', 'sparseSegmentMean');
	  var $indices = convertToTensor(indices, 'indices', 'sparseSegmentMean', 'int32');
	  var $segmentIds = convertToTensor(segmentIds, 'segmentIds', 'sparseSegmentMean', 'int32');
	  if ($data.rank < 1) {
	    throw new Error("Data should be at least 1 dimensional but received scalar");
	  }
	  if ($indices.rank !== 1) {
	    throw new Error("Indices should be Tensor1D but received shape\n          ".concat($indices.shape));
	  }
	  if ($segmentIds.rank !== 1) {
	    throw new Error("Segment ids should be Tensor1D but received shape\n          ".concat($segmentIds.shape));
	  }
	  var inputs = {
	    data: $data,
	    indices: $indices,
	    segmentIds: $segmentIds
	  };
	  return ENGINE.runKernel(SparseSegmentMean, inputs);
	}
	var sparseSegmentMean$2 = /* @__PURE__ */op({
	  sparseSegmentMean_: sparseSegmentMean_
	});

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the sum along sparse segments of a tensor.
	 *
	 * ```js
	 * const c = tf.tensor2d([[1,2,3,4], [-1,-2,-3,-4], [5,6,7,8]]);
	 * // Select two rows, one segment.
	 * const result1 = tf.sparse.sparseSegmentSum(c,
	 *                                           tf.tensor1d([0, 1], 'int32'),
	 *                                           tf.tensor1d([0, 0], 'int32'));
	 * result1.print(); // [[0, 0, 0, 0]]
	 *
	 * // Select two rows, two segments.
	 * const result2 = tf.sparse.sparseSegmentSum(c,
	 *                                           tf.tensor1d([0, 1], 'int32'),
	 *                                           tf.tensor1d([0, 1], 'int32'));
	 * result2.print(); // [[1, 2, 3, 4], [-1, -2, -3, -4]]
	 *
	 * // Select all rows, two segments.
	 * const result3 = tf.sparse.sparseSegmentSum(c,
	 *                                           tf.tensor1d([0, 1, 2], 'int32'),
	 *                                           tf.tensor1d([0, 0, 1], 'int32'));
	 * result3.print(); // [[0, 0, 0, 0], [5, 6, 7, 8]]
	 * ```
	 * @param data: A Tensor of at least one dimension with data that will be
	 *     assembled in the output.
	 * @param indices: A 1-D Tensor with indices into data. Has same rank as
	 *     segmentIds.
	 * @param segmentIds: A 1-D Tensor with indices into the output Tensor. Values
	 *     should be sorted and can be repeated.
	 * @return Has same shape as data, except for dimension 0 which has equal to
	 *         the number of segments.
	 *
	 * @doc {heading: 'Operations', subheading: 'Sparse'}
	 */
	function sparseSegmentSum_(data, indices, segmentIds) {
	  var $data = convertToTensor(data, 'data', 'sparseSegmentSum');
	  var $indices = convertToTensor(indices, 'indices', 'sparseSegmentSum', 'int32');
	  var $segmentIds = convertToTensor(segmentIds, 'segmentIds', 'sparseSegmentSum', 'int32');
	  if ($data.rank < 1) {
	    throw new Error("Data should be at least 1 dimensional but received scalar");
	  }
	  if ($indices.rank !== 1) {
	    throw new Error("Indices should be Tensor1D but received shape\n         ".concat($indices.shape));
	  }
	  if ($segmentIds.rank !== 1) {
	    throw new Error("Segment ids should be Tensor1D but received shape\n         ".concat($segmentIds.shape));
	  }
	  var inputs = {
	    data: $data,
	    indices: $indices,
	    segmentIds: $segmentIds
	  };
	  return ENGINE.runKernel(SparseSegmentSum, inputs);
	}
	var sparseSegmentSum$2 = /* @__PURE__ */op({
	  sparseSegmentSum_: sparseSegmentSum_
	});

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Creates ngrams from ragged string data.
	 *
	 * This op accepts a ragged tensor with 1 ragged dimension containing only
	 * strings and outputs a ragged tensor with 1 ragged dimension containing ngrams
	 * of that string, joined along the innermost axis.
	 *
	 * ```js
	 * const result = tf.string.stringNGrams(
	 *   ['a', 'b', 'c', 'd'], tf.tensor1d([0, 2, 4], 'int32'),
	 *   '|', [1, 2], 'LP', 'RP', -1, false);
	 * result['nGrams'].print(); // ['a', 'b', 'LP|a', 'a|b', 'b|RP',
	 *                           //  'c', 'd', 'LP|c', 'c|d', 'd|RP']
	 * result['nGramsSplits'].print(); // [0, 5, 10]
	 * ```
	 * @param data: The values tensor of the ragged string tensor to make ngrams out
	 *     of. Must be a 1D string tensor.
	 * @param dataSplits: The splits tensor of the ragged string tensor to make
	 *     ngrams out of.
	 * @param separator: The string to append between elements of the token. Use ""
	 *     for no separator.
	 * @param nGramWidths: The sizes of the ngrams to create.
	 * @param leftPad: The string to use to pad the left side of the ngram sequence.
	 *     Only used if pad_width !== 0.
	 * @param rightPad: The string to use to pad the right side of the ngram
	 *     sequence. Only used if pad_width !== 0.
	 * @param padWidth: The number of padding elements to add to each side of each
	 *     sequence. Note that padding will never be greater than `nGramWidths`-1
	 *     regardless of this value. If `padWidth`=-1, then add max(`nGramWidths`)-1
	 *     elements.
	 * @param preserveShortSequences: If true, then ensure that at least one ngram
	 *     is generated for each input sequence. In particular, if an input sequence
	 *     is shorter than min(ngramWidth) + 2*padWidth, then generate a single
	 *     ngram containing the entire sequence. If false, then no ngrams are
	 *     generated for these short input sequences.
	 * @return A map with the following properties:
	 *     - nGrams: The values tensor of the output ngrams ragged tensor.
	 *     - nGramsSplits: The splits tensor of the output ngrams ragged tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'String'}
	 */
	function stringNGrams_(data, dataSplits, separator, nGramWidths, leftPad, rightPad, padWidth, preserveShortSequences) {
	  var $data = convertToTensor(data, 'data', 'stringNGrams', 'string');
	  if ($data.dtype !== 'string') {
	    throw new Error('Data must be of datatype string');
	  }
	  if ($data.shape.length !== 1) {
	    throw new Error("Data must be a vector, saw: ".concat($data.shape));
	  }
	  var $dataSplits = convertToTensor(dataSplits, 'dataSplits', 'stringNGrams');
	  if ($dataSplits.dtype !== 'int32') {
	    throw new Error('Data splits must be of datatype int32');
	  }
	  var attrs = {
	    separator: separator,
	    nGramWidths: nGramWidths,
	    leftPad: leftPad,
	    rightPad: rightPad,
	    padWidth: padWidth,
	    preserveShortSequences: preserveShortSequences
	  };
	  var inputs = {
	    data: $data,
	    dataSplits: $dataSplits
	  };
	  var result = ENGINE.runKernel(StringNGrams, inputs, attrs);
	  return {
	    nGrams: result[0],
	    nGramsSplits: result[1]
	  };
	}
	var stringNGrams$2 = /* @__PURE__ */op({
	  stringNGrams_: stringNGrams_
	});

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Split elements of `input` based on `delimiter` into a SparseTensor .
	 *
	 * Let N be the size of source (typically N will be the batch size). Split each
	 * element of `input` based on `delimiter` and return a SparseTensor containing
	 * the splitted tokens. Empty tokens are ignored if `skipEmpty` is set to True.
	 *
	 * `delimiter` can be empty, or a string of split characters. If `delimiter` is
	 * an empty string, each element of `input` is split into individual
	 * character strings. Otherwise every character of `delimiter` is a potential
	 * split point.
	 *
	 * ```js
	 * const result = tf.string.stringSplit(['hello world',  'a b c'], ' ');
	 * result['indices'].print(); // [[0, 0], [0, 1], [1, 0], [1, 1], [1, 2]]
	 * result['values'].print(); // ['hello', 'world', 'a', 'b', 'c']
	 * result['shape'].print(); // [2, 3]
	 * ```
	 * @param input: 1-D. Strings to split.
	 * @param delimiter: 0-D. Delimiter characters, or empty string.
	 * @param skipEmpty: Optional. If true, skip the empty strings from the result.
	 *     Defaults to true.
	 * @return A map with the following properties:
	 *     - indices: A dense matrix of int32 representing the indices of the sparse
	 *       tensor.
	 *     - values: A vector of strings corresponding to the splited values.
	 *     - shape: a length-2 vector of int32 representing the shape of the sparse
	 * tensor, where the first value is N and the second value is the maximum number
	 * of tokens in a single input entry.
	 *
	 * @doc {heading: 'Operations', subheading: 'String'}
	 */
	function stringSplit_(input, delimiter) {
	  var skipEmpty = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
	  var $input = convertToTensor(input, 'input', 'stringSplit', 'string');
	  var $delimiter = convertToTensor(delimiter, 'delimiter', 'stringSplit', 'string');
	  if ($input.rank !== 1) {
	    throw new Error("Input should be Tensor1D but received shape ".concat($input.shape));
	  }
	  if ($delimiter.rank !== 0) {
	    throw new Error("Delimiter should be a scalar but received shape ".concat($delimiter.shape));
	  }
	  var attrs = {
	    skipEmpty: skipEmpty
	  };
	  var inputs = {
	    input: $input,
	    delimiter: $delimiter
	  };
	  var result = ENGINE.runKernel(StringSplit, inputs, attrs);
	  return {
	    indices: result[0],
	    values: result[1],
	    shape: result[2]
	  };
	}
	var stringSplit$2 = /* @__PURE__ */op({
	  stringSplit_: stringSplit_
	});

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Converts each string in the input Tensor to its hash mod by a number of
	 * buckets.
	 *
	 * The hash function is deterministic on the content of the string within the
	 * process and will never change. However, it is not suitable for cryptography.
	 * This function may be used when CPU time is scarce and inputs are trusted or
	 * unimportant. There is a risk of adversaries constructing inputs that all hash
	 * to the same bucket.
	 *
	 * ```js
	 * const result = tf.string.stringToHashBucketFast(
	 *   ['Hello', 'TensorFlow', '2.x'], 3);
	 * result.print(); // [0, 2, 2]
	 * ```
	 * @param input: The strings to assign a hash bucket.
	 * @param numBuckets: The number of buckets.
	 * @return A Tensor of the same shape as the input tensor.
	 *
	 * @doc {heading: 'Operations', subheading: 'String'}
	 */
	function stringToHashBucketFast_(input, numBuckets) {
	  var $input = convertToTensor(input, 'input', 'stringToHashBucketFast', 'string');
	  var attrs = {
	    numBuckets: numBuckets
	  };
	  if (numBuckets <= 0) {
	    throw new Error("Number of buckets must be at least 1");
	  }
	  var inputs = {
	    input: $input
	  };
	  return ENGINE.runKernel(StringToHashBucketFast, inputs, attrs);
	}
	var stringToHashBucketFast$2 = /* @__PURE__ */op({
	  stringToHashBucketFast_: stringToHashBucketFast_
	});

	/**
	 * @license
	 * Copyright 2023 Google LLC.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Replace the match of a `pattern` in `input` with `rewrite`.
	 *
	 * ```js
	 * const result = tf.string.staticRegexReplace(
	 *     ['format       this   spacing      better'], ' +', ' ');
	 * result.print(); // ['format this spacing better']
	 * ```
	 * @param input: A Tensor of type string. The text to be processed.
	 * @param pattern: A string. The regular expression to match the input.
	 * @param rewrite: A string. The rewrite to be applied to the matched
	 *     expression.
	 * @param replaceGlobal: An optional bool. Defaults to True. If True, the
	 *     replacement is global, otherwise the replacement is done only on the
	 *     first match.
	 * @return A Tensor of type string.
	 *
	 * @doc {heading: 'Operations', subheading: 'String'}
	 */
	function staticRegexReplace_(input, pattern, rewrite) {
	  var replaceGlobal = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : true;
	  var $input = convertToTensor(input, 'input', 'staticRegexReplace', 'string');
	  var attrs = {
	    pattern: pattern,
	    rewrite: rewrite,
	    replaceGlobal: replaceGlobal
	  };
	  return ENGINE.runKernel(StaticRegexReplace, {
	    x: $input
	  }, attrs);
	}
	var staticRegexReplace$2 = /* @__PURE__ */op({
	  staticRegexReplace_: staticRegexReplace_
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var spectral$1 = {
	  fft: fft$2,
	  ifft: ifft$2,
	  rfft: rfft,
	  irfft: irfft
	};
	var signal = {
	  hammingWindow: hammingWindow,
	  hannWindow: hannWindow,
	  frame: frame,
	  stft: stft
	};
	var image$1 = {
	  flipLeftRight: flipLeftRight,
	  grayscaleToRGB: grayscaleToRGB,
	  resizeNearestNeighbor: resizeNearestNeighbor$2,
	  resizeBilinear: resizeBilinear$3,
	  rgbToGrayscale: rgbToGrayscale,
	  rotateWithOffset: rotateWithOffset,
	  cropAndResize: cropAndResize$3,
	  nonMaxSuppression: nonMaxSuppression,
	  nonMaxSuppressionAsync: nonMaxSuppressionAsync,
	  nonMaxSuppressionWithScore: nonMaxSuppressionWithScore,
	  nonMaxSuppressionWithScoreAsync: nonMaxSuppressionWithScoreAsync,
	  nonMaxSuppressionPadded: nonMaxSuppressionPadded,
	  nonMaxSuppressionPaddedAsync: nonMaxSuppressionPaddedAsync,
	  threshold: threshold$1,
	  transform: transform$2
	};
	var linalg = {
	  bandPart: bandPart,
	  gramSchmidt: gramSchmidt,
	  qr: qr
	};
	var losses = {
	  absoluteDifference: absoluteDifference,
	  computeWeightedLoss: computeWeightedLoss$1,
	  cosineDistance: cosineDistance,
	  hingeLoss: hingeLoss,
	  huberLoss: huberLoss,
	  logLoss: logLoss,
	  meanSquaredError: meanSquaredError$2,
	  sigmoidCrossEntropy: sigmoidCrossEntropy,
	  softmaxCrossEntropy: softmaxCrossEntropy
	};
	var sparse$1 = {
	  sparseFillEmptyRows: sparseFillEmptyRows$2,
	  sparseReshape: sparseReshape$2,
	  sparseSegmentMean: sparseSegmentMean$2,
	  sparseSegmentSum: sparseSegmentSum$2
	};
	// tslint:disable-next-line:variable-name
	var string$1 = {
	  stringNGrams: stringNGrams$2,
	  stringSplit: stringSplit$2,
	  stringToHashBucketFast: stringToHashBucketFast$2,
	  staticRegexReplace: staticRegexReplace$2
	};

	/**
	 * Maps to mapping between the custom object and its name.
	 *
	 * After registering a custom class, these two maps will add key-value pairs
	 * for the class object and the registered name.
	 *
	 * Therefore we can get the relative registered name by calling
	 * getRegisteredName() function.
	 *
	 * For example:
	 * GLOBAL_CUSTOM_OBJECT: {key=registeredName: value=corresponding
	 * CustomObjectClass}
	 *
	 * GLOBAL_CUSTOM_NAMES: {key=CustomObjectClass: value=corresponding
	 * registeredName}
	 *
	 */
	var GLOBAL_CUSTOM_OBJECT = new Map();
	var GLOBAL_CUSTOM_NAMES = new Map();
	/**
	 * Serializable defines the serialization contract.
	 *
	 * TFJS requires serializable classes to return their className when asked
	 * to avoid issues with minification.
	 */
	var Serializable = /*#__PURE__*/function () {
	  function Serializable() {
	    _classCallCheck(this, Serializable);
	  }
	  _createClass(Serializable, [{
	    key: "getClassName",
	    value:
	    /**
	     * Return the class name for this class to use in serialization contexts.
	     *
	     * Generally speaking this will be the same thing that constructor.name
	     * would have returned.  However, the class name needs to be robust
	     * against minification for serialization/deserialization to work properly.
	     *
	     * There's also places such as initializers.VarianceScaling, where
	     * implementation details between different languages led to different
	     * class hierarchies and a non-leaf node is used for serialization purposes.
	     */
	    function getClassName() {
	      return this.constructor.className;
	    }
	    /**
	     * Creates an instance of T from a ConfigDict.
	     *
	     * This works for most descendants of serializable.  A few need to
	     * provide special handling.
	     * @param cls A Constructor for the class to instantiate.
	     * @param config The Configuration for the object.
	     */
	    /** @nocollapse */
	  }], [{
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      return new cls(config);
	    }
	  }]);
	  return Serializable;
	}();
	/**
	 * Maps string keys to class constructors.
	 *
	 * Used during (de)serialization from the cross-language JSON format, which
	 * requires the class name in the serialization format matches the class
	 * names as used in Python, should it exist.
	 */
	var SerializationMap = /*#__PURE__*/function () {
	  function SerializationMap() {
	    _classCallCheck(this, SerializationMap);
	    this.classNameMap = {};
	  }
	  /**
	   * Returns the singleton instance of the map.
	   */
	  _createClass(SerializationMap, null, [{
	    key: "getMap",
	    value: function getMap() {
	      if (SerializationMap.instance == null) {
	        SerializationMap.instance = new SerializationMap();
	      }
	      return SerializationMap.instance;
	    }
	    /**
	     * Registers the class as serializable.
	     */
	  }, {
	    key: "register",
	    value: function register(cls) {
	      SerializationMap.getMap().classNameMap[cls.className] = [cls, cls.fromConfig];
	    }
	  }]);
	  return SerializationMap;
	}();
	/**
	 * Register a class with the serialization map of TensorFlow.js.
	 *
	 * This is often used for registering custom Layers, so they can be
	 * serialized and deserialized.
	 *
	 * Example 1. Register the class without package name and specified name.
	 *
	 * ```js
	 * class MyCustomLayer extends tf.layers.Layer {
	 *   static className = 'MyCustomLayer';
	 *
	 *   constructor(config) {
	 *     super(config);
	 *   }
	 * }
	 * tf.serialization.registerClass(MyCustomLayer);
	 * console.log(tf.serialization.GLOBALCUSTOMOBJECT.get("Custom>MyCustomLayer"));
	 * console.log(tf.serialization.GLOBALCUSTOMNAMES.get(MyCustomLayer));
	 * ```
	 *
	 * Example 2. Register the class with package name: "Package" and specified
	 * name: "MyLayer".
	 * ```js
	 * class MyCustomLayer extends tf.layers.Layer {
	 *   static className = 'MyCustomLayer';
	 *
	 *   constructor(config) {
	 *     super(config);
	 *   }
	 * }
	 * tf.serialization.registerClass(MyCustomLayer, "Package", "MyLayer");
	 * console.log(tf.serialization.GLOBALCUSTOMOBJECT.get("Package>MyLayer"));
	 * console.log(tf.serialization.GLOBALCUSTOMNAMES.get(MyCustomLayer));
	 * ```
	 *
	 * Example 3. Register the class with specified name: "MyLayer".
	 * ```js
	 * class MyCustomLayer extends tf.layers.Layer {
	 *   static className = 'MyCustomLayer';
	 *
	 *   constructor(config) {
	 *     super(config);
	 *   }
	 * }
	 * tf.serialization.registerClass(MyCustomLayer, undefined, "MyLayer");
	 * console.log(tf.serialization.GLOBALCUSTOMOBJECT.get("Custom>MyLayer"));
	 * console.log(tf.serialization.GLOBALCUSTOMNAMES.get(MyCustomLayer));
	 * ```
	 *
	 * Example 4. Register the class with specified package name: "Package".
	 * ```js
	 * class MyCustomLayer extends tf.layers.Layer {
	 *   static className = 'MyCustomLayer';
	 *
	 *   constructor(config) {
	 *     super(config);
	 *   }
	 * }
	 * tf.serialization.registerClass(MyCustomLayer, "Package");
	 * console.log(tf.serialization.GLOBALCUSTOMOBJECT
	 * .get("Package>MyCustomLayer"));
	 * console.log(tf.serialization.GLOBALCUSTOMNAMES
	 * .get(MyCustomLayer));
	 * ```
	 *
	 * @param cls The class to be registered. It must have a public static member
	 *   called `className` defined and the value must be a non-empty string.
	 * @param pkg The package name that this class belongs to. This used to define
	 *     the key in GlobalCustomObject. If not defined, it defaults to `Custom`.
	 * @param name The name that user specified. It defaults to the actual name of
	 *     the class as specified by its static `className` property.
	 * @doc {heading: 'Models', subheading: 'Serialization', ignoreCI: true}
	 */
	function registerClass(cls, pkg, name) {
	  assert$1(cls.className != null, function () {
	    return "Class being registered does not have the static className " + "property defined.";
	  });
	  assert$1(typeof cls.className === 'string', function () {
	    return "className is required to be a string, but got type " + _typeof(cls.className);
	  });
	  assert$1(cls.className.length > 0, function () {
	    return "Class being registered has an empty-string as its className, " + "which is disallowed.";
	  });
	  if (typeof pkg === 'undefined') {
	    pkg = 'Custom';
	  }
	  if (typeof name === 'undefined') {
	    name = cls.className;
	  }
	  var className = name;
	  var registerName = pkg + '>' + className;
	  SerializationMap.register(cls);
	  GLOBAL_CUSTOM_OBJECT.set(registerName, cls);
	  GLOBAL_CUSTOM_NAMES.set(cls, registerName);
	  return cls;
	}
	/**
	 * Get the registered name of a class. If the class has not been registered,
	 * return the class name.
	 *
	 * @param cls The class we want to get register name for. It must have a public
	 *     static member called `className` defined.
	 * @returns registered name or class name.
	 */
	function getRegisteredName(cls) {
	  if (GLOBAL_CUSTOM_NAMES.has(cls)) {
	    return GLOBAL_CUSTOM_NAMES.get(cls);
	  } else {
	    return cls.className;
	  }
	}

	var serialization = {
		__proto__: null,
		Serializable: Serializable,
		SerializationMap: SerializationMap,
		getRegisteredName: getRegisteredName,
		registerClass: registerClass
	};

	/** @doc {heading: 'Training', subheading: 'Classes', namespace: 'train'} */
	var Optimizer = /*#__PURE__*/function (_Serializable) {
	  _inherits(Optimizer, _Serializable);
	  var _super = _createSuper(Optimizer);
	  function Optimizer() {
	    _classCallCheck(this, Optimizer);
	    return _super.apply(this, arguments);
	  }
	  _createClass(Optimizer, [{
	    key: "minimize",
	    value:
	    /**
	     * Executes `f()` and minimizes the scalar output of `f()` by computing
	     * gradients of y with respect to the list of trainable variables provided by
	     * `varList`. If no list is provided, it defaults to all trainable variables.
	     *
	     * @param f The function to execute and whose output to minimize.
	     * @param returnCost Whether to return the scalar cost value produced by
	     * executing `f()`.
	     * @param varList An optional list of variables to update. If specified, only
	     * the trainable variables in varList will be updated by minimize. Defaults to
	     * all trainable variables.
	     *
	     * @doc {heading: 'Training', subheading: 'Optimizers'}
	     */
	    function minimize(f) {
	      var returnCost = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
	      var varList = arguments.length > 2 ? arguments[2] : undefined;
	      var _this$computeGradient = this.computeGradients(f, varList),
	        value = _this$computeGradient.value,
	        grads = _this$computeGradient.grads;
	      if (varList != null) {
	        var gradArray = varList.map(function (v) {
	          return {
	            name: v.name,
	            tensor: grads[v.name]
	          };
	        });
	        this.applyGradients(gradArray);
	      } else {
	        this.applyGradients(grads);
	      }
	      // Dispose gradients.
	      dispose(grads);
	      if (returnCost) {
	        return value;
	      } else {
	        value.dispose();
	        return null;
	      }
	    }
	    /**
	     * The number of iterations that this optimizer instance has been invoked for.
	     */
	  }, {
	    key: "iterations",
	    get: function get() {
	      if (this.iterations_ == null) {
	        this.iterations_ = 0;
	      }
	      return this.iterations_;
	    }
	  }, {
	    key: "incrementIterations",
	    value: function incrementIterations() {
	      this.iterations_ = this.iterations + 1;
	    }
	    /**
	     * Executes f() and computes the gradient of the scalar output of f() with
	     * respect to the list of trainable variables provided by `varList`. If no
	     * list is provided, it defaults to all trainable variables.
	     *
	     * @param f The function to execute and whose output to use for computing
	     * gradients with respect to variables.
	     * @param varList An optional list of variables to compute gradients with
	     * respect to. If specified, only the trainable variables in varList will have
	     * gradients computed with respect to. Defaults to all trainable variables.
	     *
	     * @doc {heading: 'Training', subheading: 'Optimizers'}
	     */
	  }, {
	    key: "computeGradients",
	    value: function computeGradients(f, varList) {
	      return variableGrads(f, varList);
	    }
	    /**
	     * Dispose the variables (if any) owned by this optimizer instance.
	     */
	  }, {
	    key: "dispose",
	    value: function dispose$1() {
	      if (this.iterations_ != null) {
	        dispose(this.iterations_);
	      }
	    }
	  }, {
	    key: "saveIterations",
	    value: function () {
	      var _saveIterations = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              if (this.iterations_ == null) {
	                this.iterations_ = 0;
	              }
	              return _context.abrupt("return", {
	                name: 'iter',
	                // TODO(cais): Use 'int64' type when available.
	                tensor: scalar(this.iterations_, 'int32')
	              });
	            case 2:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function saveIterations() {
	        return _saveIterations.apply(this, arguments);
	      }
	      return saveIterations;
	    }()
	  }, {
	    key: "getWeights",
	    value: function () {
	      var _getWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2() {
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              throw new Error('getWeights() is not implemented for this optimizer yet.');
	            case 1:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2);
	      }));
	      function getWeights() {
	        return _getWeights.apply(this, arguments);
	      }
	      return getWeights;
	    }()
	  }, {
	    key: "setWeights",
	    value: function () {
	      var _setWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3(weightValues) {
	        return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	          while (1) switch (_context3.prev = _context3.next) {
	            case 0:
	              throw new Error("setWeights() is not implemented for this optimizer class " + "".concat(this.getClassName()));
	            case 1:
	            case "end":
	              return _context3.stop();
	          }
	        }, _callee3, this);
	      }));
	      function setWeights(_x) {
	        return _setWeights.apply(this, arguments);
	      }
	      return setWeights;
	    }()
	    /**
	     * Extract the first element of the weight values and set it
	     * as the iterations counter variable of this instance of optimizer.
	     *
	     * @param weightValues
	     * @returns Weight values with the first element consumed and excluded.
	     */
	  }, {
	    key: "extractIterations",
	    value: function () {
	      var _extractIterations = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4(weightValues) {
	        return _regeneratorRuntime().wrap(function _callee4$(_context4) {
	          while (1) switch (_context4.prev = _context4.next) {
	            case 0:
	              _context4.next = 2;
	              return weightValues[0].tensor.data();
	            case 2:
	              this.iterations_ = _context4.sent[0];
	              return _context4.abrupt("return", weightValues.slice(1));
	            case 4:
	            case "end":
	              return _context4.stop();
	          }
	        }, _callee4, this);
	      }));
	      function extractIterations(_x2) {
	        return _extractIterations.apply(this, arguments);
	      }
	      return extractIterations;
	    }()
	  }]);
	  return Optimizer;
	}(Serializable);
	Object.defineProperty(Optimizer, Symbol.hasInstance, {
	  value: function value(instance) {
	    return instance.minimize != null && instance.computeGradients != null && instance.applyGradients != null;
	  }
	});

	/** @doclink Optimizer */
	var AdadeltaOptimizer = /*#__PURE__*/function (_Optimizer) {
	  _inherits(AdadeltaOptimizer, _Optimizer);
	  var _super = _createSuper(AdadeltaOptimizer);
	  function AdadeltaOptimizer(learningRate, rho) {
	    var _this;
	    var epsilon = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
	    _classCallCheck(this, AdadeltaOptimizer);
	    _this = _super.call(this);
	    _this.learningRate = learningRate;
	    _this.rho = rho;
	    _this.epsilon = epsilon;
	    _this.accumulatedGrads = [];
	    _this.accumulatedUpdates = [];
	    if (epsilon == null) {
	      _this.epsilon = ENGINE.backend.epsilon();
	    }
	    return _this;
	  }
	  _createClass(AdadeltaOptimizer, [{
	    key: "applyGradients",
	    value: function applyGradients(variableGradients) {
	      var _this2 = this;
	      var variableNames = Array.isArray(variableGradients) ? variableGradients.map(function (item) {
	        return item.name;
	      }) : Object.keys(variableGradients);
	      variableNames.forEach(function (name, i) {
	        var value = ENGINE.registeredVariables[name];
	        var trainable = false;
	        if (_this2.accumulatedGrads[i] == null) {
	          _this2.accumulatedGrads[i] = {
	            originalName: "".concat(name, "/accum_grad"),
	            variable: tidy(function () {
	              return zerosLike$3(value).variable(trainable);
	            })
	          };
	        }
	        if (_this2.accumulatedUpdates[i] == null) {
	          _this2.accumulatedUpdates[i] = {
	            originalName: "".concat(name, "/accum_var"),
	            variable: tidy(function () {
	              return zerosLike$3(value).variable(trainable);
	            })
	          };
	        }
	        var gradient = Array.isArray(variableGradients) ? variableGradients[i].tensor : variableGradients[name];
	        if (gradient == null) {
	          return;
	        }
	        var accumulatedGrad = _this2.accumulatedGrads[i].variable;
	        var accumulatedUpdate = _this2.accumulatedUpdates[i].variable;
	        tidy(function () {
	          var newAccumulatedGrad = add$3(mul(accumulatedGrad, _this2.rho), mul(square$2(gradient), 1 - _this2.rho));
	          var updates = mul(div$1(sqrt$2(add$3(accumulatedUpdate, _this2.epsilon)), sqrt$2(add$3(accumulatedGrad, _this2.epsilon))), gradient);
	          var newAccumulatedUpdate = add$3(mul(accumulatedUpdate, _this2.rho), mul(square$2(updates), 1 - _this2.rho));
	          accumulatedGrad.assign(newAccumulatedGrad);
	          accumulatedUpdate.assign(newAccumulatedUpdate);
	          var newValue = add$3(mul(updates, -_this2.learningRate), value);
	          value.assign(newValue);
	        });
	      });
	      this.incrementIterations();
	    }
	  }, {
	    key: "dispose",
	    value: function dispose$1() {
	      if (this.accumulatedUpdates != null) {
	        dispose(this.accumulatedGrads.map(function (v) {
	          return v.variable;
	        }));
	        dispose(this.accumulatedUpdates.map(function (v) {
	          return v.variable;
	        }));
	      }
	    }
	  }, {
	    key: "getWeights",
	    value: function () {
	      var _getWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        var variables;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              // Order matters for Python compatibility.
	              variables = [].concat(_toConsumableArray(this.accumulatedGrads), _toConsumableArray(this.accumulatedUpdates));
	              _context.next = 3;
	              return this.saveIterations();
	            case 3:
	              _context.t0 = _context.sent;
	              return _context.abrupt("return", [_context.t0].concat(variables.map(function (v) {
	                return {
	                  name: v.originalName,
	                  tensor: v.variable
	                };
	              })));
	            case 5:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function getWeights() {
	        return _getWeights.apply(this, arguments);
	      }
	      return getWeights;
	    }()
	  }, {
	    key: "setWeights",
	    value: function () {
	      var _setWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(weightValues) {
	        var variableCount, trainable;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              _context2.next = 2;
	              return this.extractIterations(weightValues);
	            case 2:
	              weightValues = _context2.sent;
	              variableCount = weightValues.length / 2;
	              trainable = false;
	              this.accumulatedGrads = weightValues.slice(0, variableCount).map(function (v) {
	                return {
	                  originalName: v.name,
	                  variable: v.tensor.variable(trainable)
	                };
	              });
	              this.accumulatedUpdates = weightValues.slice(variableCount, variableCount * 2).map(function (v) {
	                return {
	                  originalName: v.name,
	                  variable: v.tensor.variable(trainable)
	                };
	              });
	            case 7:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function setWeights(_x) {
	        return _setWeights.apply(this, arguments);
	      }
	      return setWeights;
	    }()
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        'learningRate': this.learningRate,
	        'rho': this.rho,
	        'epsilon': this.epsilon
	      };
	    }
	    /** @nocollapse */
	  }], [{
	    key: "className",
	    get: /** @nocollapse */
	    function get() {
	      // Name matters for Python compatibility.
	      // This is a getter instead of a property because when it's a property, it
	      // prevents the entire class from being tree-shaken.
	      return 'Adadelta';
	    }
	  }, {
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      return new cls(config['learningRate'], config['rho'], config['epsilon']);
	    }
	  }]);
	  return AdadeltaOptimizer;
	}(Optimizer);

	/** @doclink Optimizer */
	var AdagradOptimizer = /*#__PURE__*/function (_Optimizer) {
	  _inherits(AdagradOptimizer, _Optimizer);
	  var _super = _createSuper(AdagradOptimizer);
	  function AdagradOptimizer(learningRate) {
	    var _this;
	    var initialAccumulatorValue = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0.1;
	    _classCallCheck(this, AdagradOptimizer);
	    _this = _super.call(this);
	    _this.learningRate = learningRate;
	    _this.initialAccumulatorValue = initialAccumulatorValue;
	    _this.accumulatedGrads = [];
	    return _this;
	  }
	  _createClass(AdagradOptimizer, [{
	    key: "applyGradients",
	    value: function applyGradients(variableGradients) {
	      var _this2 = this;
	      var variableNames = Array.isArray(variableGradients) ? variableGradients.map(function (item) {
	        return item.name;
	      }) : Object.keys(variableGradients);
	      variableNames.forEach(function (name, i) {
	        var value = ENGINE.registeredVariables[name];
	        if (_this2.accumulatedGrads[i] == null) {
	          var trainable = false;
	          _this2.accumulatedGrads[i] = {
	            originalName: "".concat(name, "/accumulator"),
	            variable: tidy(function () {
	              return fill$2(value.shape, _this2.initialAccumulatorValue).variable(trainable);
	            })
	          };
	        }
	        var gradient = Array.isArray(variableGradients) ? variableGradients[i].tensor : variableGradients[name];
	        if (gradient == null) {
	          return;
	        }
	        var accumulatedGrad = _this2.accumulatedGrads[i].variable;
	        tidy(function () {
	          var newAccumulatedGrad = add$3(accumulatedGrad, square$2(gradient));
	          accumulatedGrad.assign(newAccumulatedGrad);
	          var newValue = add$3(mul(div$1(gradient, sqrt$2(add$3(newAccumulatedGrad, ENGINE.backend.epsilon()))), -_this2.learningRate), value);
	          value.assign(newValue);
	        });
	      });
	      this.incrementIterations();
	    }
	  }, {
	    key: "dispose",
	    value: function dispose$1() {
	      if (this.accumulatedGrads != null) {
	        dispose(this.accumulatedGrads.map(function (v) {
	          return v.variable;
	        }));
	      }
	    }
	  }, {
	    key: "getWeights",
	    value: function () {
	      var _getWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              _context.next = 2;
	              return this.saveIterations();
	            case 2:
	              _context.t0 = _context.sent;
	              return _context.abrupt("return", [_context.t0].concat(this.accumulatedGrads.map(function (v) {
	                return {
	                  name: v.originalName,
	                  tensor: v.variable
	                };
	              })));
	            case 4:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function getWeights() {
	        return _getWeights.apply(this, arguments);
	      }
	      return getWeights;
	    }()
	  }, {
	    key: "setWeights",
	    value: function () {
	      var _setWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(weightValues) {
	        var trainable;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              _context2.next = 2;
	              return this.extractIterations(weightValues);
	            case 2:
	              weightValues = _context2.sent;
	              trainable = false;
	              this.accumulatedGrads = weightValues.map(function (v) {
	                return {
	                  originalName: v.name,
	                  variable: v.tensor.variable(trainable)
	                };
	              });
	            case 5:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function setWeights(_x) {
	        return _setWeights.apply(this, arguments);
	      }
	      return setWeights;
	    }()
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        'learningRate': this.learningRate,
	        'initialAccumulatorValue': this.initialAccumulatorValue
	      };
	    }
	    /** @nocollapse */
	  }], [{
	    key: "className",
	    get: /** @nocollapse */
	    function get() {
	      // Name matters for Python compatibility.
	      // This is a getter instead of a property because when it's a property, it
	      // prevents the entire class from being tree-shaken.
	      return 'Adagrad';
	    }
	  }, {
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      return new cls(config['learningRate'], config['initialAccumulatorValue']);
	    }
	  }]);
	  return AdagradOptimizer;
	}(Optimizer);

	var AdamOptimizer = /*#__PURE__*/function (_Optimizer) {
	  _inherits(AdamOptimizer, _Optimizer);
	  var _super = _createSuper(AdamOptimizer);
	  function AdamOptimizer(learningRate, beta1, beta2) {
	    var _this;
	    var epsilon = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;
	    _classCallCheck(this, AdamOptimizer);
	    _this = _super.call(this);
	    _this.learningRate = learningRate;
	    _this.beta1 = beta1;
	    _this.beta2 = beta2;
	    _this.epsilon = epsilon;
	    _this.accumulatedFirstMoment = [];
	    _this.accumulatedSecondMoment = [];
	    tidy(function () {
	      // accB* will be updated by batch.
	      _this.accBeta1 = scalar(beta1).variable();
	      _this.accBeta2 = scalar(beta2).variable();
	    });
	    if (epsilon == null) {
	      _this.epsilon = ENGINE.backend.epsilon();
	    }
	    return _this;
	  }
	  _createClass(AdamOptimizer, [{
	    key: "applyGradients",
	    value: function applyGradients(variableGradients) {
	      var _this2 = this;
	      var varNames = Array.isArray(variableGradients) ? variableGradients.map(function (v) {
	        return v.name;
	      }) : Object.keys(variableGradients);
	      tidy(function () {
	        var oneMinusAccBeta1 = sub$2(1, _this2.accBeta1);
	        var oneMinusAccBeta2 = sub$2(1, _this2.accBeta2);
	        varNames.forEach(function (name, i) {
	          var value = ENGINE.registeredVariables[name];
	          var trainable = false;
	          if (_this2.accumulatedFirstMoment[i] == null) {
	            _this2.accumulatedFirstMoment[i] = {
	              originalName: "".concat(name, "/m"),
	              variable: tidy(function () {
	                return zerosLike$3(value).variable(trainable);
	              })
	            };
	          }
	          if (_this2.accumulatedSecondMoment[i] == null) {
	            _this2.accumulatedSecondMoment[i] = {
	              originalName: "".concat(name, "/v"),
	              variable: tidy(function () {
	                return zerosLike$3(value).variable(trainable);
	              })
	            };
	          }
	          var gradient = Array.isArray(variableGradients) ? variableGradients[i].tensor : variableGradients[name];
	          if (gradient == null) {
	            return;
	          }
	          var firstMoment = _this2.accumulatedFirstMoment[i].variable;
	          var secondMoment = _this2.accumulatedSecondMoment[i].variable;
	          var newFirstMoment = add$3(mul(firstMoment, _this2.beta1), mul(gradient, 1 - _this2.beta1));
	          var newSecondMoment = add$3(mul(secondMoment, _this2.beta2), mul(square$2(gradient), 1 - _this2.beta2));
	          var biasCorrectedFirstMoment = div$1(newFirstMoment, oneMinusAccBeta1);
	          var biasCorrectedSecondMoment = div$1(newSecondMoment, oneMinusAccBeta2);
	          firstMoment.assign(newFirstMoment);
	          secondMoment.assign(newSecondMoment);
	          var newValue = add$3(mul(div$1(biasCorrectedFirstMoment, add$3(sqrt$2(biasCorrectedSecondMoment), _this2.epsilon)), -_this2.learningRate), value);
	          value.assign(newValue);
	        });
	        _this2.accBeta1.assign(mul(_this2.accBeta1, _this2.beta1));
	        _this2.accBeta2.assign(mul(_this2.accBeta2, _this2.beta2));
	      });
	      this.incrementIterations();
	    }
	  }, {
	    key: "dispose",
	    value: function dispose$1() {
	      this.accBeta1.dispose();
	      this.accBeta2.dispose();
	      if (this.accumulatedFirstMoment != null) {
	        dispose(this.accumulatedFirstMoment.map(function (v) {
	          return v.variable;
	        }));
	      }
	      if (this.accumulatedSecondMoment != null) {
	        dispose(this.accumulatedSecondMoment.map(function (v) {
	          return v.variable;
	        }));
	      }
	    }
	  }, {
	    key: "getWeights",
	    value: function () {
	      var _getWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        var variables;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              // Order matters for Python compatibility.
	              variables = [].concat(_toConsumableArray(this.accumulatedFirstMoment), _toConsumableArray(this.accumulatedSecondMoment));
	              _context.next = 3;
	              return this.saveIterations();
	            case 3:
	              _context.t0 = _context.sent;
	              return _context.abrupt("return", [_context.t0].concat(variables.map(function (v) {
	                return {
	                  name: v.originalName,
	                  tensor: v.variable
	                };
	              })));
	            case 5:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function getWeights() {
	        return _getWeights.apply(this, arguments);
	      }
	      return getWeights;
	    }()
	  }, {
	    key: "setWeights",
	    value: function () {
	      var _setWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(weightValues) {
	        var _this3 = this;
	        var variableCount, trainable;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              _context2.next = 2;
	              return this.extractIterations(weightValues);
	            case 2:
	              weightValues = _context2.sent;
	              tidy(function () {
	                _this3.accBeta1.assign(pow$3(_this3.beta1, _this3.iterations_ + 1));
	                _this3.accBeta2.assign(pow$3(_this3.beta2, _this3.iterations_ + 1));
	              });
	              variableCount = weightValues.length / 2;
	              trainable = false;
	              this.accumulatedFirstMoment = weightValues.slice(0, variableCount).map(function (v) {
	                return {
	                  originalName: v.name,
	                  variable: v.tensor.variable(trainable)
	                };
	              });
	              this.accumulatedSecondMoment = weightValues.slice(variableCount, variableCount * 2).map(function (v) {
	                return {
	                  originalName: v.name,
	                  variable: v.tensor.variable(trainable)
	                };
	              });
	            case 8:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function setWeights(_x) {
	        return _setWeights.apply(this, arguments);
	      }
	      return setWeights;
	    }()
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        'learningRate': this.learningRate,
	        'beta1': this.beta1,
	        'beta2': this.beta2,
	        'epsilon': this.epsilon
	      };
	    }
	    /** @nocollapse */
	  }], [{
	    key: "className",
	    get: /** @nocollapse */
	    function get() {
	      // Name matters for Python compatibility.
	      // This is a getter instead of a property because when it's a property, it
	      // prevents the entire class from being tree-shaken.
	      return 'Adam';
	    }
	  }, {
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      return new cls(config['learningRate'], config['beta1'], config['beta2'], config['epsilon']);
	    }
	  }]);
	  return AdamOptimizer;
	}(Optimizer);

	var AdamaxOptimizer = /*#__PURE__*/function (_Optimizer) {
	  _inherits(AdamaxOptimizer, _Optimizer);
	  var _super = _createSuper(AdamaxOptimizer);
	  function AdamaxOptimizer(learningRate, beta1, beta2) {
	    var _this;
	    var epsilon = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;
	    var decay = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 0.0;
	    _classCallCheck(this, AdamaxOptimizer);
	    _this = _super.call(this);
	    _this.learningRate = learningRate;
	    _this.beta1 = beta1;
	    _this.beta2 = beta2;
	    _this.epsilon = epsilon;
	    _this.decay = decay;
	    _this.accumulatedFirstMoment = [];
	    _this.accumulatedWeightedInfNorm = [];
	    tidy(function () {
	      _this.iteration = scalar(0).variable();
	      _this.accBeta1 = scalar(beta1).variable();
	    });
	    if (epsilon == null) {
	      _this.epsilon = ENGINE.backend.epsilon();
	    }
	    return _this;
	  }
	  _createClass(AdamaxOptimizer, [{
	    key: "applyGradients",
	    value: function applyGradients(variableGradients) {
	      var _this2 = this;
	      var variableNames = Array.isArray(variableGradients) ? variableGradients.map(function (item) {
	        return item.name;
	      }) : Object.keys(variableGradients);
	      tidy(function () {
	        var oneMinusAccBeta1 = sub$2(1, _this2.accBeta1);
	        var lr = div$1(-_this2.learningRate, add$3(mul(_this2.iteration, _this2.decay), 1));
	        variableNames.forEach(function (name, i) {
	          var value = ENGINE.registeredVariables[name];
	          var trainable = false;
	          if (_this2.accumulatedFirstMoment[i] == null) {
	            _this2.accumulatedFirstMoment[i] = {
	              originalName: "".concat(name, "/m"),
	              variable: zerosLike$3(value).variable(trainable)
	            };
	          }
	          if (_this2.accumulatedWeightedInfNorm[i] == null) {
	            _this2.accumulatedWeightedInfNorm[i] = {
	              originalName: "".concat(name, "/v"),
	              variable: zerosLike$3(value).variable(trainable)
	            };
	          }
	          var gradient = Array.isArray(variableGradients) ? variableGradients[i].tensor : variableGradients[name];
	          if (gradient == null) {
	            return;
	          }
	          var firstMoment = _this2.accumulatedFirstMoment[i].variable;
	          var weightedInfNorm = _this2.accumulatedWeightedInfNorm[i].variable;
	          var newFirstMoment = add$3(mul(firstMoment, _this2.beta1), mul(gradient, 1 - _this2.beta1));
	          var ut0 = mul(weightedInfNorm, _this2.beta2);
	          var ut1 = abs$2(gradient);
	          var newWeightedInfNorm = maximum$4(ut0, ut1);
	          firstMoment.assign(newFirstMoment);
	          weightedInfNorm.assign(newWeightedInfNorm);
	          var newValue = add$3(mul(div$1(lr, oneMinusAccBeta1), div$1(newFirstMoment, add$3(newWeightedInfNorm, _this2.epsilon))), value);
	          value.assign(newValue);
	        });
	        _this2.iteration.assign(add$3(_this2.iteration, 1));
	        _this2.accBeta1.assign(mul(_this2.accBeta1, _this2.beta1));
	      });
	      this.incrementIterations();
	    }
	  }, {
	    key: "dispose",
	    value: function dispose$1() {
	      this.accBeta1.dispose();
	      this.iteration.dispose();
	      if (this.accumulatedFirstMoment != null) {
	        dispose(this.accumulatedFirstMoment.map(function (v) {
	          return v.variable;
	        }));
	      }
	      if (this.accumulatedWeightedInfNorm != null) {
	        dispose(this.accumulatedWeightedInfNorm.map(function (v) {
	          return v.variable;
	        }));
	      }
	    }
	  }, {
	    key: "getWeights",
	    value: function () {
	      var _getWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              throw new Error('getWeights() is not implemented for Adamax yet.');
	            case 1:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee);
	      }));
	      function getWeights() {
	        return _getWeights.apply(this, arguments);
	      }
	      return getWeights;
	    }()
	  }, {
	    key: "setWeights",
	    value: function () {
	      var _setWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(weightValues) {
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              throw new Error('setWeights() is not implemented for Adamax yet.');
	            case 1:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2);
	      }));
	      function setWeights(_x) {
	        return _setWeights.apply(this, arguments);
	      }
	      return setWeights;
	    }()
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        'learningRate': this.learningRate,
	        'beta1': this.beta1,
	        'beta2': this.beta2,
	        'epsilon': this.epsilon,
	        'decay': this.decay
	      };
	    }
	    /** @nocollapse */
	  }], [{
	    key: "className",
	    get: /** @nocollapse */
	    function get() {
	      // Name matters for Python compatibility.
	      // This is a getter instead of a property because when it's a property, it
	      // prevents the entire class from being tree-shaken.
	      return 'Adamax';
	    }
	  }, {
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      return new cls(config['learningRate'], config['beta1'], config['beta2'], config['epsilon'], config['decay']);
	    }
	  }]);
	  return AdamaxOptimizer;
	}(Optimizer);

	/** @doclink Optimizer */
	var SGDOptimizer = /*#__PURE__*/function (_Optimizer) {
	  _inherits(SGDOptimizer, _Optimizer);
	  var _super = _createSuper(SGDOptimizer);
	  function SGDOptimizer(learningRate) {
	    var _this;
	    _classCallCheck(this, SGDOptimizer);
	    _this = _super.call(this);
	    _this.learningRate = learningRate;
	    _this.setLearningRate(learningRate);
	    return _this;
	  }
	  _createClass(SGDOptimizer, [{
	    key: "applyGradients",
	    value: function applyGradients(variableGradients) {
	      var _this2 = this;
	      var varNames = Array.isArray(variableGradients) ? variableGradients.map(function (v) {
	        return v.name;
	      }) : Object.keys(variableGradients);
	      varNames.forEach(function (name, i) {
	        var gradient = Array.isArray(variableGradients) ? variableGradients[i].tensor : variableGradients[name];
	        if (gradient == null) {
	          return;
	        }
	        var value = ENGINE.registeredVariables[name];
	        tidy(function () {
	          var newValue = add$3(mul(_this2.c, gradient), value);
	          value.assign(newValue);
	        });
	      });
	      this.incrementIterations();
	    }
	    /**
	     * Sets the learning rate of the optimizer.
	     */
	  }, {
	    key: "setLearningRate",
	    value: function setLearningRate(learningRate) {
	      this.learningRate = learningRate;
	      if (this.c != null) {
	        this.c.dispose();
	      }
	      this.c = keep(scalar(-learningRate));
	    }
	  }, {
	    key: "dispose",
	    value: function dispose() {
	      this.c.dispose();
	    }
	  }, {
	    key: "getWeights",
	    value: function () {
	      var _getWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              _context.next = 2;
	              return this.saveIterations();
	            case 2:
	              _context.t0 = _context.sent;
	              return _context.abrupt("return", [_context.t0]);
	            case 4:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function getWeights() {
	        return _getWeights.apply(this, arguments);
	      }
	      return getWeights;
	    }()
	  }, {
	    key: "setWeights",
	    value: function () {
	      var _setWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(weightValues) {
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              _context2.next = 2;
	              return this.extractIterations(weightValues);
	            case 2:
	              weightValues = _context2.sent;
	              if (!(weightValues.length !== 0)) {
	                _context2.next = 5;
	                break;
	              }
	              throw new Error('SGD optimizer does not have settable weights.');
	            case 5:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function setWeights(_x) {
	        return _setWeights.apply(this, arguments);
	      }
	      return setWeights;
	    }()
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        'learningRate': this.learningRate
	      };
	    }
	    /** @nocollapse */
	  }], [{
	    key: "className",
	    get: /** @nocollapse */
	    function get() {
	      // Name matters for Python compatibility.
	      // This is a getter instead of a property because when it's a property, it
	      // prevents the entire class from being tree-shaken.
	      return 'SGD';
	    }
	  }, {
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      return new cls(config['learningRate']);
	    }
	  }]);
	  return SGDOptimizer;
	}(Optimizer);

	/** @doclink Optimizer */
	var MomentumOptimizer = /*#__PURE__*/function (_SGDOptimizer) {
	  _inherits(MomentumOptimizer, _SGDOptimizer);
	  var _super = _createSuper(MomentumOptimizer);
	  function MomentumOptimizer(learningRate, momentum) {
	    var _this;
	    var useNesterov = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	    _classCallCheck(this, MomentumOptimizer);
	    _this = _super.call(this, learningRate);
	    _this.learningRate = learningRate;
	    _this.momentum = momentum;
	    _this.useNesterov = useNesterov;
	    _this.accumulations = [];
	    _this.m = scalar(_this.momentum);
	    return _this;
	  }
	  _createClass(MomentumOptimizer, [{
	    key: "applyGradients",
	    value: function applyGradients(variableGradients) {
	      var _this2 = this;
	      var variableNames = Array.isArray(variableGradients) ? variableGradients.map(function (item) {
	        return item.name;
	      }) : Object.keys(variableGradients);
	      variableNames.forEach(function (name, i) {
	        var value = ENGINE.registeredVariables[name];
	        if (_this2.accumulations[i] == null) {
	          var trainable = false;
	          _this2.accumulations[i] = {
	            originalName: "".concat(name, "/momentum"),
	            variable: tidy(function () {
	              return zerosLike$3(value).variable(trainable);
	            })
	          };
	        }
	        var accumulation = _this2.accumulations[i].variable;
	        var gradient = Array.isArray(variableGradients) ? variableGradients[i].tensor : variableGradients[name];
	        if (gradient == null) {
	          return;
	        }
	        tidy(function () {
	          var newValue;
	          var newAccumulation = add$3(mul(_this2.m, accumulation), gradient);
	          if (_this2.useNesterov) {
	            newValue = add$3(mul(_this2.c, add$3(gradient, mul(newAccumulation, _this2.m))), value);
	          } else {
	            newValue = add$3(mul(_this2.c, newAccumulation), value);
	          }
	          accumulation.assign(newAccumulation);
	          value.assign(newValue);
	        });
	      });
	      this.incrementIterations();
	    }
	  }, {
	    key: "dispose",
	    value: function dispose$1() {
	      this.m.dispose();
	      if (this.accumulations != null) {
	        dispose(this.accumulations.map(function (v) {
	          return v.variable;
	        }));
	      }
	    }
	    /**
	     * Sets the momentum of the optimizer.
	     *
	     * @param momentum
	     */
	  }, {
	    key: "setMomentum",
	    value: function setMomentum(momentum) {
	      this.momentum = momentum;
	    }
	  }, {
	    key: "getWeights",
	    value: function () {
	      var _getWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              _context.next = 2;
	              return this.saveIterations();
	            case 2:
	              _context.t0 = _context.sent;
	              return _context.abrupt("return", [_context.t0].concat(this.accumulations.map(function (v) {
	                return {
	                  name: v.originalName,
	                  tensor: v.variable
	                };
	              })));
	            case 4:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function getWeights() {
	        return _getWeights.apply(this, arguments);
	      }
	      return getWeights;
	    }()
	  }, {
	    key: "setWeights",
	    value: function () {
	      var _setWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(weightValues) {
	        var trainable;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              _context2.next = 2;
	              return this.extractIterations(weightValues);
	            case 2:
	              weightValues = _context2.sent;
	              trainable = false;
	              this.accumulations = weightValues.map(function (v) {
	                return {
	                  originalName: v.name,
	                  variable: v.tensor.variable(trainable)
	                };
	              });
	            case 5:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function setWeights(_x) {
	        return _setWeights.apply(this, arguments);
	      }
	      return setWeights;
	    }()
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        'learningRate': this.learningRate,
	        'momentum': this.momentum,
	        'useNesterov': this.useNesterov
	      };
	    }
	    /** @nocollapse */
	  }], [{
	    key: "className",
	    get: /** @nocollapse */
	    // Name matters for Python compatibility.
	    function get() {
	      // Name matters for Python compatibility.
	      // This is a getter instead of a property because when it's a property, it
	      // prevents the entire class from being tree-shaken.
	      return 'Momentum';
	    }
	  }, {
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      return new cls(config['learningRate'], config['momentum'], config['useNesterov']);
	    }
	  }]);
	  return MomentumOptimizer;
	}(SGDOptimizer);

	/** @doclink Optimizer */
	var RMSPropOptimizer = /*#__PURE__*/function (_Optimizer) {
	  _inherits(RMSPropOptimizer, _Optimizer);
	  var _super = _createSuper(RMSPropOptimizer);
	  function RMSPropOptimizer(learningRate) {
	    var _this;
	    var decay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0.9;
	    var momentum = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0.0;
	    var epsilon = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;
	    var centered = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
	    _classCallCheck(this, RMSPropOptimizer);
	    _this = _super.call(this);
	    _this.learningRate = learningRate;
	    _this.decay = decay;
	    _this.momentum = momentum;
	    _this.epsilon = epsilon;
	    _this.accumulatedMeanSquares = [];
	    _this.accumulatedMoments = [];
	    _this.accumulatedMeanGrads = [];
	    _this.centered = centered;
	    if (epsilon == null) {
	      _this.epsilon = ENGINE.backend.epsilon();
	    }
	    if (learningRate == null) {
	      throw new Error("learningRate for RMSPropOptimizer must be defined.");
	    }
	    return _this;
	  }
	  _createClass(RMSPropOptimizer, [{
	    key: "applyGradients",
	    value: function applyGradients(variableGradients) {
	      var _this2 = this;
	      var variableNames = Array.isArray(variableGradients) ? variableGradients.map(function (item) {
	        return item.name;
	      }) : Object.keys(variableGradients);
	      variableNames.forEach(function (name, i) {
	        var value = ENGINE.registeredVariables[name];
	        var trainable = false;
	        if (_this2.accumulatedMeanSquares[i] == null) {
	          _this2.accumulatedMeanSquares[i] = {
	            originalName: "".concat(name, "/rms"),
	            variable: tidy(function () {
	              return zerosLike$3(value).variable(trainable);
	            })
	          };
	        }
	        if (_this2.accumulatedMoments[i] == null) {
	          _this2.accumulatedMoments[i] = {
	            originalName: "".concat(name, "/momentum"),
	            variable: tidy(function () {
	              return zerosLike$3(value).variable(trainable);
	            })
	          };
	        }
	        if (_this2.accumulatedMeanGrads[i] == null && _this2.centered) {
	          _this2.accumulatedMeanGrads[i] = {
	            originalName: "".concat(name, "/mg"),
	            variable: tidy(function () {
	              return zerosLike$3(value).variable(trainable);
	            })
	          };
	        }
	        var gradient = Array.isArray(variableGradients) ? variableGradients[i].tensor : variableGradients[name];
	        if (gradient == null) {
	          return;
	        }
	        var accumulatedMeanSquare = _this2.accumulatedMeanSquares[i].variable;
	        var accumulatedMoments = _this2.accumulatedMoments[i].variable;
	        tidy(function () {
	          var newAccumulatedMeanSquare = add$3(mul(accumulatedMeanSquare, _this2.decay), mul(square$2(gradient), 1 - _this2.decay));
	          if (_this2.centered) {
	            var accumulatedMeanGrad = _this2.accumulatedMeanGrads[i].variable;
	            // Centered gradient
	            var newAccumulatedMeanGrad = add$3(mul(accumulatedMeanGrad, _this2.decay), mul(gradient, 1 - _this2.decay));
	            var gradContribution = div$1(mul(gradient, _this2.learningRate), sqrt$2(sub$2(newAccumulatedMeanSquare, add$3(square$2(newAccumulatedMeanGrad), _this2.epsilon))));
	            var newAccumulatedMoments = add$3(mul(accumulatedMoments, _this2.momentum), gradContribution);
	            accumulatedMeanSquare.assign(newAccumulatedMeanSquare);
	            accumulatedMeanGrad.assign(newAccumulatedMeanGrad);
	            accumulatedMoments.assign(newAccumulatedMoments);
	            var newValue = sub$2(value, newAccumulatedMoments);
	            value.assign(newValue);
	          } else {
	            // Plain gradient
	            var _newAccumulatedMeanSquare = add$3(mul(accumulatedMeanSquare, _this2.decay), mul(square$2(gradient), 1 - _this2.decay));
	            var _newAccumulatedMoments = add$3(mul(accumulatedMoments, _this2.momentum), div$1(mul(gradient, _this2.learningRate), sqrt$2(add$3(_newAccumulatedMeanSquare, _this2.epsilon))));
	            accumulatedMeanSquare.assign(_newAccumulatedMeanSquare);
	            accumulatedMoments.assign(_newAccumulatedMoments);
	            var _newValue = sub$2(value, _newAccumulatedMoments);
	            value.assign(_newValue);
	          }
	        });
	      });
	      this.incrementIterations();
	    }
	  }, {
	    key: "dispose",
	    value: function dispose$1() {
	      if (this.accumulatedMeanSquares != null) {
	        dispose(this.accumulatedMeanSquares.map(function (v) {
	          return v.variable;
	        }));
	      }
	      if (this.accumulatedMeanGrads != null && this.centered) {
	        dispose(this.accumulatedMeanGrads.map(function (v) {
	          return v.variable;
	        }));
	      }
	      if (this.accumulatedMoments != null) {
	        dispose(this.accumulatedMoments.map(function (v) {
	          return v.variable;
	        }));
	      }
	    }
	  }, {
	    key: "getWeights",
	    value: function () {
	      var _getWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        var variables;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              // Order matters for Python compatibility.
	              variables = [].concat(_toConsumableArray(this.accumulatedMeanSquares), _toConsumableArray(this.accumulatedMoments));
	              if (this.centered) {
	                variables.push.apply(variables, _toConsumableArray(this.accumulatedMeanGrads));
	              }
	              _context.next = 4;
	              return this.saveIterations();
	            case 4:
	              _context.t0 = _context.sent;
	              return _context.abrupt("return", [_context.t0].concat(variables.map(function (v) {
	                return {
	                  name: v.originalName,
	                  tensor: v.variable
	                };
	              })));
	            case 6:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function getWeights() {
	        return _getWeights.apply(this, arguments);
	      }
	      return getWeights;
	    }()
	  }, {
	    key: "setWeights",
	    value: function () {
	      var _setWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(weightValues) {
	        var variableCount, trainable;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              _context2.next = 2;
	              return this.extractIterations(weightValues);
	            case 2:
	              weightValues = _context2.sent;
	              variableCount = this.centered ? weightValues.length / 3 : weightValues.length / 2;
	              trainable = false;
	              this.accumulatedMeanSquares = weightValues.slice(0, variableCount).map(function (v) {
	                return {
	                  originalName: v.name,
	                  variable: v.tensor.variable(trainable)
	                };
	              });
	              this.accumulatedMoments = weightValues.slice(variableCount, variableCount * 2).map(function (v) {
	                return {
	                  originalName: v.name,
	                  variable: v.tensor.variable(trainable)
	                };
	              });
	              if (this.centered) {
	                this.accumulatedMeanGrads = weightValues.slice(variableCount * 2, variableCount * 3).map(function (v) {
	                  return {
	                    originalName: v.name,
	                    variable: v.tensor.variable(trainable)
	                  };
	                });
	              }
	            case 8:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function setWeights(_x) {
	        return _setWeights.apply(this, arguments);
	      }
	      return setWeights;
	    }()
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        'learningRate': this.learningRate,
	        'decay': this.decay,
	        'momentum': this.momentum,
	        'epsilon': this.epsilon,
	        'centered': this.centered
	      };
	    }
	    /** @nocollapse */
	  }], [{
	    key: "className",
	    get: /** @nocollapse */
	    function get() {
	      // Name matters for Python compatibility.
	      // This is a getter instead of a property because when it's a property, it
	      // prevents the entire class from being tree-shaken.
	      return 'RMSProp';
	    }
	  }, {
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      return new cls(config['learningRate'], config['decay'], config['momentum'], config['epsilon'], config['centered']);
	    }
	  }]);
	  return RMSPropOptimizer;
	}(Optimizer);

	var OPTIMIZERS = [AdadeltaOptimizer, AdagradOptimizer, AdamOptimizer, AdamaxOptimizer, MomentumOptimizer, RMSPropOptimizer, SGDOptimizer];
	function registerOptimizers() {
	  var _iterator = _createForOfIteratorHelper(OPTIMIZERS),
	    _step;
	  try {
	    for (_iterator.s(); !(_step = _iterator.n()).done;) {
	      var optimizer = _step.value;
	      registerClass(optimizer);
	    }
	  } catch (err) {
	    _iterator.e(err);
	  } finally {
	    _iterator.f();
	  }
	}

	var DEFAULT_FILE_NAME_PREFIX = 'model';
	var DEFAULT_JSON_EXTENSION_NAME = '.json';
	var DEFAULT_WEIGHT_DATA_EXTENSION_NAME = '.weights.bin';
	function defer(f) {
	  return new Promise(function (resolve) {
	    return setTimeout(resolve);
	  }).then(f);
	}
	var BrowserDownloads = /*#__PURE__*/function () {
	  function BrowserDownloads(fileNamePrefix) {
	    _classCallCheck(this, BrowserDownloads);
	    if (!env().getBool('IS_BROWSER')) {
	      // TODO(cais): Provide info on what IOHandlers are available under the
	      //   current environment.
	      throw new Error('browserDownloads() cannot proceed because the current environment ' + 'is not a browser.');
	    }
	    if (fileNamePrefix.startsWith(BrowserDownloads.URL_SCHEME)) {
	      fileNamePrefix = fileNamePrefix.slice(BrowserDownloads.URL_SCHEME.length);
	    }
	    if (fileNamePrefix == null || fileNamePrefix.length === 0) {
	      fileNamePrefix = DEFAULT_FILE_NAME_PREFIX;
	    }
	    this.modelJsonFileName = fileNamePrefix + DEFAULT_JSON_EXTENSION_NAME;
	    this.weightDataFileName = fileNamePrefix + DEFAULT_WEIGHT_DATA_EXTENSION_NAME;
	  }
	  _createClass(BrowserDownloads, [{
	    key: "save",
	    value: function () {
	      var _save = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(modelArtifacts) {
	        var weightBuffer, weightsURL, weightsManifest, modelJSON, modelJsonURL, jsonAnchor, weightDataAnchor;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              if (!(typeof document === 'undefined')) {
	                _context.next = 2;
	                break;
	              }
	              throw new Error('Browser downloads are not supported in ' + 'this environment since `document` is not present');
	            case 2:
	              // TODO(mattsoulanille): Support saving models over 2GB that exceed
	              // Chrome's ArrayBuffer size limit.
	              weightBuffer = CompositeArrayBuffer.join(modelArtifacts.weightData);
	              weightsURL = window.URL.createObjectURL(new Blob([weightBuffer], {
	                type: 'application/octet-stream'
	              }));
	              if (!(modelArtifacts.modelTopology instanceof ArrayBuffer)) {
	                _context.next = 8;
	                break;
	              }
	              throw new Error('BrowserDownloads.save() does not support saving model topology ' + 'in binary formats yet.');
	            case 8:
	              weightsManifest = [{
	                paths: ['./' + this.weightDataFileName],
	                weights: modelArtifacts.weightSpecs
	              }];
	              modelJSON = getModelJSONForModelArtifacts(modelArtifacts, weightsManifest);
	              modelJsonURL = window.URL.createObjectURL(new Blob([JSON.stringify(modelJSON)], {
	                type: 'application/json'
	              })); // If anchor elements are not provided, create them without attaching them
	              // to parents, so that the downloaded file names can be controlled.
	              jsonAnchor = this.modelJsonAnchor == null ? document.createElement('a') : this.modelJsonAnchor;
	              jsonAnchor.download = this.modelJsonFileName;
	              jsonAnchor.href = modelJsonURL;
	              // Trigger downloads by evoking a click event on the download anchors.
	              // When multiple downloads are started synchronously, Firefox will only
	              // save the last one.
	              _context.next = 16;
	              return defer(function () {
	                return jsonAnchor.dispatchEvent(new MouseEvent('click'));
	              });
	            case 16:
	              if (!(modelArtifacts.weightData != null)) {
	                _context.next = 22;
	                break;
	              }
	              weightDataAnchor = this.weightDataAnchor == null ? document.createElement('a') : this.weightDataAnchor;
	              weightDataAnchor.download = this.weightDataFileName;
	              weightDataAnchor.href = weightsURL;
	              _context.next = 22;
	              return defer(function () {
	                return weightDataAnchor.dispatchEvent(new MouseEvent('click'));
	              });
	            case 22:
	              return _context.abrupt("return", {
	                modelArtifactsInfo: getModelArtifactsInfoForJSON(modelArtifacts)
	              });
	            case 23:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function save(_x) {
	        return _save.apply(this, arguments);
	      }
	      return save;
	    }()
	  }]);
	  return BrowserDownloads;
	}();
	BrowserDownloads.URL_SCHEME = 'downloads://';
	var BrowserFiles = /*#__PURE__*/function () {
	  function BrowserFiles(files) {
	    _classCallCheck(this, BrowserFiles);
	    if (files == null || files.length < 1) {
	      throw new Error("When calling browserFiles, at least 1 file is required, " + "but received ".concat(files));
	    }
	    this.jsonFile = files[0];
	    this.weightsFiles = files.slice(1);
	  }
	  _createClass(BrowserFiles, [{
	    key: "load",
	    value: function () {
	      var _load = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2() {
	        var _this = this;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              return _context2.abrupt("return", new Promise(function (resolve, reject) {
	                var jsonReader = new FileReader();
	                jsonReader.onload = function (event) {
	                  // tslint:disable-next-line:no-any
	                  var modelJSON = JSON.parse(event.target.result);
	                  var modelTopology = modelJSON.modelTopology;
	                  if (modelTopology == null) {
	                    reject(new Error("modelTopology field is missing from file ".concat(_this.jsonFile.name)));
	                    return;
	                  }
	                  var weightsManifest = modelJSON.weightsManifest;
	                  if (weightsManifest == null) {
	                    reject(new Error("weightManifest field is missing from file ".concat(_this.jsonFile.name)));
	                    return;
	                  }
	                  if (_this.weightsFiles.length === 0) {
	                    resolve({
	                      modelTopology: modelTopology
	                    });
	                    return;
	                  }
	                  var modelArtifactsPromise = getModelArtifactsForJSON(modelJSON, function (weightsManifest) {
	                    return _this.loadWeights(weightsManifest);
	                  });
	                  resolve(modelArtifactsPromise);
	                };
	                jsonReader.onerror = function (error) {
	                  return reject("Failed to read model topology and weights manifest JSON " + "from file '".concat(_this.jsonFile.name, "'. BrowserFiles supports loading ") + "Keras-style tf.Model artifacts only.");
	                };
	                jsonReader.readAsText(_this.jsonFile);
	              }));
	            case 1:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2);
	      }));
	      function load() {
	        return _load.apply(this, arguments);
	      }
	      return load;
	    }()
	  }, {
	    key: "loadWeights",
	    value: function loadWeights(weightsManifest) {
	      var _this2 = this;
	      var weightSpecs = [];
	      var paths = [];
	      var _iterator = _createForOfIteratorHelper(weightsManifest),
	        _step;
	      try {
	        for (_iterator.s(); !(_step = _iterator.n()).done;) {
	          var entry = _step.value;
	          weightSpecs.push.apply(weightSpecs, _toConsumableArray(entry.weights));
	          paths.push.apply(paths, _toConsumableArray(entry.paths));
	        }
	      } catch (err) {
	        _iterator.e(err);
	      } finally {
	        _iterator.f();
	      }
	      var pathToFile = this.checkManifestAndWeightFiles(weightsManifest);
	      var promises = paths.map(function (path) {
	        return _this2.loadWeightsFile(path, pathToFile[path]);
	      });
	      return Promise.all(promises).then(function (buffers) {
	        return [weightSpecs, buffers];
	      });
	    }
	  }, {
	    key: "loadWeightsFile",
	    value: function loadWeightsFile(path, file) {
	      return new Promise(function (resolve, reject) {
	        var weightFileReader = new FileReader();
	        weightFileReader.onload = function (event) {
	          // tslint:disable-next-line:no-any
	          var weightData = event.target.result;
	          resolve(weightData);
	        };
	        weightFileReader.onerror = function (error) {
	          return reject("Failed to weights data from file of path '".concat(path, "'."));
	        };
	        weightFileReader.readAsArrayBuffer(file);
	      });
	    }
	    /**
	     * Check the compatibility between weights manifest and weight files.
	     */
	  }, {
	    key: "checkManifestAndWeightFiles",
	    value: function checkManifestAndWeightFiles(manifest) {
	      var _this3 = this;
	      var basenames = [];
	      var fileNames = this.weightsFiles.map(function (file) {
	        return basename(file.name);
	      });
	      var pathToFile = {};
	      var _iterator2 = _createForOfIteratorHelper(manifest),
	        _step2;
	      try {
	        for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	          var group = _step2.value;
	          group.paths.forEach(function (path) {
	            var pathBasename = basename(path);
	            if (basenames.indexOf(pathBasename) !== -1) {
	              throw new Error("Duplicate file basename found in weights manifest: " + "'".concat(pathBasename, "'"));
	            }
	            basenames.push(pathBasename);
	            if (fileNames.indexOf(pathBasename) === -1) {
	              throw new Error("Weight file with basename '".concat(pathBasename, "' is not provided."));
	            } else {
	              pathToFile[path] = _this3.weightsFiles[fileNames.indexOf(pathBasename)];
	            }
	          });
	        }
	      } catch (err) {
	        _iterator2.e(err);
	      } finally {
	        _iterator2.f();
	      }
	      if (basenames.length !== this.weightsFiles.length) {
	        throw new Error("Mismatch in the number of files in weights manifest " + "(".concat(basenames.length, ") and the number of weight files provided ") + "(".concat(this.weightsFiles.length, ")."));
	      }
	      return pathToFile;
	    }
	  }]);
	  return BrowserFiles;
	}();
	var browserDownloadsRouter = function browserDownloadsRouter(url) {
	  if (!env().getBool('IS_BROWSER')) {
	    return null;
	  } else {
	    if (!Array.isArray(url) && url.startsWith(BrowserDownloads.URL_SCHEME)) {
	      return browserDownloads(url.slice(BrowserDownloads.URL_SCHEME.length));
	    } else {
	      return null;
	    }
	  }
	};
	IORouterRegistry.registerSaveRouter(browserDownloadsRouter);
	/**
	 * Creates an IOHandler that triggers file downloads from the browser.
	 *
	 * The returned `IOHandler` instance can be used as model exporting methods such
	 * as `tf.Model.save` and supports only saving.
	 *
	 * ```js
	 * const model = tf.sequential();
	 * model.add(tf.layers.dense(
	 *     {units: 1, inputShape: [10], activation: 'sigmoid'}));
	 * const saveResult = await model.save('downloads://mymodel');
	 * // This will trigger downloading of two files:
	 * //   'mymodel.json' and 'mymodel.weights.bin'.
	 * console.log(saveResult);
	 * ```
	 *
	 * @param fileNamePrefix Prefix name of the files to be downloaded. For use with
	 *   `tf.Model`, `fileNamePrefix` should follow either of the following two
	 *   formats:
	 *   1. `null` or `undefined`, in which case the default file
	 *      names will be used:
	 *      - 'model.json' for the JSON file containing the model topology and
	 *        weights manifest.
	 *      - 'model.weights.bin' for the binary file containing the binary weight
	 *        values.
	 *   2. A single string or an Array of a single string, as the file name prefix.
	 *      For example, if `'foo'` is provided, the downloaded JSON
	 *      file and binary weights file will be named 'foo.json' and
	 *      'foo.weights.bin', respectively.
	 * @param config Additional configuration for triggering downloads.
	 * @returns An instance of `BrowserDownloads` `IOHandler`.
	 *
	 * @doc {
	 *   heading: 'Models',
	 *   subheading: 'Loading',
	 *   namespace: 'io',
	 *   ignoreCI: true
	 * }
	 */
	function browserDownloads() {
	  var fileNamePrefix = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'model';
	  return new BrowserDownloads(fileNamePrefix);
	}
	/**
	 * Creates an IOHandler that loads model artifacts from user-selected files.
	 *
	 * This method can be used for loading from files such as user-selected files
	 * in the browser.
	 * When used in conjunction with `tf.loadLayersModel`, an instance of
	 * `tf.LayersModel` (Keras-style) can be constructed from the loaded artifacts.
	 *
	 * ```js
	 * // Note: This code snippet won't run properly without the actual file input
	 * //   elements in the HTML DOM.
	 *
	 * // Suppose there are two HTML file input (`<input type="file" ...>`)
	 * // elements.
	 * const uploadJSONInput = document.getElementById('upload-json');
	 * const uploadWeightsInput = document.getElementById('upload-weights');
	 * const model = await tf.loadLayersModel(tf.io.browserFiles(
	 *     [uploadJSONInput.files[0], uploadWeightsInput.files[0]]));
	 * ```
	 *
	 * @param files `File`s to load from. Currently, this function supports only
	 *   loading from files that contain Keras-style models (i.e., `tf.Model`s), for
	 *   which an `Array` of `File`s is expected (in that order):
	 *   - A JSON file containing the model topology and weight manifest.
	 *   - Optionally, one or more binary files containing the binary weights.
	 *     These files must have names that match the paths in the `weightsManifest`
	 *     contained by the aforementioned JSON file, or errors will be thrown
	 *     during loading. These weights files have the same format as the ones
	 *     generated by `tensorflowjs_converter` that comes with the `tensorflowjs`
	 *     Python PIP package. If no weights files are provided, only the model
	 *     topology will be loaded from the JSON file above.
	 * @returns An instance of `Files` `IOHandler`.
	 *
	 * @doc {
	 *   heading: 'Models',
	 *   subheading: 'Loading',
	 *   namespace: 'io',
	 *   ignoreCI: true
	 * }
	 */
	function browserFiles(files) {
	  return new BrowserFiles(files);
	}

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Monitor Promise.all progress, fire onProgress callback function.
	 *
	 * @param promises Promise list going to be monitored
	 * @param onProgress Callback function. Fired when a promise resolved.
	 * @param startFraction Optional fraction start. Default to 0.
	 * @param endFraction Optional fraction end. Default to 1.
	 */
	function monitorPromisesProgress(promises, onProgress, startFraction, endFraction) {
	  checkPromises(promises);
	  startFraction = startFraction == null ? 0 : startFraction;
	  endFraction = endFraction == null ? 1 : endFraction;
	  checkFraction(startFraction, endFraction);
	  var resolvedPromise = 0;
	  var registerMonitor = function registerMonitor(promise) {
	    promise.then(function (value) {
	      var fraction = startFraction + ++resolvedPromise / promises.length * (endFraction - startFraction);
	      // pass fraction as parameter to callback function.
	      onProgress(fraction);
	      return value;
	    });
	    return promise;
	  };
	  function checkPromises(promises) {
	    assert$1(promises != null && Array.isArray(promises) && promises.length > 0, function () {
	      return 'promises must be a none empty array';
	    });
	  }
	  function checkFraction(startFraction, endFraction) {
	    assert$1(startFraction >= 0 && startFraction <= 1, function () {
	      return "Progress fraction must be in range [0, 1], but " + "got startFraction ".concat(startFraction);
	    });
	    assert$1(endFraction >= 0 && endFraction <= 1, function () {
	      return "Progress fraction must be in range [0, 1], but " + "got endFraction ".concat(endFraction);
	    });
	    assert$1(endFraction >= startFraction, function () {
	      return "startFraction must be no more than endFraction, but " + "got startFraction ".concat(startFraction, " and endFraction ") + "".concat(endFraction);
	    });
	  }
	  return Promise.all(promises.map(registerMonitor));
	}

	/**
	 * Reads binary weights data from a number of URLs.
	 *
	 * @param fetchURLs URLs to send the HTTP requests at, using `fetch` calls.
	 * @param requestOptions RequestInit (options) for the HTTP requests.
	 * @param fetchFunc Optional overriding value for the `window.fetch` function.
	 * @param onProgress Optional, progress callback function, fired periodically
	 *   before the load is completed.
	 * @returns A `Promise` of an Array of `ArrayBuffer`. The Array has the same
	 *   length as `fetchURLs`.
	 */
	function loadWeightsAsArrayBuffer(_x, _x2) {
	  return _loadWeightsAsArrayBuffer.apply(this, arguments);
	}
	function _loadWeightsAsArrayBuffer() {
	  _loadWeightsAsArrayBuffer = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3(fetchURLs, loadOptions) {
	    var fetchFunc, requests, fetchStartFraction, fetchEndFraction, responses, bufferPromises, bufferStartFraction, bufferEndFraction, buffers;
	    return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	      while (1) switch (_context3.prev = _context3.next) {
	        case 0:
	          if (loadOptions == null) {
	            loadOptions = {};
	          }
	          fetchFunc = loadOptions.fetchFunc == null ? env().platform.fetch : loadOptions.fetchFunc; // Create the requests for all of the weights in parallel.
	          requests = fetchURLs.map(function (fetchURL) {
	            return fetchFunc(fetchURL, loadOptions.requestInit, {
	              isBinary: true
	            });
	          });
	          fetchStartFraction = 0;
	          fetchEndFraction = 0.5;
	          if (!(loadOptions.onProgress == null)) {
	            _context3.next = 11;
	            break;
	          }
	          _context3.next = 8;
	          return Promise.all(requests);
	        case 8:
	          _context3.t0 = _context3.sent;
	          _context3.next = 14;
	          break;
	        case 11:
	          _context3.next = 13;
	          return monitorPromisesProgress(requests, loadOptions.onProgress, fetchStartFraction, fetchEndFraction);
	        case 13:
	          _context3.t0 = _context3.sent;
	        case 14:
	          responses = _context3.t0;
	          bufferPromises = responses.map(function (response) {
	            return response.arrayBuffer();
	          });
	          bufferStartFraction = 0.5;
	          bufferEndFraction = 1;
	          if (!(loadOptions.onProgress == null)) {
	            _context3.next = 24;
	            break;
	          }
	          _context3.next = 21;
	          return Promise.all(bufferPromises);
	        case 21:
	          _context3.t1 = _context3.sent;
	          _context3.next = 27;
	          break;
	        case 24:
	          _context3.next = 26;
	          return monitorPromisesProgress(bufferPromises, loadOptions.onProgress, bufferStartFraction, bufferEndFraction);
	        case 26:
	          _context3.t1 = _context3.sent;
	        case 27:
	          buffers = _context3.t1;
	          return _context3.abrupt("return", buffers);
	        case 29:
	        case "end":
	          return _context3.stop();
	      }
	    }, _callee3);
	  }));
	  return _loadWeightsAsArrayBuffer.apply(this, arguments);
	}
	function streamWeights(fetchURLs, loadOptions) {
	  var _a;
	  var fetchFunc = loadOptions.fetchFunc == null ? env().platform.fetch : loadOptions.fetchFunc;
	  var fetchIndex = 0;
	  var chunkReader;
	  (_a = loadOptions.onProgress) === null || _a === void 0 ? void 0 : _a.call(loadOptions, 0);
	  return new ReadableStream({
	    pull: function () {
	      var _pull = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(controller) {
	        var _a, body, _yield$chunkReader$re, done, value;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              if (!(fetchIndex < fetchURLs.length)) {
	                _context.next = 20;
	                break;
	              }
	              if (chunkReader) {
	                _context.next = 6;
	                break;
	              }
	              _context.next = 4;
	              return fetchFunc(fetchURLs[fetchIndex], loadOptions.requestInit, {
	                isBinary: true
	              });
	            case 4:
	              body = _context.sent.body;
	              chunkReader = body.getReader();
	            case 6:
	              _context.next = 8;
	              return chunkReader.read();
	            case 8:
	              _yield$chunkReader$re = _context.sent;
	              done = _yield$chunkReader$re.done;
	              value = _yield$chunkReader$re.value;
	              if (!done) {
	                _context.next = 16;
	                break;
	              }
	              fetchIndex++;
	              chunkReader = undefined;
	              (_a = loadOptions.onProgress) === null || _a === void 0 ? void 0 : _a.call(loadOptions, fetchIndex / fetchURLs.length);
	              return _context.abrupt("continue", 0);
	            case 16:
	              controller.enqueue(value);
	              return _context.abrupt("return");
	            case 20:
	              controller.close();
	            case 21:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee);
	      }));
	      function pull(_x3) {
	        return _pull.apply(this, arguments);
	      }
	      return pull;
	    }()
	  });
	}
	/**
	 * Reads a weights manifest JSON configuration, fetches the weights and
	 * returns them as `Tensor`s.
	 *
	 * @param manifest The weights manifest JSON.
	 * @param filePathPrefix The path prefix for filenames given in the manifest.
	 *     Defaults to the empty string.
	 * @param weightNames The names of the weights to be fetched.
	 */
	function loadWeights(_x4) {
	  return _loadWeights.apply(this, arguments);
	}
	/**
	 * Creates a function, which reads a weights manifest JSON configuration,
	 * fetches the weight files using the specified function and returns them as
	 * `Tensor`s.
	 *
	 * ```js
	 * // example for creating a nodejs weight loader, which reads the weight files
	 * // from disk using fs.readFileSync
	 *
	 * import * as fs from 'fs'
	 *
	 * const fetchWeightsFromDisk = (filePaths: string[]) =>
	 *   filePaths.map(filePath => fs.readFileSync(filePath).buffer)
	 *
	 * const loadWeights = tf.io.weightsLoaderFactory(fetchWeightsFromDisk)
	 *
	 * const manifest = JSON.parse(
	 *   fs.readFileSync('./my_model-weights_manifest').toString()
	 * )
	 * const weightMap = await loadWeights(manifest, './')
	 * ```
	 * @param fetchWeightsFunction The function used for fetching the weight files.
	 * @returns Weight loading function.
	 */
	function _loadWeights() {
	  _loadWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4(manifest) {
	    var filePathPrefix,
	      weightNames,
	      requestInit,
	      fetchWeights,
	      loadWeights,
	      _args4 = arguments;
	    return _regeneratorRuntime().wrap(function _callee4$(_context4) {
	      while (1) switch (_context4.prev = _context4.next) {
	        case 0:
	          filePathPrefix = _args4.length > 1 && _args4[1] !== undefined ? _args4[1] : '';
	          weightNames = _args4.length > 2 ? _args4[2] : undefined;
	          requestInit = _args4.length > 3 ? _args4[3] : undefined;
	          // TODO(nsthorat): Groups are currently fetched atomically. If you need a
	          // single weight from a group, the whole group will be fetched. At a future
	          // date, we should support fetching only the individual shards within a
	          // group that are needed to reconstruct the requested weight.
	          // TODO(cais): Use `decodeWeights` for implementation.
	          fetchWeights = function fetchWeights(fetchUrls) {
	            return loadWeightsAsArrayBuffer(fetchUrls, {
	              requestInit: requestInit
	            });
	          };
	          loadWeights = weightsLoaderFactory(fetchWeights);
	          return _context4.abrupt("return", loadWeights(manifest, filePathPrefix, weightNames));
	        case 6:
	        case "end":
	          return _context4.stop();
	      }
	    }, _callee4);
	  }));
	  return _loadWeights.apply(this, arguments);
	}
	function weightsLoaderFactory(fetchWeightsFunction) {
	  return /*#__PURE__*/function () {
	    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(manifest) {
	      var filePathPrefix,
	        weightNames,
	        groupIndicesToFetchMap,
	        groupWeightsToFetch,
	        weightsFound,
	        allManifestWeightNames,
	        weightsNotFound,
	        groupIndicesToFetch,
	        fetchUrls,
	        buffers,
	        weightsTensorMap,
	        bufferIndexOffset,
	        _args2 = arguments;
	      return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	        while (1) switch (_context2.prev = _context2.next) {
	          case 0:
	            filePathPrefix = _args2.length > 1 && _args2[1] !== undefined ? _args2[1] : '';
	            weightNames = _args2.length > 2 ? _args2[2] : undefined;
	            // Collect all the groups, weights, and their relative offsets to be
	            // fetched.
	            groupIndicesToFetchMap = manifest.map(function () {
	              return false;
	            });
	            groupWeightsToFetch = {};
	            weightsFound = weightNames != null ? weightNames.map(function () {
	              return false;
	            }) : [];
	            allManifestWeightNames = [];
	            manifest.forEach(function (manifestGroupConfig, groupIndex) {
	              var groupOffset = 0;
	              manifestGroupConfig.weights.forEach(function (weightsEntry) {
	                var rawDtype = 'quantization' in weightsEntry ? weightsEntry.quantization.dtype : weightsEntry.dtype;
	                var weightsBytes = DTYPE_VALUE_SIZE_MAP[rawDtype] * sizeFromShape(weightsEntry.shape);
	                var enqueueWeightsForFetchingFn = function enqueueWeightsForFetchingFn() {
	                  groupIndicesToFetchMap[groupIndex] = true;
	                  if (groupWeightsToFetch[groupIndex] == null) {
	                    groupWeightsToFetch[groupIndex] = [];
	                  }
	                  groupWeightsToFetch[groupIndex].push({
	                    manifestEntry: weightsEntry,
	                    groupOffset: groupOffset,
	                    sizeBytes: weightsBytes
	                  });
	                };
	                if (weightNames != null) {
	                  weightNames.forEach(function (weightName, weightIndex) {
	                    if (weightName === weightsEntry.name) {
	                      enqueueWeightsForFetchingFn();
	                      weightsFound[weightIndex] = true;
	                    }
	                  });
	                } else {
	                  enqueueWeightsForFetchingFn();
	                }
	                allManifestWeightNames.push(weightsEntry.name);
	                groupOffset += weightsBytes;
	              });
	            });
	            if (weightsFound.every(function (found) {
	              return found;
	            })) {
	              _context2.next = 10;
	              break;
	            }
	            weightsNotFound = weightNames.filter(function (_, i) {
	              return !weightsFound[i];
	            });
	            throw new Error("Could not find weights in manifest with names: " + "".concat(weightsNotFound.join(', '), ". \n") + "Manifest JSON has weights with names: " + "".concat(allManifestWeightNames.join(', '), "."));
	          case 10:
	            // Convert the one-hot boolean groupId => shouldFetch map to a list of group
	            // IDs.
	            groupIndicesToFetch = groupIndicesToFetchMap.reduce(function (accumulator, shouldFetch, i) {
	              if (shouldFetch) {
	                accumulator.push(i);
	              }
	              return accumulator;
	            }, []);
	            fetchUrls = [];
	            groupIndicesToFetch.forEach(function (i) {
	              manifest[i].paths.forEach(function (filepath) {
	                var fetchUrl = filePathPrefix + (!filePathPrefix.endsWith('/') ? '/' : '') + filepath;
	                fetchUrls.push(fetchUrl);
	              });
	            });
	            _context2.next = 15;
	            return fetchWeightsFunction(fetchUrls);
	          case 15:
	            buffers = _context2.sent;
	            weightsTensorMap = {};
	            bufferIndexOffset = 0;
	            groupIndicesToFetch.forEach(function (i) {
	              var numBuffers = manifest[i].paths.length;
	              var weightsBuffer = new CompositeArrayBuffer(buffers.slice(bufferIndexOffset, bufferIndexOffset + numBuffers));
	              var weightsEntries = groupWeightsToFetch[i];
	              weightsEntries.forEach(function (weightsEntry) {
	                var byteBuffer = weightsBuffer.slice(weightsEntry.groupOffset, weightsEntry.groupOffset + weightsEntry.sizeBytes);
	                var nameToTensorMap = decodeWeights(byteBuffer, [weightsEntry.manifestEntry]);
	                for (var name in nameToTensorMap) {
	                  weightsTensorMap[name] = nameToTensorMap[name];
	                }
	              });
	              bufferIndexOffset += numBuffers;
	            });
	            return _context2.abrupt("return", weightsTensorMap);
	          case 20:
	          case "end":
	            return _context2.stop();
	        }
	      }, _callee2);
	    }));
	    return function (_x5) {
	      return _ref.apply(this, arguments);
	    };
	  }();
	}

	var OCTET_STREAM_MIME_TYPE = 'application/octet-stream';
	var JSON_TYPE = 'application/json';
	var HTTPRequest = /*#__PURE__*/function () {
	  function HTTPRequest(path, loadOptions) {
	    _classCallCheck(this, HTTPRequest);
	    this.DEFAULT_METHOD = 'POST';
	    if (loadOptions == null) {
	      loadOptions = {};
	    }
	    this.weightPathPrefix = loadOptions.weightPathPrefix;
	    this.weightUrlConverter = loadOptions.weightUrlConverter;
	    if (loadOptions.fetchFunc != null) {
	      assert$1(typeof loadOptions.fetchFunc === 'function', function () {
	        return 'Must pass a function that matches the signature of ' + '`fetch` (see ' + 'https://developer.mozilla.org/en-US/docs/Web/API/Fetch_API)';
	      });
	      this.fetch = loadOptions.fetchFunc;
	    } else {
	      this.fetch = env().platform.fetch;
	    }
	    assert$1(path != null && path.length > 0, function () {
	      return 'URL path for http must not be null, undefined or ' + 'empty.';
	    });
	    if (Array.isArray(path)) {
	      assert$1(path.length === 2, function () {
	        return 'URL paths for http must have a length of 2, ' + "(actual length is ".concat(path.length, ").");
	      });
	    }
	    this.path = path;
	    if (loadOptions.requestInit != null && loadOptions.requestInit.body != null) {
	      throw new Error('requestInit is expected to have no pre-existing body, but has one.');
	    }
	    this.requestInit = loadOptions.requestInit || {};
	    this.loadOptions = loadOptions;
	  }
	  _createClass(HTTPRequest, [{
	    key: "save",
	    value: function () {
	      var _save = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(modelArtifacts) {
	        var init, weightsManifest, modelTopologyAndWeightManifest, weightBuffer, response;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              if (!(modelArtifacts.modelTopology instanceof ArrayBuffer)) {
	                _context.next = 2;
	                break;
	              }
	              throw new Error('BrowserHTTPRequest.save() does not support saving model topology ' + 'in binary formats yet.');
	            case 2:
	              init = Object.assign({
	                method: this.DEFAULT_METHOD
	              }, this.requestInit);
	              init.body = new FormData();
	              weightsManifest = [{
	                paths: ['./model.weights.bin'],
	                weights: modelArtifacts.weightSpecs
	              }];
	              modelTopologyAndWeightManifest = getModelJSONForModelArtifacts(modelArtifacts, weightsManifest);
	              init.body.append('model.json', new Blob([JSON.stringify(modelTopologyAndWeightManifest)], {
	                type: JSON_TYPE
	              }), 'model.json');
	              if (modelArtifacts.weightData != null) {
	                // TODO(mattsoulanille): Support saving models over 2GB that exceed
	                // Chrome's ArrayBuffer size limit.
	                weightBuffer = CompositeArrayBuffer.join(modelArtifacts.weightData);
	                init.body.append('model.weights.bin', new Blob([weightBuffer], {
	                  type: OCTET_STREAM_MIME_TYPE
	                }), 'model.weights.bin');
	              }
	              _context.next = 10;
	              return this.fetch(this.path, init);
	            case 10:
	              response = _context.sent;
	              if (!response.ok) {
	                _context.next = 15;
	                break;
	              }
	              return _context.abrupt("return", {
	                modelArtifactsInfo: getModelArtifactsInfoForJSON(modelArtifacts),
	                responses: [response]
	              });
	            case 15:
	              throw new Error("BrowserHTTPRequest.save() failed due to HTTP response status " + "".concat(response.status, "."));
	            case 16:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function save(_x) {
	        return _save.apply(this, arguments);
	      }
	      return save;
	    }()
	  }, {
	    key: "loadModelJSON",
	    value: function () {
	      var _loadModelJSON = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2() {
	        var modelConfigRequest, modelJSON, message, modelTopology, weightsManifest;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              _context2.next = 2;
	              return this.fetch(this.path, this.requestInit);
	            case 2:
	              modelConfigRequest = _context2.sent;
	              if (modelConfigRequest.ok) {
	                _context2.next = 5;
	                break;
	              }
	              throw new Error("Request to ".concat(this.path, " failed with status code ") + "".concat(modelConfigRequest.status, ". Please verify this URL points to ") + "the model JSON of the model to load.");
	            case 5:
	              _context2.prev = 5;
	              _context2.next = 8;
	              return modelConfigRequest.json();
	            case 8:
	              modelJSON = _context2.sent;
	              _context2.next = 16;
	              break;
	            case 11:
	              _context2.prev = 11;
	              _context2.t0 = _context2["catch"](5);
	              message = "Failed to parse model JSON of response from ".concat(this.path, "."); // TODO(nsthorat): Remove this after some time when we're comfortable that
	              // .pb files are mostly gone.
	              if (this.path.endsWith('.pb')) {
	                message += ' Your path contains a .pb file extension. ' + 'Support for .pb models have been removed in TensorFlow.js 1.0 ' + 'in favor of .json models. You can re-convert your Python ' + 'TensorFlow model using the TensorFlow.js 1.0 conversion scripts ' + 'or you can convert your.pb models with the \'pb2json\'' + 'NPM script in the tensorflow/tfjs-converter repository.';
	              } else {
	                message += ' Please make sure the server is serving valid ' + 'JSON for this request.';
	              }
	              throw new Error(message);
	            case 16:
	              // We do not allow both modelTopology and weightsManifest to be missing.
	              modelTopology = modelJSON.modelTopology;
	              weightsManifest = modelJSON.weightsManifest;
	              if (!(modelTopology == null && weightsManifest == null)) {
	                _context2.next = 20;
	                break;
	              }
	              throw new Error("The JSON from HTTP path ".concat(this.path, " contains neither model ") + "topology or manifest for weights.");
	            case 20:
	              return _context2.abrupt("return", modelJSON);
	            case 21:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this, [[5, 11]]);
	      }));
	      function loadModelJSON() {
	        return _loadModelJSON.apply(this, arguments);
	      }
	      return loadModelJSON;
	    }()
	    /**
	     * Load model artifacts via HTTP request(s).
	     *
	     * See the documentation to `tf.io.http` for details on the saved
	     * artifacts.
	     *
	     * @returns The loaded model artifacts (if loading succeeds).
	     */
	  }, {
	    key: "load",
	    value: function () {
	      var _load = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3() {
	        var _this = this;
	        var modelJSON;
	        return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	          while (1) switch (_context3.prev = _context3.next) {
	            case 0:
	              if (!this.loadOptions.streamWeights) {
	                _context3.next = 2;
	                break;
	              }
	              return _context3.abrupt("return", this.loadStream());
	            case 2:
	              _context3.next = 4;
	              return this.loadModelJSON();
	            case 4:
	              modelJSON = _context3.sent;
	              return _context3.abrupt("return", getModelArtifactsForJSON(modelJSON, function (weightsManifest) {
	                return _this.loadWeights(weightsManifest);
	              }));
	            case 6:
	            case "end":
	              return _context3.stop();
	          }
	        }, _callee3, this);
	      }));
	      function load() {
	        return _load.apply(this, arguments);
	      }
	      return load;
	    }()
	  }, {
	    key: "loadStream",
	    value: function () {
	      var _loadStream = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4() {
	        var _this2 = this;
	        var modelJSON, fetchURLs, weightSpecs, stream;
	        return _regeneratorRuntime().wrap(function _callee4$(_context4) {
	          while (1) switch (_context4.prev = _context4.next) {
	            case 0:
	              _context4.next = 2;
	              return this.loadModelJSON();
	            case 2:
	              modelJSON = _context4.sent;
	              _context4.next = 5;
	              return this.getWeightUrls(modelJSON.weightsManifest);
	            case 5:
	              fetchURLs = _context4.sent;
	              weightSpecs = getWeightSpecs(modelJSON.weightsManifest);
	              stream = function stream() {
	                return streamWeights(fetchURLs, _this2.loadOptions);
	              };
	              return _context4.abrupt("return", Object.assign(Object.assign({}, modelJSON), {
	                weightSpecs: weightSpecs,
	                getWeightStream: stream
	              }));
	            case 9:
	            case "end":
	              return _context4.stop();
	          }
	        }, _callee4, this);
	      }));
	      function loadStream() {
	        return _loadStream.apply(this, arguments);
	      }
	      return loadStream;
	    }()
	  }, {
	    key: "getWeightUrls",
	    value: function () {
	      var _getWeightUrls = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee5(weightsManifest) {
	        var weightPath, _parseUrl, _parseUrl2, prefix, suffix, pathPrefix, fetchURLs, urlPromises, _iterator, _step, weightsGroup, _iterator2, _step2, path;
	        return _regeneratorRuntime().wrap(function _callee5$(_context5) {
	          while (1) switch (_context5.prev = _context5.next) {
	            case 0:
	              weightPath = Array.isArray(this.path) ? this.path[1] : this.path;
	              _parseUrl = parseUrl(weightPath), _parseUrl2 = _slicedToArray(_parseUrl, 2), prefix = _parseUrl2[0], suffix = _parseUrl2[1];
	              pathPrefix = this.weightPathPrefix || prefix;
	              fetchURLs = [];
	              urlPromises = [];
	              _iterator = _createForOfIteratorHelper(weightsManifest);
	              try {
	                for (_iterator.s(); !(_step = _iterator.n()).done;) {
	                  weightsGroup = _step.value;
	                  _iterator2 = _createForOfIteratorHelper(weightsGroup.paths);
	                  try {
	                    for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	                      path = _step2.value;
	                      if (this.weightUrlConverter != null) {
	                        urlPromises.push(this.weightUrlConverter(path));
	                      } else {
	                        fetchURLs.push(pathPrefix + path + suffix);
	                      }
	                    }
	                  } catch (err) {
	                    _iterator2.e(err);
	                  } finally {
	                    _iterator2.f();
	                  }
	                }
	              } catch (err) {
	                _iterator.e(err);
	              } finally {
	                _iterator.f();
	              }
	              if (!this.weightUrlConverter) {
	                _context5.next = 16;
	                break;
	              }
	              _context5.t0 = fetchURLs.push;
	              _context5.t1 = fetchURLs;
	              _context5.t2 = _toConsumableArray;
	              _context5.next = 13;
	              return Promise.all(urlPromises);
	            case 13:
	              _context5.t3 = _context5.sent;
	              _context5.t4 = (0, _context5.t2)(_context5.t3);
	              _context5.t0.apply.call(_context5.t0, _context5.t1, _context5.t4);
	            case 16:
	              return _context5.abrupt("return", fetchURLs);
	            case 17:
	            case "end":
	              return _context5.stop();
	          }
	        }, _callee5, this);
	      }));
	      function getWeightUrls(_x2) {
	        return _getWeightUrls.apply(this, arguments);
	      }
	      return getWeightUrls;
	    }()
	  }, {
	    key: "loadWeights",
	    value: function () {
	      var _loadWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee6(weightsManifest) {
	        var fetchURLs, weightSpecs, buffers;
	        return _regeneratorRuntime().wrap(function _callee6$(_context6) {
	          while (1) switch (_context6.prev = _context6.next) {
	            case 0:
	              _context6.next = 2;
	              return this.getWeightUrls(weightsManifest);
	            case 2:
	              fetchURLs = _context6.sent;
	              weightSpecs = getWeightSpecs(weightsManifest);
	              _context6.next = 6;
	              return loadWeightsAsArrayBuffer(fetchURLs, this.loadOptions);
	            case 6:
	              buffers = _context6.sent;
	              return _context6.abrupt("return", [weightSpecs, buffers]);
	            case 8:
	            case "end":
	              return _context6.stop();
	          }
	        }, _callee6, this);
	      }));
	      function loadWeights(_x3) {
	        return _loadWeights.apply(this, arguments);
	      }
	      return loadWeights;
	    }()
	  }]);
	  return HTTPRequest;
	}();
	HTTPRequest.URL_SCHEME_REGEX = /^https?:\/\//;
	/**
	 * Extract the prefix and suffix of the url, where the prefix is the path before
	 * the last file, and suffix is the search params after the last file.
	 * ```
	 * const url = 'http://tfhub.dev/model/1/tensorflowjs_model.pb?tfjs-format=file'
	 * [prefix, suffix] = parseUrl(url)
	 * // prefix = 'http://tfhub.dev/model/1/'
	 * // suffix = '?tfjs-format=file'
	 * ```
	 * @param url the model url to be parsed.
	 */
	function parseUrl(url) {
	  var lastSlash = url.lastIndexOf('/');
	  var lastSearchParam = url.lastIndexOf('?');
	  var prefix = url.substring(0, lastSlash);
	  var suffix = lastSearchParam > lastSlash ? url.substring(lastSearchParam) : '';
	  return [prefix + '/', suffix];
	}
	function isHTTPScheme(url) {
	  return url.match(HTTPRequest.URL_SCHEME_REGEX) != null;
	}
	var httpRouter = function httpRouter(url, loadOptions) {
	  if (typeof fetch === 'undefined' && (loadOptions == null || loadOptions.fetchFunc == null)) {
	    // `http` uses `fetch` or `node-fetch`, if one wants to use it in
	    // an environment that is not the browser or node they have to setup a
	    // global fetch polyfill.
	    return null;
	  } else {
	    var isHTTP = true;
	    if (Array.isArray(url)) {
	      isHTTP = url.every(function (urlItem) {
	        return isHTTPScheme(urlItem);
	      });
	    } else {
	      isHTTP = isHTTPScheme(url);
	    }
	    if (isHTTP) {
	      return http(url, loadOptions);
	    }
	  }
	  return null;
	};
	IORouterRegistry.registerSaveRouter(httpRouter);
	IORouterRegistry.registerLoadRouter(httpRouter);
	/**
	 * Creates an IOHandler subtype that sends model artifacts to HTTP server.
	 *
	 * An HTTP request of the `multipart/form-data` mime type will be sent to the
	 * `path` URL. The form data includes artifacts that represent the topology
	 * and/or weights of the model. In the case of Keras-style `tf.Model`, two
	 * blobs (files) exist in form-data:
	 *   - A JSON file consisting of `modelTopology` and `weightsManifest`.
	 *   - A binary weights file consisting of the concatenated weight values.
	 * These files are in the same format as the one generated by
	 * [tfjs_converter](https://js.tensorflow.org/tutorials/import-keras.html).
	 *
	 * The following code snippet exemplifies the client-side code that uses this
	 * function:
	 *
	 * ```js
	 * const model = tf.sequential();
	 * model.add(
	 *     tf.layers.dense({units: 1, inputShape: [100], activation: 'sigmoid'}));
	 *
	 * const saveResult = await model.save(tf.io.http(
	 *     'http://model-server:5000/upload', {requestInit: {method: 'PUT'}}));
	 * console.log(saveResult);
	 * ```
	 *
	 * If the default `POST` method is to be used, without any custom parameters
	 * such as headers, you can simply pass an HTTP or HTTPS URL to `model.save`:
	 *
	 * ```js
	 * const saveResult = await model.save('http://model-server:5000/upload');
	 * ```
	 *
	 * The following GitHub Gist
	 * https://gist.github.com/dsmilkov/1b6046fd6132d7408d5257b0976f7864
	 * implements a server based on [flask](https://github.com/pallets/flask) that
	 * can receive the request. Upon receiving the model artifacts via the request,
	 * this particular server reconstitutes instances of [Keras
	 * Models](https://keras.io/models/model/) in memory.
	 *
	 *
	 * @param path A URL path to the model.
	 *   Can be an absolute HTTP path (e.g.,
	 *   'http://localhost:8000/model-upload)') or a relative path (e.g.,
	 *   './model-upload').
	 * @param requestInit Request configurations to be used when sending
	 *    HTTP request to server using `fetch`. It can contain fields such as
	 *    `method`, `credentials`, `headers`, `mode`, etc. See
	 *    https://developer.mozilla.org/en-US/docs/Web/API/Request/Request
	 *    for more information. `requestInit` must not have a body, because the
	 * body will be set by TensorFlow.js. File blobs representing the model
	 * topology (filename: 'model.json') and the weights of the model (filename:
	 * 'model.weights.bin') will be appended to the body. If `requestInit` has a
	 * `body`, an Error will be thrown.
	 * @param loadOptions Optional configuration for the loading. It includes the
	 *   following fields:
	 *   - weightPathPrefix Optional, this specifies the path prefix for weight
	 *     files, by default this is calculated from the path param.
	 *   - fetchFunc Optional, custom `fetch` function. E.g., in Node.js,
	 *     the `fetch` from node-fetch can be used here.
	 *   - onProgress Optional, progress callback function, fired periodically
	 *     before the load is completed.
	 * @returns An instance of `IOHandler`.
	 *
	 * @doc {
	 *   heading: 'Models',
	 *   subheading: 'Loading',
	 *   namespace: 'io',
	 *   ignoreCI: true
	 * }
	 */
	function http(path, loadOptions) {
	  return new HTTPRequest(path, loadOptions);
	}
	/**
	 * Deprecated. Use `tf.io.http`.
	 * @param path
	 * @param loadOptions
	 */
	function browserHTTPRequest(path, loadOptions) {
	  return http(path, loadOptions);
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var PassthroughLoader = /*#__PURE__*/function () {
	  function PassthroughLoader(modelArtifacts) {
	    _classCallCheck(this, PassthroughLoader);
	    this.modelArtifacts = modelArtifacts;
	  }
	  _createClass(PassthroughLoader, [{
	    key: "load",
	    value: function load() {
	      return this.modelArtifacts;
	    }
	  }]);
	  return PassthroughLoader;
	}();
	var PassthroughSaver = /*#__PURE__*/function () {
	  function PassthroughSaver(saveHandler) {
	    _classCallCheck(this, PassthroughSaver);
	    this.saveHandler = saveHandler;
	  }
	  _createClass(PassthroughSaver, [{
	    key: "save",
	    value: function save(modelArtifacts) {
	      return this.saveHandler(modelArtifacts);
	    }
	  }]);
	  return PassthroughSaver;
	}();
	var PassthroughAsync = /*#__PURE__*/_createClass(function PassthroughAsync(handler) {
	  _classCallCheck(this, PassthroughAsync);
	  if (handler.load) {
	    this.load = function () {
	      return Promise.resolve(handler.load());
	    };
	  }
	  if (handler.save) {
	    this.save = function (modelArtifacts) {
	      return Promise.resolve(handler.save(modelArtifacts));
	    };
	  }
	});
	/**
	 * Creates an IOHandler that loads model artifacts from memory.
	 *
	 * When used in conjunction with `tf.loadLayersModel`, an instance of
	 * `tf.LayersModel` (Keras-style) can be constructed from the loaded artifacts.
	 *
	 * ```js
	 * const model = await tf.loadLayersModel(tf.io.fromMemory(
	 *     modelTopology, weightSpecs, weightData));
	 * ```
	 *
	 * @param modelArtifacts a object containing model topology (i.e., parsed from
	 *   the JSON format).
	 * @param weightSpecs An array of `WeightsManifestEntry` objects describing the
	 *   names, shapes, types, and quantization of the weight data. Optional.
	 * @param weightData A single `ArrayBuffer` containing the weight data,
	 *   concatenated in the order described by the weightSpecs. Optional.
	 * @param trainingConfig Model training configuration. Optional.
	 *
	 * @returns A passthrough `IOHandler` that simply loads the provided data.
	 */
	function fromMemory(modelArtifacts, weightSpecs, weightData, trainingConfig) {
	  var args = arguments;
	  return new PassthroughAsync(fromMemorySync.apply(void 0, _toConsumableArray(args)));
	}
	/**
	 * Creates an IOHandler that loads model artifacts from memory.
	 *
	 * When used in conjunction with `tf.loadLayersModel`, an instance of
	 * `tf.LayersModel` (Keras-style) can be constructed from the loaded artifacts.
	 *
	 * ```js
	 * const model = await tf.loadLayersModel(tf.io.fromMemory(
	 *     modelTopology, weightSpecs, weightData));
	 * ```
	 *
	 * @param modelArtifacts a object containing model topology (i.e., parsed from
	 *   the JSON format).
	 * @param weightSpecs An array of `WeightsManifestEntry` objects describing the
	 *   names, shapes, types, and quantization of the weight data. Optional.
	 * @param weightData A single `ArrayBuffer` containing the weight data,
	 *   concatenated in the order described by the weightSpecs. Optional.
	 * @param trainingConfig Model training configuration. Optional.
	 *
	 * @returns A passthrough `IOHandlerSync` that simply loads the provided data.
	 */
	function fromMemorySync(modelArtifacts, weightSpecs, weightData, trainingConfig) {
	  if (arguments.length === 1) {
	    var isModelArtifacts = modelArtifacts.modelTopology != null || modelArtifacts.weightSpecs != null;
	    if (isModelArtifacts) {
	      return new PassthroughLoader(modelArtifacts);
	    } else {
	      // Legacy support: with only modelTopology.
	      // TODO(cais): Remove this deprecated API.
	      console.warn('Please call tf.io.fromMemory() with only one argument. ' + 'The argument should be of type ModelArtifacts. ' + 'The multi-argument signature of tf.io.fromMemory() has been ' + 'deprecated and will be removed in a future release.');
	      return new PassthroughLoader({
	        modelTopology: modelArtifacts
	      });
	    }
	  } else {
	    // Legacy support.
	    // TODO(cais): Remove this deprecated API.
	    console.warn('Please call tf.io.fromMemory() with only one argument. ' + 'The argument should be of type ModelArtifacts. ' + 'The multi-argument signature of tf.io.fromMemory() has been ' + 'deprecated and will be removed in a future release.');
	    return new PassthroughLoader({
	      modelTopology: modelArtifacts,
	      weightSpecs: weightSpecs,
	      weightData: weightData,
	      trainingConfig: trainingConfig
	    });
	  }
	}
	/**
	 * Creates an IOHandler that passes saved model artifacts to a callback.
	 *
	 * ```js
	 * function handleSave(artifacts) {
	 *   // ... do something with the artifacts ...
	 *   return {modelArtifactsInfo: {...}, ...};
	 * }
	 *
	 * const saveResult = model.save(tf.io.withSaveHandler(handleSave));
	 * ```
	 *
	 * @param saveHandler A function that accepts a `ModelArtifacts` and returns a
	 *     promise that resolves to a `SaveResult`.
	 */
	function withSaveHandler(saveHandler) {
	  return new PassthroughSaver(saveHandler);
	}
	/**
	 * Creates an IOHandlerSync that passes saved model artifacts to a callback.
	 *
	 * ```js
	 * function handleSave(artifacts) {
	 *   // ... do something with the artifacts ...
	 *   return {modelArtifactsInfo: {...}, ...};
	 * }
	 *
	 * const saveResult = model.save(tf.io.withSaveHandler(handleSave));
	 * ```
	 *
	 * @param saveHandler A function that accepts a `ModelArtifacts` and returns a
	 *     `SaveResult`.
	 */
	function withSaveHandlerSync(saveHandler) {
	  return new PassthroughSaver(saveHandler);
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */

	var io = {
		__proto__: null,
		CompositeArrayBuffer: CompositeArrayBuffer,
		browserFiles: browserFiles,
		browserHTTPRequest: browserHTTPRequest,
		concatenateArrayBuffers: concatenateArrayBuffers,
		copyModel: copyModel,
		decodeWeights: decodeWeights,
		decodeWeightsStream: decodeWeightsStream,
		encodeWeights: encodeWeights,
		fromMemory: fromMemory,
		fromMemorySync: fromMemorySync,
		getLoadHandlers: getLoadHandlers,
		getModelArtifactsForJSON: getModelArtifactsForJSON,
		getModelArtifactsForJSONSync: getModelArtifactsForJSONSync,
		getModelArtifactsInfoForJSON: getModelArtifactsInfoForJSON,
		getSaveHandlers: getSaveHandlers,
		getWeightSpecs: getWeightSpecs,
		http: http,
		isHTTPScheme: isHTTPScheme,
		listModels: listModels,
		loadWeights: loadWeights,
		moveModel: moveModel,
		registerLoadRouter: registerLoadRouter,
		registerSaveRouter: registerSaveRouter,
		removeModel: removeModel,
		weightsLoaderFactory: weightsLoaderFactory,
		withSaveHandler: withSaveHandler,
		withSaveHandlerSync: withSaveHandlerSync
	};

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the confusion matrix from true labels and predicted labels.
	 *
	 * ```js
	 * const labels = tf.tensor1d([0, 1, 2, 1, 0], 'int32');
	 * const predictions = tf.tensor1d([0, 2, 2, 1, 0], 'int32');
	 * const numClasses = 3;
	 * const out = tf.math.confusionMatrix(labels, predictions, numClasses);
	 * out.print();
	 * // Expected output matrix:
	 * // [[2, 0, 0],
	 * //  [0, 1, 1],
	 * //  [0, 0, 1]]
	 * ```
	 *
	 * @param labels The target labels, assumed to be 0-based integers
	 *   for the classes. The shape is `[numExamples]`, where
	 *   `numExamples` is the number of examples included.
	 * @param predictions The predicted classes, assumed to be
	 *   0-based integers for the classes. Must have the same shape as `labels`.
	 * @param numClasses Number of all classes, as an integer.
	 *   Its value must be larger than the largest element in `labels` and
	 *   `predictions`.
	 * @returns The confusion matrix as a int32-type 2D tensor. The value at
	 *   row `r` and column `c` is the number of times examples of actual class
	 *   `r` were predicted as class `c`.
	 *
	 * @doc {heading: 'Operations', subheading: 'Evaluation'}
	 */
	function confusionMatrix_(labels, predictions, numClasses) {
	  var $labels = convertToTensor(labels, 'labels', 'confusionMatrix');
	  var $predictions = convertToTensor(predictions, 'predictions', 'confusionMatrix');
	  assert$1(numClasses == null || numClasses > 0 && Number.isInteger(numClasses), function () {
	    return "If provided, numClasses must be a positive integer, " + "but got ".concat(numClasses);
	  });
	  assert$1($labels.rank === 1, function () {
	    return "Expected the rank of labels to be 1, but got ".concat($labels.rank);
	  });
	  assert$1($predictions.rank === 1, function () {
	    return "Expected the rank of predictions to be 1, " + "but got ".concat($predictions.rank);
	  });
	  assert$1($labels.shape[0] === $predictions.shape[0], function () {
	    return "Mismatch in the number of examples: " + "".concat($labels.shape[0], " vs. ").concat($predictions.shape[0], ". ") + "Labels and predictions should have the same number of elements.";
	  });
	  assert$1(numClasses > 0 && Number.isInteger(numClasses), function () {
	    return "numClasses is required to be a positive integer, but got " + "".concat(numClasses);
	  });
	  // TODO(cais): In the future, if oneHot supports tensors inputs for
	  //   `numClasses`, `confusionMatrix` can make `numClasses` optional.
	  var oneHotLabels = oneHot$3(cast$3($labels, 'int32'), numClasses);
	  var oneHotPredictions = oneHot$3(cast$3($predictions, 'int32'), numClasses);
	  var oneHotLabelsT = transpose$2(oneHotLabels);
	  var product = matMul$1(oneHotLabelsT, oneHotPredictions);
	  return cast$3(product, 'int32');
	}
	var confusionMatrix = /* @__PURE__ */op({
	  confusionMatrix_: confusionMatrix_
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */

	var math = {
		__proto__: null,
		confusionMatrix: confusionMatrix
	};

	var fromPixels2DContext$1;
	var hasToPixelsWarned = false;
	/**
	 * Creates a `tf.Tensor` from an image.
	 *
	 * ```js
	 * const image = new ImageData(1, 1);
	 * image.data[0] = 100;
	 * image.data[1] = 150;
	 * image.data[2] = 200;
	 * image.data[3] = 255;
	 *
	 * tf.browser.fromPixels(image).print();
	 * ```
	 *
	 * @param pixels The input image to construct the tensor from. The
	 * supported image types are all 4-channel. You can also pass in an image
	 * object with following attributes:
	 * `{data: Uint8Array; width: number; height: number}`
	 * @param numChannels The number of channels of the output tensor. A
	 * numChannels value less than 4 allows you to ignore channels. Defaults to
	 * 3 (ignores alpha channel of input image).
	 *
	 * @returns A Tensor3D with the shape `[height, width, numChannels]`.
	 *
	 * Note: fromPixels can be lossy in some cases, same image may result in
	 * slightly different tensor values, if rendered by different rendering
	 * engines. This means that results from different browsers, or even same
	 * browser with CPU and GPU rendering engines can be different. See discussion
	 * in details:
	 * https://github.com/tensorflow/tfjs/issues/5482
	 *
	 * @doc {heading: 'Browser', namespace: 'browser', ignoreCI: true}
	 */
	function fromPixels_(pixels) {
	  var numChannels = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 3;
	  // Sanity checks.
	  if (numChannels > 4) {
	    throw new Error('Cannot construct Tensor with more than 4 channels from pixels.');
	  }
	  if (pixels == null) {
	    throw new Error('pixels passed to tf.browser.fromPixels() can not be null');
	  }
	  var isPixelData = false;
	  var isImageData = false;
	  var isVideo = false;
	  var isImage = false;
	  var isCanvasLike = false;
	  var isImageBitmap = false;
	  if (pixels.data instanceof Uint8Array) {
	    isPixelData = true;
	  } else if (typeof ImageData !== 'undefined' && pixels instanceof ImageData) {
	    isImageData = true;
	  } else if (typeof HTMLVideoElement !== 'undefined' && pixels instanceof HTMLVideoElement) {
	    isVideo = true;
	  } else if (typeof HTMLImageElement !== 'undefined' && pixels instanceof HTMLImageElement) {
	    isImage = true;
	    // tslint:disable-next-line: no-any
	  } else if (pixels.getContext != null) {
	    isCanvasLike = true;
	  } else if (typeof ImageBitmap !== 'undefined' && pixels instanceof ImageBitmap) {
	    isImageBitmap = true;
	  } else {
	    throw new Error('pixels passed to tf.browser.fromPixels() must be either an ' + "HTMLVideoElement, HTMLImageElement, HTMLCanvasElement, ImageData " + "in browser, or OffscreenCanvas, ImageData in webworker" + " or {data: Uint32Array, width: number, height: number}, " + "but was ".concat(pixels.constructor.name));
	  }
	  // If the current backend has 'FromPixels' registered, it has a more
	  // efficient way of handling pixel uploads, so we call that.
	  var kernel = getKernel(FromPixels, ENGINE.backendName);
	  if (kernel != null) {
	    var inputs = {
	      pixels: pixels
	    };
	    var attrs = {
	      numChannels: numChannels
	    };
	    return ENGINE.runKernel(FromPixels, inputs, attrs);
	  }
	  var _ref = isVideo ? [pixels.videoWidth, pixels.videoHeight] : [pixels.width, pixels.height],
	    _ref2 = _slicedToArray(_ref, 2),
	    width = _ref2[0],
	    height = _ref2[1];
	  var vals;
	  if (isCanvasLike) {
	    vals =
	    // tslint:disable-next-line:no-any
	    pixels.getContext('2d').getImageData(0, 0, width, height).data;
	  } else if (isImageData || isPixelData) {
	    vals = pixels.data;
	  } else if (isImage || isVideo || isImageBitmap) {
	    if (fromPixels2DContext$1 == null) {
	      if (typeof document === 'undefined') {
	        if (typeof OffscreenCanvas !== 'undefined' && typeof OffscreenCanvasRenderingContext2D !== 'undefined') {
	          // @ts-ignore
	          fromPixels2DContext$1 = new OffscreenCanvas(1, 1).getContext('2d');
	        } else {
	          throw new Error('Cannot parse input in current context. ' + 'Reason: OffscreenCanvas Context2D rendering is not supported.');
	        }
	      } else {
	        fromPixels2DContext$1 = document.createElement('canvas').getContext('2d', {
	          willReadFrequently: true
	        });
	      }
	    }
	    fromPixels2DContext$1.canvas.width = width;
	    fromPixels2DContext$1.canvas.height = height;
	    fromPixels2DContext$1.drawImage(pixels, 0, 0, width, height);
	    vals = fromPixels2DContext$1.getImageData(0, 0, width, height).data;
	  }
	  var values;
	  if (numChannels === 4) {
	    values = new Int32Array(vals);
	  } else {
	    var numPixels = width * height;
	    values = new Int32Array(numPixels * numChannels);
	    for (var i = 0; i < numPixels; i++) {
	      for (var channel = 0; channel < numChannels; ++channel) {
	        values[i * numChannels + channel] = vals[i * 4 + channel];
	      }
	    }
	  }
	  var outShape = [height, width, numChannels];
	  return tensor3d(values, outShape, 'int32');
	}
	// Helper functions for |fromPixelsAsync| to check whether the input can
	// be wrapped into imageBitmap.
	function isPixelData(pixels) {
	  return pixels != null && pixels.data instanceof Uint8Array;
	}
	function isImageBitmapFullySupported() {
	  return typeof window !== 'undefined' && typeof ImageBitmap !== 'undefined' && window.hasOwnProperty('createImageBitmap');
	}
	function isNonEmptyPixels(pixels) {
	  return pixels != null && pixels.width !== 0 && pixels.height !== 0;
	}
	function canWrapPixelsToImageBitmap(pixels) {
	  return isImageBitmapFullySupported() && !(pixels instanceof ImageBitmap) && isNonEmptyPixels(pixels) && !isPixelData(pixels);
	}
	/**
	 * Creates a `tf.Tensor` from an image in async way.
	 *
	 * ```js
	 * const image = new ImageData(1, 1);
	 * image.data[0] = 100;
	 * image.data[1] = 150;
	 * image.data[2] = 200;
	 * image.data[3] = 255;
	 *
	 * (await tf.browser.fromPixelsAsync(image)).print();
	 * ```
	 * This API is the async version of fromPixels. The API will first
	 * check |WRAP_TO_IMAGEBITMAP| flag, and try to wrap the input to
	 * imageBitmap if the flag is set to true.
	 *
	 * @param pixels The input image to construct the tensor from. The
	 * supported image types are all 4-channel. You can also pass in an image
	 * object with following attributes:
	 * `{data: Uint8Array; width: number; height: number}`
	 * @param numChannels The number of channels of the output tensor. A
	 * numChannels value less than 4 allows you to ignore channels. Defaults to
	 * 3 (ignores alpha channel of input image).
	 *
	 * @doc {heading: 'Browser', namespace: 'browser', ignoreCI: true}
	 */
	function fromPixelsAsync(_x) {
	  return _fromPixelsAsync.apply(this, arguments);
	}
	function _fromPixelsAsync() {
	  _fromPixelsAsync = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(pixels) {
	    var numChannels,
	      inputs,
	      imageBitmap,
	      _args = arguments;
	    return _regeneratorRuntime().wrap(function _callee$(_context) {
	      while (1) switch (_context.prev = _context.next) {
	        case 0:
	          numChannels = _args.length > 1 && _args[1] !== undefined ? _args[1] : 3;
	          inputs = null; // Check whether the backend needs to wrap |pixels| to imageBitmap and
	          // whether |pixels| can be wrapped to imageBitmap.
	          if (!(env().getBool('WRAP_TO_IMAGEBITMAP') && canWrapPixelsToImageBitmap(pixels))) {
	            _context.next = 15;
	            break;
	          }
	          _context.prev = 3;
	          _context.next = 6;
	          return createImageBitmap(pixels, {
	            premultiplyAlpha: 'none'
	          });
	        case 6:
	          imageBitmap = _context.sent;
	          _context.next = 12;
	          break;
	        case 9:
	          _context.prev = 9;
	          _context.t0 = _context["catch"](3);
	          imageBitmap = null;
	        case 12:
	          // createImageBitmap will clip the source size.
	          // In some cases, the input will have larger size than its content.
	          // E.g. new Image(10, 10) but with 1 x 1 content. Using
	          // createImageBitmap will clip the size from 10 x 10 to 1 x 1, which
	          // is not correct. We should avoid wrapping such resouce to
	          // imageBitmap.
	          if (imageBitmap != null && imageBitmap.width === pixels.width && imageBitmap.height === pixels.height) {
	            inputs = imageBitmap;
	          } else {
	            inputs = pixels;
	          }
	          _context.next = 16;
	          break;
	        case 15:
	          inputs = pixels;
	        case 16:
	          return _context.abrupt("return", fromPixels_(inputs, numChannels));
	        case 17:
	        case "end":
	          return _context.stop();
	      }
	    }, _callee, null, [[3, 9]]);
	  }));
	  return _fromPixelsAsync.apply(this, arguments);
	}
	function validateImgTensor(img) {
	  if (img.rank !== 2 && img.rank !== 3) {
	    throw new Error("toPixels only supports rank 2 or 3 tensors, got rank ".concat(img.rank, "."));
	  }
	  var depth = img.rank === 2 ? 1 : img.shape[2];
	  if (depth > 4 || depth === 2) {
	    throw new Error("toPixels only supports depth of size " + "1, 3 or 4 but got ".concat(depth));
	  }
	  if (img.dtype !== 'float32' && img.dtype !== 'int32') {
	    throw new Error("Unsupported type for toPixels: ".concat(img.dtype, ".") + " Please use float32 or int32 tensors.");
	  }
	}
	function validateImageOptions(imageOptions) {
	  var alpha = (imageOptions === null || imageOptions === void 0 ? void 0 : imageOptions.alpha) || 1;
	  if (alpha > 1 || alpha < 0) {
	    throw new Error("Alpha value ".concat(alpha, " is suppoed to be in range [0 - 1]."));
	  }
	}
	/**
	 * Draws a `tf.Tensor` of pixel values to a byte array or optionally a
	 * canvas.
	 *
	 * When the dtype of the input is 'float32', we assume values in the range
	 * [0-1]. Otherwise, when input is 'int32', we assume values in the range
	 * [0-255].
	 *
	 * Returns a promise that resolves when the canvas has been drawn to.
	 *
	 * @param img A rank-2 tensor with shape `[height, width]`, or a rank-3 tensor
	 * of shape `[height, width, numChannels]`. If rank-2, draws grayscale. If
	 * rank-3, must have depth of 1, 3 or 4. When depth of 1, draws
	 * grayscale. When depth of 3, we draw with the first three components of
	 * the depth dimension corresponding to r, g, b and alpha = 1. When depth of
	 * 4, all four components of the depth dimension correspond to r, g, b, a.
	 * @param canvas The canvas to draw to.
	 *
	 * @doc {heading: 'Browser', namespace: 'browser'}
	 */
	function toPixels(_x2, _x3) {
	  return _toPixels.apply(this, arguments);
	}
	/**
	 * Draws a `tf.Tensor` to a canvas.
	 *
	 * When the dtype of the input is 'float32', we assume values in the range
	 * [0-1]. Otherwise, when input is 'int32', we assume values in the range
	 * [0-255].
	 *
	 * @param image The tensor to draw on the canvas. Must match one of
	 * these shapes:
	 *   - Rank-2 with shape `[height, width`]: Drawn as grayscale.
	 *   - Rank-3 with shape `[height, width, 1]`: Drawn as grayscale.
	 *   - Rank-3 with shape `[height, width, 3]`: Drawn as RGB with alpha set in
	 *     `imageOptions` (defaults to 1, which is opaque).
	 *   - Rank-3 with shape `[height, width, 4]`: Drawn as RGBA.
	 * @param canvas The canvas to draw to.
	 * @param options The configuration arguments for image to be drawn and the
	 *     canvas to draw to.
	 *
	 * @doc {heading: 'Browser', namespace: 'browser'}
	 */
	function _toPixels() {
	  _toPixels = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(img, canvas) {
	    var $img, originalImgTensor, _$img$shape$slice, _$img$shape$slice2, height, width, depth, data, multiplier, bytes, i, rgba, d, value, j, kernel, ctx, imageData;
	    return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	      while (1) switch (_context2.prev = _context2.next) {
	        case 0:
	          $img = convertToTensor(img, 'img', 'toPixels');
	          if (!(img instanceof Tensor)) {
	            // Assume int32 if user passed a native array.
	            originalImgTensor = $img;
	            $img = cast$3(originalImgTensor, 'int32');
	            originalImgTensor.dispose();
	          }
	          validateImgTensor($img);
	          _$img$shape$slice = $img.shape.slice(0, 2), _$img$shape$slice2 = _slicedToArray(_$img$shape$slice, 2), height = _$img$shape$slice2[0], width = _$img$shape$slice2[1];
	          depth = $img.rank === 2 ? 1 : $img.shape[2];
	          _context2.next = 7;
	          return $img.data();
	        case 7:
	          data = _context2.sent;
	          multiplier = $img.dtype === 'float32' ? 255 : 1;
	          bytes = new Uint8ClampedArray(width * height * 4);
	          i = 0;
	        case 11:
	          if (!(i < height * width)) {
	            _context2.next = 36;
	            break;
	          }
	          rgba = [0, 0, 0, 255];
	          d = 0;
	        case 14:
	          if (!(d < depth)) {
	            _context2.next = 28;
	            break;
	          }
	          value = data[i * depth + d];
	          if (!($img.dtype === 'float32')) {
	            _context2.next = 21;
	            break;
	          }
	          if (!(value < 0 || value > 1)) {
	            _context2.next = 19;
	            break;
	          }
	          throw new Error("Tensor values for a float32 Tensor must be in the " + "range [0 - 1] but encountered ".concat(value, "."));
	        case 19:
	          _context2.next = 24;
	          break;
	        case 21:
	          if (!($img.dtype === 'int32')) {
	            _context2.next = 24;
	            break;
	          }
	          if (!(value < 0 || value > 255)) {
	            _context2.next = 24;
	            break;
	          }
	          throw new Error("Tensor values for a int32 Tensor must be in the " + "range [0 - 255] but encountered ".concat(value, "."));
	        case 24:
	          if (depth === 1) {
	            rgba[0] = value * multiplier;
	            rgba[1] = value * multiplier;
	            rgba[2] = value * multiplier;
	          } else {
	            rgba[d] = value * multiplier;
	          }
	        case 25:
	          d++;
	          _context2.next = 14;
	          break;
	        case 28:
	          j = i * 4;
	          bytes[j + 0] = Math.round(rgba[0]);
	          bytes[j + 1] = Math.round(rgba[1]);
	          bytes[j + 2] = Math.round(rgba[2]);
	          bytes[j + 3] = Math.round(rgba[3]);
	        case 33:
	          ++i;
	          _context2.next = 11;
	          break;
	        case 36:
	          if (canvas != null) {
	            if (!hasToPixelsWarned) {
	              kernel = getKernel(Draw, ENGINE.backendName);
	              if (kernel != null) {
	                console.warn('tf.browser.toPixels is not efficient to draw tensor on canvas. ' + 'Please try tf.browser.draw instead.');
	                hasToPixelsWarned = true;
	              }
	            }
	            canvas.width = width;
	            canvas.height = height;
	            ctx = canvas.getContext('2d');
	            imageData = new ImageData(bytes, width, height);
	            ctx.putImageData(imageData, 0, 0);
	          }
	          if ($img !== img) {
	            $img.dispose();
	          }
	          return _context2.abrupt("return", bytes);
	        case 39:
	        case "end":
	          return _context2.stop();
	      }
	    }, _callee2);
	  }));
	  return _toPixels.apply(this, arguments);
	}
	function draw$1(image, canvas, options) {
	  var $img = convertToTensor(image, 'img', 'draw');
	  if (!(image instanceof Tensor)) {
	    // Assume int32 if user passed a native array.
	    var originalImgTensor = $img;
	    $img = cast$3(originalImgTensor, 'int32');
	    originalImgTensor.dispose();
	  }
	  validateImgTensor($img);
	  validateImageOptions(options === null || options === void 0 ? void 0 : options.imageOptions);
	  var inputs = {
	    image: $img
	  };
	  var attrs = {
	    canvas: canvas,
	    options: options
	  };
	  ENGINE.runKernel(Draw, inputs, attrs);
	}
	var fromPixels$1 = /* @__PURE__ */op({
	  fromPixels_: fromPixels_
	});

	var browser = {
		__proto__: null,
		draw: draw$1,
		fromPixels: fromPixels$1,
		fromPixelsAsync: fromPixelsAsync,
		toPixels: toPixels
	};

	/**
	 * Validate gather nd inputs.
	 *
	 * @param tensor The tensor contains the source values.
	 * @param indices The tensor contains the indices to slice the source.
	 *
	 * @returns [resultShape, numUpdates, sliceSize, strides]
	 */
	function prepareAndValidate(tensor, indices) {
	  var tensorRank = tensor.shape.length;
	  var indicesRank = indices.shape.length;
	  if (tensorRank < 1) {
	    throw new Error('tf.gatherND() expects the input to be rank 1 or higher,' + " but the rank was ".concat(tensorRank, "."));
	  }
	  if (indicesRank < 1) {
	    throw new Error('tf.gatherND() expects the indices to be rank 1 or higher,' + " but the rank was ".concat(indicesRank, "."));
	  }
	  if (indices.dtype !== 'int32') {
	    throw new Error('tf.gatherND() expects the indices to be int32 type,' + " but the dtype was ".concat(indices.dtype, "."));
	  }
	  if (indices.shape[indicesRank - 1] > tensorRank) {
	    throw new Error('index innermost dimension length must be <= tensor rank; saw: ' + "".concat(indices.shape[indicesRank - 1], " vs. ").concat(tensorRank));
	  }
	  if (sizeFromShape(tensor.shape) === 0) {
	    throw new Error('Requested more than 0 entries, but input is empty.' + " Input shape: ".concat(tensor.shape, "."));
	  }
	  var indicesShape = indices.shape;
	  var sliceRank = indicesShape[indicesShape.length - 1];
	  // The result shape is
	  //   indices.shape[:-1] + params.shape[indices.shape[-1]:]
	  var nResult = 1;
	  for (var i = 0; i < indicesShape.length - 1; ++i) {
	    nResult *= indicesShape[i];
	  }
	  var inputShape = tensor.shape;
	  var resultShape = indicesShape.slice();
	  resultShape.pop();
	  var sliceSize = 1;
	  for (var _i = sliceRank; _i < tensorRank; ++_i) {
	    sliceSize *= inputShape[_i];
	    resultShape.push(inputShape[_i]);
	  }
	  var strides = [].concat(_toConsumableArray(computeStrides(tensor.shape).map(function (stride) {
	    return stride / sliceSize;
	  })), [1]).slice(0, sliceRank);
	  return [resultShape, nResult, sliceSize, strides];
	}

	var gather_nd_util = {
		__proto__: null,
		prepareAndValidate: prepareAndValidate
	};

	var NEW_AXIS = -2;
	var SHRINK_AXIS = -1;
	function assertParamsValid(input, begin, size) {
	  var inputRank = input.shape.length;
	  assert$1(inputRank === begin.length, function () {
	    return "Error in slice".concat(inputRank, "D: Length of begin ").concat(begin, " must ") + "match the rank of the array (".concat(inputRank, ").");
	  });
	  assert$1(inputRank === size.length, function () {
	    return "Error in slice".concat(inputRank, "D: Length of size ").concat(size, " must ") + "match the rank of the array (".concat(inputRank, ").");
	  });
	  var _loop = function _loop(i) {
	    assert$1(begin[i] + size[i] <= input.shape[i], function () {
	      return "Error in slice".concat(inputRank, "D: begin[").concat(i, "] + size[").concat(i, "] ") + "(".concat(begin[i] + size[i], ") would overflow input.shape[").concat(i, "] (").concat(input.shape[i], ")");
	    });
	  };
	  for (var i = 0; i < inputRank; ++i) {
	    _loop(i);
	  }
	}
	/** Converts a binary mask to an array of axes. Used in stridedSlice(). */
	function maskToAxes(mask) {
	  var axes = [];
	  var axis = 0;
	  while (mask > 0) {
	    if (mask & 1) {
	      axes.push(axis);
	    }
	    mask /= 2;
	    axis++;
	  }
	  return axes;
	}
	/** Computes the output shape given the strided slice params. */
	function computeOutShape$2(begin, end, strides) {
	  var size = [];
	  for (var axis = 0; axis < begin.length; axis++) {
	    size[axis] = Math.ceil((end[axis] - begin[axis]) / strides[axis]);
	  }
	  return size;
	}
	// Creates full selection at the elided dimensions. If the dimension matches
	// the ellipsis mask, override the current stride value. Otherwise, insert.
	function stridesWithElidedDims(strides, ellipsisInsertionIndex, numElidedAxes, inputShape) {
	  var newStrides = _toConsumableArray(strides);
	  for (var i = newStrides.length; i < inputShape.length; i++) {
	    newStrides.push(1);
	  }
	  for (var _i = 0; _i < numElidedAxes; _i++) {
	    if (_i === 0) {
	      newStrides[ellipsisInsertionIndex] = 1;
	    } else {
	      newStrides.splice(ellipsisInsertionIndex, 0 /* num elements to delete */, 1 /* element to add */);
	      newStrides.pop();
	    }
	  }
	  return newStrides;
	}
	function unnormalizeAxis(ellipsisInsertionIndex, numElidedAxes, normalizedAxis) {
	  if (normalizedAxis <= ellipsisInsertionIndex) {
	    return normalizedAxis;
	  }
	  return normalizedAxis - (numElidedAxes - 1);
	}
	function getElidedAxes(numElidedAxes, ellipsisInsertionIndex) {
	  var elidedAxes = [];
	  for (var i = 0; i < numElidedAxes; i++) {
	    elidedAxes.push(ellipsisInsertionIndex + i);
	  }
	  return elidedAxes;
	}
	// Normalize the start, end and strides.
	function getNormalizedAxes(inputShape, ellipsisAxes, numInterpolatedAxes, begin, end, strides, beginMask, endMask, ellipsisMask) {
	  var inputRank = inputShape.length;
	  var normalizedBegin = new Array(inputRank),
	    normalizedEnd = new Array(inputRank),
	    normalizedStrides = new Array(inputRank);
	  if (ellipsisAxes.length && numInterpolatedAxes > 0) {
	    var fullIndex = ellipsisAxes[0];
	    // The ellipsis applies to the masked index as well as any dimensions
	    // that are interpolated.
	    var numElidedAxes = numInterpolatedAxes + 1;
	    normalizedBegin = startIndicesWithElidedDims(beginMask, fullIndex, numElidedAxes, begin, inputShape);
	    normalizedEnd = stopIndicesWithElidedDims(endMask, fullIndex, numElidedAxes, end, inputShape);
	    normalizedStrides = stridesWithElidedDims(strides, fullIndex, numElidedAxes, inputShape);
	  } else {
	    for (var axis = 0; axis < inputRank; axis++) {
	      normalizedBegin[axis] = startForAxis(beginMask, begin, strides, inputShape, axis, ellipsisMask);
	      normalizedEnd[axis] = stopForAxis(endMask, end, strides, inputShape, axis, ellipsisMask);
	      normalizedStrides[axis] = stridesForAxis(strides, axis, ellipsisMask);
	    }
	  }
	  return {
	    begin: normalizedBegin,
	    end: normalizedEnd,
	    strides: normalizedStrides
	  };
	}
	// Creates full selection at the elided dimensions. If the dimension matches
	// the ellipsis mask, override the current start value. Otherwise, insert.
	function startIndicesWithElidedDims(beginMask, ellipsisInsertionIndex, numElidedAxes, originalBegin, inputShape) {
	  var newIndices = _toConsumableArray(inputShape);
	  var elidedAxes = getElidedAxes(numElidedAxes, ellipsisInsertionIndex);
	  for (var axis = 0; axis < newIndices.length; axis++) {
	    if (elidedAxes.indexOf(axis) > -1) {
	      newIndices[axis] = 0;
	    } else {
	      var originalAxis = unnormalizeAxis(ellipsisInsertionIndex, numElidedAxes, axis);
	      var originalValue = originalBegin[originalAxis];
	      if (beginMask & 1 << originalAxis) {
	        originalValue = 0;
	      }
	      newIndices[axis] = originalValue;
	    }
	  }
	  return newIndices;
	}
	// Creates full selection at the elided dimensions. If the dimension matches
	// the ellipsis mask, override the current stop value. Otherwise, insert.
	function stopIndicesWithElidedDims(endMask, ellipsisInsertionIndex, numElidedAxes, originalEnd, inputShape) {
	  var newIndices = _toConsumableArray(inputShape);
	  var elidedAxes = getElidedAxes(numElidedAxes, ellipsisInsertionIndex);
	  for (var axis = 0; axis < newIndices.length; axis++) {
	    if (elidedAxes.indexOf(axis) > -1) {
	      newIndices[axis] = Number.MAX_SAFE_INTEGER;
	    } else {
	      var originalAxis = unnormalizeAxis(ellipsisInsertionIndex, numElidedAxes, axis);
	      var originalValue = originalEnd[originalAxis];
	      if (endMask & 1 << originalAxis) {
	        originalValue = Number.MAX_SAFE_INTEGER;
	      }
	      newIndices[axis] = originalValue;
	    }
	  }
	  for (var i = 0; i < newIndices.length; i++) {
	    // Handle negative indices
	    var axisSize = inputShape[i];
	    if (newIndices[i] < 0) {
	      newIndices[i] += axisSize;
	    }
	    newIndices[i] = clamp(0, newIndices[i], inputShape[i]);
	  }
	  return newIndices;
	}
	function stridesForAxis(strides, axis, ellipsisMask) {
	  var stride = strides[axis];
	  if (ellipsisMask & 1 << axis || stride == null) {
	    stride = 1;
	  }
	  return stride;
	}
	function startForAxis(beginMask, startIndices, strides, inputShape, axis, ellipsisMask) {
	  // Begin with the specified index
	  var start = startIndices[axis];
	  var stride = strides[axis] || 1;
	  // Check the axis bit from right of masked axes, or the begin index is not set
	  // for the axis.
	  if (beginMask & 1 << axis || ellipsisMask & 1 << axis || start == null) {
	    if (stride > 0) {
	      // Forward iteration - use the first element. These values will get
	      // clamped below (Note: We could have set them to 0 and axis_size-1, but
	      // use lowest() and max() to maintain symmetry with StopForAxis())
	      start = Number.MIN_SAFE_INTEGER;
	    } else {
	      // Backward iteration - use the last element.
	      start = Number.MAX_SAFE_INTEGER;
	    }
	  }
	  // Handle negative indices
	  var axisSize = inputShape[axis];
	  if (start < 0) {
	    start += axisSize;
	  }
	  // Clamping
	  start = clamp(0, start, axisSize - 1);
	  return start;
	}
	function stopForAxis(endMask, stopIndices, strides, inputShape, axis, ellipsisMask) {
	  // Begin with the specified index
	  var stop = stopIndices[axis];
	  var stride = strides[axis] || 1;
	  // Check the axis bit from right of masked axes, or if the stop index is not
	  // set for this axis.
	  if (endMask & 1 << axis || ellipsisMask & 1 << axis || stop == null) {
	    if (stride > 0) {
	      // Forward iteration - use the last element. These values will get
	      // clamped below
	      stop = Number.MAX_SAFE_INTEGER;
	    } else {
	      // Backward iteration - use the first element.
	      stop = Number.MIN_SAFE_INTEGER;
	    }
	  }
	  // Handle negative indices
	  var axisSize = inputShape[axis];
	  if (stop < 0) {
	    stop += axisSize;
	  }
	  // Clamping
	  // Because the end index points one past the last element, we need slightly
	  // different clamping ranges depending on the direction.
	  if (stride > 0) {
	    // Forward iteration
	    stop = clamp(0, stop, axisSize);
	  } else {
	    // Backward iteration
	    stop = clamp(-1, stop, axisSize - 1);
	  }
	  return stop;
	}
	/**
	 * Returns true if the slice occupies a continous set of elements in the
	 * 'flat' space.
	 */
	function isSliceContinous(shape, begin, size) {
	  // Index of the first axis that has size > 1.
	  var firstNonOneAxis = size.length;
	  for (var i = 0; i < size.length; i++) {
	    if (size[i] > 1) {
	      firstNonOneAxis = i;
	      break;
	    }
	  }
	  for (var _i2 = firstNonOneAxis + 1; _i2 < size.length; _i2++) {
	    if (begin[_i2] > 0 || size[_i2] !== shape[_i2]) {
	      return false;
	    }
	  }
	  return true;
	}
	function computeFlatOffset(begin, strides) {
	  var flatOffset = begin.length > 0 ? begin[begin.length - 1] : 1;
	  for (var i = 0; i < begin.length - 1; i++) {
	    flatOffset += begin[i] * strides[i];
	  }
	  return flatOffset;
	}
	function parseSliceParams(x, begin, size) {
	  // The following logic allows for more ergonomic calls.
	  var begin_;
	  var xRank = x.shape.length;
	  if (typeof begin === 'number') {
	    begin_ = [begin].concat(_toConsumableArray(new Array(xRank - 1).fill(0)));
	  } else if (begin.length < xRank) {
	    begin_ = begin.concat(new Array(xRank - begin.length).fill(0));
	  } else {
	    begin_ = begin.slice();
	  }
	  begin_.forEach(function (d) {
	    assert$1(d !== -1, function () {
	      return 'slice() does not support negative begin indexing.';
	    });
	  });
	  var size_;
	  if (size == null) {
	    size_ = new Array(xRank).fill(-1);
	  } else if (typeof size === 'number') {
	    size_ = [size].concat(_toConsumableArray(new Array(xRank - 1).fill(-1)));
	  } else if (size.length < xRank) {
	    size_ = size.concat(new Array(xRank - size.length).fill(-1));
	  } else {
	    size_ = size;
	  }
	  size_ = size_.map(function (d, i) {
	    if (d >= 0) {
	      return d;
	    } else {
	      assert$1(d === -1, function () {
	        return "Negative size values should be exactly -1 but got " + "".concat(d, " for the slice() size at index ").concat(i, ".");
	      });
	      return x.shape[i] - begin_[i];
	    }
	  });
	  return [begin_, size_];
	}
	// Convert the slicing specification from a sparse representation to a dense
	// representation. This means that all ellipses and newaxis are expanded out.
	function sliceInfo(xShape, begin, end, strides, beginMask, endMask, ellipsisMask, newAxisMask, shrinkAxisMask) {
	  var stridesNonNull;
	  if (strides == null) {
	    stridesNonNull = new Array(begin.length);
	    stridesNonNull.fill(1);
	  } else {
	    stridesNonNull = strides;
	  }
	  // Only one non-zero bit is allowed in ellipsisMask, which means ellipsisMask
	  // is a power of 2. Use bit compares to ensure ellipsisMask is 0 or a power
	  // of 2. When i is a power of 2, i & (i - 1) is always 0.
	  // Also ref:
	  // https://stackoverflow.com/questions/600293/how-to-check-if-a-number-is-a-power-of-2
	  if (ellipsisMask != null && (ellipsisMask & ellipsisMask - 1) !== 0) {
	    throw new Error('Multiple ellipses in slice is not allowed.');
	  }
	  // Step 1: Account for ellipsis and new axis.
	  // Check for ellipsis and count how many non-newaxis there are after.
	  var ellipsisSeen = false;
	  var sparseSpec = {
	    dims: stridesNonNull.length,
	    numAddAxisAfterEllipsis: 0,
	    begin: begin.slice(),
	    end: end.slice(),
	    strides: stridesNonNull.slice(),
	    beginMask: beginMask,
	    endMask: endMask,
	    ellipsisMask: ellipsisMask,
	    newAxisMask: newAxisMask,
	    shrinkAxisMask: shrinkAxisMask
	  };
	  for (var i = 0; i < sparseSpec.dims; i++) {
	    if (ellipsisSeen && (1 << i & newAxisMask) !== 0) {
	      sparseSpec.numAddAxisAfterEllipsis++;
	    }
	    if (1 << i & ellipsisMask) {
	      ellipsisSeen = true;
	    }
	  }
	  // If no ellipsis insert one at the end.
	  if (!ellipsisSeen) {
	    sparseSpec.ellipsisMask |= 1 << sparseSpec.dims;
	    sparseSpec.dims++; // this effects loop iteration below
	  }
	  // Step 2: Make a sparse spec into a full index spec.
	  //
	  // The sparse spec deos not correspond to the number of dimensions.
	  // Make a dense spec that cooresponds to the number of dimensions.
	  //
	  // For example suppose foo[...,3:] on foo.shape = [2, 2, 3] then we need to
	  // produce the missing beginMask for the first two dimensions i.e. from
	  // beginMaskSpec = 0, endMaskSpec = 2, we achieve beginMask = 6 (110),
	  // endMask = 7 (111).
	  var denseSpec = {
	    dims: xShape.length,
	    beginMask: 0,
	    endMask: 0,
	    beginValid: false,
	    endValid: false
	  };
	  buildDenseSpec(sparseSpec, denseSpec);
	  // Step 3: Make implicit ranges (non-zero beginMasks and endMasks) explicit
	  // and bounds check.
	  var isIdentity = true;
	  var sliceDim0 = true;
	  var isSimpleSlice = true;
	  var processingShape = [];
	  var finalShape = [];
	  for (var _i3 = 0; _i3 < xShape.length; ++_i3) {
	    if (denseSpec.strides[_i3] === 0) {
	      throw Error("strides[".concat(_i3, "] must be non-zero"));
	    }
	    var shrinkI = !!(denseSpec.shrinkAxisMask & 1 << _i3);
	    var dimI = xShape[_i3];
	    if (dimI === -1) {
	      processingShape.push(shrinkI ? 1 : -1);
	      continue;
	    }
	    var masks = [denseSpec.beginMask & 1 << _i3, denseSpec.endMask & 1 << _i3];
	    var validRange = [denseSpec.strides[_i3] > 0 ? 0 : -1, denseSpec.strides[_i3] > 0 ? dimI : dimI - 1];
	    if (shrinkI && denseSpec.strides[_i3] <= 0) {
	      throw Error('only stride 1 allowed on non-range indexing.');
	    }
	    isSimpleSlice = isSimpleSlice && denseSpec.strides[_i3] === 1;
	    var beginAndEndMasked = !!(denseSpec.beginMask & 1 << _i3 && denseSpec.endMask & 1 << _i3);
	    if (denseSpec.beginValid && denseSpec.endValid) {
	      if (shrinkI) {
	        // If we are shrinking, the end index is now possibly incorrect. In
	        // particular foo[-1] produces sparseBegin = -1, sparseEnd = 0.
	        // and canonical puts these to n-1 and 0, which implies a degenerate
	        // interval. Fortunately, it is now safe to re-create end as begin + 1.
	        var xFwd = denseSpec.begin[_i3] < 0 ? dimI + denseSpec.begin[_i3] : denseSpec.begin[_i3];
	        denseSpec.begin[_i3] = xFwd;
	        denseSpec.end[_i3] = denseSpec.begin[_i3] + 1;
	        if (xFwd < 0 || xFwd >= dimI) {
	          throw Error("slice index ".concat(denseSpec.begin[_i3], " of dimension ").concat(_i3, " out of bounds."));
	        }
	      } else {
	        denseSpec.begin[_i3] = canonical(denseSpec.begin[_i3], 0, denseSpec.strides[_i3], dimI, masks, validRange);
	        denseSpec.end[_i3] = canonical(denseSpec.end[_i3], 1, denseSpec.strides[_i3], dimI, masks, validRange);
	      }
	      // Update optimization values
	      var takeAllInDimension = denseSpec.strides[_i3] === 1 && denseSpec.begin[_i3] === 0 && denseSpec.end[_i3] === dimI;
	      isIdentity = isIdentity && takeAllInDimension;
	      sliceDim0 = sliceDim0 && (_i3 === 0 && denseSpec.strides[_i3] === 1 || takeAllInDimension);
	    } else {
	      isIdentity = isIdentity && denseSpec.strides[_i3] === 1 && beginAndEndMasked;
	      sliceDim0 = sliceDim0 && (_i3 === 0 && denseSpec.strides[_i3] === 1 || beginAndEndMasked);
	    }
	    // Compute the processing shape (the intermediate Eigen will produce)
	    var intervalLength = void 0;
	    var knownInterval = false;
	    if (denseSpec.beginValid && denseSpec.endValid) {
	      intervalLength = denseSpec.end[_i3] - denseSpec.begin[_i3];
	      knownInterval = true;
	    } else if (shrinkI) {
	      // The dimension is still known as 1 for the processingShape, but will be
	      // discarded for the final shape.
	      intervalLength = 1;
	      knownInterval = true;
	    } else if (beginAndEndMasked) {
	      // Even if we don't have values for begin or end, we do know that this
	      // dimension covers the whole interval. If we have shape information for
	      // this dimension, that tells us the interval length.
	      if (dimI >= 0) {
	        if (denseSpec.strides[_i3] < 0) {
	          intervalLength = -dimI;
	        } else {
	          intervalLength = dimI;
	        }
	        knownInterval = true;
	      }
	    }
	    if (knownInterval) {
	      var sizeI = void 0;
	      // Hold zero if the interval is degenerate, otherwise account for
	      // remainder
	      if (intervalLength === 0 || intervalLength < 0 !== denseSpec.strides[_i3] < 0) {
	        sizeI = 0;
	      } else {
	        sizeI = Math.trunc(intervalLength / denseSpec.strides[_i3]) + (intervalLength % denseSpec.strides[_i3] !== 0 ? 1 : 0);
	      }
	      processingShape.push(sizeI);
	    } else {
	      processingShape.push(-1);
	    }
	  }
	  // Step 4: Compute the final shape
	  //
	  // newAxis will increase dimension by 1 (with a one-size dimension)
	  // slices like foo[3, ...] will reduce dimension by 1.
	  // This cannot be done earlier, because it depends on Step 3.
	  for (var denseDim = 0; denseDim < denseSpec.finalShapeGatherIndices.length; ++denseDim) {
	    var gatherIndex = denseSpec.finalShapeGatherIndices[denseDim];
	    if (gatherIndex >= 0) {
	      finalShape.push(processingShape[gatherIndex]);
	    } else if (gatherIndex === NEW_AXIS) {
	      finalShape.push(1);
	    }
	  }
	  var finalShapeSparse = finalShape.filter(function (dim, i) {
	    return denseSpec.finalShapeGatherIndices[i] !== NEW_AXIS;
	  });
	  return {
	    finalShapeSparse: finalShapeSparse,
	    finalShape: finalShape,
	    isIdentity: isIdentity,
	    sliceDim0: sliceDim0,
	    isSimpleSlice: isSimpleSlice,
	    begin: denseSpec.begin,
	    end: denseSpec.end,
	    strides: denseSpec.strides
	  };
	}
	function buildDenseSpec(sparse, dense) {
	  dense.beginMask = 0;
	  dense.endMask = 0;
	  dense.shrinkAxisMask = 0;
	  var fullIndex = 0;
	  dense.beginValid = sparse.begin != null;
	  dense.endValid = sparse.end != null;
	  dense.begin = new Array(dense.dims);
	  dense.end = new Array(dense.dims);
	  dense.strides = new Array(dense.dims);
	  dense.finalShapeGatherIndices = [];
	  dense.finalShapeGatherIndicesSparse = [];
	  dense.inputShapeGatherIndicesSparse = new Array(dense.dims);
	  for (var i = 0; i < sparse.dims; i++) {
	    if (1 << i & sparse.ellipsisMask) {
	      // Only the bit that has ellipsis will fall in this condition.
	      // Expand the ellipsis into the appropriate indices
	      // Note: this only works because we guaranteed one ellipsis.
	      var nextIndex = Math.min(dense.dims - (sparse.dims - i) + 1 + sparse.numAddAxisAfterEllipsis, dense.dims);
	      for (; fullIndex < nextIndex; fullIndex++) {
	        // newAxis aren't real axis so you have to skip.
	        dense.begin[fullIndex] = 0;
	        dense.end[fullIndex] = 0;
	        dense.strides[fullIndex] = 1;
	        dense.beginMask |= 1 << fullIndex;
	        dense.endMask |= 1 << fullIndex;
	        dense.finalShapeGatherIndices.push(fullIndex);
	        dense.finalShapeGatherIndicesSparse.push(-1);
	        dense.inputShapeGatherIndicesSparse[fullIndex] = i;
	      }
	    } else if (1 << i & sparse.newAxisMask) {
	      // Only the bit that has newAxis will fall in this condition.
	      dense.finalShapeGatherIndices.push(NEW_AXIS);
	      dense.finalShapeGatherIndicesSparse.push(-1);
	    } else {
	      if (fullIndex === dense.begin.length) {
	        throw Error("Index out of range using input dim ".concat(fullIndex, "; input ") + "has only ".concat(dense.dims, " dims, ").concat(dense.begin.length, "."));
	      }
	      // Gather slicing spec into appropriate index.
	      if (sparse.begin != null) {
	        dense.begin[fullIndex] = sparse.begin[i];
	      }
	      if (sparse.end != null) {
	        dense.end[fullIndex] = sparse.end[i];
	      }
	      dense.strides[fullIndex] = sparse.strides[i];
	      if (sparse.beginMask & 1 << i) {
	        dense.beginMask |= 1 << fullIndex;
	      }
	      if (sparse.endMask & 1 << i) {
	        dense.endMask |= 1 << fullIndex;
	      }
	      // If shrink, record where to get the dimensionality from (i.e. newAxis)
	      // creates a fake 1 size dimension. Also remember shrink axis (now in
	      // dense form) so we can ignore dense.end below.
	      if (sparse.shrinkAxisMask & 1 << i) {
	        dense.finalShapeGatherIndices.push(SHRINK_AXIS);
	        dense.finalShapeGatherIndicesSparse.push(-1);
	        dense.shrinkAxisMask |= 1 << fullIndex;
	      } else {
	        dense.finalShapeGatherIndices.push(fullIndex);
	        // Remember that where in the sparse shape the dense dim comes from.
	        dense.finalShapeGatherIndicesSparse.push(i);
	      }
	      dense.inputShapeGatherIndicesSparse[fullIndex] = i;
	      fullIndex++;
	    }
	  }
	}
	function canonical(x, c, strideI, dimI, masks, validRange) {
	  if (masks[c]) {
	    return strideI > 0 ? validRange[c] : validRange[c + 1 & 1];
	  } else {
	    var xFwd = x < 0 ? dimI + x : x; // make negative indices positive
	    return xFwd < validRange[0] ? validRange[0] : xFwd > validRange[1] ? validRange[1] : xFwd;
	  }
	}

	var slice_util = {
		__proto__: null,
		assertParamsValid: assertParamsValid,
		computeFlatOffset: computeFlatOffset,
		computeOutShape: computeOutShape$2,
		getNormalizedAxes: getNormalizedAxes,
		isSliceContinous: isSliceContinous,
		maskToAxes: maskToAxes,
		parseSliceParams: parseSliceParams,
		sliceInfo: sliceInfo,
		startForAxis: startForAxis,
		startIndicesWithElidedDims: startIndicesWithElidedDims,
		stopForAxis: stopForAxis,
		stopIndicesWithElidedDims: stopIndicesWithElidedDims,
		stridesForAxis: stridesForAxis,
		stridesWithElidedDims: stridesWithElidedDims
	};

	/** @license See the LICENSE file. */
	// This code is auto-generated, do not modify this file!
	var version$7 = '4.22.0';

	var OptimizerConstructors = /*#__PURE__*/function () {
	  function OptimizerConstructors() {
	    _classCallCheck(this, OptimizerConstructors);
	  }
	  _createClass(OptimizerConstructors, null, [{
	    key: "sgd",
	    value:
	    /**
	     * Constructs a `tf.SGDOptimizer` that uses stochastic gradient descent.
	     *
	     * ```js
	     * // Fit a quadratic function by learning the coefficients a, b, c.
	     * const xs = tf.tensor1d([0, 1, 2, 3]);
	     * const ys = tf.tensor1d([1.1, 5.9, 16.8, 33.9]);
	     *
	     * const a = tf.scalar(Math.random()).variable();
	     * const b = tf.scalar(Math.random()).variable();
	     * const c = tf.scalar(Math.random()).variable();
	     *
	     * // y = a * x^2 + b * x + c.
	     * const f = x => a.mul(x.square()).add(b.mul(x)).add(c);
	     * const loss = (pred, label) => pred.sub(label).square().mean();
	     *
	     * const learningRate = 0.01;
	     * const optimizer = tf.train.sgd(learningRate);
	     *
	     * // Train the model.
	     * for (let i = 0; i < 10; i++) {
	     *   optimizer.minimize(() => loss(f(xs), ys));
	     * }
	     *
	     * // Make predictions.
	     * console.log(
	     *     `a: ${a.dataSync()}, b: ${b.dataSync()}, c: ${c.dataSync()}`);
	     * const preds = f(xs).dataSync();
	     * preds.forEach((pred, i) => {
	     *   console.log(`x: ${i}, pred: ${pred}`);
	     * });
	     * ```
	     *
	     * @param learningRate The learning rate to use for the SGD algorithm.
	     *
	     * @doc {heading: 'Training', subheading: 'Optimizers', namespace: 'train'}
	     */
	    function sgd(learningRate) {
	      return new SGDOptimizer(learningRate);
	    }
	    /**
	     * Constructs a `tf.MomentumOptimizer` that uses momentum gradient
	     * descent.
	     *
	     * See
	     * [http://proceedings.mlr.press/v28/sutskever13.pdf](
	     * http://proceedings.mlr.press/v28/sutskever13.pdf)
	     *
	     * @param learningRate The learning rate to use for the Momentum gradient
	     * descent algorithm.
	     * @param momentum The momentum to use for the momentum gradient descent
	     * algorithm.
	     *
	     * @doc {heading: 'Training', subheading: 'Optimizers', namespace: 'train'}
	     */
	  }, {
	    key: "momentum",
	    value: function momentum(learningRate, _momentum) {
	      var useNesterov = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	      return new MomentumOptimizer(learningRate, _momentum, useNesterov);
	    }
	    /**
	     * Constructs a `tf.RMSPropOptimizer` that uses RMSProp gradient
	     * descent. This implementation uses plain momentum and is not centered
	     * version of RMSProp.
	     *
	     * See
	     * [http://www.cs.toronto.edu/~tijmen/csc321/slides/lecture_slides_lec6.pdf](
	     * http://www.cs.toronto.edu/~tijmen/csc321/slides/lecture_slides_lec6.pdf)
	     *
	     * @param learningRate The learning rate to use for the RMSProp gradient
	     * descent algorithm.
	     * @param decay The discounting factor for the history/coming gradient.
	     * @param momentum The momentum to use for the RMSProp gradient descent
	     * algorithm.
	     * @param epsilon Small value to avoid zero denominator.
	     * @param centered If true, gradients are normalized by the estimated
	     * variance of the gradient.
	     *
	     * @doc {heading: 'Training', subheading: 'Optimizers', namespace: 'train'}
	     */
	  }, {
	    key: "rmsprop",
	    value: function rmsprop(learningRate) {
	      var decay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : .9;
	      var momentum = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0.0;
	      var epsilon = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;
	      var centered = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
	      return new RMSPropOptimizer(learningRate, decay, momentum, epsilon, centered);
	    }
	    /**
	     * Constructs a `tf.AdamOptimizer` that uses the Adam algorithm.
	     * See [https://arxiv.org/abs/1412.6980](https://arxiv.org/abs/1412.6980)
	     *
	     * @param learningRate The learning rate to use for the Adam gradient
	     * descent algorithm.
	     * @param beta1 The exponential decay rate for the 1st moment estimates.
	     * @param beta2 The exponential decay rate for the 2nd moment estimates.
	     * @param epsilon A small constant for numerical stability.
	     *
	     * @doc {heading: 'Training', subheading: 'Optimizers', namespace: 'train'}
	     */
	  }, {
	    key: "adam",
	    value: function adam() {
	      var learningRate = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0.001;
	      var beta1 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0.9;
	      var beta2 = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0.999;
	      var epsilon = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;
	      return new AdamOptimizer(learningRate, beta1, beta2, epsilon);
	    }
	    /**
	     * Constructs a `tf.AdadeltaOptimizer` that uses the Adadelta algorithm.
	     * See [https://arxiv.org/abs/1212.5701](https://arxiv.org/abs/1212.5701)
	     *
	     * @param learningRate The learning rate to use for the Adadelta gradient
	     * descent algorithm.
	     * @param rho The learning rate decay over each update.
	     * @param epsilon A constant epsilon used to better condition the grad
	     * update.
	     *
	     * @doc {heading: 'Training', subheading: 'Optimizers', namespace: 'train'}
	     */
	  }, {
	    key: "adadelta",
	    value: function adadelta() {
	      var learningRate = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : .001;
	      var rho = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : .95;
	      var epsilon = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
	      return new AdadeltaOptimizer(learningRate, rho, epsilon);
	    }
	    /**
	     * Constructs a `tf.AdamaxOptimizer` that uses the Adamax algorithm.
	     * See [https://arxiv.org/abs/1412.6980](https://arxiv.org/abs/1412.6980)
	     *
	     * @param learningRate The learning rate to use for the Adamax gradient
	     * descent algorithm.
	     * @param beta1 The exponential decay rate for the 1st moment estimates.
	     * @param beta2 The exponential decay rate for the 2nd moment estimates.
	     * @param epsilon A small constant for numerical stability.
	     * @param decay The learning rate decay over each update.
	     *
	     * @doc {heading: 'Training', subheading: 'Optimizers', namespace: 'train'}
	     */
	  }, {
	    key: "adamax",
	    value: function adamax() {
	      var learningRate = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0.002;
	      var beta1 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0.9;
	      var beta2 = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0.999;
	      var epsilon = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;
	      var decay = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 0.0;
	      return new AdamaxOptimizer(learningRate, beta1, beta2, epsilon, decay);
	    }
	    /**
	     * Constructs a `tf.AdagradOptimizer` that uses the Adagrad algorithm.
	     * See
	     * [http://www.jmlr.org/papers/volume12/duchi11a/duchi11a.pdf](
	     * http://www.jmlr.org/papers/volume12/duchi11a/duchi11a.pdf)
	     * or
	     * [http://ruder.io/optimizing-gradient-descent/index.html#adagrad](
	     * http://ruder.io/optimizing-gradient-descent/index.html#adagrad)
	     *
	     * @param learningRate The learning rate to use for the Adagrad gradient
	     * descent algorithm.
	     * @param initialAccumulatorValue Starting value for the accumulators, must be
	     * positive.
	     *
	     * @doc {heading: 'Training', subheading: 'Optimizers', namespace: 'train'}
	     */
	  }, {
	    key: "adagrad",
	    value: function adagrad(learningRate) {
	      var initialAccumulatorValue = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0.1;
	      return new AdagradOptimizer(learningRate, initialAccumulatorValue);
	    }
	  }]);
	  return OptimizerConstructors;
	}();

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var train = OptimizerConstructors;

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var delayCallback = function () {
	  if (typeof requestAnimationFrame !== 'undefined') {
	    return requestAnimationFrame;
	  } else if (typeof setImmediate !== 'undefined') {
	    return setImmediate;
	  }
	  return function (f) {
	    return f();
	  }; // no delays
	}();
	/**
	 * Returns a promise that resolves when a requestAnimationFrame has completed.
	 *
	 * On Node.js this uses setImmediate instead of requestAnimationFrame.
	 *
	 * This is simply a sugar method so that users can do the following:
	 * `await tf.nextFrame();`
	 *
	 * @doc {heading: 'Performance', subheading: 'Timing'}
	 */
	function nextFrame() {
	  return new Promise(function (resolve) {
	    return delayCallback(function () {
	      return resolve();
	    });
	  });
	}

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function assertParamsConsistent(shapes, axis) {
	  var rank = shapes[0].length;
	  shapes.forEach(function (shape, i) {
	    assert$1(shape.length === rank, function () {
	      return "Error in concat".concat(rank, "D: rank of tensors[").concat(i, "] must be the same ") + "as the rank of the rest (".concat(rank, ")");
	    });
	  });
	  assert$1(axis >= 0 && axis < rank, function () {
	    return "Error in concat".concat(rank, "D: axis must be between 0 and ").concat(rank - 1, ".");
	  });
	  var firstShape = shapes[0];
	  shapes.forEach(function (shape, i) {
	    for (var r = 0; r < rank; r++) {
	      assert$1(r === axis || shape[r] === firstShape[r], function () {
	        return "Error in concat".concat(rank, "D: Shape of tensors[").concat(i, "] (").concat(shape, ") ") + "does not match the shape of the rest (".concat(firstShape, ") ") + "along the non-concatenated axis ".concat(i, ".");
	      });
	    }
	  });
	}
	function computeOutShape$1(shapes, axis) {
	  var outputShape = shapes[0].slice();
	  for (var i = 1; i < shapes.length; i++) {
	    outputShape[axis] += shapes[i][axis];
	  }
	  return outputShape;
	}

	/**
	 * @license
	 * Copyright 2020 Google Inc. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var RowPartitionType$1;
	(function (RowPartitionType) {
	  RowPartitionType[RowPartitionType["FIRST_DIM_SIZE"] = 0] = "FIRST_DIM_SIZE";
	  RowPartitionType[RowPartitionType["VALUE_ROWIDS"] = 1] = "VALUE_ROWIDS";
	  RowPartitionType[RowPartitionType["ROW_LENGTHS"] = 2] = "ROW_LENGTHS";
	  RowPartitionType[RowPartitionType["ROW_SPLITS"] = 3] = "ROW_SPLITS";
	  RowPartitionType[RowPartitionType["ROW_LIMITS"] = 4] = "ROW_LIMITS";
	  RowPartitionType[RowPartitionType["ROW_STARTS"] = 5] = "ROW_STARTS";
	})(RowPartitionType$1 || (RowPartitionType$1 = {}));
	function combineRaggedTensorToTensorShapes(raggedRank, shape, valueShape) {
	  // Test for consistency of valueShape and shape specified.
	  // If shape is unspecified and valueShape is specified, then copy
	  // over the size from the valueShape dimension.
	  var outputShape = new Array();
	  if (valueShape == null && shape == null) {
	    return outputShape;
	  }
	  if (shape == null) {
	    // Here, value_shape must be of known size.
	    while (outputShape.length < raggedRank + valueShape.length) {
	      outputShape.push(-1);
	    }
	  } else {
	    outputShape = shape.slice();
	  }
	  if (valueShape == null) {
	    return outputShape;
	  }
	  // At this point, valueShape and output_shape have known ranks.
	  if (raggedRank + valueShape.length !== outputShape.length) {
	    throw new Error("rt input.shape and shape=".concat(shape, " are incompatible: rt input.rank = ").concat(raggedRank + valueShape.length, ", but shape.rank = ").concat(outputShape.length));
	  }
	  for (var i = 1; i < valueShape.length; ++i) {
	    var valueDim = valueShape[i];
	    var outputShapeDimIndex = outputShape[outputShape.length - valueShape.length + i];
	    var outputShapeDim = outputShape[outputShapeDimIndex];
	    if (valueDim >= 0) {
	      if (outputShapeDim >= 0) {
	        if (outputShapeDim !== valueDim) {
	          throw new Error("rt input.shape and shape=".concat(shape, " are incompatible: rt input.shape[").concat(i + raggedRank, "] = ").concat(valueDim, " but shape[").concat(i + raggedRank, "] = ").concat(outputShapeDim));
	        }
	      } else {
	        outputShape[outputShapeDimIndex] = valueDim;
	      }
	    }
	  }
	  return outputShape;
	}
	function getRowPartitionTypesHelper(rowPartitionTypeStrings) {
	  var stringToType = {
	    'FIRST_DIM_SIZE': RowPartitionType$1.FIRST_DIM_SIZE,
	    'VALUE_ROWIDS': RowPartitionType$1.VALUE_ROWIDS,
	    'ROW_LENGTHS': RowPartitionType$1.ROW_LENGTHS,
	    'ROW_SPLITS': RowPartitionType$1.ROW_SPLITS,
	    'ROW_LIMITS': RowPartitionType$1.ROW_LIMITS,
	    'ROW_STARTS': RowPartitionType$1.ROW_STARTS
	  };
	  var result = [];
	  var _iterator = _createForOfIteratorHelper(rowPartitionTypeStrings),
	    _step;
	  try {
	    for (_iterator.s(); !(_step = _iterator.n()).done;) {
	      var typeStr = _step.value;
	      if (typeStr in stringToType) {
	        result.push(stringToType[typeStr]);
	      } else {
	        break;
	      }
	    }
	  } catch (err) {
	    _iterator.e(err);
	  } finally {
	    _iterator.f();
	  }
	  return result;
	}
	function getRaggedRank(rowPartitionTypes) {
	  if (rowPartitionTypes.length === 0) {
	    return 0;
	  }
	  if (rowPartitionTypes[0] === RowPartitionType$1.FIRST_DIM_SIZE) {
	    return rowPartitionTypes.length - 1;
	  }
	  return rowPartitionTypes.length;
	}
	function validateDefaultValueShape(defaultValueShape, valueShape) {
	  if (defaultValueShape == null || valueShape == null) {
	    return;
	  }
	  var defaultNDims = defaultValueShape.length;
	  var valuesNDims = valueShape.length;
	  if (defaultNDims >= valuesNDims) {
	    throw new Error("defaultValue.shape=".concat(defaultValueShape, " and ragged tensor flatValues.shape=").concat(valueShape, ", are incompatible: defaultValue.rank = ").concat(defaultNDims, " must be less than ragged tensor input flatValues.rank = ").concat(valuesNDims, ")"));
	  }
	  for (var i = 0; i < Math.min(defaultNDims, valuesNDims - 1); ++i) {
	    var defaultDim = defaultValueShape[i];
	    var valueDim = valueShape[i + 1];
	    if (defaultDim >= 0 && valueDim >= 0 && defaultDim !== 1 && defaultDim !== valueDim) {
	      throw new Error("defaultValue.shape=".concat(defaultValueShape, ", and ragged tensor input flatValues.shape=").concat(valueShape, " are incompatible: defaultValue.shape[").concat(i - defaultValueShape.length, "] = ").concat(defaultDim, " but ragged tensor input.flatValues.shape[").concat(i - defaultValueShape.length, "] = ").concat(valueDim));
	    }
	  }
	}

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var PARALLELIZE_THRESHOLD = 30;
	function computeOptimalWindowSize(inSize) {
	  if (inSize <= PARALLELIZE_THRESHOLD) {
	    return inSize;
	  }
	  return nearestDivisor(inSize, Math.floor(Math.sqrt(inSize)));
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	// Returns the image center in pixels.
	function getImageCenter(center, imageHeight, imageWidth) {
	  var centerX = imageWidth * (typeof center === 'number' ? center : center[0]);
	  var centerY = imageHeight * (typeof center === 'number' ? center : center[1]);
	  return [centerX, centerY];
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Gets the new shape of the input Tensor after it's been reshaped
	 * to:
	 * [blockShape[0], ..., blockShape[M-1], batch / prod(blockShape),
	 * inputShape[1], ..., inputShape[N-1]]
	 *
	 * See step 1: https://www.tensorflow.org/api_docs/python/tf/batch_to_space_nd
	 */
	function getReshaped(inputShape, blockShape, prod) {
	  var batchToSpace = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : true;
	  var reshaped = [];
	  if (batchToSpace) {
	    reshaped = reshaped.concat(blockShape.slice(0));
	    reshaped.push(inputShape[0] / prod);
	    reshaped = reshaped.concat(inputShape.slice(1));
	  } else {
	    reshaped = reshaped.concat(inputShape[0]);
	    var spatialLength = blockShape.length;
	    for (var i = 0; i < spatialLength; ++i) {
	      reshaped = reshaped.concat([inputShape[i + 1] / blockShape[i], blockShape[i]]);
	    }
	    reshaped = reshaped.concat(inputShape.slice(spatialLength + 1));
	  }
	  return reshaped;
	}
	/**
	 * Gets the permutation that will transpose the dimensions of the
	 * reshaped tensor to shape:
	 *
	 * [batch / prod(block_shape),inputShape[1], blockShape[0], ...,
	 * inputShape[M], blockShape[M-1],inputShape[M+1], ..., inputShape[N-1]]
	 *
	 * see step 2: https://www.tensorflow.org/api_docs/python/tf/batch_to_space_nd
	 */
	function getPermuted(reshapedRank, blockShapeRank) {
	  var batchToSpace = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
	  var permuted = [];
	  if (batchToSpace) {
	    permuted.push(blockShapeRank);
	    for (var i = blockShapeRank + 1; i < reshapedRank; ++i) {
	      if (i <= 2 * blockShapeRank) {
	        permuted.push(i);
	        permuted.push(i - (blockShapeRank + 1));
	      } else {
	        permuted.push(i);
	      }
	    }
	  } else {
	    var permutedBeforeBatch = [];
	    var permutedAfterBatch = [];
	    for (var _i = 1; _i < reshapedRank; ++_i) {
	      if (_i >= blockShapeRank * 2 + 1 || _i % 2 === 1) {
	        permutedAfterBatch.push(_i);
	      } else {
	        permutedBeforeBatch.push(_i);
	      }
	    }
	    permuted.push.apply(permuted, permutedBeforeBatch);
	    permuted.push(0);
	    permuted.push.apply(permuted, permutedAfterBatch);
	  }
	  return permuted;
	}
	/**
	 * Gets the shape of the reshaped and permuted input Tensor before any cropping
	 * is applied.  The new shape will be:
	 *
	 * [batch / prod(blockShape),inputShape[1] * blockShape[0], ...,
	 * inputShape[M] * blockShape[M-1],inputShape[M+1], ..., inputShape[N-1]]
	 *
	 * See step 3: https://www.tensorflow.org/api_docs/python/tf/batch_to_space_nd
	 */
	function getReshapedPermuted(inputShape, blockShape, prod) {
	  var batchToSpace = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : true;
	  var reshapedPermuted = [];
	  if (batchToSpace) {
	    reshapedPermuted.push(inputShape[0] / prod);
	  } else {
	    reshapedPermuted.push(inputShape[0] * prod);
	  }
	  for (var i = 1; i < inputShape.length; ++i) {
	    if (i <= blockShape.length) {
	      if (batchToSpace) {
	        reshapedPermuted.push(blockShape[i - 1] * inputShape[i]);
	      } else {
	        reshapedPermuted.push(inputShape[i] / blockShape[i - 1]);
	      }
	    } else {
	      reshapedPermuted.push(inputShape[i]);
	    }
	  }
	  return reshapedPermuted;
	}
	/**
	 * Converts the crops argument into the beginning coordinates of a slice
	 * operation.
	 */
	function getSliceBeginCoords(crops, blockShape) {
	  var sliceBeginCoords = [0];
	  for (var i = 0; i < blockShape; ++i) {
	    sliceBeginCoords.push(crops[i][0]);
	  }
	  return sliceBeginCoords;
	}
	/**
	 * Converts the crops argument into the size of a slice operation.  When
	 * combined with getSliceBeginCoords this function allows the reshaped and
	 * permuted Tensor to be cropped to its final output shape of:
	 *
	 * inputShape[1] * blockShape[0] - crops[0,0] - crops[0,1], ...,
	 * inputShape[M] * blockShape[M-1] -crops[M-1,0] -
	 * crops[M-1,1],inputShape[M+1], ..., inputShape[N-1]]
	 *
	 * See step 4: https://www.tensorflow.org/api_docs/python/tf/batch_to_space_nd
	 */
	function getSliceSize(uncroppedShape, crops, blockShape) {
	  var sliceSize = uncroppedShape.slice(0, 1);
	  for (var i = 0; i < blockShape; ++i) {
	    sliceSize.push(uncroppedShape[i + 1] - crops[i][0] - crops[i][1]);
	  }
	  return sliceSize;
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var SELU_SCALEALPHA = 1.7580993408473768599402175208123;
	var SELU_SCALE = 1.0507009873554804934193349852946;

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ERF_P = 0.3275911;
	var ERF_A1 = 0.254829592;
	var ERF_A2 = -0.284496736;
	var ERF_A3 = 1.421413741;
	var ERF_A4 = -1.453152027;
	var ERF_A5 = 1.061405429;

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Merges real and imaginary Float32Arrays into a single complex Float32Array.
	 *
	 * The memory layout is interleaved as follows:
	 * real: [r0, r1, r2]
	 * imag: [i0, i1, i2]
	 * complex: [r0, i0, r1, i1, r2, i2]
	 *
	 * This is the inverse of splitRealAndImagArrays.
	 *
	 * @param real The real values of the complex tensor values.
	 * @param imag The imag values of the complex tensor values.
	 * @returns A complex tensor as a Float32Array with merged values.
	 */
	function mergeRealAndImagArrays(real, imag) {
	  if (real.length !== imag.length) {
	    throw new Error("Cannot merge real and imag arrays of different lengths. real:" + "".concat(real.length, ", imag: ").concat(imag.length, "."));
	  }
	  var result = new Float32Array(real.length * 2);
	  for (var i = 0; i < result.length; i += 2) {
	    result[i] = real[i / 2];
	    result[i + 1] = imag[i / 2];
	  }
	  return result;
	}
	/**
	 * Splits a complex Float32Array into real and imag parts.
	 *
	 * The memory layout is interleaved as follows:
	 * complex: [r0, i0, r1, i1, r2, i2]
	 * real: [r0, r1, r2]
	 * imag: [i0, i1, i2]
	 *
	 * This is the inverse of mergeRealAndImagArrays.
	 *
	 * @param complex The complex tensor values.
	 * @returns An object with real and imag Float32Array components of the complex
	 *     tensor.
	 */
	function splitRealAndImagArrays(complex) {
	  var real = new Float32Array(complex.length / 2);
	  var imag = new Float32Array(complex.length / 2);
	  for (var i = 0; i < complex.length; i += 2) {
	    real[i / 2] = complex[i];
	    imag[i / 2] = complex[i + 1];
	  }
	  return {
	    real: real,
	    imag: imag
	  };
	}
	/**
	 * Extracts even indexed complex values in the given array.
	 * @param complex The complex tensor values
	 */
	function complexWithEvenIndex(complex) {
	  var len = Math.ceil(complex.length / 4);
	  var real = new Float32Array(len);
	  var imag = new Float32Array(len);
	  for (var i = 0; i < complex.length; i += 4) {
	    real[Math.floor(i / 4)] = complex[i];
	    imag[Math.floor(i / 4)] = complex[i + 1];
	  }
	  return {
	    real: real,
	    imag: imag
	  };
	}
	/**
	 * Extracts odd indexed complete values in the given array.
	 * @param complex The complex tensor values
	 */
	function complexWithOddIndex(complex) {
	  var len = Math.floor(complex.length / 4);
	  var real = new Float32Array(len);
	  var imag = new Float32Array(len);
	  for (var i = 2; i < complex.length; i += 4) {
	    real[Math.floor(i / 4)] = complex[i];
	    imag[Math.floor(i / 4)] = complex[i + 1];
	  }
	  return {
	    real: real,
	    imag: imag
	  };
	}
	/**
	 * Get the map representing a complex value in the given array.
	 * @param complex The complex tensor values.
	 * @param index An index of the target complex value.
	 */
	function getComplexWithIndex(complex, index) {
	  var real = complex[index * 2];
	  var imag = complex[index * 2 + 1];
	  return {
	    real: real,
	    imag: imag
	  };
	}
	/**
	 * Insert a given complex value into the TypedArray.
	 * @param data The array in which the complex value is inserted.
	 * @param c The complex value to be inserted.
	 * @param index An index of the target complex value.
	 */
	function assignToTypedArray(data, real, imag, index) {
	  data[index * 2] = real;
	  data[index * 2 + 1] = imag;
	}
	/**
	 * Make the list of exponent terms used by FFT.
	 */
	function exponents(n, inverse) {
	  var real = new Float32Array(n / 2);
	  var imag = new Float32Array(n / 2);
	  for (var i = 0; i < Math.ceil(n / 2); i++) {
	    var x = (inverse ? 2 : -2) * Math.PI * (i / n);
	    real[i] = Math.cos(x);
	    imag[i] = Math.sin(x);
	  }
	  return {
	    real: real,
	    imag: imag
	  };
	}
	/**
	 * Make the exponent term used by FFT.
	 */
	function exponent(k, n, inverse) {
	  var x = (inverse ? 2 : -2) * Math.PI * (k / n);
	  var real = Math.cos(x);
	  var imag = Math.sin(x);
	  return {
	    real: real,
	    imag: imag
	  };
	}

	var ARROW = '->';
	var ARROW_REGEX = /->/g;
	var COMMA = ',';
	var ELLIPSIS = '...';
	/**
	 * Parse an equation for einsum.
	 *
	 * @param equation The einsum equation (e.g., "ij,jk->ik").
	 * @param numTensors Number of tensors provided along with `equation`. Used to
	 *   check matching number of input tensors.
	 * @returns An object consisting of the following fields:
	 *   - allDims: all dimension names as strings.
	 *   - summedDims: a list of all dimensions being summed over, as indices to
	 *     the elements of `allDims`.
	 *   - idDims: indices of the dimensions in each input tensor, as indices to
	 *     the elements of `allDims.
	 */
	function decodeEinsumEquation(equation, numTensors) {
	  equation = equation.replace(/\s/g, ''); // Remove witespace in equation.
	  var numArrows = (equation.length - equation.replace(ARROW_REGEX, '').length) / ARROW.length;
	  if (numArrows < 1) {
	    throw new Error('Equations without an arrow are not supported.');
	  } else if (numArrows > 1) {
	    throw new Error("Equation must contain exactly one arrow (\"".concat(ARROW, "\")."));
	  }
	  var _equation$split = equation.split(ARROW),
	    _equation$split2 = _slicedToArray(_equation$split, 2),
	    inputString = _equation$split2[0],
	    outputString = _equation$split2[1];
	  assert$1(inputString.indexOf(ELLIPSIS) === -1, function () {
	    return "The ellipsis notation (\"".concat(ELLIPSIS, "\") is not supported yet.");
	  });
	  var inputTerms = inputString.split(COMMA);
	  var numInputs = inputTerms.length;
	  if (numTensors !== numInputs) {
	    throw new Error("Expected ".concat(numInputs, " input tensors, received ").concat(numTensors));
	  }
	  if (numInputs > 2) {
	    throw new Error('Support for more than 2 input tensors is not implemented yet.');
	  }
	  var allDims = [];
	  var _loop = function _loop() {
	    var dimName = outputString[i];
	    if (!inputTerms.some(function (inputTerm) {
	      return inputTerm.indexOf(dimName) !== -1;
	    })) {
	      throw new Error("Output subscripts contain the label ".concat(dimName, " ") + "not present in the input subscripts.");
	    }
	    if (allDims.indexOf(dimName) === -1) {
	      allDims.push(dimName);
	    }
	  };
	  for (var i = 0; i < outputString.length; ++i) {
	    _loop();
	  }
	  for (var _i = 0; _i < inputString.length; ++_i) {
	    var dimName = inputString[_i];
	    if (allDims.indexOf(dimName) === -1 && dimName !== COMMA) {
	      allDims.push(dimName);
	    }
	  }
	  var idDims = new Array(inputTerms.length);
	  for (var _i2 = 0; _i2 < numInputs; ++_i2) {
	    if (new Set(inputTerms[_i2].split('')).size !== inputTerms[_i2].length) {
	      throw new Error("Found duplicate axes in input component ".concat(inputTerms[_i2], ". ") + "Support for duplicate axes in input is not implemented yet.");
	    }
	    idDims[_i2] = [];
	    for (var j = 0; j < inputTerms[_i2].length; ++j) {
	      idDims[_i2].push(allDims.indexOf(inputTerms[_i2][j]));
	    }
	  }
	  var numDims = allDims.length; // Number of unique dimensions.
	  var numOutDims = outputString.length; // Number of output dimensions.
	  var summedDims = []; // Dimensions being summed over.
	  for (var _i3 = numOutDims; _i3 < numDims; ++_i3) {
	    summedDims.push(_i3);
	  }
	  return {
	    allDims: allDims,
	    summedDims: summedDims,
	    idDims: idDims
	  };
	}
	/**
	 * Get the permutation for a given input tensor.
	 *
	 * @param nDims Total number of dimension of all tensors involved in the einsum
	 *   operation.
	 * @param idDims Dimension indices involve in the tensor in question.
	 * @returns An object consisting of the following fields:
	 *   - permutationIndices: Indices to permute the axes of the tensor with.
	 *   - expandDims: Indices to the dimension that need to be expanded from the
	 *     tensor after permutation.
	 */
	function getEinsumPermutation(nDims, idDims) {
	  var permutationIndices = new Array(nDims);
	  permutationIndices.fill(-1);
	  for (var i = 0; i < idDims.length; ++i) {
	    permutationIndices[idDims[i]] = i;
	  }
	  var expandDims = [];
	  for (var _i4 = 0; _i4 < nDims; ++_i4) {
	    if (permutationIndices[_i4] === -1) {
	      expandDims.push(_i4);
	    }
	  }
	  permutationIndices = permutationIndices.filter(function (d) {
	    return d !== -1;
	  });
	  return {
	    permutationIndices: permutationIndices,
	    expandDims: expandDims
	  };
	}
	/**
	 * Checks that the dimension sizes from different input tensors match the
	 * equation.
	 */
	function checkEinsumDimSizes(nDims, idDims, tensors) {
	  var dimSizes = new Array(nDims);
	  var _loop2 = function _loop2(i) {
	    var shape = tensors[i].shape;
	    var _loop3 = function _loop3(j) {
	      if (dimSizes[idDims[i][j]] === undefined) {
	        dimSizes[idDims[i][j]] = shape[j];
	      } else {
	        assert$1(dimSizes[idDims[i][j]] === shape[j], function () {
	          return "Expected dimension ".concat(dimSizes[idDims[i][j]], " at axis ").concat(j, " ") + "of input shaped ".concat(JSON.stringify(shape), ", ") + "but got dimension ".concat(shape[j]);
	        });
	      }
	    };
	    for (var j = 0; j < idDims[i].length; ++j) {
	      _loop3(j);
	    }
	  };
	  for (var i = 0; i < tensors.length; ++i) {
	    _loop2(i);
	  }
	}
	/**
	 * Gets path of computation for einsum.
	 *
	 * @param summedDims indices to the dimensions being summed over.
	 * @param idDims A look up table for the dimensions present in each input
	 *     tensor.Each constituent array contains indices for the dimensions in the
	 *     corresponding input tensor.
	 *
	 * @return A map with two fields:
	 *   - path: The path of computation, with each element indicating the dimension
	 *     being summed over after the element-wise multiplication in that step.
	 *   - steps: With the same length as `path`. Each element contains the indices
	 *     to the input tensors being used for element-wise multiplication in the
	 *     corresponding step.
	 */
	function getEinsumComputePath(summedDims, idDims) {
	  var path = summedDims;
	  var steps = [];
	  var nSteps = 0;
	  if (summedDims.length === 0) {
	    // Einsum that involes no summing: e.g., transpose and outer product.
	    path.push(-1);
	  }
	  nSteps = summedDims.length + 1;
	  for (var i = 0; i < nSteps; ++i) {
	    steps.push([]);
	  }
	  var computedTermIndices = [];
	  for (var _i5 = 0; _i5 < path.length; ++_i5) {
	    var summedDim = path[_i5];
	    var termIndices = findTermsWithDim(idDims, summedDim);
	    var _iterator = _createForOfIteratorHelper(termIndices),
	      _step;
	    try {
	      for (_iterator.s(); !(_step = _iterator.n()).done;) {
	        var termIndex = _step.value;
	        if (computedTermIndices.indexOf(termIndex) === -1) {
	          steps[_i5].push(termIndex);
	          computedTermIndices.push(termIndex);
	        }
	      }
	    } catch (err) {
	      _iterator.e(err);
	    } finally {
	      _iterator.f();
	    }
	  }
	  return {
	    path: path,
	    steps: steps
	  };
	}
	/** Determines if an axes permutation is the identity permutation. */
	function isIdentityPermutation(perm) {
	  return perm.every(function (dim, index) {
	    return dim === index;
	  });
	}
	function findTermsWithDim(idDims, dim) {
	  var termIndices = [];
	  for (var i = 0; i < idDims.length; ++i) {
	    if (idDims[i].length === 0 || idDims[i].indexOf(dim) !== -1 || dim === -1) {
	      termIndices.push(i);
	    }
	  }
	  return termIndices;
	}

	/**
	 * Prepare the split size array. When the input is a number, the axis is evenly
	 * divided among the split size. When the input contains the negative value, the
	 * rest of the axis is allocated toward that.
	 */
	function prepareSplitSize(x, numOrSizeSplits) {
	  var axis = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
	  var splitSizes = [];
	  if (typeof numOrSizeSplits === 'number') {
	    assert$1(x.shape[axis] % numOrSizeSplits === 0, function () {
	      return 'Number of splits must evenly divide the axis.';
	    });
	    splitSizes = new Array(numOrSizeSplits).fill(x.shape[axis] / numOrSizeSplits);
	  } else {
	    var numOfNegs = numOrSizeSplits.reduce(function (count, value) {
	      if (value === -1) {
	        count += 1;
	      }
	      return count;
	    }, 0);
	    assert$1(numOfNegs <= 1, function () {
	      return 'There should be only one negative value in split array.';
	    });
	    var negIndex = numOrSizeSplits.indexOf(-1);
	    // Allow the number of split array to be -1, which indicates the rest
	    // of dimension is allocated to that split.
	    if (negIndex !== -1) {
	      var total = numOrSizeSplits.reduce(function (a, b) {
	        return b > 0 ? a + b : a;
	      });
	      numOrSizeSplits[negIndex] = x.shape[axis] - total;
	    }
	    assert$1(x.shape[axis] === numOrSizeSplits.reduce(function (a, b) {
	      return a + b;
	    }), function () {
	      return 'The sum of sizes must match the size of the axis dimension.';
	    });
	    splitSizes = numOrSizeSplits;
	  }
	  return splitSizes;
	}

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Generates sparse fill empty rows indices, dense shape mismatch error message.
	 *
	 * @param indicesLength The first dimension of indices.
	 */
	function getSparseFillEmptyRowsIndicesDenseShapeMismatch(indicesLength) {
	  return "Received SparseTensor with denseShape[0] = 0 but\n  indices.shape[0] = ".concat(indicesLength);
	}
	/**
	 * Generates sparse fill empty rows negative index error message.
	 *
	 * @param index The index with a negative value.
	 * @param value The negative value.
	 */
	function getSparseFillEmptyRowsNegativeIndexErrorMessage(index, value) {
	  return "indices(".concat(index, ", 0) is invalid: ").concat(value, " < 0");
	}
	/**
	 * Generates sparse fill empty rows out of range index error message.
	 *
	 * @param index The index with an out of range value.
	 * @param value The out of range value.
	 * @param limit The upper limit for indices.
	 */
	function getSparseFillEmptyRowsOutOfRangeIndexErrorMessage(index, value, limit) {
	  return "indices(".concat(index, ", 0) is invalid: ").concat(value, " >= ").concat(limit);
	}

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Generates sparse reshape multiple negative 1 output dimension error message.
	 *
	 * @param dim1 The first dimension with a negative 1 value.
	 * @param dim2 The second dimension with a negative 1 value.
	 */
	function getSparseReshapeMultipleNegativeOneOutputDimErrorMessage(dim1, dim2) {
	  return "only one output dimension may be -1, not both ".concat(dim1, " and ").concat(dim2);
	}
	/**
	 * Generates sparse reshape negative output dimension error message.
	 *
	 * @param dim The dimension with a negative value.
	 * @param value The negative value.
	 */
	function getSparseReshapeNegativeOutputDimErrorMessage(dim, value) {
	  return "size ".concat(dim, " must be non-negative, not ").concat(value);
	}
	/**
	 * Generates sparse reshape empty tensor zero output dimension error message.
	 *
	 */
	function getSparseReshapeEmptyTensorZeroOutputDimErrorMessage() {
	  return 'reshape cannot infer the missing input size for an empty tensor ' + 'unless all specified input sizes are non-zero';
	}
	/**
	 * Generates sparse reshape input output multiple mismatch error message.
	 *
	 * @param inputShape the input shape.
	 * @param outputShape the requested output shape.
	 */
	function getSparseReshapeInputOutputMultipleErrorMessage(inputShape, outputShape) {
	  var inputSize = sizeFromShape(inputShape);
	  var outputSize = sizeFromShape(outputShape);
	  return "Input to reshape is a SparseTensor with ".concat(inputSize, "\n  dense values, but the requested shape requires a multiple of ").concat(outputSize, ". inputShape=").concat(inputShape, " outputShape= ").concat(outputShape);
	}
	/**
	 * Generates sparse reshape input output inequality error message.
	 *
	 * @param inputShape the input shape.
	 * @param outputShape the requested output shape.
	 */
	function getSparseReshapeInputOutputMismatchErrorMessage(inputShape, outputShape) {
	  var inputSize = sizeFromShape(inputShape);
	  var outputSize = sizeFromShape(outputShape);
	  return "Input to reshape is a tensor with ".concat(inputSize, " dense values, but the requested shape has ").concat(outputSize, ". inputShape=").concat(inputShape, " outputShape=").concat(outputShape);
	}

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Generates sparse segment reduction negative segment ids error message.
	 *
	 */
	function getSparseSegmentReductionNegativeSegmentIdsErrorMessage() {
	  return "segment ids must be >= 0";
	}
	/**
	 * Generates sparse segment reduction non increasing segment ids error message.
	 *
	 */
	function getSparseSegmentReductionNonIncreasingSegmentIdsErrorMessage() {
	  return "segment ids are not increasing";
	}
	/**
	 * Generates sparse segment reduction segment id out of range error message.
	 *
	 * @param segmentId The segment id index that is out of range.
	 * @param outputRows Upper bound of valid segment id values.
	 */
	function getSparseSegmentReductionSegmentIdOutOfRangeErrorMessage(segmentId, outputRows) {
	  return "Segment id ".concat(segmentId, " out of range [0, ").concat(outputRows, "), possibly because segmentIds input is not sorted.");
	}
	/**
	 * Generates sparse segment reduction input indice out of range error message.
	 *
	 * @param index The index that holds the out of range value.
	 * @param indexValue The value that is out of range.
	 * @param inputRows Upper bound of valid index values.
	 */
	function getSparseSegmentReductionIndicesOutOfRangeErrorMessage(index, indexValue, inputRows) {
	  return "Bad: indices[".concat(index, "] == ").concat(indexValue, " out of range [0, ").concat(inputRows, ")");
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function segOpComputeOptimalWindowSize(inSize, numSegments) {
	  var done = false;
	  var res;
	  if (inSize <= PARALLELIZE_THRESHOLD) {
	    res = inSize;
	    done = true;
	  } else {
	    res = nearestDivisor(inSize, Math.floor(Math.sqrt(inSize)));
	  }
	  while (!done) {
	    if (res > numSegments || res === inSize) {
	      done = true;
	    } else {
	      res = nearestDivisor(inSize, res + 1);
	    }
	  }
	  return res;
	}
	function computeOutShape(aShape, axis, numSegments) {
	  var outShape = [];
	  var rank = aShape.length;
	  for (var dim = 0; dim < rank; dim++) {
	    if (dim !== axis) {
	      outShape.push(aShape[dim]);
	    } else {
	      outShape.push(numSegments);
	    }
	  }
	  return outShape;
	}
	function collectGatherOpShapeInfo(x, indices, axis, batchDims) {
	  var indicesRank = indices.shape.length;
	  var xRank = x.shape.length;
	  if (batchDims !== 0) {
	    if (batchDims < -indicesRank || batchDims > indicesRank) {
	      throw new Error("Expect batchDims in the range of [-".concat(indicesRank, ", ").concat(indicesRank, "], but got ").concat(batchDims));
	    }
	  }
	  if (batchDims < 0) {
	    batchDims += indicesRank;
	  }
	  if (batchDims > xRank) {
	    throw new Error("batchDims (".concat(batchDims, ") must be less than rank(x) (\n    ").concat(xRank, ")."));
	  }
	  if (axis < batchDims) {
	    throw new Error("batchDims (".concat(batchDims, ") must be less than or equal to axis (").concat(axis, ")."));
	  }
	  for (var i = 0; i < batchDims; ++i) {
	    if (x.shape[i] !== indices.shape[i]) {
	      throw new Error("x.shape[".concat(i, "]: ").concat(x.shape[i], " should be equal to indices.shape[").concat(i, "]: ").concat(indices.shape[i], "."));
	    }
	  }
	  var dimSize = x.shape[axis];
	  var outputShape = [];
	  var batchSize = 1;
	  var outerSize = 1;
	  var sliceSize = 1;
	  for (var _i = 0; _i < batchDims; ++_i) {
	    outputShape.push(x.shape[_i]);
	    batchSize *= x.shape[_i];
	  }
	  for (var _i2 = batchDims; _i2 < axis; _i2++) {
	    outputShape.push(x.shape[_i2]);
	    outerSize *= x.shape[_i2];
	  }
	  for (var _i3 = batchDims; _i3 < indicesRank; _i3++) {
	    outputShape.push(indices.shape[_i3]);
	  }
	  for (var _i4 = axis + 1; _i4 < xRank; _i4++) {
	    outputShape.push(x.shape[_i4]);
	    sliceSize *= x.shape[_i4];
	  }
	  return {
	    batchSize: batchSize,
	    sliceSize: sliceSize,
	    outerSize: outerSize,
	    dimSize: dimSize,
	    outputShape: outputShape
	  };
	}

	var segment_util = {
		__proto__: null,
		collectGatherOpShapeInfo: collectGatherOpShapeInfo,
		computeOutShape: computeOutShape,
		segOpComputeOptimalWindowSize: segOpComputeOptimalWindowSize
	};

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function fromUint8ToStringArray(vals) {
	  try {
	    // Decode the bytes into string.
	    return vals.map(function (val) {
	      return decodeString(val);
	    });
	  } catch (err) {
	    throw new Error("Failed to decode encoded string bytes into utf-8, error: ".concat(err));
	  }
	}
	function fromStringArrayToUint8(strings) {
	  return strings.map(function (s) {
	    return encodeString(s);
	  });
	}

	var backend_util = {
		__proto__: null,
		ERF_A1: ERF_A1,
		ERF_A2: ERF_A2,
		ERF_A3: ERF_A3,
		ERF_A4: ERF_A4,
		ERF_A5: ERF_A5,
		ERF_P: ERF_P,
		PARALLELIZE_THRESHOLD: PARALLELIZE_THRESHOLD,
		get RowPartitionType () { return RowPartitionType$1; },
		SELU_SCALE: SELU_SCALE,
		SELU_SCALEALPHA: SELU_SCALEALPHA,
		applyActivation: applyActivation$1,
		assertAndGetBroadcastShape: assertAndGetBroadcastShape,
		assertAxesAreInnerMostDims: assertAxesAreInnerMostDims,
		assertParamsConsistent: assertParamsConsistent,
		assignToTypedArray: assignToTypedArray,
		axesAreInnerMostDims: axesAreInnerMostDims,
		calculateShapes: calculateShapes,
		checkEinsumDimSizes: checkEinsumDimSizes,
		checkPadOnDimRoundingMode: checkPadOnDimRoundingMode,
		combineLocations: combineLocations,
		combineRaggedTensorToTensorShapes: combineRaggedTensorToTensorShapes,
		complexWithEvenIndex: complexWithEvenIndex,
		complexWithOddIndex: complexWithOddIndex,
		computeConv2DInfo: computeConv2DInfo,
		computeConv3DInfo: computeConv3DInfo,
		computeDefaultPad: computeDefaultPad,
		computeDilation2DInfo: computeDilation2DInfo,
		computeOptimalWindowSize: computeOptimalWindowSize,
		computeOutAndReduceShapes: computeOutAndReduceShapes,
		computeOutShape: computeOutShape$1,
		computePool2DInfo: computePool2DInfo,
		computePool3DInfo: computePool3DInfo,
		convertConv2DDataFormat: convertConv2DDataFormat,
		decodeEinsumEquation: decodeEinsumEquation,
		eitherStridesOrDilationsAreOne: eitherStridesOrDilationsAreOne,
		expandShapeToKeepDim: expandShapeToKeepDim,
		exponent: exponent,
		exponents: exponents,
		fromStringArrayToUint8: fromStringArrayToUint8,
		fromUint8ToStringArray: fromUint8ToStringArray,
		getAxesPermutation: getAxesPermutation,
		getBroadcastDims: getBroadcastDims$1,
		getComplexWithIndex: getComplexWithIndex,
		getEinsumComputePath: getEinsumComputePath,
		getEinsumPermutation: getEinsumPermutation,
		getFusedBiasGradient: getFusedBiasGradient,
		getFusedDyActivation: getFusedDyActivation,
		getImageCenter: getImageCenter,
		getInnerMostAxes: getInnerMostAxes,
		getPermuted: getPermuted,
		getRaggedRank: getRaggedRank,
		getReductionAxes: getReductionAxes,
		getReshaped: getReshaped,
		getReshapedPermuted: getReshapedPermuted,
		getRowPartitionTypesHelper: getRowPartitionTypesHelper,
		getSliceBeginCoords: getSliceBeginCoords,
		getSliceSize: getSliceSize,
		getSparseFillEmptyRowsIndicesDenseShapeMismatch: getSparseFillEmptyRowsIndicesDenseShapeMismatch,
		getSparseFillEmptyRowsNegativeIndexErrorMessage: getSparseFillEmptyRowsNegativeIndexErrorMessage,
		getSparseFillEmptyRowsOutOfRangeIndexErrorMessage: getSparseFillEmptyRowsOutOfRangeIndexErrorMessage,
		getSparseReshapeEmptyTensorZeroOutputDimErrorMessage: getSparseReshapeEmptyTensorZeroOutputDimErrorMessage,
		getSparseReshapeInputOutputMismatchErrorMessage: getSparseReshapeInputOutputMismatchErrorMessage,
		getSparseReshapeInputOutputMultipleErrorMessage: getSparseReshapeInputOutputMultipleErrorMessage,
		getSparseReshapeMultipleNegativeOneOutputDimErrorMessage: getSparseReshapeMultipleNegativeOneOutputDimErrorMessage,
		getSparseReshapeNegativeOutputDimErrorMessage: getSparseReshapeNegativeOutputDimErrorMessage,
		getSparseSegmentReductionIndicesOutOfRangeErrorMessage: getSparseSegmentReductionIndicesOutOfRangeErrorMessage,
		getSparseSegmentReductionNegativeSegmentIdsErrorMessage: getSparseSegmentReductionNegativeSegmentIdsErrorMessage,
		getSparseSegmentReductionNonIncreasingSegmentIdsErrorMessage: getSparseSegmentReductionNonIncreasingSegmentIdsErrorMessage,
		getSparseSegmentReductionSegmentIdOutOfRangeErrorMessage: getSparseSegmentReductionSegmentIdOutOfRangeErrorMessage,
		getUndoAxesPermutation: getUndoAxesPermutation,
		isIdentityPermutation: isIdentityPermutation,
		log: log$3,
		mergeRealAndImagArrays: mergeRealAndImagArrays,
		prepareAndValidate: prepareAndValidate,
		prepareSplitSize: prepareSplitSize,
		segment_util: segment_util,
		shouldFuse: shouldFuse,
		slice_util: slice_util,
		splitRealAndImagArrays: splitRealAndImagArrays,
		stridesOrDilationsArePositive: stridesOrDilationsArePositive,
		tupleValuesAreOne: tupleValuesAreOne,
		upcastType: upcastType,
		validateDefaultValueShape: validateDefaultValueShape,
		validateInput: validateInput$1,
		validateUpdateShape: validateUpdateShape,
		warn: warn
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */

	var kernel_impls = {
		__proto__: null,
		nonMaxSuppressionV3Impl: nonMaxSuppressionV3Impl$2,
		nonMaxSuppressionV4Impl: nonMaxSuppressionV4Impl$2,
		nonMaxSuppressionV5Impl: nonMaxSuppressionV5Impl$2,
		whereImpl: whereImpl$2
	};

	/**
	 * @license
	 * Copyright 2020 Google Inc. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	registerOptimizers();

	var absGradConfig = {
	  kernelName: Abs,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return mul(dy, step$2(cast$3(_x, 'float32'), -1));
	      }
	    };
	  }
	};

	var acosGradConfig = {
	  kernelName: Acos,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        var a = square$2(cast$3(_x, 'float32'));
	        var b = sqrt$2(sub$2(scalar(1), a));
	        return neg$2(div$1(dy, b));
	      }
	    };
	  }
	};

	var acoshGradConfig = {
	  kernelName: Acosh,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        var a = sqrt$2(sub$2(square$2(cast$3(_x, 'float32')), 1));
	        return div$1(dy, a);
	      }
	    };
	  }
	};

	var addGradConfig = {
	  kernelName: Add$1,
	  inputsToSave: ['a', 'b'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 2),
	      a = _saved[0],
	      b = _saved[1];
	    var outShape = assertAndGetBroadcastShape(a.shape, b.shape);
	    var derA = function derA() {
	      var res = dy;
	      var reduceAxes = getReductionAxes(a.shape, outShape);
	      if (reduceAxes.length > 0) {
	        res = sum$3(res, reduceAxes);
	      }
	      return reshape$3(res, a.shape);
	    };
	    var derB = function derB() {
	      var res = dy;
	      var reduceAxes = getReductionAxes(b.shape, outShape);
	      if (reduceAxes.length > 0) {
	        res = sum$3(res, reduceAxes);
	      }
	      return reshape$3(res, b.shape);
	    };
	    return {
	      a: derA,
	      b: derB
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var addNGradConfig = {
	  kernelName: AddN,
	  saveAllInputs: true,
	  gradFunc: function gradFunc(dy, saved) {
	    var ders = {};
	    saved.forEach(function (_, i) {
	      ders[i] = function () {
	        return dy.clone();
	      };
	    });
	    return ders;
	  }
	};

	var argMaxGradConfig = {
	  kernelName: ArgMax,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return zerosLike$3(_x);
	      }
	    };
	  }
	};

	var argMinGradConfig = {
	  kernelName: ArgMin,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return zerosLike$3(_x);
	      }
	    };
	  }
	};

	var asinGradConfig = {
	  kernelName: Asin,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return div$1(dy, sqrt$2(sub$2(scalar(1), square$2(cast$3(_x, 'float32')))));
	      }
	    };
	  }
	};

	var asinhGradConfig = {
	  kernelName: Asinh,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        var a = sqrt$2(add$3(scalar(1), square$2(cast$3(_x, 'float32'))));
	        return div$1(dy, a);
	      }
	    };
	  }
	};

	var atan2GradConfig = {
	  kernelName: Atan2,
	  inputsToSave: ['a', 'b'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 2),
	      a = _saved[0],
	      b = _saved[1];
	    var outShape = assertAndGetBroadcastShape(a.shape, b.shape);
	    var derA = function derA() {
	      var d = add$3(square$2(a), square$2(b));
	      var res = mul(dy, div$1(b, d));
	      var reduceAxes = getReductionAxes(a.shape, outShape);
	      if (reduceAxes.length > 0) {
	        res = sum$3(res, reduceAxes);
	      }
	      return reshape$3(res, a.shape);
	    };
	    var derB = function derB() {
	      var d = add$3(square$2(a), square$2(b));
	      var res = neg$2(mul(dy, div$1(a, d)));
	      var reduceAxes = getReductionAxes(b.shape, outShape);
	      if (reduceAxes.length > 0) {
	        res = sum$3(res, reduceAxes);
	      }
	      return reshape$3(res, b.shape);
	    };
	    return {
	      a: derA,
	      b: derB
	    };
	  }
	};

	var atanGradConfig = {
	  kernelName: Atan,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return div$1(dy, add$3(square$2(cast$3(_x, 'float32')), 1));
	      }
	    };
	  }
	};

	var atanhGradConfig = {
	  kernelName: Atanh,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return div$1(dy, sub$2(scalar(1), square$2(cast$3(_x, 'float32'))));
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the backprop of a 3d avg pool.
	 *
	 * @param dy The dy error, of rank 5 of shape
	 *     [batchSize, depth, height, width, channels].
	 * assumed.
	 * @param input The original input image, of rank 5 or rank4 of shape
	 *     [batchSize, depth, height, width, channels].
	 * @param filterSize The filter size:
	 *     `[filterDepth, filterHeight, filterWidth]`.
	 *     `filterSize` is a single number,
	 *     then `filterDepth == filterHeight == filterWidth`.
	 * @param strides The strides of the pooling:
	 *     `[strideDepth, strideHeight, strideWidth]`. If
	 *     `strides` is a single number, then `strideHeight == strideWidth`.
	 * @param pad A string from: 'same', 'valid'. The type of padding algorithm
	 *     used in the forward prop of the op.
	 * @param dimRoundingMode A string from: 'ceil', 'round', 'floor'. If none is
	 *     provided, it will default to truncate.
	 */
	function avgPool3dGrad_(dy, input, filterSize, strides, pad, dimRoundingMode) {
	  var $dy = convertToTensor(dy, 'dy', 'avgPool3dGrad');
	  var $input = convertToTensor(input, 'input', 'avgPool3dGrad');
	  var dy5D = $dy;
	  var input5D = $input;
	  var reshapedTo5D = false;
	  if ($input.rank === 4) {
	    reshapedTo5D = true;
	    dy5D = reshape$3($dy, [1, $dy.shape[0], $dy.shape[1], $dy.shape[2], $dy.shape[3]]);
	    input5D = reshape$3($input, [1, $input.shape[0], $input.shape[1], $input.shape[2], $input.shape[3]]);
	  }
	  assert$1(dy5D.rank === 5, function () {
	    return "Error in avgPool3dGrad: dy must be rank 5 but got rank " + "".concat(dy5D.rank, ".");
	  });
	  assert$1(input5D.rank === 5, function () {
	    return "Error in avgPool3dGrad: input must be rank 5 but got rank " + "".concat(input5D.rank, ".");
	  });
	  checkPadOnDimRoundingMode('avgPool3dGrad', pad, dimRoundingMode);
	  var inputs = {
	    dy: dy5D,
	    input: input5D
	  };
	  var attrs = {
	    filterSize: filterSize,
	    strides: strides,
	    pad: pad,
	    dimRoundingMode: dimRoundingMode
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var res = ENGINE.runKernel(AvgPool3DGrad, inputs, attrs);
	  if (reshapedTo5D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3], res.shape[4]]);
	  }
	  return res;
	}
	var avgPool3dGrad = /* @__PURE__ */op({
	  avgPool3dGrad_: avgPool3dGrad_
	});

	var avgPool3DGradConfig$2 = {
	  kernelName: AvgPool3D,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    var filterSize = attrs.filterSize,
	      strides = attrs.strides,
	      pad = attrs.pad,
	      dimRoundingMode = attrs.dimRoundingMode;
	    return {
	      x: function x() {
	        return avgPool3dGrad(dy, _x, filterSize, strides, pad, dimRoundingMode);
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the backprop of an 2D avg pool.
	 *
	 * @param dy The dy error, of rank 4 or rank 3 of shape
	 *     [batchSize, height, width, channels]. If rank 3, batch of 1 is
	 * assumed.
	 * @param input The input image, of rank 4 or rank 3 of shape
	 *     [batchSize, height, width, channels]. If rank 3, batch of 1 is
	 * assumed.
	 * @param filterSize The filter size: `[filterHeight, filterWidth]`. If
	 *     `filterSize` is a single number, then `filterHeight == filterWidth`.
	 * @param strides The strides of the pooling: `[strideHeight, strideWidth]`. If
	 *     `strides` is a single number, then `strideHeight == strideWidth`.
	 * @param pad The type of padding algorithm used in the forward prop of the op.
	 *     'same', 'valid', for more info, see this guide:
	 *     [https://www.tensorflow.org/api_docs/python/tf/nn/convolution](
	 *         https://www.tensorflow.org/api_docs/python/tf/nn/convolution)
	 */
	function avgPoolGrad_(dy, input, filterSize, strides, pad) {
	  var $dy = convertToTensor(dy, 'dy', 'avgPoolGrad');
	  var $input = convertToTensor(input, 'input', 'avgPoolGrad');
	  assert$1($input.rank === $dy.rank, function () {
	    return "Rank of input (".concat($input.rank, ") does not match rank of dy (").concat($dy.rank, ")");
	  });
	  var input4D = $input;
	  var dy4D = $dy;
	  var reshapedTo4D = false;
	  if ($input.rank === 3) {
	    reshapedTo4D = true;
	    input4D = reshape$3($input, [1, $input.shape[0], $input.shape[1], $input.shape[2]]);
	    dy4D = reshape$3($dy, [1, $dy.shape[0], $dy.shape[1], $dy.shape[2]]);
	  }
	  assert$1(dy4D.rank === 4, function () {
	    return "Error in avgPoolGrad: dy must be rank 4 but got rank " + "".concat(dy4D.rank, ".");
	  });
	  assert$1(input4D.rank === 4, function () {
	    return "Error in avgPoolGrad: input must be rank 4 but got rank " + "".concat(input4D.rank, ".");
	  });
	  var inputs = {
	    dy: dy4D,
	    input: input4D
	  };
	  var attrs = {
	    filterSize: filterSize,
	    strides: strides,
	    pad: pad
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var res = ENGINE.runKernel(AvgPoolGrad, inputs, attrs);
	  if (reshapedTo4D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3]]);
	  }
	  return res;
	}
	var avgPoolGrad$2 = /* @__PURE__ */op({
	  avgPoolGrad_: avgPoolGrad_
	});

	var avgPoolGradConfig$2 = {
	  kernelName: AvgPool,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    var filterSize = attrs.filterSize,
	      strides = attrs.strides,
	      pad = attrs.pad;
	    return {
	      x: function x() {
	        return avgPoolGrad$2(dy, _x, filterSize, strides, pad);
	      }
	    };
	  }
	};

	var batchMatMulGradConfig = {
	  kernelName: BatchMatMul,
	  inputsToSave: ['a', 'b'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 2),
	      a = _saved[0],
	      b = _saved[1];
	    var transposeA = attrs.transposeA,
	      transposeB = attrs.transposeB;
	    if (!transposeA && !transposeB) {
	      return {
	        a: function a() {
	          return matMul$1(dy, b, false, true);
	        },
	        b: function b() {
	          return matMul$1(a, dy, true, false);
	        }
	      };
	    } else if (!transposeA && transposeB) {
	      return {
	        a: function a() {
	          return matMul$1(dy, b, false, false);
	        },
	        b: function b() {
	          return matMul$1(dy, a, true, false);
	        }
	      };
	    } else if (transposeA && !transposeB) {
	      return {
	        a: function a() {
	          return matMul$1(b, dy, false, true);
	        },
	        b: function b() {
	          return matMul$1(a, dy, false, false);
	        }
	      };
	    } else {
	      return {
	        a: function a() {
	          return matMul$1(b, dy, true, true);
	        },
	        b: function b() {
	          return matMul$1(dy, a, true, true);
	        }
	      };
	    }
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var batchToSpaceNDGradConfig = {
	  kernelName: BatchToSpaceND,
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var blockShape = attrs.blockShape,
	      crops = attrs.crops;
	    return {
	      x: function x() {
	        return spaceToBatchND$2(dy, blockShape, crops);
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var broadcastToGradConfig = {
	  kernelName: BroadcastTo,
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var broadCastToAttrs = attrs;
	    var inputShape = broadCastToAttrs.inputShape;
	    var outputShape = broadCastToAttrs.shape;
	    var reps = Array.from(outputShape);
	    for (var i = inputShape.length - 1; i >= 0; i--) {
	      if (inputShape[i] === outputShape[i]) {
	        reps[i] = 1;
	      } else if (inputShape[i] !== 1) {
	        throw new Error("broadcastTo(): [".concat(inputShape, "] cannot be broadcast to [").concat(outputShape, "]."));
	      }
	    }
	    var axes = [];
	    for (var _i = 0; _i < reps.length; _i++) {
	      if (reps[_i] > 1) {
	        axes.push(_i);
	      }
	    }
	    return {
	      x: function x() {
	        return sum$3(dy, axes, true /* keepDims */);
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var castGradConfig = {
	  kernelName: Cast,
	  gradFunc: function gradFunc(dy) {
	    return {
	      x: function x() {
	        return dy.clone();
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ceilGradConfig = {
	  kernelName: Ceil,
	  gradFunc: function gradFunc(dy) {
	    // TODO(manrajgrover): Return null for gradients when backprop supports it.
	    return {
	      x: function x() {
	        return zerosLike$3(dy);
	      }
	    };
	  }
	};

	var clipByValueGradConfig = {
	  kernelName: ClipByValue,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    var clipValueMin = attrs.clipValueMin,
	      clipValueMax = attrs.clipValueMax;
	    return {
	      x: function x() {
	        return where(logicalAnd$2(greaterEqual$2(_x, clipValueMin), lessEqual$2(_x, clipValueMax)), dy, zerosLike$3(dy));
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var complexAbsGradConfig = {
	  kernelName: ComplexAbs,
	  inputsToSave: ['x'],
	  gradFunc: absGradConfig.gradFunc
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var concatGradConfig = {
	  kernelName: Concat,
	  saveAllInputs: true,
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var shapes = saved.map(function (t) {
	      return t.shape;
	    });
	    var axis = attrs.axis;
	    var $axis = parseAxisParam(axis, saved[0].shape)[0];
	    var sizeSplits = shapes.map(function (s) {
	      return s[$axis];
	    });
	    var derTensors = split$3(dy, sizeSplits, $axis);
	    return derTensors.map(function (t) {
	      return function () {
	        return t;
	      };
	    });
	  }
	};

	var conv2DGradConfig = {
	  kernelName: Conv2D$1,
	  inputsToSave: ['x', 'filter'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 2),
	      x4D = _saved[0],
	      $filter = _saved[1];
	    var dilations = attrs.dilations,
	      strides = attrs.strides,
	      pad = attrs.pad,
	      dataFormat = attrs.dataFormat;
	    assert$1(tupleValuesAreOne(dilations), function () {
	      return 'Error in gradient of conv2D: dilation rates greater than 1 ' + "are not yet supported in gradients. Got dilations '".concat(dilations, "'");
	    });
	    return {
	      x: function x() {
	        return conv2DBackpropInput$2(x4D.shape, dy, $filter, strides, pad, dataFormat);
	      },
	      filter: function filter() {
	        return conv2DBackpropFilter$2(x4D, dy, $filter.shape, strides, pad, dataFormat);
	      }
	    };
	  }
	};

	var conv2DBackpropInputGradConfig = {
	  kernelName: Conv2DBackpropInput,
	  inputsToSave: ['dy', 'filter'],
	  gradFunc: function gradFunc(ddx, saved, attrs) {
	    var _saved = _slicedToArray(saved, 2),
	      dy = _saved[0],
	      _filter = _saved[1];
	    var strides = attrs.strides,
	      pad = attrs.pad,
	      dataFormat = attrs.dataFormat,
	      dimRoundingMode = attrs.dimRoundingMode;
	    return {
	      dy: function dy() {
	        return conv2d$4(ddx, _filter, strides, pad, dataFormat, 1 /* dilations */, dimRoundingMode);
	      },
	      filter: function filter() {
	        return conv2DBackpropFilter$2(ddx, dy, _filter.shape, strides, pad, dataFormat, dimRoundingMode);
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the derivative of the filter of a 3D convolution.
	 *
	 * @param x The input tensor, of rank 5 or rank 4 of shape
	 *     [batch, depth, height, width, inChannels]. If rank 4, batch of 1 is
	 *     assumed.
	 * @param dy The dy image, of rank 5 or rank 4, of shape
	 *     [batch, depth, height, width, outDepth]. If rank 4, batch of 1 is
	 *     assumed.
	 * @param filterShape The shape of the filter, length 5,
	 *     [filterDepth, filterHeight, filterWidth, inDepth, outDepth].
	 * @param strides The strides of the convolution: [strideDepth, strideHeight,
	 * strideWidth].
	 * @param pad A string from: 'same', 'valid'. The type of padding algorithm
	 *     used in the forward prop of the op.
	 */
	function conv3DBackpropFilter_(x, dy, filterShape, strides, pad) {
	  var x5D = x;
	  if (x.rank === 4) {
	    x5D = reshape$3(x, [1, x.shape[0], x.shape[1], x.shape[2], x.shape[3]]);
	  }
	  var dy5D = dy;
	  if (dy5D.rank === 4) {
	    dy5D = reshape$3(dy, [1, dy.shape[0], dy.shape[1], dy.shape[2], dy.shape[3]]);
	  }
	  assert$1(x5D.rank === 5, function () {
	    return "Error in conv3dDerFilter: input must be rank 5, but got shape " + "".concat(x5D.shape, ".");
	  });
	  assert$1(dy5D.rank === 5, function () {
	    return "Error in conv3dDerFilter: dy must be rank 5, but got shape " + "".concat(dy5D.shape, ".");
	  });
	  assert$1(filterShape.length === 5, function () {
	    return "Error in conv3dDerFilter: filterShape must be length 5, but got " + "".concat(filterShape, ".");
	  });
	  assert$1(x5D.shape[4] === filterShape[3], function () {
	    return "Error in conv3dDerFilter: depth of input ".concat(x5D.shape[4], ") must ") + "match input depth in filter (".concat(filterShape[3], ".");
	  });
	  assert$1(dy5D.shape[4] === filterShape[4], function () {
	    return "Error in conv3dDerFilter: depth of dy (".concat(dy5D.shape[4], ") must ") + "match output depth for filter (".concat(filterShape[4], ").");
	  });
	  var inputs = {
	    x: x5D,
	    dy: dy5D
	  };
	  var attrs = {
	    strides: strides,
	    pad: pad,
	    filterShape: filterShape
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  return ENGINE.runKernel(Conv3DBackpropFilterV2, inputs, attrs);
	}
	var conv3DBackpropFilter = /* @__PURE__ */op({
	  conv3DBackpropFilter_: conv3DBackpropFilter_
	});

	var conv3DGradConfig = {
	  kernelName: Conv3D$1,
	  inputsToSave: ['x', 'filter'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var dilations = attrs.dilations,
	      strides = attrs.strides,
	      pad = attrs.pad;
	    assert$1(tupleValuesAreOne(dilations), function () {
	      return 'Error in gradient of conv3D: dilation rates greater than 1 are ' + "not yet supported in gradients. Got dilations '".concat(dilations, "'");
	    });
	    var _saved = _slicedToArray(saved, 2),
	      x5D = _saved[0],
	      $filter = _saved[1];
	    return {
	      x: function x() {
	        return conv3DBackpropInput$1(x5D.shape, dy, $filter, strides, pad);
	      },
	      filter: function filter() {
	        return conv3DBackpropFilter(x5D, dy, $filter.shape, strides, pad);
	      }
	    };
	  }
	};

	var cosGradConfig = {
	  kernelName: Cos,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return mul(neg$2(sin$2(cast$3(_x, 'float32'))), dy);
	      }
	    };
	  }
	};

	var coshGradConfig = {
	  kernelName: Cosh,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return mul(sinh$2(cast$3(_x, 'float32')), dy);
	      }
	    };
	  }
	};

	var cumsumGradConfig = {
	  kernelName: Cumsum,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    var axis = attrs.axis,
	      exclusive = attrs.exclusive,
	      reverse = attrs.reverse;
	    return {
	      x: function x() {
	        var permutation = getAxesPermutation([axis], _x.rank);
	        var out = cumsum$2(dy, axis, exclusive, !reverse);
	        if (permutation != null) {
	          out = transpose$2(out, permutation);
	        }
	        return out;
	      }
	    };
	  }
	};

	var depthwiseConv2dNativeGradConfig = {
	  kernelName: DepthwiseConv2dNative,
	  inputsToSave: ['x', 'filter'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var dilations = attrs.dilations,
	      strides = attrs.strides,
	      pad = attrs.pad,
	      dimRoundingMode = attrs.dimRoundingMode;
	    var $dilations = dilations == null ? [1, 1] : dilations;
	    assert$1(tupleValuesAreOne($dilations), function () {
	      return 'Error in gradient of depthwiseConv2dNative: dilation rates ' + "greater than 1 are not yet supported. Got dilations " + "'".concat($dilations, "'");
	    });
	    var _saved = _slicedToArray(saved, 2),
	      _x = _saved[0],
	      _filter = _saved[1];
	    assert$1(_x.rank === 4, function () {
	      return "Error in gradient of depthwiseConv2dNative: input must be " + "rank 4, but got rank ".concat(_x.rank, ".");
	    });
	    assert$1(_filter.rank === 4, function () {
	      return "Error in gradient of depthwiseConv2dNative: filter must be " + "rank 4, but got rank ".concat(_filter.rank, ".");
	    });
	    assert$1(_x.shape[3] === _filter.shape[2], function () {
	      return "Error in gradient of depthwiseConv2d: number of input " + "channels (".concat(_x.shape[3], ") must match the inChannels dimension ") + "in filter ".concat(_filter.shape[2], ".");
	    });
	    assert$1(eitherStridesOrDilationsAreOne(strides, $dilations), function () {
	      return 'Error in gradient of depthwiseConv2d: Either strides or ' + "dilations must be  1. Got strides ".concat(strides, " and dilations ") + "'".concat($dilations, "'.");
	    });
	    checkPadOnDimRoundingMode('depthwiseConv2d', pad, dimRoundingMode);
	    return {
	      x: function x() {
	        return depthwiseConv2dNativeBackpropInput$2(_x.shape, dy, _filter, strides, pad, $dilations, dimRoundingMode);
	      },
	      filter: function filter() {
	        return depthwiseConv2dNativeBackpropFilter$2(_x, dy, _filter.shape, strides, pad, $dilations, dimRoundingMode);
	      }
	    };
	  }
	};

	var dilation2dGradConfig = {
	  kernelName: Dilation2D,
	  inputsToSave: ['x', 'filter'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 2),
	      x = _saved[0],
	      filter = _saved[1];
	    var inputInputs = {
	      x: x,
	      filter: filter,
	      dy: dy
	    };
	    var filterInputs = {
	      x: x,
	      filter: filter,
	      dy: dy
	    };
	    return {
	      x: function x() {
	        return ENGINE.runKernel(Dilation2DBackpropInput, inputInputs, attrs);
	      },
	      filter: function filter() {
	        return ENGINE.runKernel(Dilation2DBackpropFilter, filterInputs, attrs);
	      }
	    };
	  }
	};

	var eluGradConfig$2 = {
	  kernelName: Elu$1,
	  outputsToSave: [true],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      y = _saved[0];
	    var inputs = {
	      dy: dy,
	      y: y
	    };
	    return {
	      x: function x() {
	        return ENGINE.runKernel(EluGrad, inputs);
	      }
	    };
	  }
	};

	var erfGradConfig = {
	  kernelName: Erf,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      x = _saved[0];
	    var a = mul(exp$2(neg$2(square$2(x))), 2 / Math.sqrt(Math.PI));
	    return {
	      x: function x() {
	        return mul(dy, a);
	      }
	    };
	  }
	};

	var expGradConfig = {
	  kernelName: Exp,
	  outputsToSave: [true],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      y = _saved[0];
	    return {
	      x: function x() {
	        return mul(dy, y);
	      }
	    };
	  }
	};

	var expandDimsGradConfig = {
	  kernelName: ExpandDims,
	  inputsToSave: ['input'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _input = _saved[0];
	    return {
	      input: function input() {
	        return reshape$3(dy, _input.shape);
	      }
	    };
	  }
	};

	var expm1GradConfig = {
	  kernelName: Expm1,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return mul(dy, exp$2(_x));
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var floorGradConfig = {
	  kernelName: Floor,
	  gradFunc: function gradFunc(dy) {
	    return {
	      x: function x() {
	        return zerosLike$3(dy);
	      }
	    };
	  }
	};

	var floorDivGradConfig = {
	  kernelName: FloorDiv,
	  inputsToSave: ['a', 'b'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 2),
	      a = _saved[0],
	      b = _saved[1];
	    var outShape = assertAndGetBroadcastShape(a.shape, b.shape);
	    var derA = function derA() {
	      var res = div$1(dy, cast$3(b, 'float32'));
	      var reduceAxes = getReductionAxes(a.shape, outShape);
	      if (reduceAxes.length > 0) {
	        return reshape$3(sum$3(res, reduceAxes), a.shape);
	      }
	      return res;
	    };
	    var derB = function derB() {
	      var res = mul(dy, cast$3(a, 'float32'));
	      var reduceAxes = getReductionAxes(b.shape, outShape);
	      if (reduceAxes.length > 0) {
	        res = reshape$3(sum$3(res, reduceAxes), b.shape);
	      }
	      var tmp = square$2(b);
	      return neg$2(div$1(res, cast$3(tmp, 'float32')));
	    };
	    return {
	      a: derA,
	      b: derB
	    };
	  }
	};

	var fusedBatchNormGradConfig = {
	  kernelName: FusedBatchNorm,
	  inputsToSave: ['x', 'mean', 'variance', 'scale'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var varianceEpsilon = attrs.varianceEpsilon;
	    var _saved = _slicedToArray(saved, 4),
	      x = _saved[0],
	      mean = _saved[1],
	      variance = _saved[2],
	      scale = _saved[3];
	    var scaleValue = scale == null ? scalar(1) : scale;
	    var reductionAxes = getReductionAxes(mean.shape, x.shape);
	    var tileShape = [];
	    if (mean.rank === 1) {
	      for (var i = 0; i < x.shape.length - 1; ++i) {
	        tileShape.push(x.shape[i]);
	      }
	      tileShape.push(1);
	    }
	    var xMinusMean = sub$2(x, mean);
	    var dyTimesScaleValue = mul(dy, scaleValue);
	    var oneOverSqrtVariance = rsqrt$2(add$3(variance, scalar(varianceEpsilon)));
	    var minusHalfRCube = mul(mul(mul(oneOverSqrtVariance, oneOverSqrtVariance), oneOverSqrtVariance), scalar(-0.5));
	    var derX = function derX() {
	      if (mean.rank === 1) {
	        return reshape$3(mul(mul(dy, tile$3(reshape$3(oneOverSqrtVariance, [1, 1, 1, mean.shape[0]]), tileShape)), scaleValue), x.shape);
	      } else {
	        return reshape$3(mul(mul(dy, oneOverSqrtVariance), scaleValue), x.shape);
	      }
	    };
	    var derMean = function derMean() {
	      var meanDer = mul(mul(oneOverSqrtVariance, scalar(-1)), dyTimesScaleValue);
	      if (mean.rank === 1) {
	        meanDer = sum$3(meanDer, reductionAxes);
	      }
	      return reshape$3(meanDer, mean.shape);
	    };
	    var derVariance = function derVariance() {
	      var varianceDer = mul(mul(minusHalfRCube, xMinusMean), dyTimesScaleValue);
	      if (mean.rank === 1) {
	        varianceDer = sum$3(varianceDer, reductionAxes);
	      }
	      return reshape$3(varianceDer, mean.shape);
	    };
	    var derScale = function derScale() {
	      var xMinusMean2TimesRsqrt = mul(xMinusMean, oneOverSqrtVariance);
	      var scaleDer = mul(dy, xMinusMean2TimesRsqrt);
	      if (mean.rank === 1) {
	        scaleDer = sum$3(scaleDer, reductionAxes);
	      }
	      return reshape$3(scaleDer, mean.shape);
	    };
	    var derOffset = function derOffset() {
	      var offsetDer = dy;
	      if (mean.rank === 1) {
	        offsetDer = sum$3(offsetDer, reductionAxes);
	      }
	      return reshape$3(offsetDer, mean.shape);
	    };
	    return {
	      x: derX,
	      mean: derMean,
	      variance: derVariance,
	      scale: derScale,
	      offset: derOffset
	    };
	  }
	};

	var gatherGradConfig = {
	  kernelName: GatherV2,
	  inputsToSave: ['x', 'indices'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 2),
	      x = _saved[0],
	      _indices = _saved[1];
	    var axis = attrs.axis,
	      batchDims = attrs.batchDims;
	    var parsedAxis = parseAxisParam(axis, x.shape)[0];
	    var derXBatch = function derXBatch(x, indices, dy) {
	      return function () {
	        var paramsShape = x.shape;
	        var indicesSize = indices.size;
	        var outerShape = paramsShape.slice(0, parsedAxis);
	        var outerDims = outerShape.length;
	        var innerShape = paramsShape.slice(axis, paramsShape.length).slice(1);
	        var innerDims = innerShape.length;
	        var outerAxesIndices = arrayRange(0, outerDims);
	        var innerAxesIndices = arrayRange(outerDims + 1, outerDims + 1 + innerDims);
	        var valuesShape = arrayConcat([outerShape, [indicesSize], innerShape]);
	        var values = reshape$3(dy, valuesShape);
	        var reshapedIndices = reshape$3(indices, [indicesSize]);
	        var transposeDims = arrayConcat([[outerDims], outerAxesIndices, innerAxesIndices]);
	        var valuesTranspose = transpose$2(values, transposeDims);
	        var paramsGrad = unsortedSegmentSum$2(valuesTranspose, reshapedIndices, x.shape[parsedAxis]);
	        var invertTransposeDims = getUndoAxesPermutation(transposeDims);
	        paramsGrad = transpose$2(paramsGrad, invertTransposeDims);
	        return paramsGrad;
	      };
	    };
	    if (batchDims === 1) {
	      var batchSize = x.shape[0];
	      var xBatch = x.split(batchSize, 0);
	      var derXBatched = function derXBatched() {
	        var stacked = stack(xBatch.map(function (x, i) {
	          return derXBatch(x, _indices.slice(i, 1), dy.slice(i, 1))();
	        }));
	        return stacked.reshape(x.shape);
	      };
	      return {
	        x: derXBatched,
	        indices: function indices() {
	          return _indices;
	        }
	      };
	    } else {
	      return {
	        x: derXBatch(x, _indices, dy),
	        indices: function indices() {
	          return _indices;
	        }
	      };
	    }
	  }
	};
	function arrayRange(start, stop) {
	  var result = [];
	  for (var i = start; i < stop; ++i) {
	    result.push(i);
	  }
	  return result;
	}
	function arrayConcat(arrays) {
	  var result = [];
	  for (var i = 0; i < arrays.length; ++i) {
	    for (var j = 0; j < arrays[i].length; ++j) {
	      result.push(arrays[i][j]);
	    }
	  }
	  return result;
	}

	var greaterEqualGradConfig = {
	  kernelName: GreaterEqual,
	  inputsToSave: ['a', 'b'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 2),
	      _a = _saved[0],
	      _b = _saved[1];
	    return {
	      a: function a() {
	        return zerosLike$3(_a);
	      },
	      b: function b() {
	        return zerosLike$3(_b);
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var identityGradConfig = {
	  kernelName: Identity$1,
	  gradFunc: function gradFunc(dy) {
	    return {
	      x: function x() {
	        return cast$3(dy, 'float32');
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var isFiniteGradConfig = {
	  kernelName: IsFinite,
	  gradFunc: function gradFunc(dy) {
	    // TODO(nsthorat): Let gradients be null for cases where we want to stop
	    // backpropgation.
	    return {
	      x: function x() {
	        return zerosLike$3(dy);
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var isInfGradConfig = {
	  kernelName: IsInf,
	  gradFunc: function gradFunc(dy) {
	    // TODO(nsthorat): Let gradients be null for cases where we want to stop
	    // backpropgation.
	    return {
	      x: function x() {
	        return zerosLike$3(dy);
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var isNanGradConfig = {
	  kernelName: IsNan,
	  gradFunc: function gradFunc(dy) {
	    // TODO(nsthorat): Let gradients be null for cases where we want to stop
	    // backpropgation.
	    return {
	      x: function x() {
	        return zerosLike$3(dy);
	      }
	    };
	  }
	};

	var leakyReluGradConfig = {
	  kernelName: LeakyRelu,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 1),
	      x = _saved[0];
	    var alpha = attrs.alpha;
	    var mask = greater$3(x, 0);
	    // Returns `gradients * (features > 0) + alpha * gradients * (features <=
	    // 0)`.
	    return {
	      x: function x() {
	        return where(mask, dy, mul(dy, alpha));
	      }
	    };
	  }
	};

	var log1pGradConfig = {
	  kernelName: Log1p,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return div$1(dy, add$3(_x, 1));
	      }
	    };
	  }
	};

	var logGradConfig = {
	  kernelName: Log,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return div$1(dy, cast$3(_x, 'float32'));
	      }
	    };
	  }
	};

	var logSoftmaxGradConfig = {
	  kernelName: LogSoftmax$1,
	  inputsToSave: [],
	  outputsToSave: [true],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 1),
	      value = _saved[0];
	    var axis = attrs.axis;
	    return {
	      logits: function logits() {
	        var keepDims = true;
	        var softmax = exp$2(value);
	        return sub$2(dy, mul(sum$3(dy, axis, keepDims), softmax));
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function localResponseNormalizationBackprop_(x, y, dy) {
	  var depthRadius = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 5;
	  var bias = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 1;
	  var alpha = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : 1;
	  var beta = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : 0.5;
	  var inputs = {
	    x: x,
	    y: y,
	    dy: dy
	  };
	  var attrs = {
	    depthRadius: depthRadius,
	    bias: bias,
	    alpha: alpha,
	    beta: beta
	  };
	  return ENGINE.runKernel(LRNGrad, inputs, attrs);
	}
	var localResponseNormalizationBackprop = op({
	  localResponseNormalizationBackprop_: localResponseNormalizationBackprop_
	});

	var lrnGradConfig = {
	  kernelName: LRN,
	  inputsToSave: ['x'],
	  outputsToSave: [true],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 2),
	      _x = _saved[0],
	      y = _saved[1];
	    var depthRadius = attrs.depthRadius,
	      bias = attrs.bias,
	      alpha = attrs.alpha,
	      beta = attrs.beta;
	    return {
	      x: function x() {
	        return localResponseNormalizationBackprop(_x, y, dy, depthRadius, bias, alpha, beta);
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Gradient helper function for the min and max operations.
	 */
	function gradForMinAndMax(dy, y, xOrig, origAxes) {
	  if (y.rank < xOrig.rank) {
	    y = reshape$3(y, expandShapeToKeepDim(y.shape, origAxes));
	  }
	  if (dy.rank < xOrig.rank) {
	    dy = reshape$3(dy, expandShapeToKeepDim(dy.shape, origAxes));
	  }
	  return {
	    x: function x() {
	      var dx = mul(dy, cast$3(equal$2(xOrig, y), dy.dtype));
	      return dx;
	    }
	  };
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var maxGradConfig = {
	  kernelName: Max,
	  inputsToSave: ['x'],
	  outputsToSave: [true],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var maxAttrs = attrs;
	    var reductionIndices = maxAttrs.reductionIndices;
	    var x = saved[0];
	    var y = saved[1];
	    var origAxes = parseAxisParam(reductionIndices, x.shape);
	    var maxGrad = gradForMinAndMax(dy, y, x, origAxes);
	    return {
	      x: function x() {
	        return maxGrad['x']();
	      }
	    };
	  }
	};

	var maximumGradConfig = {
	  kernelName: Maximum$1,
	  inputsToSave: ['a', 'b'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 2),
	      a = _saved[0],
	      b = _saved[1];
	    var derA = function derA() {
	      return mul(dy, cast$3(greaterEqual$2(a, b), 'float32'));
	    };
	    var derB = function derB() {
	      return mul(dy, cast$3(less$3(a, b), 'float32'));
	    };
	    return {
	      a: derA,
	      b: derB
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the backprop of a 3d max pool.
	 *
	 * @param dy The dy error, of rank 5 of shape
	 *     [batchSize, depth, height, width, channels].
	 * assumed.
	 * @param input The original input image, of rank 5 or rank 4 of shape
	 *     [batchSize, depth, height, width, channels].
	 * @param output The original output image, of rank 5 of shape
	 *     [batchSize, outDepth, outHeight, outWidth, channels].
	 * @param filterSize The filter size:
	 *     `[filterDepth, filterHeight, filterWidth]`.
	 *     `filterSize` is a single number,
	 *     then `filterDepth == filterHeight == filterWidth`.
	 * @param strides The strides of the pooling:
	 *     `[strideDepth, strideHeight, strideWidth]`. If
	 *     `strides` is a single number, then `strideHeight == strideWidth`.
	 * @param pad A string from: 'same', 'valid'. The type of padding algorithm
	 *     used in the forward prop of the op.
	 * @param dimRoundingMode A string from: 'ceil', 'round', 'floor'. If none is
	 *     provided, it will default to truncate.
	 */
	function maxPool3dGrad_(dy, input, output, filterSize, strides, pad, dimRoundingMode) {
	  var $dy = convertToTensor(dy, 'dy', 'maxPool3dGrad');
	  var $input = convertToTensor(input, 'input', 'maxPool3dGrad');
	  var $output = convertToTensor(output, 'output', 'maxPool3dGrad');
	  var dy5D = $dy;
	  var input5D = $input;
	  var output5D = $output;
	  var reshapedTo5D = false;
	  if ($input.rank === 4) {
	    reshapedTo5D = true;
	    dy5D = reshape$3($dy, [1, $dy.shape[0], $dy.shape[1], $dy.shape[2], $dy.shape[3]]);
	    input5D = reshape$3($input, [1, $input.shape[0], $input.shape[1], $input.shape[2], $input.shape[3]]);
	    output5D = reshape$3($output, [1, $output.shape[0], $output.shape[1], $output.shape[2], $output.shape[3]]);
	  }
	  assert$1(dy5D.rank === 5, function () {
	    return "Error in maxPool3dGrad: dy must be rank 5 but got rank " + "".concat(dy5D.rank, ".");
	  });
	  assert$1(input5D.rank === 5, function () {
	    return "Error in maxPool3dGrad: input must be rank 5 but got rank " + "".concat(input5D.rank, ".");
	  });
	  assert$1(output5D.rank === 5, function () {
	    return "Error in maxPool3dGrad: output must be rank 5 but got rank " + "".concat(output5D.rank, ".");
	  });
	  checkPadOnDimRoundingMode('maxPool3dGrad', pad, dimRoundingMode);
	  var inputs = {
	    dy: dy5D,
	    input: input5D,
	    output: output5D
	  };
	  var attrs = {
	    filterSize: filterSize,
	    strides: strides,
	    pad: pad,
	    dimRoundingMode: dimRoundingMode
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  var res = ENGINE.runKernel(MaxPool3DGrad, inputs, attrs);
	  if (reshapedTo5D) {
	    return reshape$3(res, [res.shape[1], res.shape[2], res.shape[3], res.shape[4]]);
	  }
	  return res;
	}
	var maxPool3dGrad = /* @__PURE__ */op({
	  maxPool3dGrad_: maxPool3dGrad_
	});

	var maxPool3DGradConfig$2 = {
	  kernelName: MaxPool3D,
	  inputsToSave: ['x'],
	  outputsToSave: [true],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 2),
	      _x = _saved[0],
	      y = _saved[1];
	    var filterSize = attrs.filterSize,
	      strides = attrs.strides,
	      pad = attrs.pad,
	      dimRoundingMode = attrs.dimRoundingMode;
	    return {
	      x: function x() {
	        return maxPool3dGrad(dy, _x, y, filterSize, strides, pad, dimRoundingMode);
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Computes the backprop of a 2D max pool.
	 *
	 * @param dy The dy error, of rank 4 or rank 3 of shape
	 *     [batchSize, height, width, channels]. If rank 3, batch of 1 is
	 * assumed.
	 * @param input The original input image, of rank 4, of shape
	 *     [batchSize, height, width, channels].
	 * @param output The original output image, of rank 4, of shape
	 *     [batchSize, outHeight, outWidth, channels].
	 * @param filterSize The filter size: `[filterHeight, filterWidth]`. If
	 *     `filterSize` is a single number, then `filterHeight == filterWidth`.
	 * @param strides The strides of the pooling: `[strideHeight, strideWidth]`. If
	 *     `strides` is a single number, then `strideHeight == strideWidth`.
	 * @param pad The type of padding algorithm used in the forward prop of the op.
	 *     'same', 'valid', for more info, see this guide:
	 *     [https://www.tensorflow.org/api_docs/python/tf/nn/convolution](
	 *          https://www.tensorflow.org/api_docs/python/tf/nn/convolution)
	 * @param dimRoundingMode A string from: 'ceil', 'round', 'floor'. If none is
	 *     provided, it will default to truncate.
	 */
	function maxPoolGrad_(dy, input, output, filterSize, strides, pad, dimRoundingMode) {
	  var $dy = convertToTensor(dy, 'dy', 'maxPoolGrad');
	  var $input = convertToTensor(input, 'input', 'maxPoolGrad');
	  var $output = convertToTensor(output, 'output', 'maxPoolGrad');
	  assert$1($input.rank === $dy.rank, function () {
	    return "Rank of input (".concat($input.rank, ") does not match rank of dy ") + "(".concat($dy.rank, ")");
	  });
	  assert$1($dy.rank === 4, function () {
	    return "Error in maxPoolGrad: dy must be rank 4 but got rank " + "".concat($dy.rank, ".");
	  });
	  assert$1($input.rank === 4, function () {
	    return "Error in maxPoolGrad: input must be rank 4 but got rank " + "".concat($input.rank, ".");
	  });
	  checkPadOnDimRoundingMode('maxPoolGrad', pad, dimRoundingMode);
	  var inputs = {
	    dy: $dy,
	    input: $input,
	    output: $output
	  };
	  var attrs = {
	    filterSize: filterSize,
	    strides: strides,
	    pad: pad,
	    dimRoundingMode: dimRoundingMode
	  };
	  // tslint:disable-next-line: no-unnecessary-type-assertion
	  return ENGINE.runKernel(MaxPoolGrad, inputs, attrs);
	}
	var maxPoolGrad$2 = /* @__PURE__ */op({
	  maxPoolGrad_: maxPoolGrad_
	});

	var maxPoolGradConfig$2 = {
	  kernelName: MaxPool,
	  inputsToSave: ['x'],
	  outputsToSave: [true],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 2),
	      _x = _saved[0],
	      y = _saved[1];
	    var filterSize = attrs.filterSize,
	      strides = attrs.strides,
	      pad = attrs.pad;
	    return {
	      x: function x() {
	        return maxPoolGrad$2(dy, _x, y, filterSize, strides, pad);
	      }
	    };
	  }
	};

	var meanGradConfig = {
	  kernelName: Mean,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 1),
	      x = _saved[0];
	    var axis = attrs.axis;
	    var axes = parseAxisParam(axis, x.shape);
	    var shapes = computeOutAndReduceShapes(x.shape, axes);
	    var reduceShape = shapes[1];
	    var reduceSize = sizeFromShape(reduceShape);
	    var derX = function derX() {
	      var expandedDyShape = x.shape.slice();
	      axes.forEach(function (axis) {
	        expandedDyShape[axis] = 1;
	      });
	      var expandedDy = reshape$3(dy, expandedDyShape);
	      var res = div$1(mul(expandedDy, ones$1(x.shape, 'float32')), reduceSize);
	      return res;
	    };
	    return {
	      x: derX
	    };
	  }
	};

	var minGradConfig = {
	  kernelName: Min,
	  inputsToSave: ['x'],
	  outputsToSave: [true],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var minAttrs = attrs;
	    var axis = minAttrs.axis;
	    var _saved = _slicedToArray(saved, 2),
	      x = _saved[0],
	      y = _saved[1];
	    var origAxes = parseAxisParam(axis, x.shape);
	    var minGrad = gradForMinAndMax(dy, y, x, origAxes);
	    return {
	      x: function x() {
	        return minGrad['x']();
	      }
	    };
	  }
	};

	var minimumGradConfig = {
	  kernelName: Minimum$1,
	  inputsToSave: ['a', 'b'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 2),
	      a = _saved[0],
	      b = _saved[1];
	    var derA = function derA() {
	      return mul(dy, cast$3(lessEqual$2(a, b), 'float32'));
	    };
	    var derB = function derB() {
	      return mul(dy, cast$3(greater$3(a, b), 'float32'));
	    };
	    return {
	      a: derA,
	      b: derB
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var mirrorPadGradConfig = {
	  kernelName: MirrorPad,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    // Pad introduces values around the original tensor, so the gradient
	    // slices the original shape out of the gradient.
	    var _x = saved[0];
	    var paddings = attrs.paddings;
	    var begin = paddings.map(function (p) {
	      return p[0];
	    });
	    return {
	      x: function x() {
	        return slice$2(dy, begin, _x.shape);
	      }
	    };
	  }
	};

	var modGradConfig = {
	  kernelName: Mod,
	  inputsToSave: ['a', 'b'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 2),
	      a = _saved[0],
	      b = _saved[1];
	    var outShape = assertAndGetBroadcastShape(a.shape, b.shape);
	    var derA = function derA() {
	      var reduceAxes = getReductionAxes(a.shape, outShape);
	      if (reduceAxes.length > 0) {
	        return reshape$3(sum$3(dy, reduceAxes), a.shape);
	      }
	      return dy;
	    };
	    var derB = function derB() {
	      var res = mul(dy, neg$2(floor$2(div$1(a, b))));
	      var reduceAxes = getReductionAxes(b.shape, outShape);
	      if (reduceAxes.length > 0) {
	        return reshape$3(sum$3(res, reduceAxes), b.shape);
	      }
	      return res;
	    };
	    return {
	      a: derA,
	      b: derB
	    };
	  }
	};

	var multiplyGradConfig = {
	  kernelName: Multiply$1,
	  inputsToSave: ['a', 'b'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 2),
	      a = _saved[0],
	      b = _saved[1];
	    var outShape = assertAndGetBroadcastShape(a.shape, b.shape);
	    var derA = function derA() {
	      var res = mul(dy, cast$3(b, 'float32'));
	      var reduceAxes = getReductionAxes(a.shape, outShape);
	      if (reduceAxes.length > 0) {
	        return reshape$3(sum$3(res, reduceAxes), a.shape);
	      }
	      return res;
	    };
	    var derB = function derB() {
	      var res = mul(dy, cast$3(a, 'float32'));
	      var reduceAxes = getReductionAxes(b.shape, outShape);
	      if (reduceAxes.length > 0) {
	        return reshape$3(sum$3(res, reduceAxes), b.shape);
	      }
	      return res;
	    };
	    return {
	      a: derA,
	      b: derB
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var negGradConfig = {
	  kernelName: Neg,
	  gradFunc: function gradFunc(dy) {
	    return {
	      x: function x() {
	        return neg$2(dy);
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var oneHotGradConfig = {
	  kernelName: OneHot,
	  inputsToSave: ['indices'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _indices = saved[0];
	    return {
	      indices: function indices() {
	        return zeros$2(_indices.shape, 'float32');
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var onesLikeGradConfig = {
	  kernelName: OnesLike,
	  gradFunc: function gradFunc(dy) {
	    return {
	      x: function x() {
	        return zerosLike$3(dy);
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var packGradConfig = {
	  kernelName: Pack,
	  saveAllInputs: true,
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var axis = attrs.axis;
	    var derTensors = unstack(dy, axis);
	    return derTensors.map(function (t) {
	      return function () {
	        return t;
	      };
	    });
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var padV2GradConfig = {
	  kernelName: PadV2,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    // Pad introduces values around the original tensor, so the gradient
	    // slices the original shape out of the gradient.
	    var _x = saved[0];
	    var paddings = attrs.paddings;
	    var begin = paddings.map(function (p) {
	      return p[0];
	    });
	    return {
	      x: function x() {
	        return slice$2(dy, begin, _x.shape);
	      }
	    };
	  }
	};

	var powGradConfig = {
	  kernelName: Pow,
	  inputsToSave: ['a', 'b'],
	  outputsToSave: [true],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 3),
	      a = _saved[0],
	      b = _saved[1],
	      y = _saved[2];
	    var base = a;
	    var exp = b;
	    var outShape = assertAndGetBroadcastShape(base.shape, exp.shape);
	    var derBase = function derBase() {
	      var expFloat = cast$3(exp, 'float32');
	      var res = mul(dy, mul(expFloat, pow$3(base, sub$2(expFloat, scalar(1)))));
	      var reduceAxes = getReductionAxes(base.shape, outShape);
	      if (reduceAxes.length > 0) {
	        res = sum$3(res, reduceAxes);
	      }
	      return reshape$3(res, base.shape);
	    };
	    var derExp = function derExp() {
	      var condition = greater$3(base, 0);
	      var logBase = where(condition, log$2(base), zerosLike$3(base));
	      var res = mul(dy, mul(y, logBase));
	      var reduceAxes = getReductionAxes(exp.shape, outShape);
	      if (reduceAxes.length > 0) {
	        res = sum$3(res, reduceAxes);
	      }
	      return reshape$3(res, exp.shape);
	    };
	    return {
	      a: derBase,
	      b: derExp
	    };
	  }
	};

	var preluGradConfig = {
	  kernelName: Prelu,
	  inputsToSave: ['x', 'alpha'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 2),
	      x = _saved[0],
	      _alpha = _saved[1];
	    var mask = greater$3(x, 0);
	    return {
	      x: function x() {
	        return where(mask, dy, mul(dy, _alpha));
	      },
	      alpha: function alpha() {
	        var res = where(mask, zerosLike$3(dy), mul(dy, x));
	        var reduceAxes = getReductionAxes(_alpha.shape, dy.shape);
	        if (reduceAxes.length > 0) {
	          res = sum$3(res, reduceAxes);
	        }
	        return reshape$3(res, _alpha.shape);
	      }
	    };
	  }
	};

	// Gradient for product operation on a single axis.
	function prodGradFn_(x, dy, axis) {
	  // The gradient tensor (dy) has a set of axes removed, so we create re-shaped
	  // versions (of size 1) for the removed axis; this supports broadcasting over
	  // those dimensions.
	  var expandedYShape = x.shape.slice();
	  expandedYShape[axis] = 1;
	  // The actual gradient computation.
	  var expandedDy = reshape$3(dy, expandedYShape);
	  var xCumProd = cumprod$2(x, axis, true, false);
	  var xCumRevProd = cumprod$2(x, axis, true, true);
	  var dx = mul(xCumProd, xCumRevProd);
	  return mul(expandedDy, dx);
	}
	// Support gradients when the product is done on many axes at once.
	// This done py pushing all the axes on which the product is applied into a
	// single axis.
	function prodsGradFn_(x, dy, axis) {
	  // Move all axes for doing prod over to the end of the tensor.
	  var xRank = x.shape.length;
	  var finalProdAxis = xRank - axis.length;
	  var xPermutation = getAxesPermutation(axis, xRank);
	  var permutedX = x;
	  if (xPermutation != null) {
	    permutedX = transpose$2(x, xPermutation);
	  }
	  // Reshape all the prod dimensions into a single one, and do compute prod
	  // gradients on that.
	  var newShape = permutedX.shape.slice();
	  var removedShape = newShape.splice(xRank - axis.length, axis.length);
	  var endPartShape = removedShape.reduce(function (p, c) {
	    return p * c;
	  }, 1);
	  newShape.push(endPartShape);
	  var reshapedPermutedX = permutedX.reshape(newShape);
	  var prodGrad = prodGradFn_(reshapedPermutedX, dy, finalProdAxis);
	  // Undo the re-shaping now we have the dx vector, and permute back to
	  // original axes order.
	  prodGrad = prodGrad.reshape(permutedX.shape);
	  if (xPermutation != null) {
	    var undoPermutation = getUndoAxesPermutation(xPermutation);
	    prodGrad = transpose$2(prodGrad, undoPermutation);
	  }
	  return prodGrad;
	}
	// Running example:
	// [
	//   [
	//     [3.0, 4.0],
	//     [5.0, 6.0],
	//     [7.0, 8.0]
	//   ],
	//   [
	//     [3.0, 5.0],
	//     [0.0, 6.0],
	//     [5.0, 6.0]
	//   ]
	// ]
	//
	var prodGradConfig = {
	  kernelName: Prod,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    var axis = attrs.axis;
	    var axisArr = [];
	    if (axis === undefined || axis === null) {
	      axisArr = _x.shape.map(function (_, i) {
	        return i;
	      });
	    } else if (typeof axis === 'number') {
	      axisArr = [axis];
	    } else {
	      axisArr = axis;
	    }
	    return {
	      x: function x() {
	        return prodsGradFn_(_x, dy, axisArr);
	      }
	    };
	  }
	};

	var divGradConfig = {
	  kernelName: RealDiv,
	  inputsToSave: ['a', 'b'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 2),
	      a = _saved[0],
	      b = _saved[1];
	    var outShape = assertAndGetBroadcastShape(a.shape, b.shape);
	    var derA = function derA() {
	      var res = div$1(dy, cast$3(b, 'float32'));
	      var reduceAxes = getReductionAxes(a.shape, outShape);
	      if (reduceAxes.length > 0) {
	        return reshape$3(sum$3(res, reduceAxes), a.shape);
	      }
	      return res;
	    };
	    var derB = function derB() {
	      var res = mul(dy, cast$3(a, 'float32'));
	      var reduceAxes = getReductionAxes(b.shape, outShape);
	      if (reduceAxes.length > 0) {
	        res = reshape$3(sum$3(res, reduceAxes), b.shape);
	      }
	      var tmp = square$2(b);
	      return neg$2(div$1(res, cast$3(tmp, 'float32')));
	    };
	    return {
	      a: derA,
	      b: derB
	    };
	  }
	};

	var reciprocalGradConfig = {
	  kernelName: Reciprocal,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return div$1(dy, neg$2(square$2(_x)));
	      }
	    };
	  }
	};

	var relu6GradConfig = {
	  kernelName: Relu6$1,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      x = _saved[0];
	    var mask = mul(lessEqual$2(x, 6), step$2(x));
	    return {
	      x: function x() {
	        return mul(dy, cast$3(mask, 'float32'));
	      }
	    };
	  }
	};

	var reluGradConfig = {
	  kernelName: Relu$1,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return mul(dy, cast$3(step$2(_x), 'float32'));
	      }
	    };
	  }
	};

	var reshapeGradConfig = {
	  kernelName: Reshape$1,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return reshape$3(dy, _x.shape);
	      }
	    };
	  }
	};

	var resizeBilinearGradConfig$2 = {
	  kernelName: ResizeBilinear,
	  inputsToSave: ['images'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 1),
	      images = _saved[0];
	    var inputs = {
	      dy: dy,
	      images: images
	    };
	    var imagesDer = function imagesDer() {
	      return (
	        // tslint:disable-next-line: no-unnecessary-type-assertion
	        ENGINE.runKernel(ResizeBilinearGrad, inputs, attrs)
	      );
	    };
	    return {
	      images: imagesDer
	    };
	  }
	};

	var resizeNearestNeighborGradConfig$2 = {
	  kernelName: ResizeNearestNeighbor,
	  inputsToSave: ['images'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 1),
	      images = _saved[0];
	    var inputs = {
	      dy: dy,
	      images: images
	    };
	    var imagesDer = function imagesDer() {
	      return (
	        // tslint:disable-next-line: no-unnecessary-type-assertion
	        ENGINE.runKernel(ResizeNearestNeighborGrad, inputs, attrs)
	      );
	    };
	    return {
	      images: imagesDer
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var reverseGradConfig = {
	  kernelName: Reverse,
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var dims = attrs.dims;
	    var axes = parseAxisParam(dims, dy.shape);
	    return {
	      x: function x() {
	        return reverse$2(dy, axes);
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var roundGradConfig = {
	  kernelName: Round,
	  gradFunc: function gradFunc(dy) {
	    // TODO(nsthorat): Let gradients be null for cases where we want to stop
	    // backpropgation.
	    return {
	      x: function x() {
	        return zerosLike$3(dy);
	      }
	    };
	  }
	};

	var rsqrtGradConfig = {
	  kernelName: Rsqrt,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return neg$2(div$1(dy, mul(pow$3(_x, 1.5), 2)));
	      }
	    };
	  }
	};

	var selectGradConfig = {
	  kernelName: Select,
	  inputsToSave: ['condition'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _condition = _saved[0];
	    return {
	      // TODO(julianoks): Return null for condition gradient
	      // when backprop supports it.
	      condition: function condition() {
	        return cast$3(zerosLike$3(_condition), 'float32');
	      },
	      t: function t() {
	        return mul(dy, cast$3(_condition, dy.dtype));
	      },
	      e: function e() {
	        return mul(dy, cast$3(logicalNot$2(_condition), dy.dtype));
	      }
	    };
	  }
	};

	var seluGradConfig = {
	  kernelName: Selu$1,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        var mask = greater$3(_x, scalar(0));
	        var scaleAlpha = scalar(SELU_SCALEALPHA);
	        var scale = scalar(SELU_SCALE);
	        var greaterThanZeroDer = mul(dy, scale);
	        var lessEqualZeroDer = mul(mul(dy, scaleAlpha), exp$2(cast$3(_x, 'float32')));
	        return where(mask, greaterThanZeroDer, lessEqualZeroDer);
	      }
	    };
	  }
	};

	var sigmoidGradConfig = {
	  kernelName: Sigmoid$1,
	  outputsToSave: [true],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      y = _saved[0];
	    return {
	      x: function x() {
	        return mul(dy, mul(y, sub$2(scalar(1), y)));
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var signGradConfig = {
	  kernelName: Sign,
	  gradFunc: function gradFunc(dy) {
	    return {
	      x: function x() {
	        return zerosLike$3(dy);
	      }
	    };
	  }
	};

	var sinGradConfig = {
	  kernelName: Sin,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return mul(cos$2(cast$3(_x, 'float32')), dy);
	      }
	    };
	  }
	};

	var sinhGradConfig = {
	  kernelName: Sinh,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return mul(cosh$2(cast$3(_x, 'float32')), dy);
	      }
	    };
	  }
	};

	var sliceGradConfig = {
	  kernelName: Slice,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 1),
	      x = _saved[0];
	    var begin = attrs.begin,
	      size = attrs.size;
	    var inputShape = x.shape;
	    var _parseSliceParams = parseSliceParams(x, begin, size),
	      _parseSliceParams2 = _slicedToArray(_parseSliceParams, 2),
	      begin_ = _parseSliceParams2[0],
	      size_ = _parseSliceParams2[1];
	    // Create an Nx2 padding where the first column represents how many
	    // zeros are prepended (at start) for each dimension, and the second
	    // column indicates how many zeros are appended (at end).
	    // The number of zeros to append is the shape of the input
	    // elementwise-subtracted by both the begin vector and sizes vector.
	    var paddings = [];
	    for (var i = 0; i < dy.rank; i++) {
	      paddings.push([begin_[i], inputShape[i] - begin_[i] - size_[i]]);
	    }
	    return {
	      x: function x() {
	        return pad(dy, paddings);
	      }
	    };
	  }
	};

	var softmaxGradConfig = {
	  kernelName: Softmax$2,
	  outputsToSave: [true],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 1),
	      y = _saved[0];
	    var dim = attrs.dim;
	    var keepDims = true;
	    var dyTimesY = mul(dy, y);
	    return {
	      logits: function logits() {
	        return sub$2(dyTimesY, mul(sum$3(dyTimesY, [dim], keepDims), y));
	      }
	    };
	  }
	};

	var softplusGradConfig = {
	  kernelName: Softplus$1,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return mul(dy, sigmoid$2(_x));
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var spaceToBatchNDGradConfig = {
	  kernelName: SpaceToBatchND,
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var blockShape = attrs.blockShape,
	      paddings = attrs.paddings;
	    return {
	      x: function x() {
	        return batchToSpaceND$2(dy, blockShape, paddings);
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var splitVGradConfig = {
	  kernelName: SplitV,
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var axis = attrs.axis;
	    return {
	      x: function x() {
	        return concat$2(dy, axis);
	      }
	    };
	  }
	};

	var sqrtGradConfig = {
	  kernelName: Sqrt,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return div$1(dy, mul(sqrt$2(cast$3(_x, 'float32')), 2));
	      }
	    };
	  }
	};

	var squareGradConfig = {
	  kernelName: Square,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return mul(dy, mul(cast$3(_x, 'float32'), 2));
	      }
	    };
	  }
	};

	var squaredDifferenceGradConfig = {
	  kernelName: SquaredDifference,
	  inputsToSave: ['a', 'b'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 2),
	      a = _saved[0],
	      b = _saved[1];
	    var two = scalar(2);
	    var derA = function derA() {
	      return mul(dy, mul(two, sub$2(a, b)));
	    };
	    var derB = function derB() {
	      return mul(dy, mul(two, sub$2(b, a)));
	    };
	    return {
	      a: derA,
	      b: derB
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var stepGradConfig = {
	  kernelName: Step,
	  gradFunc: function gradFunc(dy) {
	    // TODO(manrajgrover): Return null for gradients when backprop supports
	    // it.
	    return {
	      x: function x() {
	        return zerosLike$3(dy);
	      }
	    };
	  }
	};

	var subGradConfig = {
	  kernelName: Sub,
	  inputsToSave: ['a', 'b'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 2),
	      a = _saved[0],
	      b = _saved[1];
	    var outShape = assertAndGetBroadcastShape(a.shape, b.shape);
	    var derA = function derA() {
	      var res = dy;
	      var reduceAxes = getReductionAxes(a.shape, outShape);
	      if (reduceAxes.length > 0) {
	        res = sum$3(res, reduceAxes);
	      }
	      return reshape$3(res, a.shape);
	    };
	    var derB = function derB() {
	      var res = dy;
	      var reduceAxes = getReductionAxes(b.shape, outShape);
	      if (reduceAxes.length > 0) {
	        res = sum$3(res, reduceAxes);
	      }
	      return reshape$3(neg$2(res), b.shape);
	    };
	    return {
	      a: derA,
	      b: derB
	    };
	  }
	};

	var sumGradConfig = {
	  kernelName: Sum,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 1),
	      x = _saved[0];
	    var expandedDyShape = x.shape.slice();
	    var axis = attrs.axis;
	    var axes = parseAxisParam(axis, x.shape);
	    axes.forEach(function (axis) {
	      expandedDyShape[axis] = 1;
	    });
	    var expandedDy = reshape$3(dy, expandedDyShape);
	    var derX = mul(expandedDy, ones$1(x.shape, 'float32'));
	    return {
	      x: function x() {
	        return derX;
	      }
	    };
	  }
	};

	var tanGradConfig = {
	  kernelName: Tan,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      _x = _saved[0];
	    return {
	      x: function x() {
	        return div$1(dy, square$2(cos$2(_x)));
	      }
	    };
	  }
	};

	var tanhGradConfig = {
	  kernelName: Tanh$1,
	  outputsToSave: [true],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      y = _saved[0];
	    return {
	      x: function x() {
	        return mul(sub$2(scalar(1), square$2(y)), dy);
	      }
	    };
	  }
	};

	var tileGradConfig = {
	  kernelName: Tile,
	  inputsToSave: ['x'],
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var _saved = _slicedToArray(saved, 1),
	      x = _saved[0];
	    var reps = attrs.reps;
	    var derX = function derX() {
	      var xGrad = zerosLike$3(x);
	      // TODO(cais): Maybe reduce memory footprint by avoiding repeated
	      // slicing.
	      if (x.rank === 1) {
	        for (var i = 0; i < reps[0]; ++i) {
	          xGrad = add$3(xGrad, slice$2(dy, [i * x.shape[0]], [x.shape[0]]));
	        }
	      } else if (x.rank === 2) {
	        for (var _i = 0; _i < reps[0]; ++_i) {
	          for (var j = 0; j < reps[1]; ++j) {
	            xGrad = add$3(xGrad, slice$2(dy, [_i * x.shape[0], j * x.shape[1]], [x.shape[0], x.shape[1]]));
	          }
	        }
	      } else if (x.rank === 3) {
	        for (var _i2 = 0; _i2 < reps[0]; ++_i2) {
	          for (var _j = 0; _j < reps[1]; ++_j) {
	            for (var k = 0; k < reps[2]; ++k) {
	              xGrad = add$3(xGrad, slice$2(dy, [_i2 * x.shape[0], _j * x.shape[1], k * x.shape[2]], [x.shape[0], x.shape[1], x.shape[2]]));
	            }
	          }
	        }
	      } else if (x.rank === 4) {
	        for (var _i3 = 0; _i3 < reps[0]; ++_i3) {
	          for (var _j2 = 0; _j2 < reps[1]; ++_j2) {
	            for (var _k = 0; _k < reps[2]; ++_k) {
	              for (var l = 0; l < reps[3]; ++l) {
	                xGrad = add$3(xGrad, slice$2(dy, [_i3 * x.shape[0], _j2 * x.shape[1], _k * x.shape[2], l * x.shape[3]], [x.shape[0], x.shape[1], x.shape[2], x.shape[3]]));
	              }
	            }
	          }
	        }
	      } else {
	        throw new Error("Gradient for tile operation is not implemented for rank-" + "".concat(x.rank, " tensors yet."));
	      }
	      return xGrad;
	    };
	    return {
	      x: derX
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var transposeGradConfig = {
	  kernelName: Transpose,
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var transposeAttrs = attrs;
	    var perm = transposeAttrs.perm;
	    var undoPerm = getUndoAxesPermutation(perm);
	    return {
	      x: function x() {
	        return transpose$2(dy, undoPerm);
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google Inc. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var unpackGradConfig = {
	  kernelName: Unpack,
	  gradFunc: function gradFunc(dy, saved, attrs) {
	    var unpackAttrs = attrs;
	    var axis = unpackAttrs.axis;
	    return {
	      value: function value() {
	        return stack(dy, axis);
	      }
	    };
	  }
	};

	var unsortedSegmentSumGradConfig = {
	  kernelName: UnsortedSegmentSum,
	  inputsToSave: ['segmentIds'],
	  gradFunc: function gradFunc(dy, saved) {
	    var _saved = _slicedToArray(saved, 1),
	      segmentIds = _saved[0];
	    var derX = function derX() {
	      return gatherDropNegatives(dy, segmentIds);
	    };
	    return {
	      x: derX
	    };
	  }
	};
	function gatherDropNegatives(x, indices) {
	  // Helper function for unsorted segment ops. Gathers params for
	  // positive segment ids and gathers 0 for inputs with negative segment id.
	  // Mirrors _GatherDropNegatives from tensorflow/python/ops/math_grad.py
	  var zeroClippedIndices = maximum$4(indices, zerosLike$3(indices));
	  var gathered = gather$1(x, zeroClippedIndices);
	  var isPositive = greaterEqual$2(indices, scalar(0, 'int32'));
	  var numIters = gathered.rank - isPositive.rank;
	  for (var i = 0; i < numIters; ++i) {
	    isPositive = expandDims$3(isPositive, i + 1);
	  }
	  isPositive = logicalAnd$2(isPositive, ones$1(gathered.shape, 'bool'));
	  var zeroSlice = zerosLike$3(gathered);
	  return where(isPositive, gathered, zeroSlice);
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var zerosLikeGradConfig = {
	  kernelName: ZerosLike,
	  gradFunc: function gradFunc(dy) {
	    return {
	      x: function x() {
	        return zerosLike$3(dy);
	      }
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	// Export all kernel configs here so that the package can auto register them
	var gradConfigs = [absGradConfig, acosGradConfig, acoshGradConfig, addGradConfig, addNGradConfig, argMaxGradConfig, argMinGradConfig, asinGradConfig, asinhGradConfig, atan2GradConfig, atanGradConfig, atanhGradConfig, avgPool3DGradConfig$2, avgPoolGradConfig$2, batchMatMulGradConfig, batchToSpaceNDGradConfig, broadcastToGradConfig, castGradConfig, ceilGradConfig, clipByValueGradConfig, complexAbsGradConfig, concatGradConfig, conv2DBackpropInputGradConfig, conv2DGradConfig, conv3DGradConfig, cosGradConfig, coshGradConfig, cumsumGradConfig, depthwiseConv2dNativeGradConfig, dilation2dGradConfig, divGradConfig, eluGradConfig$2, erfGradConfig, expGradConfig, expandDimsGradConfig, expm1GradConfig, floorDivGradConfig, floorGradConfig, fusedBatchNormGradConfig, gatherGradConfig, greaterEqualGradConfig, identityGradConfig, isFiniteGradConfig, isInfGradConfig, isNanGradConfig, leakyReluGradConfig, log1pGradConfig, logGradConfig, logSoftmaxGradConfig, lrnGradConfig, maxGradConfig, maxGradConfig, maximumGradConfig, maxPool3DGradConfig$2, maxPoolGradConfig$2, meanGradConfig, minGradConfig, minimumGradConfig, mirrorPadGradConfig, modGradConfig, multiplyGradConfig, negGradConfig, oneHotGradConfig, onesLikeGradConfig, packGradConfig, padV2GradConfig, padV2GradConfig, powGradConfig, preluGradConfig, prodGradConfig, reciprocalGradConfig, relu6GradConfig, reluGradConfig, reshapeGradConfig, resizeBilinearGradConfig$2, resizeNearestNeighborGradConfig$2, reverseGradConfig, roundGradConfig, rsqrtGradConfig, selectGradConfig, seluGradConfig, sigmoidGradConfig, signGradConfig, sinGradConfig, sinhGradConfig, sliceGradConfig, softmaxGradConfig, softplusGradConfig, spaceToBatchNDGradConfig, spaceToBatchNDGradConfig, splitVGradConfig, splitVGradConfig, sqrtGradConfig, squaredDifferenceGradConfig, squareGradConfig, stepGradConfig, subGradConfig, sumGradConfig, tanGradConfig, tanhGradConfig, tileGradConfig, transposeGradConfig, unpackGradConfig, unsortedSegmentSumGradConfig, zerosLikeGradConfig];
	for (var _i$2 = 0, _gradConfigs = gradConfigs; _i$2 < _gradConfigs.length; _i$2++) {
	  var gradientConfig = _gradConfigs[_i$2];
	  registerGradient(gradientConfig);
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.abs = function () {
	  this.throwIfDisposed();
	  return abs$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.acos = function () {
	  this.throwIfDisposed();
	  return acos$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.acosh = function () {
	  this.throwIfDisposed();
	  return acosh$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.add = function (b) {
	  this.throwIfDisposed();
	  return add$3(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.all = function (axis, keepDims) {
	  this.throwIfDisposed();
	  return all$2(this, axis, keepDims);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.any = function (axis, keepDims) {
	  this.throwIfDisposed();
	  return any$2(this, axis, keepDims);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.argMax = function (axis) {
	  this.throwIfDisposed();
	  return argMax$2(this, axis);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.argMin = function (axis) {
	  this.throwIfDisposed();
	  return argMin$2(this, axis);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Converts a size-1 `tf.Tensor` to a `tf.Scalar`.
	 * @doc {heading: 'Tensors', subheading: 'Classes'}
	 */
	getGlobalTensorClass().prototype.asScalar = function () {
	  this.throwIfDisposed();
	  assert$1(this.size === 1, function () {
	    return 'The array must have only 1 element.';
	  });
	  return reshape$3(this, []);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Casts a `tf.Tensor` to a specified dtype.
	 *
	 * @param dtype Data-type to cast the tensor to.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Classes'}
	 */
	getGlobalTensorClass().prototype.asType = function (dtype) {
	  this.throwIfDisposed();
	  return cast$3(this, dtype);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Converts a `tf.Tensor` to a `tf.Tensor1D`.
	 * @doc {heading: 'Tensors', subheading: 'Classes'}
	 */
	getGlobalTensorClass().prototype.as1D = function () {
	  this.throwIfDisposed();
	  return reshape$3(this, [this.size]);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Converts a `tf.Tensor` to a `tf.Tensor2D`.
	 *
	 * @param rows Number of rows in `tf.Tensor2D`.
	 * @param columns Number of columns in `tf.Tensor2D`.
	 * @doc {heading: 'Tensors', subheading: 'Classes'}
	 */
	getGlobalTensorClass().prototype.as2D = function (rows, columns) {
	  this.throwIfDisposed();
	  return reshape$3(this, [rows, columns]);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Converts a `tf.Tensor` to a `tf.Tensor3D`.
	 *
	 * @param rows Number of rows in `tf.Tensor3D`.
	 * @param columns Number of columns in `tf.Tensor3D`.
	 * @param depth Depth of `tf.Tensor3D`.
	 * @doc {heading: 'Tensors', subheading: 'Classes'}
	 */
	getGlobalTensorClass().prototype.as3D = function (rows, columns, depth) {
	  this.throwIfDisposed();
	  return reshape$3(this, [rows, columns, depth]);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Converts a `tf.Tensor` to a `tf.Tensor4D`.
	 *
	 * @param rows Number of rows in `tf.Tensor4D`.
	 * @param columns Number of columns in `tf.Tensor4D`.
	 * @param depth Depth of `tf.Tensor4D`.
	 * @param depth2 4th dimension of `tf.Tensor4D`.
	 * @doc {heading: 'Tensors', subheading: 'Classes'}
	 */
	getGlobalTensorClass().prototype.as4D = function (rows, columns, depth, depth2) {
	  this.throwIfDisposed();
	  return reshape$3(this, [rows, columns, depth, depth2]);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Converts a `tf.Tensor` to a `tf.Tensor5D`.
	 *
	 * @param rows Number of rows in `tf.Tensor5D`.
	 * @param columns Number of columns in `tf.Tensor5D`.
	 * @param depth Depth of `tf.Tensor5D`.
	 * @param depth2 4th dimension of `tf.Tensor5D`.
	 * @param depth3 5th dimension of 'tf.Tensor5D'
	 *
	 * @doc {heading: 'Tensors', subheading: 'Classes'}
	 */
	getGlobalTensorClass().prototype.as5D = function (rows, columns, depth, depth2, depth3) {
	  this.throwIfDisposed();
	  return reshape$3(this, [rows, columns, depth, depth2, depth3]);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.asin = function () {
	  this.throwIfDisposed();
	  return asin$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.asinh = function () {
	  this.throwIfDisposed();
	  return asinh$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.atan = function () {
	  this.throwIfDisposed();
	  return atan$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.atan2 = function (b) {
	  this.throwIfDisposed();
	  return atan2$2(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.atanh = function () {
	  this.throwIfDisposed();
	  return atanh$2(this);
	};

	getGlobalTensorClass().prototype.avgPool = function (filterSize, strides, pad, dimRoundingMode) {
	  this.throwIfDisposed();
	  return avgPool$2(this, filterSize, strides, pad, dimRoundingMode);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.batchToSpaceND = function (blockShape, crops) {
	  this.throwIfDisposed();
	  return batchToSpaceND$2(this, blockShape, crops);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.batchNorm = function (mean, variance, offset, scale, varianceEpsilon) {
	  this.throwIfDisposed();
	  return batchNorm$2(this, mean, variance, offset, scale, varianceEpsilon);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.broadcastTo = function (shape) {
	  this.throwIfDisposed();
	  return broadcastTo(this, shape);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.cast = function (dtype) {
	  this.throwIfDisposed();
	  return cast$3(this, dtype);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.ceil = function () {
	  this.throwIfDisposed();
	  return ceil$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.clipByValue = function (min, max) {
	  this.throwIfDisposed();
	  return clipByValue$2(this, min, max);
	};

	getGlobalTensorClass().prototype.concat = function (x, axis) {
	  this.throwIfDisposed();
	  if (x instanceof Tensor) {
	    x = [x];
	  }
	  return concat$2([this].concat(_toConsumableArray(x)), axis);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.conv1d = function (filter, stride, pad, dataFormat, dilation, dimRoundingMode) {
	  this.throwIfDisposed();
	  return conv1d$2(this, filter, stride, pad, dataFormat, dilation, dimRoundingMode);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.conv2dTranspose = function (filter, outputShape, strides, pad, dimRoundingMode) {
	  this.throwIfDisposed();
	  return conv2dTranspose$1(this, filter, outputShape, strides, pad, dimRoundingMode);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.conv2d = function (filter, strides, pad, dataFormat, dilations, dimRoundingMode) {
	  this.throwIfDisposed();
	  return conv2d$4(this, filter, strides, pad, dataFormat, dilations, dimRoundingMode);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.cos = function () {
	  this.throwIfDisposed();
	  return cos$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.cosh = function () {
	  this.throwIfDisposed();
	  return cosh$2(this);
	};

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the 'License');
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an 'AS IS' BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.cumprod = function (axis, exclusive, reverse) {
	  this.throwIfDisposed();
	  return cumprod$2(this, axis, exclusive, reverse);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.cumsum = function (axis, exclusive, reverse) {
	  this.throwIfDisposed();
	  return cumsum$2(this, axis, exclusive, reverse);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.depthToSpace = function (blockSize, dataFormat) {
	  this.throwIfDisposed();
	  return depthToSpace$2(this, blockSize, dataFormat);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.depthwiseConv2d = function (filter, strides, pad, dataFormat, dilations, dimRoundingMode) {
	  this.throwIfDisposed();
	  return depthwiseConv2d$3(this, filter, strides, pad, dataFormat, dilations, dimRoundingMode);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.dilation2d = function (filter, strides, pad, dilations, dataFormat) {
	  this.throwIfDisposed();
	  return dilation2d(this, filter, strides, pad, dilations, dataFormat);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.divNoNan = function (b) {
	  this.throwIfDisposed();
	  return divNoNan(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.div = function (b) {
	  this.throwIfDisposed();
	  return div$1(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.dot = function (b) {
	  this.throwIfDisposed();
	  return dot$2(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.elu = function () {
	  this.throwIfDisposed();
	  return elu$4(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.equal = function (b) {
	  this.throwIfDisposed();
	  return equal$2(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.erf = function () {
	  this.throwIfDisposed();
	  return erf$2(this);
	};

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.euclideanNorm = function (axis, keepDims) {
	  this.throwIfDisposed();
	  return euclideanNorm(this, axis, keepDims);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.exp = function () {
	  this.throwIfDisposed();
	  return exp$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.expandDims = function (axis) {
	  this.throwIfDisposed();
	  return expandDims$3(this, axis);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.expm1 = function () {
	  this.throwIfDisposed();
	  return expm1$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.fft = function () {
	  this.throwIfDisposed();
	  return fft$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Flatten a Tensor to a 1D array.
	 * @doc {heading: 'Tensors', subheading: 'Classes'}
	 */
	getGlobalTensorClass().prototype.flatten = function () {
	  this.throwIfDisposed();
	  return reshape$3(this, [this.size]);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.floor = function () {
	  this.throwIfDisposed();
	  return floor$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.floorDiv = function (b) {
	  this.throwIfDisposed();
	  return floorDiv$2(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.gather = function (indices, axis, batchDims) {
	  this.throwIfDisposed();
	  return gather$1(this, indices, axis, batchDims);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.greaterEqual = function (b) {
	  this.throwIfDisposed();
	  return greaterEqual$2(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.greater = function (b) {
	  this.throwIfDisposed();
	  return greater$3(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.ifft = function () {
	  this.throwIfDisposed();
	  return ifft$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.irfft = function () {
	  this.throwIfDisposed();
	  return irfft(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.isFinite = function () {
	  this.throwIfDisposed();
	  return isFinite$3(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.isInf = function () {
	  this.throwIfDisposed();
	  return isInf$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.isNaN = function () {
	  this.throwIfDisposed();
	  return isNaN$3(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.leakyRelu = function (alpha) {
	  this.throwIfDisposed();
	  return leakyRelu$2(this, alpha);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.lessEqual = function (b) {
	  this.throwIfDisposed();
	  return lessEqual$2(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.less = function (b) {
	  this.throwIfDisposed();
	  return less$3(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.localResponseNormalization = function (depthRadius, bias, alpha, beta) {
	  this.throwIfDisposed();
	  return localResponseNormalization(this, depthRadius, bias, alpha, beta);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.logSigmoid = function () {
	  this.throwIfDisposed();
	  return logSigmoid(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.logSoftmax = function (axis) {
	  this.throwIfDisposed();
	  return logSoftmax(this, axis);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.logSumExp = function (axis, keepDims) {
	  this.throwIfDisposed();
	  return logSumExp(this, axis, keepDims);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.log = function () {
	  this.throwIfDisposed();
	  return log$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.log1p = function () {
	  this.throwIfDisposed();
	  return log1p$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.logicalAnd = function (b) {
	  this.throwIfDisposed();
	  return logicalAnd$2(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.logicalNot = function () {
	  this.throwIfDisposed();
	  return logicalNot$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.logicalOr = function (b) {
	  this.throwIfDisposed();
	  return logicalOr$2(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.logicalXor = function (b) {
	  this.throwIfDisposed();
	  return logicalXor(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.matMul = function (b, transposeA, transposeB) {
	  this.throwIfDisposed();
	  return matMul$1(this, b, transposeA, transposeB);
	};

	getGlobalTensorClass().prototype.maxPool = function (filterSize, strides, pad, dimRoundingMode) {
	  this.throwIfDisposed();
	  return maxPool$2(this, filterSize, strides, pad, dimRoundingMode);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.max = function (axis, keepDims) {
	  this.throwIfDisposed();
	  return max$3(this, axis, keepDims);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.maximum = function (b) {
	  this.throwIfDisposed();
	  return maximum$4(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.mean = function (axis, keepDims) {
	  this.throwIfDisposed();
	  return mean$3(this, axis, keepDims);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.min = function (axis, keepDims) {
	  this.throwIfDisposed();
	  return min$3(this, axis, keepDims);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.minimum = function (b) {
	  this.throwIfDisposed();
	  return minimum$4(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.mirrorPad = function (paddings, mode) {
	  this.throwIfDisposed();
	  return mirrorPad$1(this, paddings, mode);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.mod = function (b) {
	  this.throwIfDisposed();
	  return mod$2(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.mul = function (b) {
	  this.throwIfDisposed();
	  return mul(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.neg = function () {
	  this.throwIfDisposed();
	  return neg$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.norm = function (ord, axis, keepDims) {
	  this.throwIfDisposed();
	  return norm(this, ord, axis, keepDims);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.notEqual = function (b) {
	  this.throwIfDisposed();
	  return notEqual$2(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.oneHot = function (depth) {
	  var onValue = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
	  var offValue = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
	  this.throwIfDisposed();
	  return oneHot$3(this, depth, onValue, offValue);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.onesLike = function () {
	  this.throwIfDisposed();
	  return onesLike$3(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.pad = function (paddings, constantValue) {
	  this.throwIfDisposed();
	  return pad(this, paddings, constantValue);
	};

	getGlobalTensorClass().prototype.pool = function (windowShape, poolingType, padding, dilationRate, strides, dimRoundingMode) {
	  this.throwIfDisposed();
	  return pool$1(this, windowShape, poolingType, padding, dilationRate, strides, dimRoundingMode);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.pow = function (exp) {
	  this.throwIfDisposed();
	  return pow$3(this, exp);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.prelu = function (alpha) {
	  this.throwIfDisposed();
	  return prelu$3(this, alpha);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.prod = function (axis, keepDims) {
	  this.throwIfDisposed();
	  return prod$2(this, axis, keepDims);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.reciprocal = function () {
	  this.throwIfDisposed();
	  return reciprocal$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.relu = function () {
	  this.throwIfDisposed();
	  return relu$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.relu6 = function () {
	  this.throwIfDisposed();
	  return relu6$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Reshapes the tensor into the shape of the provided tensor.
	 *
	 * @param x The tensor of required shape.
	 *
	 * @doc {heading: 'Tensors', subheading: 'Classes'}
	 */
	getGlobalTensorClass().prototype.reshapeAs = function (x) {
	  this.throwIfDisposed();
	  return reshape$3(this, x.shape);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.reshape = function (shape) {
	  this.throwIfDisposed();
	  return reshape$3(this, shape);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.resizeBilinear = function (newShape2D, alignCorners, halfPixelCenters) {
	  this.throwIfDisposed();
	  return resizeBilinear$3(this, newShape2D, alignCorners, halfPixelCenters);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.resizeNearestNeighbor = function (newShape2D, alignCorners, halfFloatCenters) {
	  this.throwIfDisposed();
	  return resizeNearestNeighbor$2(this, newShape2D, alignCorners, halfFloatCenters);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.reverse = function (axis) {
	  this.throwIfDisposed();
	  return reverse$2(this, axis);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.rfft = function () {
	  this.throwIfDisposed();
	  return rfft(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.round = function () {
	  this.throwIfDisposed();
	  return round$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.rsqrt = function () {
	  this.throwIfDisposed();
	  return rsqrt$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.selu = function () {
	  this.throwIfDisposed();
	  return selu$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.separableConv2d = function (depthwiseFilter, pointwiseFilter, strides, pad, dilation, dataFormat) {
	  this.throwIfDisposed();
	  return separableConv2d$1(this, depthwiseFilter, pointwiseFilter, strides, pad, dilation, dataFormat);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.sigmoid = function () {
	  this.throwIfDisposed();
	  return sigmoid$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.sign = function () {
	  this.throwIfDisposed();
	  return sign$3(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.sin = function () {
	  this.throwIfDisposed();
	  return sin$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.sinh = function () {
	  this.throwIfDisposed();
	  return sinh$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.slice = function (begin, size) {
	  this.throwIfDisposed();
	  return slice$2(this, begin, size);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.softmax = function (dim) {
	  this.throwIfDisposed();
	  return softmax$3(this, dim);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.softplus = function () {
	  this.throwIfDisposed();
	  return softplus$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.spaceToBatchND = function (blockShape, paddings) {
	  this.throwIfDisposed();
	  return spaceToBatchND$2(this, blockShape, paddings);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.split = function (numOrSizeSplits, axis) {
	  this.throwIfDisposed();
	  return split$3(this, numOrSizeSplits, axis);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.sqrt = function () {
	  this.throwIfDisposed();
	  return sqrt$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.square = function () {
	  this.throwIfDisposed();
	  return square$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.squaredDifference = function (b) {
	  this.throwIfDisposed();
	  return squaredDifference$2(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.squeeze = function (axis) {
	  this.throwIfDisposed();
	  return squeeze(this, axis);
	};

	getGlobalTensorClass().prototype.stack = function (x, axis) {
	  this.throwIfDisposed();
	  var tensorsToBeStacked = x instanceof Tensor ? [this, x] : [this].concat(_toConsumableArray(x));
	  return stack(tensorsToBeStacked, axis);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.step = function (alpha) {
	  this.throwIfDisposed();
	  return step$2(this, alpha);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.stridedSlice = function (begin, end, strides, beginMask, endMask, ellipsisMask, newAxisMask, shrinkAxisMask) {
	  this.throwIfDisposed();
	  return stridedSlice$2(this, begin, end, strides, beginMask, endMask, ellipsisMask, newAxisMask, shrinkAxisMask);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.sub = function (b) {
	  this.throwIfDisposed();
	  return sub$2(this, b);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.sum = function (axis, keepDims) {
	  this.throwIfDisposed();
	  return sum$3(this, axis, keepDims);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.tan = function () {
	  this.throwIfDisposed();
	  return tan$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.tanh = function () {
	  this.throwIfDisposed();
	  return tanh$2(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.tile = function (reps) {
	  this.throwIfDisposed();
	  return tile$3(this, reps);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Casts the array to type `bool`
	 *
	 * @doc {heading: 'Tensors', subheading: 'Classes'}
	 */
	getGlobalTensorClass().prototype.toBool = function () {
	  this.throwIfDisposed();
	  return cast$3(this, 'bool');
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Casts the array to type `float32`
	 *
	 * @doc {heading: 'Tensors', subheading: 'Classes'}
	 */
	getGlobalTensorClass().prototype.toFloat = function () {
	  this.throwIfDisposed();
	  return cast$3(this, 'float32');
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Casts the array to type `int32`
	 *
	 * @doc {heading: 'Tensors', subheading: 'Classes'}
	 */
	getGlobalTensorClass().prototype.toInt = function () {
	  this.throwIfDisposed();
	  return cast$3(this, 'int32');
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.topk = function (k, sorted) {
	  this.throwIfDisposed();
	  return topk(this, k, sorted);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.transpose = function (perm) {
	  this.throwIfDisposed();
	  return transpose$2(this, perm);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.unique = function (axis) {
	  this.throwIfDisposed();
	  return unique$3(this, axis);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.unsortedSegmentSum = function (segmentIds, numSegments) {
	  this.throwIfDisposed();
	  return unsortedSegmentSum$2(this, segmentIds, numSegments);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.unstack = function (axis) {
	  this.throwIfDisposed();
	  return unstack(this, axis);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.where = function (condition, x) {
	  this.throwIfDisposed();
	  return where(condition, this, x);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	getGlobalTensorClass().prototype.zerosLike = function () {
	  this.throwIfDisposed();
	  return zerosLike$3(this);
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	/**
	 * Explicit error types.
	 *
	 * See the following link for more information about why the code includes
	 * calls to setPrototypeOf:
	 *
	 * https://github.com/Microsoft/TypeScript-wiki/blob/master/Breaking-Changes.md#extending-built-ins-like-error-array-and-map-may-no-longer-work
	 */
	// tslint:enable
	/**
	 * Equivalent of Python's AttributeError.
	 */
	var AttributeError = /*#__PURE__*/function (_Error) {
	  _inherits(AttributeError, _Error);
	  var _super = _createSuper(AttributeError);
	  function AttributeError(message) {
	    var _this;
	    _classCallCheck(this, AttributeError);
	    _this = _super.call(this, message);
	    // Set the prototype explicitly.
	    Object.setPrototypeOf(_assertThisInitialized(_this), AttributeError.prototype);
	    return _this;
	  }
	  return _createClass(AttributeError);
	}( /*#__PURE__*/_wrapNativeSuper(Error));
	/**
	 * Equivalent of Python's RuntimeError.
	 */
	var RuntimeError = /*#__PURE__*/function (_Error2) {
	  _inherits(RuntimeError, _Error2);
	  var _super2 = _createSuper(RuntimeError);
	  function RuntimeError(message) {
	    var _this2;
	    _classCallCheck(this, RuntimeError);
	    _this2 = _super2.call(this, message);
	    // Set the prototype explicitly.
	    Object.setPrototypeOf(_assertThisInitialized(_this2), RuntimeError.prototype);
	    return _this2;
	  }
	  return _createClass(RuntimeError);
	}( /*#__PURE__*/_wrapNativeSuper(Error));
	/**
	 * Equivalent of Python's ValueError.
	 */
	var ValueError = /*#__PURE__*/function (_Error3) {
	  _inherits(ValueError, _Error3);
	  var _super3 = _createSuper(ValueError);
	  function ValueError(message) {
	    var _this3;
	    _classCallCheck(this, ValueError);
	    _this3 = _super3.call(this, message);
	    // Set the prototype explicitly.
	    Object.setPrototypeOf(_assertThisInitialized(_this3), ValueError.prototype);
	    return _this3;
	  }
	  return _createClass(ValueError);
	}( /*#__PURE__*/_wrapNativeSuper(Error));
	/**
	 * Equivalent of Python's NotImplementedError.
	 */
	var NotImplementedError = /*#__PURE__*/function (_Error4) {
	  _inherits(NotImplementedError, _Error4);
	  var _super4 = _createSuper(NotImplementedError);
	  function NotImplementedError(message) {
	    var _this4;
	    _classCallCheck(this, NotImplementedError);
	    _this4 = _super4.call(this, message);
	    // Set the prototype explicitly.
	    Object.setPrototypeOf(_assertThisInitialized(_this4), NotImplementedError.prototype);
	    return _this4;
	  }
	  return _createClass(NotImplementedError);
	}( /*#__PURE__*/_wrapNativeSuper(Error));
	/**
	 * Equivalent of Python's AssertionError.
	 */
	var AssertionError = /*#__PURE__*/function (_Error5) {
	  _inherits(AssertionError, _Error5);
	  var _super5 = _createSuper(AssertionError);
	  function AssertionError(message) {
	    var _this5;
	    _classCallCheck(this, AssertionError);
	    _this5 = _super5.call(this, message);
	    // Set the prototype explicitly.
	    Object.setPrototypeOf(_assertThisInitialized(_this5), AssertionError.prototype);
	    return _this5;
	  }
	  return _createClass(AssertionError);
	}( /*#__PURE__*/_wrapNativeSuper(Error));
	/**
	 * Equivalent of Python's IndexError.
	 */
	var IndexError = /*#__PURE__*/function (_Error6) {
	  _inherits(IndexError, _Error6);
	  var _super6 = _createSuper(IndexError);
	  function IndexError(message) {
	    var _this6;
	    _classCallCheck(this, IndexError);
	    _this6 = _super6.call(this, message);
	    // Set the prototype explicitly.
	    Object.setPrototypeOf(_assertThisInitialized(_this6), IndexError.prototype);
	    return _this6;
	  }
	  return _createClass(IndexError);
	}( /*#__PURE__*/_wrapNativeSuper(Error));

	/**
	 * @license
	 * Copyright 2022 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	/**
	 * LruCache: A mapping from the String to T. If the number of the entries is
	 * exceeding the `maxEntries`, the LruCache will delete the least recently
	 * used entry.
	 */
	var LruCache = /*#__PURE__*/function () {
	  function LruCache(maxEntries) {
	    _classCallCheck(this, LruCache);
	    this.maxEntries = maxEntries || 100;
	    this.cache = new Map();
	  }
	  /**
	   * Get the entry for the key and mark it as used recently.
	   */
	  _createClass(LruCache, [{
	    key: "get",
	    value: function get(key) {
	      var entry;
	      if (this.cache.has(key)) {
	        entry = this.cache.get(key);
	        this.cache.delete(key);
	        this.cache.set(key, entry);
	      }
	      return entry;
	    }
	    /**
	     * Put the entry into the cache. If the key already existed, mark the key as
	     * used recently.
	     */
	  }, {
	    key: "put",
	    value: function put(key, value) {
	      if (this.cache.has(key)) {
	        this.cache.delete(key);
	      } else if (this.cache.size >= this.maxEntries) {
	        var keyToDelete = this.cache.keys().next().value;
	        this.cache.delete(keyToDelete);
	      }
	      this.cache.set(key, value);
	    }
	    /**
	     * Get the MaxEntries of the cache.
	     */
	  }, {
	    key: "getMaxEntries",
	    value: function getMaxEntries() {
	      return this.maxEntries;
	    }
	    /**
	     * Set the MaxEntries of the cache. If the maxEntries is decreased, reduce
	     * entries in the cache.
	     */
	  }, {
	    key: "setMaxEntries",
	    value: function setMaxEntries(maxEntries) {
	      if (maxEntries < 0) {
	        throw new Error("The maxEntries of LRU caches must be at least 0, but got ".concat(maxEntries, "."));
	      }
	      if (this.maxEntries > maxEntries) {
	        for (var i = 0; i < this.maxEntries - maxEntries; i++) {
	          var keyToDelete = this.cache.keys().next().value;
	          this.cache.delete(keyToDelete);
	        }
	      }
	      this.maxEntries = maxEntries;
	    }
	  }]);
	  return LruCache;
	}();

	// tslint:enable
	/**
	 * If `value` is an Array, equivalent to Python's `value * numValues`.
	 * If `value` is not an Array, equivalent to Python's `[value] * numValues`
	 */
	// tslint:disable-next-line:no-any
	function pyListRepeat(value, numValues) {
	  if (Array.isArray(value)) {
	    // tslint:disable-next-line:no-any
	    var newArray = [];
	    for (var i = 0; i < numValues; i++) {
	      newArray = newArray.concat(value);
	    }
	    return newArray;
	  } else {
	    var _newArray = new Array(numValues);
	    _newArray.fill(value);
	    return _newArray;
	  }
	}
	function assert(val, message) {
	  if (!val) {
	    throw new AssertionError(message);
	  }
	}
	/**
	 * Count the number of elements of the `array` that are equal to `reference`.
	 */
	function count(array, refernce) {
	  var counter = 0;
	  var _iterator = _createForOfIteratorHelper(array),
	    _step;
	  try {
	    for (_iterator.s(); !(_step = _iterator.n()).done;) {
	      var item = _step.value;
	      if (item === refernce) {
	        counter++;
	      }
	    }
	  } catch (err) {
	    _iterator.e(err);
	  } finally {
	    _iterator.f();
	  }
	  return counter;
	}
	/**
	 * If an array is of length 1, just return the first element. Otherwise, return
	 * the full array.
	 * @param tensors
	 */
	function singletonOrArray(xs) {
	  if (xs.length === 1) {
	    return xs[0];
	  }
	  return xs;
	}
	/**
	 * Normalizes a list/tensor into a list.
	 *
	 * If a tensor is passed, we return
	 * a list of size 1 containing the tensor.
	 *
	 * @param x target object to be normalized.
	 */
	// tslint:disable-next-line:no-any
	function toList(x) {
	  if (Array.isArray(x)) {
	    return x;
	  }
	  return [x];
	}
	/**
	 * Generate a UID for a list
	 */
	// tslint:disable-next-line:no-any
	function objectListUid(objs) {
	  var objectList = toList(objs);
	  var retVal = '';
	  var _iterator2 = _createForOfIteratorHelper(objectList),
	    _step2;
	  try {
	    for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	      var obj = _step2.value;
	      if (obj.id == null) {
	        throw new ValueError("Object ".concat(obj, " passed to objectListUid without an id"));
	      }
	      if (retVal !== '') {
	        retVal = retVal + ', ';
	      }
	      retVal = "".concat(retVal).concat(Math.abs(obj.id));
	    }
	  } catch (err) {
	    _iterator2.e(err);
	  } finally {
	    _iterator2.f();
	  }
	  return retVal;
	}
	/**
	 * Converts string to snake-case.
	 * @param name
	 */
	function toSnakeCase(name) {
	  var intermediate = name.replace(/(.)([A-Z][a-z0-9]+)/g, '$1_$2');
	  var insecure = intermediate.replace(/([a-z])([A-Z])/g, '$1_$2').toLowerCase();
	  /*
	   If the class is private the name starts with "_" which is not secure
	   for creating scopes. We prefix the name with "private" in this case.
	   */
	  if (insecure[0] !== '_') {
	    return insecure;
	  }
	  return 'private' + insecure;
	}
	function toCamelCase(identifier) {
	  // quick return for empty string or single character strings
	  if (identifier.length <= 1) {
	    return identifier;
	  }
	  // Check for the underscore indicating snake_case
	  if (identifier.indexOf('_') === -1) {
	    return identifier;
	  }
	  return identifier.replace(/[_]+(\w|$)/g, function (m, p1) {
	    return p1.toUpperCase();
	  });
	}
	// tslint:disable-next-line:no-any
	var _GLOBAL_CUSTOM_OBJECTS = {};
	function serializeKerasObject(instance) {
	  if (instance === null || instance === undefined) {
	    return null;
	  }
	  var dict = {};
	  dict['className'] = instance.getClassName();
	  dict['config'] = instance.getConfig();
	  return dict;
	}
	/**
	 * Replace ndarray-style scalar objects in serialization objects with numbers.
	 *
	 * Background: In some versions of tf.keras, certain scalar values in the HDF5
	 * model save file can be serialized as: `{'type': 'ndarray', 'value': num}`,
	 * where in `num` is a plain number. This method converts such serialization
	 * to a `number`.
	 *
	 * @param config The keras-format serialization object to be processed
	 *   (in place).
	 */
	function convertNDArrayScalarsInConfig(config) {
	  if (config == null || _typeof(config) !== 'object') {
	    return;
	  } else if (Array.isArray(config)) {
	    config.forEach(function (configItem) {
	      return convertNDArrayScalarsInConfig(configItem);
	    });
	  } else {
	    var fields = Object.keys(config);
	    for (var _i = 0, _fields = fields; _i < _fields.length; _i++) {
	      var field = _fields[_i];
	      var value = config[field];
	      if (value != null && _typeof(value) === 'object') {
	        if (!Array.isArray(value) && value['type'] === 'ndarray' && typeof value['value'] === 'number') {
	          config[field] = value['value'];
	        } else {
	          convertNDArrayScalarsInConfig(value);
	        }
	      }
	    }
	  }
	}
	/**
	 * Deserialize a saved Keras Object
	 * @param identifier either a string ID or a saved Keras dictionary
	 * @param moduleObjects a list of Python class names to object constructors
	 * @param customObjects a list of Python class names to object constructors
	 * @param printableModuleName debug text for the object being reconstituted
	 * @param fastWeightInit Optional flag to use fast weight initialization
	 *   during deserialization. This is applicable to cases in which
	 *   the initialization will be immediately overwritten by loaded weight
	 *   values. Default: `false`.
	 * @returns a TensorFlow.js Layers object
	 */
	// tslint:disable:no-any
	function deserializeKerasObject(identifier) {
	  var moduleObjects = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	  var customObjects = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
	  var printableModuleName = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'object';
	  var fastWeightInit = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
	  // tslint:enable
	  if (typeof identifier === 'string') {
	    var functionName = identifier;
	    var fn;
	    if (functionName in customObjects) {
	      fn = customObjects[functionName];
	    } else if (functionName in _GLOBAL_CUSTOM_OBJECTS) {
	      fn = _GLOBAL_CUSTOM_OBJECTS[functionName];
	    } else {
	      fn = moduleObjects[functionName];
	      if (fn == null) {
	        throw new ValueError("Unknown ".concat(printableModuleName, ": ").concat(identifier, ". ") + "This may be due to one of the following reasons:\n" + "1. The ".concat(printableModuleName, " is defined in Python, in which ") + "case it needs to be ported to TensorFlow.js or your JavaScript " + "code.\n" + "2. The custom ".concat(printableModuleName, " is defined in JavaScript, ") + "but is not registered properly with " + "tf.serialization.registerClass().");
	        // TODO(cais): Add link to tutorial page on custom layers.
	      }
	    }

	    return fn;
	  } else {
	    // In this case we are dealing with a Keras config dictionary.
	    var config = identifier;
	    if (config['className'] == null || config['config'] == null) {
	      throw new ValueError("".concat(printableModuleName, ": Improper config format: ") + "".concat(JSON.stringify(config), ".\n") + "'className' and 'config' must set.");
	    }
	    var className = config['className'];
	    var cls, fromConfig;
	    if (className in customObjects) {
	      var _customObjects$classN = _slicedToArray(customObjects[className], 2);
	      cls = _customObjects$classN[0];
	      fromConfig = _customObjects$classN[1];
	    } else if (className in _GLOBAL_CUSTOM_OBJECTS) {
	      var _GLOBAL_CUSTOM_OBJECT = _slicedToArray(_GLOBAL_CUSTOM_OBJECTS['className'], 2);
	      cls = _GLOBAL_CUSTOM_OBJECT[0];
	      fromConfig = _GLOBAL_CUSTOM_OBJECT[1];
	    } else if (className in moduleObjects) {
	      var _moduleObjects$classN = _slicedToArray(moduleObjects[className], 2);
	      cls = _moduleObjects$classN[0];
	      fromConfig = _moduleObjects$classN[1];
	    }
	    if (cls == null) {
	      throw new ValueError("Unknown ".concat(printableModuleName, ": ").concat(className, ". ") + "This may be due to one of the following reasons:\n" + "1. The ".concat(printableModuleName, " is defined in Python, in which ") + "case it needs to be ported to TensorFlow.js or your JavaScript " + "code.\n" + "2. The custom ".concat(printableModuleName, " is defined in JavaScript, ") + "but is not registered properly with " + "tf.serialization.registerClass().");
	      // TODO(cais): Add link to tutorial page on custom layers.
	    }

	    if (fromConfig != null) {
	      // Porting notes: Instead of checking to see whether fromConfig accepts
	      // customObjects, we create a customObjects dictionary and tack it on to
	      // config['config'] as config['config'].customObjects. Objects can use it,
	      // if they want.
	      // tslint:disable-next-line:no-any
	      var customObjectsCombined = {};
	      for (var _i2 = 0, _Object$keys = Object.keys(_GLOBAL_CUSTOM_OBJECTS); _i2 < _Object$keys.length; _i2++) {
	        var key = _Object$keys[_i2];
	        customObjectsCombined[key] = _GLOBAL_CUSTOM_OBJECTS[key];
	      }
	      for (var _i3 = 0, _Object$keys2 = Object.keys(customObjects); _i3 < _Object$keys2.length; _i3++) {
	        var _key = _Object$keys2[_i3];
	        customObjectsCombined[_key] = customObjects[_key];
	      }
	      // Add the customObjects to config
	      var nestedConfig = config['config'];
	      nestedConfig['customObjects'] = customObjectsCombined;
	      var backupCustomObjects = Object.assign({}, _GLOBAL_CUSTOM_OBJECTS);
	      for (var _i4 = 0, _Object$keys3 = Object.keys(customObjects); _i4 < _Object$keys3.length; _i4++) {
	        var _key2 = _Object$keys3[_i4];
	        _GLOBAL_CUSTOM_OBJECTS[_key2] = customObjects[_key2];
	      }
	      convertNDArrayScalarsInConfig(config['config']);
	      var returnObj = fromConfig(cls, config['config'], customObjects, fastWeightInit);
	      _GLOBAL_CUSTOM_OBJECTS = Object.assign({}, backupCustomObjects);
	      return returnObj;
	    } else {
	      // Then `cls` may be a function returning a class.
	      // In this case by convention `config` holds
	      // the kwargs of the function.
	      var _backupCustomObjects = Object.assign({}, _GLOBAL_CUSTOM_OBJECTS);
	      for (var _i5 = 0, _Object$keys4 = Object.keys(customObjects); _i5 < _Object$keys4.length; _i5++) {
	        var _key3 = _Object$keys4[_i5];
	        _GLOBAL_CUSTOM_OBJECTS[_key3] = customObjects[_key3];
	      }
	      // In python this is **config['config'], for tfjs-layers we require
	      // classes that use this fall-through construction method to take
	      // a config interface that mimics the expansion of named parameters.
	      var _returnObj = new cls(config['config']);
	      _GLOBAL_CUSTOM_OBJECTS = Object.assign({}, _backupCustomObjects);
	      return _returnObj;
	    }
	  }
	}
	/**
	 * Compares two numbers for sorting.
	 * @param a
	 * @param b
	 */
	function numberCompare(a, b) {
	  return a < b ? -1 : a > b ? 1 : 0;
	}
	/**
	 * Comparison of two numbers for reverse sorting.
	 * @param a
	 * @param b
	 */
	function reverseNumberCompare(a, b) {
	  return -1 * numberCompare(a, b);
	}
	/**
	 * Convert a string into the corresponding DType.
	 * @param dtype
	 * @returns An instance of DType.
	 */
	function stringToDType(dtype) {
	  switch (dtype) {
	    case 'float32':
	      return 'float32';
	    default:
	      throw new ValueError("Invalid dtype: ".concat(dtype));
	  }
	}
	/**
	 * Test the element-by-element equality of two Arrays of strings.
	 * @param xs First array of strings.
	 * @param ys Second array of strings.
	 * @returns Wether the two arrays are all equal, element by element.
	 */
	function stringsEqual(xs, ys) {
	  if (xs == null || ys == null) {
	    return xs === ys;
	  }
	  if (xs.length !== ys.length) {
	    return false;
	  }
	  for (var i = 0; i < xs.length; ++i) {
	    if (xs[i] !== ys[i]) {
	      return false;
	    }
	  }
	  return true;
	}
	/**
	 * Get the unique elements of an array.
	 * @param xs Array.
	 * @returns An Array consisting of the unique elements in `xs`.
	 */
	function unique$2(xs) {
	  if (xs == null) {
	    return xs;
	  }
	  var out = [];
	  // TODO(cais): Maybe improve performance by sorting.
	  var _iterator3 = _createForOfIteratorHelper(xs),
	    _step3;
	  try {
	    for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
	      var x = _step3.value;
	      if (out.indexOf(x) === -1) {
	        out.push(x);
	      }
	    }
	  } catch (err) {
	    _iterator3.e(err);
	  } finally {
	    _iterator3.f();
	  }
	  return out;
	}
	/**
	 * Determine if an Object is empty (i.e., does not have own properties).
	 * @param obj Object
	 * @returns Whether the Object is empty.
	 * @throws ValueError: If object is `null` or `undefined`.
	 */
	function isObjectEmpty(obj) {
	  if (obj == null) {
	    throw new ValueError("Invalid value in obj: ".concat(JSON.stringify(obj)));
	  }
	  for (var key in obj) {
	    if (obj.hasOwnProperty(key)) {
	      return false;
	    }
	  }
	  return true;
	}
	/**
	 * Helper function used to build type union/enum run-time checkers.
	 * @param values The list of allowed values.
	 * @param label A string name for the type
	 * @param value The value to test.
	 * @throws ValueError: If the value is not in values nor `undefined`/`null`.
	 */
	function checkStringTypeUnionValue(values, label, value) {
	  if (value == null) {
	    return;
	  }
	  if (values.indexOf(value) < 0) {
	    throw new ValueError("".concat(value, " is not a valid ").concat(label, ".  Valid values are ").concat(values, " or null/undefined."));
	  }
	}
	/**
	 * Helper function for verifying the types of inputs.
	 *
	 * Ensures that the elements of `x` are all of type `expectedType`.
	 * Also verifies that the length of `x` is within bounds.
	 *
	 * @param x Object to test.
	 * @param expectedType The string expected type of all of the elements in the
	 * Array.
	 * @param minLength Return false if x.length is less than this.
	 * @param maxLength Return false if x.length is greater than this.
	 * @returns true if and only if `x` is an `Array<expectedType>` with
	 * length >= `minLength` and <= `maxLength`.
	 */
	// tslint:disable:no-any
	function checkArrayTypeAndLength(x, expectedType) {
	  var minLength = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
	  var maxLength = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : Infinity;
	  assert(minLength >= 0);
	  assert(maxLength >= minLength);
	  return Array.isArray(x) && x.length >= minLength && x.length <= maxLength && x.every(function (e) {
	    return _typeof(e) === expectedType;
	  });
	}
	// tslint:enable:no-any
	/**
	 * Assert that a value or an array of value are positive integer.
	 *
	 * @param value The value being asserted on. May be a single number or an array
	 *   of numbers.
	 * @param name Name of the value, used to make the error message.
	 */
	function assertPositiveInteger(value, name) {
	  if (Array.isArray(value)) {
	    assert$1(value.length > 0, function () {
	      return "".concat(name, " is unexpectedly an empty array.");
	    });
	    value.forEach(function (v, i) {
	      return assertPositiveInteger(v, "element ".concat(i + 1, " of ").concat(name));
	    });
	  } else {
	    assert$1(Number.isInteger(value) && value > 0, function () {
	      return "Expected ".concat(name, " to be a positive integer, but got ") + "".concat(formatAsFriendlyString(value), ".");
	    });
	  }
	}
	/**
	 * Format a value into a display-friendly, human-readable fashion.
	 *
	 * - `null` is formatted as `'null'`
	 * - Strings are formated with flanking pair of quotes.
	 * - Arrays are formatted with flanking pair of square brackets.
	 *
	 * @param value The value to display.
	 * @return Formatted string.
	 */
	// tslint:disable-next-line:no-any
	function formatAsFriendlyString(value) {
	  if (value === null) {
	    return 'null';
	  } else if (Array.isArray(value)) {
	    return '[' + value.map(function (v) {
	      return formatAsFriendlyString(v);
	    }).join(',') + ']';
	  } else if (typeof value === 'string') {
	    return "\"".concat(value, "\"");
	  } else {
	    return "".concat(value);
	  }
	}
	/**
	 * Returns a function `f2` (decorator) which wraps the original function
	 * `f`. `f2` guarantees that `f` can be called at most once
	 * every `waitMs` ms. If `f2` is called more often, it will return
	 * the last returned result of `f`.
	 *
	 * @param f The original function `f` to wrap.
	 * @param waitMs The time between two consecutive calls to `f` in ms.
	 */
	function debounce(f, waitMs, nowFunc) {
	  var lastTime = nowFunc != null ? nowFunc() : now();
	  var lastResult;
	  var f2 = function f2() {
	    var now$1 = nowFunc != null ? nowFunc() : now();
	    if (now$1 - lastTime < waitMs) {
	      return lastResult;
	    }
	    lastTime = now$1;
	    lastResult = f.apply(void 0, arguments);
	    return lastResult;
	  };
	  return f2;
	}
	/**
	 * Returns the fusable activation given a layers identifier.
	 *
	 * @param activationName The layers identifier string.
	 * @return The name of the fusable activation.
	 */
	function mapActivationToFusedKernel(activationName) {
	  if (activationName === 'relu') {
	    return 'relu';
	  }
	  if (activationName === 'linear') {
	    return 'linear';
	  }
	  if (activationName === 'elu') {
	    return 'elu';
	  }
	  return null;
	}
	/**
	 * Returns the cartesian product of sets of values.
	 * This works the same as itertools.product in Python.
	 *
	 * Example:
	 *
	 * filters = [128, 256, 512]
	 * paddings = ['same', 'valid']
	 *
	 * product = [ [128, 'same'], [128, 'valid'], [256, 'same'], [256, 'valid'],
	 * [512, 'same'], [512, 'valid']]
	 *
	 * @param arrayOfValues List/array of values.
	 * @return The cartesian product.
	 */
	function getCartesianProductOfValues() {
	  for (var _len = arguments.length, arrayOfValues = new Array(_len), _key4 = 0; _key4 < _len; _key4++) {
	    arrayOfValues[_key4] = arguments[_key4];
	  }
	  assert(arrayOfValues.length > 0, 'arrayOfValues is empty');
	  for (var _i6 = 0, _arrayOfValues = arrayOfValues; _i6 < _arrayOfValues.length; _i6++) {
	    var values = _arrayOfValues[_i6];
	    assert(Array.isArray(values), 'one of the values is not an array');
	    assert(values.length > 0, 'one of the values is empty');
	  }
	  return arrayOfValues.reduce(function (products, values) {
	    if (products.length === 0) {
	      return values.map(function (value) {
	        return [value];
	      });
	    }
	    return values.map(function (value) {
	      return products.map(function (prevValue) {
	        return [].concat(_toConsumableArray(prevValue), [value]);
	      });
	    }).reduce(function (flattenedProduct, unflattenedProduct) {
	      return flattenedProduct.concat(unflattenedProduct);
	    }, []);
	  }, []);
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	/**
	 * Utilities related to persistent state in the backend.
	 */
	/**
	 * An ID to track `tf.SymbolicTensor`s and derived classes.
	 * Required in different places in engine/topology.ts to identify unique
	 * tensors.
	 */
	var _nextUniqueTensorId = 0;
	function getNextUniqueTensorId() {
	  return _nextUniqueTensorId++;
	}
	var _uidPrefixes = {};
	/**
	 * Provides a unique UID given a string prefix.
	 *
	 * @param prefix
	 */
	function getUid() {
	  var prefix = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
	  if (!(prefix in _uidPrefixes)) {
	    _uidPrefixes[prefix] = 0;
	  }
	  _uidPrefixes[prefix] += 1;
	  return prefix + _uidPrefixes[prefix].toString();
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	var VALID_DATA_FORMAT_VALUES = ['channelsFirst', 'channelsLast'];
	var VALID_INTERPOLATION_FORMAT_VALUES = ['nearest', 'bilinear'];
	var VALID_PADDING_MODE_VALUES = ['valid', 'same', 'causal'];
	var VALID_POOL_MODE_VALUES = ['max', 'avg'];
	var VALID_BIDIRECTIONAL_MERGE_MODES = ['sum', 'mul', 'concat', 'ave'];
	var VALID_SAMPLE_WEIGHT_MODES = ['temporal'];

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	// A map from the requested scoped name of a Tensor to the number of Tensors
	// wanting that name so far.  This allows enforcing name uniqueness by appending
	// an incrementing index, e.g. scope/name, scope/name_1, scope/name_2, etc.
	var nameMap = new Map();
	function checkDataFormat(value) {
	  checkStringTypeUnionValue(VALID_DATA_FORMAT_VALUES, 'DataFormat', value);
	}
	function checkInterpolationFormat(value) {
	  checkStringTypeUnionValue(VALID_INTERPOLATION_FORMAT_VALUES, 'InterpolationFormat', value);
	}
	function checkPaddingMode(value) {
	  checkStringTypeUnionValue(VALID_PADDING_MODE_VALUES, 'PaddingMode', value);
	}
	function checkPoolMode(value) {
	  checkStringTypeUnionValue(VALID_POOL_MODE_VALUES, 'PoolMode', value);
	}
	var _nameScopeStack = [];
	var _nameScopeDivider = '/';
	/**
	 * Enter namescope, which can be nested.
	 */
	function nameScope(name, fn) {
	  _nameScopeStack.push(name);
	  try {
	    var val = fn();
	    _nameScopeStack.pop();
	    return val;
	  } catch (e) {
	    _nameScopeStack.pop();
	    throw e;
	  }
	}
	/**
	 * Get the current namescope as a flat, concatenated string.
	 */
	function currentNameScopePrefix() {
	  if (_nameScopeStack.length === 0) {
	    return '';
	  } else {
	    return _nameScopeStack.join(_nameScopeDivider) + _nameScopeDivider;
	  }
	}
	/**
	 * Get the name a Tensor (or Variable) would have if not uniqueified.
	 * @param tensorName
	 * @return Scoped name string.
	 */
	function getScopedTensorName(tensorName) {
	  if (!isValidTensorName(tensorName)) {
	    throw new Error('Not a valid tensor name: \'' + tensorName + '\'');
	  }
	  return currentNameScopePrefix() + tensorName;
	}
	/**
	 * Get unique names for Tensors and Variables.
	 * @param scopedName The fully-qualified name of the Tensor, i.e. as produced by
	 *  `getScopedTensorName()`.
	 * @return A unique version of the given fully scoped name.
	 *   If this is the first time that the scoped name is seen in this session,
	 *   then the given `scopedName` is returned unaltered.  If the same name is
	 *   seen again (producing a collision), an incrementing suffix is added to the
	 *   end of the name, so it takes the form 'scope/name_1', 'scope/name_2', etc.
	 */
	function getUniqueTensorName(scopedName) {
	  if (!isValidTensorName(scopedName)) {
	    throw new Error('Not a valid tensor name: \'' + scopedName + '\'');
	  }
	  if (!nameMap.has(scopedName)) {
	    nameMap.set(scopedName, 0);
	  }
	  var index = nameMap.get(scopedName);
	  nameMap.set(scopedName, nameMap.get(scopedName) + 1);
	  if (index > 0) {
	    var result = "".concat(scopedName, "_").concat(index);
	    // Mark the composed name as used in case someone wants
	    // to call getUniqueTensorName("name_1").
	    nameMap.set(result, 1);
	    return result;
	  } else {
	    return scopedName;
	  }
	}
	var tensorNameRegex = new RegExp(/^[A-Za-z0-9][-A-Za-z0-9\._\/]*$/);
	/**
	 * Determine whether a string is a valid tensor name.
	 * @param name
	 * @returns A Boolean indicating whether `name` is a valid tensor name.
	 */
	function isValidTensorName(name) {
	  return !!name.match(tensorNameRegex);
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	/**
	 * Determine if a number is an integer.
	 */
	function isInteger(x) {
	  return x === parseInt(x.toString(), 10);
	}
	/**
	 * Calculate the product of an array of numbers.
	 * @param array The array to calculate the product over.
	 * @param begin Beginning index, inclusive.
	 * @param end Ending index, exclusive.
	 * @return The product.
	 */
	function arrayProd(array, begin, end) {
	  if (begin == null) {
	    begin = 0;
	  }
	  if (end == null) {
	    end = array.length;
	  }
	  var prod = 1;
	  for (var i = begin; i < end; ++i) {
	    prod *= array[i];
	  }
	  return prod;
	}
	/**
	 * Compute minimum value.
	 * @param array
	 * @return minimum value.
	 */
	function min$2(array) {
	  // same behavior as tf.min()
	  if (array.length === 0) {
	    return Number.NaN;
	  }
	  var min = Number.POSITIVE_INFINITY;
	  for (var i = 0; i < array.length; i++) {
	    var value = array[i];
	    if (value < min) {
	      min = value;
	    }
	  }
	  return min;
	}
	/**
	 * Compute maximum value.
	 * @param array
	 * @return maximum value
	 */
	function max$2(array) {
	  // same behavior as tf.max()
	  if (array.length === 0) {
	    return Number.NaN;
	  }
	  var max = Number.NEGATIVE_INFINITY;
	  for (var i = 0; i < array.length; i++) {
	    var value = array[i];
	    if (value > max) {
	      max = value;
	    }
	  }
	  return max;
	}
	/**
	 * Compute sum of array.
	 * @param array
	 * @return The sum.
	 */
	function sum$2(array) {
	  var sum = 0;
	  for (var i = 0; i < array.length; i++) {
	    var value = array[i];
	    sum += value;
	  }
	  return sum;
	}
	/**
	 * Compute mean of array.
	 * @param array
	 * @return The mean.
	 */
	function mean$1(array) {
	  return sum$2(array) / array.length;
	}
	/**
	 * Compute variance of array.
	 * @param array
	 * @return The variance.
	 */
	function variance(array) {
	  var meanValue = mean$1(array);
	  var demeaned = array.map(function (value) {
	    return value - meanValue;
	  });
	  var sumSquare = 0;
	  for (var i = 0; i < demeaned.length; i++) {
	    var value = demeaned[i];
	    sumSquare += value * value;
	  }
	  return sumSquare / array.length;
	}
	/**
	 * Compute median of array.
	 * @param array
	 * @return The median value.
	 */
	function median(array) {
	  var arraySorted = array.slice().sort(function (a, b) {
	    return a - b;
	  });
	  var lowIdx = Math.floor((arraySorted.length - 1) / 2);
	  var highIdx = Math.ceil((arraySorted.length - 1) / 2);
	  if (lowIdx === highIdx) {
	    return arraySorted[lowIdx];
	  }
	  return (arraySorted[lowIdx] + arraySorted[highIdx]) / 2;
	}
	/**
	 * Generate an array of integers in [begin, end).
	 * @param begin Beginning integer, inclusive.
	 * @param end Ending integer, exclusive.
	 * @returns Range array.
	 * @throws ValueError, iff `end` < `begin`.
	 */
	function range$2(begin, end) {
	  if (end < begin) {
	    throw new ValueError("end (".concat(end, ") < begin (").concat(begin, ") is forbidden."));
	  }
	  var out = [];
	  for (var i = begin; i < end; ++i) {
	    out.push(i);
	  }
	  return out;
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	var _epsilon;
	/**
	 * Returns the value of the fuzz factor used in numeric expressions.
	 */
	function epsilon$1() {
	  if (_epsilon == null) {
	    _epsilon = backend$1().epsilon();
	  }
	  return _epsilon;
	}
	/**
	 * Sets the value of the fuzz factor used in numeric expressions.
	 * @param e New value of epsilon.
	 */
	function setEpsilon(e) {
	  _epsilon = e;
	}
	/**
	 * Returns the default image data format convention.
	 */
	function imageDataFormat() {
	  return 'channelsLast';
	}

	// tslint:enable
	/* Setting and getting backend from deeplearn.js. */
	// Default deeplearn.js backend is WebGL (GPU).
	var backend = 'webgl';
	function setBackend(requestedBackend) {
	  setBackend$1(requestedBackend);
	  backend = requestedBackend;
	}
	function getBackend() {
	  return backend;
	}
	/**
	 * Indicates whether the backend is operating symbolically.
	 *
	 * This function will be used to determine how to interpret user code. If
	 * it returns true, calls to the backend construct a symbolic graph; if
	 * it returns false, calls to the backend execute immediately.
	 */
	function isBackendSymbolic() {
	  return false;
	}
	/**
	 * Get the number of elements in a Tensor.
	 * @param x The Tensor.
	 * @return Number of elements in `x`.
	 */
	function countParams(x) {
	  var shape = x.shape;
	  if (shape.length > 0) {
	    return shape.reduce(function (a, b) {
	      return a * b;
	    });
	  } else {
	    // Scalar.
	    return 1;
	  }
	}
	/**
	 * Casts a tensor to a different dtype and returns it.
	 * @param x Input tensor.
	 * @param dtype String: 'float32'|'int32'|'bool'.
	 * @returns Tensor of the specified `dtype`.
	 */
	function cast$2(x, dtype) {
	  return cast$3(x, dtype);
	}
	/**
	 * Adds a 1-sized dimension at index "axis".
	 * @param x Input tensor.
	 * @param axis Position where to add the new axis.
	 * @returns Result of the dimension expansion.
	 */
	function expandDims$2(x) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : -1;
	  var outShape = x.shape.slice();
	  if (axis < 0) {
	    axis = outShape.length + axis + 1;
	  }
	  outShape.splice(axis, 0, 1);
	  return reshape$3(x, outShape);
	}
	/**
	 * Repeats a 2D tensor.
	 *
	 * If `x` has shape `[samples, dim]` and `n` is 2, for example, the output
	 * will have shape `[samples, 2, dim]`.
	 *
	 * @param x Input tensor.
	 * @param n Integer, number of times to repeat.
	 * @returns The result of the repeat operation.
	 * @throws ValueError: If input tensor is not 2D.
	 */
	function repeat(x, n) {
	  return tidy(function () {
	    if (x.shape.length !== 2) {
	      throw new ValueError("repeat() expects a rank-2 tensor, but received a " + "rank-".concat(x.shape.length, " tensor."));
	    }
	    var y = expandDims$2(x, 1);
	    return tile$2(y, [1, n, 1]);
	  });
	}
	/**
	 * Flatten a Tensor into 1D.
	 * @param x Input tensor.
	 * @return The result of the flattening `x`.
	 */
	function flatten$1(x) {
	  var newShape = [arrayProd(x.shape)];
	  return reshape$3(x, newShape);
	}
	/**
	 * Turn a nD tensor into a 2D tensor with same 0th dimension.
	 * In other words, it flattens each data samples of a batch.
	 *
	 * @param x The tensor to flatten. The rank of this tensor is required to be 2
	 *   or higher.
	 * @return The result of the flattening.
	 */
	function batchFlatten(x) {
	  if (x.rank <= 1) {
	    throw new ValueError("batchFlatten requires a minimum rank of 2. Got rank: ".concat(x.rank, "."));
	  }
	  var newShape = [x.shape[0], arrayProd(x.shape, 1)];
	  return reshape$3(x, newShape);
	}
	/**
	 * Do slicing along the first axis.
	 * @param array input `tf.Tensor`.
	 * @param start starting index, inclusive.
	 * @param size size of the slice along the first axis.
	 * @returns result of the slicing.
	 * @throws ValueError: If `array` is of an unsupported subtype of `tf.Tensor`.
	 */
	function sliceAlongFirstAxis(array, start, size) {
	  return tidy(function () {
	    switch (array.rank) {
	      case 1:
	        return slice1d(array, start, size);
	      case 2:
	        return slice2d(array, [start, 0], [size, array.shape[1]]);
	      case 3:
	        return slice3d(array, [start, 0, 0], [size, array.shape[1], array.shape[2]]);
	      case 4:
	        return slice4d(array, [start, 0, 0, 0], [size, array.shape[1], array.shape[2], array.shape[3]]);
	      case 5:
	        return slice$2(array, [start, 0, 0, 0, 0], [size, array.shape[1], array.shape[2], array.shape[3], array.shape[4]]);
	      case 6:
	        return slice$2(array, [start, 0, 0, 0, 0, 0], [size, array.shape[1], array.shape[2], array.shape[3], array.shape[4], array.shape[5]]);
	      default:
	        throw new ValueError("sliceAlongFirstAxis() received an unsupported tensor rank: " + "".concat(array.rank));
	    }
	  });
	}
	/**
	 * Do slicing along the last axis.
	 * @param array input `tf.Tensor`.
	 * @param start starting index, inclusive.
	 * @param size size of the slice along the last axis.
	 * @returns result of the slicing.
	 * @throws ValueError: If `array` is of an unsupported subtype of `tf.Tensor`.
	 */
	function sliceAlongLastAxis(array, start, size) {
	  return tidy(function () {
	    switch (array.rank) {
	      case 1:
	        return slice1d(array, start, size);
	      case 2:
	        return slice2d(array, [0, start], [array.shape[0], size]);
	      case 3:
	        return slice3d(array, [0, 0, start], [array.shape[0], array.shape[1], size]);
	      case 4:
	        return slice4d(array, [0, 0, 0, start], [array.shape[0], array.shape[1], array.shape[2], size]);
	      default:
	        throw new ValueError("sliceAlongLastAxis() received an unsupported tensor rank: " + "".concat(array.rank));
	    }
	  });
	}
	/**
	 * Do slicing along the sepcified axis.
	 * @param array input `tf.Tensor`.
	 * @param start starting index, inclusive.
	 * @param size of the slice along the chosen axis.
	 * @param choose an axis.
	 * @returns result of the slicing.
	 * @throws ValueError: If `array` is of an unsupported subtype of `tf.Tensor`.
	 */
	function sliceAlongAxis(array, start, size, axis) {
	  return tidy(function () {
	    switch (array.rank) {
	      case 1:
	        return slice1d(array, start, size);
	      case 2:
	        switch (axis) {
	          case 1:
	            return sliceAlongFirstAxis(array, start, size);
	          case 2:
	            return sliceAlongLastAxis(array, start, size);
	          default:
	            throw new ValueError("The axis is not within the rank of the tensor " + "".concat(axis));
	        }
	      case 3:
	        switch (axis) {
	          case 1:
	            return sliceAlongFirstAxis(array, start, size);
	          case 2:
	            return slice3d(array, [0, start, 0], [array.shape[0], size, array.shape[2]]);
	          case 3:
	            return sliceAlongLastAxis(array, start, size);
	          default:
	            throw new ValueError("The axis is not within the rank of the tensor " + "".concat(axis));
	        }
	      case 4:
	        switch (axis) {
	          case 1:
	            return sliceAlongFirstAxis(array, start, size);
	          case 2:
	            return slice4d(array, [0, start, 0, 0], [array.shape[0], size, array.shape[2], array.shape[3]]);
	          case 3:
	            return slice4d(array, [0, 0, start, 0], [array.shape[0], array.shape[1], size, array.shape[3]]);
	          case 4:
	            return sliceAlongLastAxis(array, start, size);
	          default:
	            throw new ValueError("The axis is not within the rank of the tensor " + "".concat(axis));
	        }
	      default:
	        throw new ValueError("sliceAlongLastAxis() received an unsupported tensor rank: " + "".concat(array.rank));
	    }
	  });
	}
	/**
	 * Concatenates a list of tensors alongside the specified axis.
	 * @param tensors `Array` of tensors to concatenate.
	 * @param axis Concatenation axis.
	 * @returns The result of the concatenation.
	 */
	function concatenate$2(tensors) {
	  var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : -1;
	  var rank;
	  if (axis < 0) {
	    rank = tensors[0].rank;
	    if (rank !== 0) {
	      axis = rank;
	    } else {
	      axis = 0;
	    }
	  }
	  if (axis === tensors[0].rank) {
	    // Porting Note: This is necessary because tfc.concat() requires axis to be
	    //   in the interval [-rank, rank).
	    axis = -1;
	  }
	  // Porting Note: Sparse concat is not supported yet.
	  return concat$2(tensors, axis);
	}
	/**
	 * Concatenate two arrays along the first dimension.
	 * @param a The 1st `tf.Tensor` to concatenate.
	 * @param b The 2nd `tf.Tensor` to concatenate.
	 * @returns Result of the concatenation.
	 * @throws ValueError: If `a` is of an unsupported subtype of `tf.Tensor`.
	 */
	function concatAlongFirstAxis(a, b) {
	  switch (a.rank) {
	    case 1:
	      return concat1d([a, b]);
	    case 2:
	      return concat2d([a, b], 0);
	    case 3:
	      return concat3d([a, b], 0);
	    case 4:
	      return concat4d([a, b], 0);
	    default:
	      throw new ValueError("concatAlongFirstAxis() received an unsupported " + "tensor rank: ".concat(a.rank));
	  }
	}
	/**
	 * Creates a tensor by tiling `x` by `n`.
	 * @param x A tensor.
	 * @param n An Array of integers or a single integer. If an Array, the length
	 *   must be the same as the number of dimensions in `x`. If a single integer,
	 *   it will be treated as an Array of length 1.
	 */
	function tile$2(x, n) {
	  if (!Array.isArray(n)) {
	    n = [n];
	  }
	  if (x.rank !== n.length) {
	    throw new ValueError("The length of input n (".concat(n.length, ") does not match ") + "the number of dimensions in input x (".concat(x.rank, ")"));
	  }
	  return tile$3(x, n);
	}
	/* Creation of random tensors. */
	/**
	 * Get a tensor with normal distribution of values.
	 *
	 * @param shape Shape of the tensor.
	 * @param mean mean value of the normal distribution.
	 * @param stddev standard deviation of the normal distribution.
	 * @param dtype
	 * @param seed
	 * @return The normal tensor.
	 */
	function randomNormal$1(shape) {
	  var mean = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0.0;
	  var stddev = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1.0;
	  var dtype = arguments.length > 3 ? arguments[3] : undefined;
	  var seed = arguments.length > 4 ? arguments[4] : undefined;
	  return randomNormal$2(shape, mean, stddev, dtype, seed);
	}
	/* Linear Algebra */
	/**
	 * Multiply two tensors and returns the result as a tensor.
	 *
	 * For 2D tensors, this is equivalent to matrix multiplication (matMul).
	 * For tensors of higher ranks, it follows the Theano behavior,
	 * (e.g. `(2, 3) * (4, 3, 5) -> (2, 4, 5)`).  From the Theano documentation:
	 *
	 * For N dimensions it is a sum product over the last axis of x and the
	 * second-to-last of y:
	 *
	 * @param a A tensor of at least rank 2.
	 * @param b A tensor of at least rank 2.
	 * @param activation (optional) A string identifying the activation
	 *   function.
	 * @return Result of the dot operation.
	 */
	function dot$1(a, b, activation, bias) {
	  if (a.rank < 2 || b.rank < 2) {
	    throw new NotImplementedError("dot requires both inputs to be rank >= 2" + " but got x shape = ".concat(a.shape, " and y shape = ").concat(b.shape));
	  }
	  if (b.rank >= 3) {
	    var xLastDim = a.shape.slice(-1)[0];
	    var ySecondLastDim = b.shape.slice(-2)[0];
	    if (xLastDim !== ySecondLastDim) {
	      throw new NotImplementedError("If rank y >= 3, then the second last dim" + " of y must equal the last dim of x but got x shape = ".concat(a.shape, " and ") + " y shape = ".concat(b.shape));
	    }
	  }
	  // Handle basic 2D x 2D case.
	  if (a.rank === 2 && b.rank === 2) {
	    var transposeA = false;
	    var transposeB = false;
	    // tfc.fused.matMul only fuses certain activation functions. Unsupported
	    // activation functions are treated as 'linear' activations, which is
	    // equivalent to a no-op.
	    return matMul({
	      a: a,
	      b: b,
	      transposeA: transposeA,
	      transposeB: transposeB,
	      bias: bias ? reshapeBias(a.rank, bias, imageDataFormat()) : null,
	      activation: activation
	    });
	  } else {
	    // Reshape x into the analogous 2D Tensor.
	    var aFirstDims = a.shape.slice(); // Holds all but the last dim of x.
	    var aLastDim = aFirstDims.pop();
	    a = reshape$3(a, [-1, aLastDim]);
	    // Reshape y into the analogous 2D Tensor, and keep track of the
	    // required dimensions to reproduce the output shape.
	    var bShape = b.shape.slice();
	    var bLastDim = bShape.pop();
	    var _ySecondLastDim = bShape.pop();
	    var yOtherDims = [].concat(_toConsumableArray(bShape), [bLastDim]);
	    // permutation should be like [r-2, 0, 1, 2, ... r-4, r-3, r-1]
	    // where r is the rank of y.
	    var perm = Array.from({
	      length: b.rank
	    }, function (_, i) {
	      if (i === 0) {
	        return b.rank - 2;
	      } else if (i <= b.rank - 2) {
	        return i - 1;
	      }
	      return i;
	    });
	    b = reshape$3(transpose$2(b, perm), [_ySecondLastDim, -1]);
	    // Multiply x and y as 2D Tensors, and then reshape back to original.
	    var outputShape = [].concat(_toConsumableArray(aFirstDims), _toConsumableArray(yOtherDims));
	    var _transposeA = false;
	    var _transposeB = false;
	    return reshape$3(matMul({
	      a: a,
	      b: b,
	      transposeA: _transposeA,
	      transposeB: _transposeB,
	      bias: bias ? reshapeBias(a.rank, bias, imageDataFormat()) : null,
	      activation: activation
	    }), outputShape);
	  }
	}
	/**
	 * Compute the sign Tensor of an input Tensor.
	 *
	 * Elements of the input `tf.Tensor` that are === 0 are mapped to 0.
	 * Elements of the input `tf.Tensor` that are > 0 are mapped to 1.
	 * Elements of the input `tf.Tensor` that are < 0 are mapped to -1.
	 *
	 * @param x Input `tf.Tensor`.
	 * @return The sign `tf.Tensor`.
	 */
	function sign$2(x) {
	  // TODO(cais): Move to the core.
	  return tidy(function () {
	    var zerosLikeX = zerosLike$3(x);
	    var onesLikeX = onesLike$3(x);
	    return where(equal$2(x, zerosLikeX), zerosLikeX, where(greater$3(x, zerosLike$3(x)), onesLikeX, mul(-1, onesLikeX)));
	  });
	}
	/**
	 * Computes the one-hot representation of an integer tensor.
	 * @param indices nD integer tensor of shape
	 *   `(batch_size, dim1, dim2, ... dim(n-1))`
	 * @param numClasses Integer, number of classes to consider.
	 * @returns (n + 1)D one hot representation of the input
	 *   with shape `(batch_size, dim1, dim2, ... dim(n-1), num_classes)`
	 */
	function oneHot$2(indices, numClasses) {
	  return tidy(function () {
	    if (indices.rank !== 1) {
	      throw new Error('Only 1D one-hot tensors are supported in the ' + 'deeplearn backend, at present.');
	    }
	    indices = cast$3(indices, 'int32');
	    return cast$3(oneHot$3(indices, numClasses), 'float32');
	  });
	}
	/* Elementary math functions. */
	/**
	 * Retrieves the elements of indices `indices` in the tensor `reference`.
	 * @param reference A tensor.
	 * @param indices An integer tensor of indices or an `Array` of integers.
	 * @param axis Axis along which to perform the gather operation.
	 * @returns The result of the gathering as a tensor.
	 */
	function gather(reference, indices, axis) {
	  return tidy(function () {
	    if (Array.isArray(indices)) {
	      indices = tensor1d(indices, 'int32');
	    } else {
	      indices = cast$3(indices, 'int32');
	    }
	    return gather$1(reference, indices, axis);
	  });
	}
	/**
	 * Element-wise square.
	 * @param x Input tensor.
	 * @return element-wise x^2
	 */
	function square$1(x) {
	  return mul(x, x);
	}
	/**
	 * Element-wise exponentiation.
	 *
	 * Porting Note: In PyKeras, `a` (the exponent) is a Python integer, which
	 *   takes advatnage of the backend's (e.g., TensorFlow's) automatic
	 * conversion to tensor. Here we allow `a` to be either a number or a tensor.
	 *
	 * @param x The base tensor.
	 * @param a The exponent, tensor or number. If a number, it is rounded to the
	 *   nearest integer and converted to a tensor.
	 * @returns A tensor of the same shape as `x`.
	 */
	function pow$2(x, a) {
	  return tidy(function () {
	    if (typeof a === 'number') {
	      a = scalar(Math.round(a), 'int32');
	    }
	    if (a.dtype !== 'int32') {
	      throw new NotImplementedError("Non-int32 dtype (".concat(a.dtype, ") is not supported by pow() yet"));
	    }
	    return pow$3(x, a);
	  });
	}
	/**
	 * Reshapes bias tensor according to rank of x.
	 */
	function reshapeBias(xRank, bias, dataFormat) {
	  var biasShape = bias.shape;
	  if (bias.rank !== 1 && bias.rank !== xRank) {
	    throw new ValueError("Unexpected bias dimensions: ".concat(bias.rank) + "; expected it to be 1 or ".concat(xRank));
	  }
	  if (xRank === 5) {
	    if (dataFormat === 'channelsFirst') {
	      if (biasShape.length === 1) {
	        return reshape$3(bias, [1, biasShape[0], 1, 1, 1]);
	      } else {
	        return reshape$3(bias, [1, biasShape[3], biasShape[0], biasShape[1], biasShape[2]]);
	      }
	    } else if (dataFormat === 'channelsLast') {
	      if (biasShape.length === 1) {
	        return reshape$3(bias, [1, 1, 1, 1, biasShape[0]]);
	      } else {
	        return reshape$3(bias, [1].concat(biasShape));
	      }
	    }
	  } else if (xRank === 4) {
	    if (dataFormat === 'channelsFirst') {
	      if (biasShape.length === 1) {
	        return reshape$3(bias, [1, biasShape[0], 1, 1]);
	      } else {
	        return reshape$3(bias, [1, biasShape[2], biasShape[0], biasShape[1]]);
	      }
	    } else if (dataFormat === 'channelsLast') {
	      if (biasShape.length === 1) {
	        return reshape$3(bias, [1, 1, 1, biasShape[0]]);
	      } else {
	        return reshape$3(bias, [1].concat(biasShape));
	      }
	    }
	  } else if (xRank === 3) {
	    if (dataFormat === 'channelsFirst') {
	      if (biasShape.length === 1) {
	        return reshape$3(bias, [1, biasShape[0], 1]);
	      } else {
	        return reshape$3(bias, [1, biasShape[1], biasShape[0]]);
	      }
	    } else if (dataFormat === 'channelsLast') {
	      if (biasShape.length === 1) {
	        return reshape$3(bias, [1, 1, biasShape[0]]);
	      } else {
	        return reshape$3(bias, [1].concat(biasShape));
	      }
	    }
	  } else if (xRank < 3) {
	    return bias;
	  }
	  throw new ValueError("Unsupported input rank by biasAdd: ".concat(bias.rank));
	}
	/* Neural-network operations. */
	/**
	 * Add a bias to a tensor.
	 *
	 * @param x The tensor to add the bias to.
	 * @param bias The bias to add to `x`. Must be 1D or the same rank as `x`.
	 * @return Result of the bias adding.
	 * @throws ValueError: If the rank of `bias` is incorrect.
	 */
	function biasAdd(x, bias, dataFormat) {
	  return tidy(function () {
	    if (dataFormat == null) {
	      dataFormat = imageDataFormat();
	    }
	    checkDataFormat(dataFormat);
	    return add$3(x, reshapeBias(x.rank, bias, dataFormat));
	  });
	}
	/**
	 * Exponential linear unit (ELU).
	 * @param x A tensor or variable to compute the activation function for.
	 * @param alpha: A scalar, a scaling factor for the negative section.
	 * @return Output of the ELU operation.
	 */
	function elu$3(x) {
	  var alpha = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
	  // TODO(cais): Add support for alpha values other than 1.
	  if (alpha !== 1) {
	    throw new NotImplementedError("Support for alpha values other than 1 (".concat(alpha, ") is not implemented ") + "yet.");
	  }
	  return elu$4(x);
	}
	/**
	 * Softsign of a tensor.
	 *
	 * Defined as x / (abs(x) + 1), element-wise.
	 *
	 * @param x: Input.
	 * @returns Output.
	 */
	function softsign(x) {
	  return tidy(function () {
	    return div$1(x, add$3(abs$2(x), 1));
	  });
	}
	/**
	 * Sets entries in `x` to zero at random, while scaling the entire tensor.
	 *
	 * @param x input tensor.
	 * @param level fraction of the entries in the tensor that will be set to 0.
	 * @param noiseShape shape of randomly generated keep/drop flags, must be
	 *   broadcastable to the shape of `x`. Optional.
	 * @param seed random seed to ensure determinism. Optional.
	 * @returns Result of the dropout operation.
	 */
	function dropout$1(x, level, noiseShape, seed) {
	  return tidy(function () {
	    return dropout$2(x, level, noiseShape, seed);
	  });
	}
	/**
	 * Element-wise, segment-wise linear approximation of sigmoid.
	 *
	 * Returns `0.` if `x < -2.5`, `1.` if `x > 2.5`.
	 * In `-2.5 <= x <= 2.5`, returns `0.2 * x + 0.5`.
	 *
	 * @param x Input tensor.
	 * @returns Output tensor.
	 */
	function hardSigmoid(x) {
	  return tidy(function () {
	    var y = add$3(.5, mul(.2, x));
	    return clipByValue$2(y, 0, 1);
	  });
	}
	/**
	 * Invoke `x` in the training phase, and `alt` otherwise.
	 *
	 * Porting Note: We do not create placeholder tensors for the `training`
	 * boolean flag here, because there is no such thing in the TF.js imperative
	 * backend.
	 *
	 * @param x The function to invoke iff `training` is `true`.
	 * @param alt The function to invoke iff `training` is `false`.
	 * @param training Boolean flag for whether training phase is active.
	 * @returns The return value of `x()` if `training` is `true`, or the return
	 *   value of `alt()` if `training` is `false`.
	 */
	function inTrainPhase(x, alt) {
	  var training = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  return training ? x() : alt();
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	var VALID_FAN_MODE_VALUES = ['fanIn', 'fanOut', 'fanAvg'];
	var VALID_DISTRIBUTION_VALUES = ['normal', 'uniform', 'truncatedNormal'];
	// We can't easily extract a string[] from the string union type, but we can
	// recapitulate the list, enforcing at compile time that the values are valid
	// and that we have the right number of them.
	/**
	 * A string array of valid Initializer class names.
	 *
	 * This is guaranteed to match the `InitializerClassName` union type.
	 */
	var initializerClassNames = ['Zeros', 'Ones', 'Constant', 'RandomNormal', 'RandomUniform', 'TruncatedNormal', 'VarianceScaling', 'Orthogonal', 'Identity'];

	function checkFanMode(value) {
	  checkStringTypeUnionValue(VALID_FAN_MODE_VALUES, 'FanMode', value);
	}
	function checkDistribution(value) {
	  checkStringTypeUnionValue(VALID_DISTRIBUTION_VALUES, 'Distribution', value);
	}
	/**
	 * Initializer base class.
	 *
	 * @doc {
	 *   heading: 'Initializers', subheading: 'Classes', namespace: 'initializers'}
	 */
	var Initializer = /*#__PURE__*/function (_serialization$Serial) {
	  _inherits(Initializer, _serialization$Serial);
	  var _super = _createSuper(Initializer);
	  function Initializer() {
	    _classCallCheck(this, Initializer);
	    return _super.apply(this, arguments);
	  }
	  _createClass(Initializer, [{
	    key: "fromConfigUsesCustomObjects",
	    value: function fromConfigUsesCustomObjects() {
	      return false;
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {};
	    }
	  }]);
	  return Initializer;
	}(Serializable);
	var Zeros = /*#__PURE__*/function (_Initializer) {
	  _inherits(Zeros, _Initializer);
	  var _super2 = _createSuper(Zeros);
	  function Zeros() {
	    _classCallCheck(this, Zeros);
	    return _super2.apply(this, arguments);
	  }
	  _createClass(Zeros, [{
	    key: "apply",
	    value: function apply(shape, dtype) {
	      return zeros$2(shape, dtype);
	    }
	  }]);
	  return Zeros;
	}(Initializer);
	/** @nocollapse */
	Zeros.className = 'Zeros';
	registerClass(Zeros);
	var Ones = /*#__PURE__*/function (_Initializer2) {
	  _inherits(Ones, _Initializer2);
	  var _super3 = _createSuper(Ones);
	  function Ones() {
	    _classCallCheck(this, Ones);
	    return _super3.apply(this, arguments);
	  }
	  _createClass(Ones, [{
	    key: "apply",
	    value: function apply(shape, dtype) {
	      return ones$1(shape, dtype);
	    }
	  }]);
	  return Ones;
	}(Initializer);
	/** @nocollapse */
	Ones.className = 'Ones';
	registerClass(Ones);
	var Constant = /*#__PURE__*/function (_Initializer3) {
	  _inherits(Constant, _Initializer3);
	  var _super4 = _createSuper(Constant);
	  function Constant(args) {
	    var _this;
	    _classCallCheck(this, Constant);
	    _this = _super4.call(this);
	    if (_typeof(args) !== 'object') {
	      throw new ValueError("Expected argument of type ConstantConfig but got ".concat(args));
	    }
	    if (args.value === undefined) {
	      throw new ValueError("config must have value set but got ".concat(args));
	    }
	    _this.value = args.value;
	    return _this;
	  }
	  _createClass(Constant, [{
	    key: "apply",
	    value: function apply(shape, dtype) {
	      var _this2 = this;
	      return tidy(function () {
	        return mul(scalar(_this2.value), ones$1(shape, dtype));
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        value: this.value
	      };
	    }
	  }]);
	  return Constant;
	}(Initializer);
	/** @nocollapse */
	Constant.className = 'Constant';
	registerClass(Constant);
	var RandomUniform = /*#__PURE__*/function (_Initializer4) {
	  _inherits(RandomUniform, _Initializer4);
	  var _super5 = _createSuper(RandomUniform);
	  function RandomUniform(args) {
	    var _this3;
	    _classCallCheck(this, RandomUniform);
	    _this3 = _super5.call(this);
	    _this3.DEFAULT_MINVAL = -0.05;
	    _this3.DEFAULT_MAXVAL = 0.05;
	    _this3.minval = args.minval || _this3.DEFAULT_MINVAL;
	    _this3.maxval = args.maxval || _this3.DEFAULT_MAXVAL;
	    _this3.seed = args.seed;
	    return _this3;
	  }
	  _createClass(RandomUniform, [{
	    key: "apply",
	    value: function apply(shape, dtype) {
	      return randomUniform$1(shape, this.minval, this.maxval, dtype, this.seed);
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        minval: this.minval,
	        maxval: this.maxval,
	        seed: this.seed
	      };
	    }
	  }]);
	  return RandomUniform;
	}(Initializer);
	/** @nocollapse */
	RandomUniform.className = 'RandomUniform';
	registerClass(RandomUniform);
	var RandomNormal = /*#__PURE__*/function (_Initializer5) {
	  _inherits(RandomNormal, _Initializer5);
	  var _super6 = _createSuper(RandomNormal);
	  function RandomNormal(args) {
	    var _this4;
	    _classCallCheck(this, RandomNormal);
	    _this4 = _super6.call(this);
	    _this4.DEFAULT_MEAN = 0.;
	    _this4.DEFAULT_STDDEV = 0.05;
	    _this4.mean = args.mean || _this4.DEFAULT_MEAN;
	    _this4.stddev = args.stddev || _this4.DEFAULT_STDDEV;
	    _this4.seed = args.seed;
	    return _this4;
	  }
	  _createClass(RandomNormal, [{
	    key: "apply",
	    value: function apply(shape, dtype) {
	      dtype = dtype || 'float32';
	      if (dtype !== 'float32' && dtype !== 'int32') {
	        throw new NotImplementedError("randomNormal does not support dType ".concat(dtype, "."));
	      }
	      return randomNormal$1(shape, this.mean, this.stddev, dtype, this.seed);
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        mean: this.mean,
	        stddev: this.stddev,
	        seed: this.seed
	      };
	    }
	  }]);
	  return RandomNormal;
	}(Initializer);
	/** @nocollapse */
	RandomNormal.className = 'RandomNormal';
	registerClass(RandomNormal);
	var TruncatedNormal = /*#__PURE__*/function (_Initializer6) {
	  _inherits(TruncatedNormal, _Initializer6);
	  var _super7 = _createSuper(TruncatedNormal);
	  function TruncatedNormal(args) {
	    var _this5;
	    _classCallCheck(this, TruncatedNormal);
	    _this5 = _super7.call(this);
	    _this5.DEFAULT_MEAN = 0.;
	    _this5.DEFAULT_STDDEV = 0.05;
	    _this5.mean = args.mean || _this5.DEFAULT_MEAN;
	    _this5.stddev = args.stddev || _this5.DEFAULT_STDDEV;
	    _this5.seed = args.seed;
	    return _this5;
	  }
	  _createClass(TruncatedNormal, [{
	    key: "apply",
	    value: function apply(shape, dtype) {
	      dtype = dtype || 'float32';
	      if (dtype !== 'float32' && dtype !== 'int32') {
	        throw new NotImplementedError("truncatedNormal does not support dType ".concat(dtype, "."));
	      }
	      return truncatedNormal$1(shape, this.mean, this.stddev, dtype, this.seed);
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        mean: this.mean,
	        stddev: this.stddev,
	        seed: this.seed
	      };
	    }
	  }]);
	  return TruncatedNormal;
	}(Initializer);
	/** @nocollapse */
	TruncatedNormal.className = 'TruncatedNormal';
	registerClass(TruncatedNormal);
	var Identity = /*#__PURE__*/function (_Initializer7) {
	  _inherits(Identity, _Initializer7);
	  var _super8 = _createSuper(Identity);
	  function Identity(args) {
	    var _this6;
	    _classCallCheck(this, Identity);
	    _this6 = _super8.call(this);
	    _this6.gain = args.gain != null ? args.gain : 1.0;
	    return _this6;
	  }
	  _createClass(Identity, [{
	    key: "apply",
	    value: function apply(shape, dtype) {
	      var _this7 = this;
	      return tidy(function () {
	        if (shape.length !== 2 || shape[0] !== shape[1]) {
	          throw new ValueError('Identity matrix initializer can only be used for' + ' 2D square matrices.');
	        } else {
	          return mul(_this7.gain, eye(shape[0]));
	        }
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        gain: this.gain
	      };
	    }
	  }]);
	  return Identity;
	}(Initializer);
	/** @nocollapse */
	Identity.className = 'Identity';
	registerClass(Identity);
	/**
	 * Computes the number of input and output units for a weight shape.
	 * @param shape Shape of weight.
	 * @param dataFormat data format to use for convolution kernels.
	 *   Note that all kernels in Keras are standardized on the
	 *   CHANNEL_LAST ordering (even when inputs are set to CHANNEL_FIRST).
	 * @return An length-2 array: fanIn, fanOut.
	 */
	function computeFans(shape) {
	  var dataFormat = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'channelsLast';
	  var fanIn;
	  var fanOut;
	  checkDataFormat(dataFormat);
	  if (shape.length === 2) {
	    fanIn = shape[0];
	    fanOut = shape[1];
	  } else if ([3, 4, 5].indexOf(shape.length) !== -1) {
	    if (dataFormat === 'channelsFirst') {
	      var receptiveFieldSize = arrayProd(shape, 2);
	      fanIn = shape[1] * receptiveFieldSize;
	      fanOut = shape[0] * receptiveFieldSize;
	    } else if (dataFormat === 'channelsLast') {
	      var _receptiveFieldSize = arrayProd(shape, 0, shape.length - 2);
	      fanIn = shape[shape.length - 2] * _receptiveFieldSize;
	      fanOut = shape[shape.length - 1] * _receptiveFieldSize;
	    }
	  } else {
	    var shapeProd = arrayProd(shape);
	    fanIn = Math.sqrt(shapeProd);
	    fanOut = Math.sqrt(shapeProd);
	  }
	  return [fanIn, fanOut];
	}
	var VarianceScaling = /*#__PURE__*/function (_Initializer8) {
	  _inherits(VarianceScaling, _Initializer8);
	  var _super9 = _createSuper(VarianceScaling);
	  /**
	   * Constructor of VarianceScaling.
	   * @throws ValueError for invalid value in scale.
	   */
	  function VarianceScaling(args) {
	    var _this8;
	    _classCallCheck(this, VarianceScaling);
	    _this8 = _super9.call(this);
	    if (args.scale < 0.0) {
	      throw new ValueError("scale must be a positive float. Got: ".concat(args.scale));
	    }
	    _this8.scale = args.scale == null ? 1.0 : args.scale;
	    _this8.mode = args.mode == null ? 'fanIn' : args.mode;
	    checkFanMode(_this8.mode);
	    _this8.distribution = args.distribution == null ? 'normal' : args.distribution;
	    checkDistribution(_this8.distribution);
	    _this8.seed = args.seed;
	    return _this8;
	  }
	  _createClass(VarianceScaling, [{
	    key: "apply",
	    value: function apply(shape, dtype) {
	      var fans = computeFans(shape);
	      var fanIn = fans[0];
	      var fanOut = fans[1];
	      var scale = this.scale;
	      if (this.mode === 'fanIn') {
	        scale /= Math.max(1, fanIn);
	      } else if (this.mode === 'fanOut') {
	        scale /= Math.max(1, fanOut);
	      } else {
	        scale /= Math.max(1, (fanIn + fanOut) / 2);
	      }
	      if (this.distribution === 'normal') {
	        var stddev = Math.sqrt(scale);
	        dtype = dtype || 'float32';
	        if (dtype !== 'float32' && dtype !== 'int32') {
	          throw new NotImplementedError("".concat(this.getClassName(), " does not support dType ").concat(dtype, "."));
	        }
	        return truncatedNormal$1(shape, 0, stddev, dtype, this.seed);
	      } else {
	        var limit = Math.sqrt(3 * scale);
	        return randomUniform$1(shape, -limit, limit, dtype, this.seed);
	      }
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        scale: this.scale,
	        mode: this.mode,
	        distribution: this.distribution,
	        seed: this.seed
	      };
	    }
	  }]);
	  return VarianceScaling;
	}(Initializer);
	/** @nocollapse */
	VarianceScaling.className = 'VarianceScaling';
	registerClass(VarianceScaling);
	var GlorotUniform = /*#__PURE__*/function (_VarianceScaling) {
	  _inherits(GlorotUniform, _VarianceScaling);
	  var _super10 = _createSuper(GlorotUniform);
	  /**
	   * Constructor of GlorotUniform
	   * @param scale
	   * @param mode
	   * @param distribution
	   * @param seed
	   */
	  function GlorotUniform(args) {
	    _classCallCheck(this, GlorotUniform);
	    return _super10.call(this, {
	      scale: 1.0,
	      mode: 'fanAvg',
	      distribution: 'uniform',
	      seed: args == null ? null : args.seed
	    });
	  }
	  _createClass(GlorotUniform, [{
	    key: "getClassName",
	    value: function getClassName() {
	      // In Python Keras, GlorotUniform is not a class, but a helper method
	      // that creates a VarianceScaling object. Use 'VarianceScaling' as
	      // class name to be compatible with that.
	      return VarianceScaling.className;
	    }
	  }]);
	  return GlorotUniform;
	}(VarianceScaling);
	/** @nocollapse */
	GlorotUniform.className = 'GlorotUniform';
	registerClass(GlorotUniform);
	var GlorotNormal = /*#__PURE__*/function (_VarianceScaling2) {
	  _inherits(GlorotNormal, _VarianceScaling2);
	  var _super11 = _createSuper(GlorotNormal);
	  /**
	   * Constructor of GlorotNormal.
	   * @param scale
	   * @param mode
	   * @param distribution
	   * @param seed
	   */
	  function GlorotNormal(args) {
	    _classCallCheck(this, GlorotNormal);
	    return _super11.call(this, {
	      scale: 1.0,
	      mode: 'fanAvg',
	      distribution: 'normal',
	      seed: args == null ? null : args.seed
	    });
	  }
	  _createClass(GlorotNormal, [{
	    key: "getClassName",
	    value: function getClassName() {
	      // In Python Keras, GlorotNormal is not a class, but a helper method
	      // that creates a VarianceScaling object. Use 'VarianceScaling' as
	      // class name to be compatible with that.
	      return VarianceScaling.className;
	    }
	  }]);
	  return GlorotNormal;
	}(VarianceScaling);
	/** @nocollapse */
	GlorotNormal.className = 'GlorotNormal';
	registerClass(GlorotNormal);
	var HeNormal = /*#__PURE__*/function (_VarianceScaling3) {
	  _inherits(HeNormal, _VarianceScaling3);
	  var _super12 = _createSuper(HeNormal);
	  function HeNormal(args) {
	    _classCallCheck(this, HeNormal);
	    return _super12.call(this, {
	      scale: 2.0,
	      mode: 'fanIn',
	      distribution: 'normal',
	      seed: args == null ? null : args.seed
	    });
	  }
	  _createClass(HeNormal, [{
	    key: "getClassName",
	    value: function getClassName() {
	      // In Python Keras, HeNormal is not a class, but a helper method
	      // that creates a VarianceScaling object. Use 'VarianceScaling' as
	      // class name to be compatible with that.
	      return VarianceScaling.className;
	    }
	  }]);
	  return HeNormal;
	}(VarianceScaling);
	/** @nocollapse */
	HeNormal.className = 'HeNormal';
	registerClass(HeNormal);
	var HeUniform = /*#__PURE__*/function (_VarianceScaling4) {
	  _inherits(HeUniform, _VarianceScaling4);
	  var _super13 = _createSuper(HeUniform);
	  function HeUniform(args) {
	    _classCallCheck(this, HeUniform);
	    return _super13.call(this, {
	      scale: 2.0,
	      mode: 'fanIn',
	      distribution: 'uniform',
	      seed: args == null ? null : args.seed
	    });
	  }
	  _createClass(HeUniform, [{
	    key: "getClassName",
	    value: function getClassName() {
	      // In Python Keras, HeUniform is not a class, but a helper method
	      // that creates a VarianceScaling object. Use 'VarianceScaling' as
	      // class name to be compatible with that.
	      return VarianceScaling.className;
	    }
	  }]);
	  return HeUniform;
	}(VarianceScaling);
	/** @nocollapse */
	HeUniform.className = 'HeUniform';
	registerClass(HeUniform);
	var LeCunNormal = /*#__PURE__*/function (_VarianceScaling5) {
	  _inherits(LeCunNormal, _VarianceScaling5);
	  var _super14 = _createSuper(LeCunNormal);
	  function LeCunNormal(args) {
	    _classCallCheck(this, LeCunNormal);
	    return _super14.call(this, {
	      scale: 1.0,
	      mode: 'fanIn',
	      distribution: 'normal',
	      seed: args == null ? null : args.seed
	    });
	  }
	  _createClass(LeCunNormal, [{
	    key: "getClassName",
	    value: function getClassName() {
	      // In Python Keras, LeCunNormal is not a class, but a helper method
	      // that creates a VarianceScaling object. Use 'VarianceScaling' as
	      // class name to be compatible with that.
	      return VarianceScaling.className;
	    }
	  }]);
	  return LeCunNormal;
	}(VarianceScaling);
	/** @nocollapse */
	LeCunNormal.className = 'LeCunNormal';
	registerClass(LeCunNormal);
	var LeCunUniform = /*#__PURE__*/function (_VarianceScaling6) {
	  _inherits(LeCunUniform, _VarianceScaling6);
	  var _super15 = _createSuper(LeCunUniform);
	  function LeCunUniform(args) {
	    _classCallCheck(this, LeCunUniform);
	    return _super15.call(this, {
	      scale: 1.0,
	      mode: 'fanIn',
	      distribution: 'uniform',
	      seed: args == null ? null : args.seed
	    });
	  }
	  _createClass(LeCunUniform, [{
	    key: "getClassName",
	    value: function getClassName() {
	      // In Python Keras, LeCunUniform is not a class, but a helper method
	      // that creates a VarianceScaling object. Use 'VarianceScaling' as
	      // class name to be compatible with that.
	      return VarianceScaling.className;
	    }
	  }]);
	  return LeCunUniform;
	}(VarianceScaling);
	/** @nocollapse */
	LeCunUniform.className = 'LeCunUniform';
	registerClass(LeCunUniform);
	var Orthogonal = /*#__PURE__*/function (_Initializer9) {
	  _inherits(Orthogonal, _Initializer9);
	  var _super16 = _createSuper(Orthogonal);
	  function Orthogonal(args) {
	    var _this9;
	    _classCallCheck(this, Orthogonal);
	    _this9 = _super16.call(this);
	    _this9.DEFAULT_GAIN = 1;
	    _this9.ELEMENTS_WARN_SLOW = 2000;
	    _this9.gain = args.gain == null ? _this9.DEFAULT_GAIN : args.gain;
	    _this9.seed = args.seed;
	    return _this9;
	  }
	  _createClass(Orthogonal, [{
	    key: "apply",
	    value: function apply(shape, dtype) {
	      var _this10 = this;
	      return tidy(function () {
	        if (shape.length < 2) {
	          throw new NotImplementedError('Shape must be at least 2D.');
	        }
	        if (dtype !== 'int32' && dtype !== 'float32' && dtype !== undefined) {
	          throw new TypeError("Unsupported data type ".concat(dtype, "."));
	        }
	        dtype = dtype;
	        // flatten the input shape with the last dimension remaining its
	        // original shape so it works for conv2d
	        var numRows = sizeFromShape(shape.slice(0, -1));
	        var numCols = shape[shape.length - 1];
	        var numElements = numRows * numCols;
	        if (numElements > _this10.ELEMENTS_WARN_SLOW) {
	          console.warn("Orthogonal initializer is being called on a matrix with more " + "than ".concat(_this10.ELEMENTS_WARN_SLOW, " (").concat(numElements, ") elements: ") + "Slowness may result.");
	        }
	        var flatShape = [Math.max(numCols, numRows), Math.min(numCols, numRows)];
	        // Generate a random matrix
	        var randNormalMat = randomNormal$1(flatShape, 0, 1, dtype, _this10.seed);
	        // Compute QR factorization
	        var qr = linalg.qr(randNormalMat, false);
	        var qMat = qr[0];
	        var rMat = qr[1];
	        // Make Q uniform
	        var diag = rMat.flatten().stridedSlice([0], [Math.min(numCols, numRows) * Math.min(numCols, numRows)], [Math.min(numCols, numRows) + 1]);
	        qMat = mul(qMat, diag.sign());
	        if (numRows < numCols) {
	          qMat = qMat.transpose();
	        }
	        return mul(scalar(_this10.gain), qMat.reshape(shape));
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        gain: this.gain,
	        seed: this.seed
	      };
	    }
	  }]);
	  return Orthogonal;
	}(Initializer);
	/** @nocollapse */
	Orthogonal.className = 'Orthogonal';
	registerClass(Orthogonal);
	// Maps the JavaScript-like identifier keys to the corresponding registry
	// symbols.
	var INITIALIZER_IDENTIFIER_REGISTRY_SYMBOL_MAP = {
	  'constant': 'Constant',
	  'glorotNormal': 'GlorotNormal',
	  'glorotUniform': 'GlorotUniform',
	  'heNormal': 'HeNormal',
	  'heUniform': 'HeUniform',
	  'identity': 'Identity',
	  'leCunNormal': 'LeCunNormal',
	  'leCunUniform': 'LeCunUniform',
	  'ones': 'Ones',
	  'orthogonal': 'Orthogonal',
	  'randomNormal': 'RandomNormal',
	  'randomUniform': 'RandomUniform',
	  'truncatedNormal': 'TruncatedNormal',
	  'varianceScaling': 'VarianceScaling',
	  'zeros': 'Zeros'
	};
	function deserializeInitializer(config) {
	  var customObjects = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	  return deserializeKerasObject(config, SerializationMap.getMap().classNameMap, customObjects, 'initializer');
	}
	function serializeInitializer(initializer) {
	  return serializeKerasObject(initializer);
	}
	function getInitializer(identifier) {
	  if (typeof identifier === 'string') {
	    var className = identifier in INITIALIZER_IDENTIFIER_REGISTRY_SYMBOL_MAP ? INITIALIZER_IDENTIFIER_REGISTRY_SYMBOL_MAP[identifier] : identifier;
	    /* We have four 'helper' classes for common initializers that
	    all get serialized as 'VarianceScaling' and shouldn't go through
	    the deserializeInitializer pathway. */
	    if (className === 'GlorotNormal') {
	      return new GlorotNormal();
	    } else if (className === 'GlorotUniform') {
	      return new GlorotUniform();
	    } else if (className === 'HeNormal') {
	      return new HeNormal();
	    } else if (className === 'HeUniform') {
	      return new HeUniform();
	    } else if (className === 'LeCunNormal') {
	      return new LeCunNormal();
	    } else if (className === 'LeCunUniform') {
	      return new LeCunUniform();
	    } else {
	      var config = {};
	      config['className'] = className;
	      config['config'] = {};
	      return deserializeInitializer(config);
	    }
	  } else if (identifier instanceof Initializer) {
	    return identifier;
	  } else {
	    return deserializeInitializer(identifier);
	  }
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	// tslint:enable
	/**
	 * Determine whether the input is an Array of Shapes.
	 */
	function isArrayOfShapes(x) {
	  return Array.isArray(x) && Array.isArray(x[0]);
	}
	/**
	 * Special case of normalizing shapes to lists.
	 *
	 * @param x A shape or list of shapes to normalize into a list of Shapes.
	 * @return A list of Shapes.
	 */
	function normalizeShapeList(x) {
	  if (x.length === 0) {
	    return [];
	  }
	  if (!Array.isArray(x[0])) {
	    return [x];
	  }
	  return x;
	}
	/**
	 * Helper function to obtain exactly one Tensor.
	 * @param xs: A single `tf.Tensor` or an `Array` of `tf.Tensor`s.
	 * @return A single `tf.Tensor`. If `xs` is an `Array`, return the first one.
	 * @throws ValueError: If `xs` is an `Array` and its length is not 1.
	 */
	function getExactlyOneTensor(xs) {
	  var x;
	  if (Array.isArray(xs)) {
	    if (xs.length !== 1) {
	      throw new ValueError("Expected Tensor length to be 1; got ".concat(xs.length));
	    }
	    x = xs[0];
	  } else {
	    x = xs;
	  }
	  return x;
	}
	/**
	 * Helper function to obtain exactly on instance of Shape.
	 *
	 * @param shapes Input single `Shape` or Array of `Shape`s.
	 * @returns If input is a single `Shape`, return it unchanged. If the input is
	 *   an `Array` containing exactly one instance of `Shape`, return the instance.
	 *   Otherwise, throw a `ValueError`.
	 * @throws ValueError: If input is an `Array` of `Shape`s, and its length is not
	 *   1.
	 */
	function getExactlyOneShape(shapes) {
	  if (Array.isArray(shapes) && Array.isArray(shapes[0])) {
	    if (shapes.length === 1) {
	      shapes = shapes;
	      return shapes[0];
	    } else {
	      throw new ValueError("Expected exactly 1 Shape; got ".concat(shapes.length));
	    }
	  } else {
	    return shapes;
	  }
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	/**
	 * Count the elements in an Array of LayerVariables.
	 *
	 * @param weights: The LayerVariables of which the constituent numbers are to
	 *   be counted.
	 * @returns A count of the elements in all the LayerVariables
	 */
	function countParamsInWeights(weights) {
	  var count = 0;
	  var _iterator = _createForOfIteratorHelper(weights),
	    _step;
	  try {
	    for (_iterator.s(); !(_step = _iterator.n()).done;) {
	      var weight = _step.value;
	      if (weight.shape.length === 0) {
	        count += 1;
	      } else {
	        count += weight.shape.reduce(function (a, b) {
	          return a * b;
	        });
	      }
	    }
	  } catch (err) {
	    _iterator.e(err);
	  } finally {
	    _iterator.f();
	  }
	  return count;
	}

	var DEFAULT_VARIABLE_NAME_PREFIX = 'Variable';
	/**
	 * A `tf.layers.LayerVariable` is similar to a `tf.Tensor` in that it has a
	 * dtype and shape, but its value is mutable.  The value is itself represented
	 * as a`tf.Tensor`, and can be read with the `read()` method and updated with
	 * the `write()` method.
	 */
	var LayerVariable = /*#__PURE__*/function () {
	  /**
	   * Construct Variable from a `tf.Tensor`.
	   *
	   * If not explicitly named, the Variable will be given a name with the
	   * prefix 'Variable'. Variable names are unique. In the case of name
	   * collision, suffixies '_<num>' will be added to the name.
	   *
	   * @param val Initial value of the Variable.
	   * @param name Name of the variable. If `null` or `undefined` is provided, it
	   *   will default a name with the prefix 'Variable'.
	   * @param constraint Optional, projection function to be applied to the
	   * variable after optimize updates
	   * @throws ValueError if `name` is `null` or `undefined`.
	   */
	  function LayerVariable(val) {
	    var dtype = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'float32';
	    var name = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : DEFAULT_VARIABLE_NAME_PREFIX;
	    var trainable = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : true;
	    var constraint = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : null;
	    _classCallCheck(this, LayerVariable);
	    this.dtype = dtype == null ? 'float32' : dtype;
	    this.shape = val.shape;
	    this.id = getNextUniqueTensorId();
	    name = name == null ? DEFAULT_VARIABLE_NAME_PREFIX : name;
	    this.originalName = getScopedTensorName(name);
	    this.name = getUniqueTensorName(this.originalName);
	    this.trainable_ = trainable;
	    this.constraint = constraint;
	    this.val = variable$1(val, this.trainable_, this.name, this.dtype);
	  }
	  /**
	   * Get a snapshot of the Variable's value.
	   *
	   * The returned value is a snapshot of the Variable's value at the time of
	   * the invocation. Future mutations in the value of the tensor will only
	   * be reflected by future calls to this method.
	   */
	  _createClass(LayerVariable, [{
	    key: "read",
	    value: function read() {
	      this.assertNotDisposed();
	      return this.val;
	    }
	    /**
	     * Update the value of the Variable.
	     *
	     * @param newVal: The new value to update to. Must be consistent with the
	     *   dtype and shape of the Variable.
	     * @return This Variable.
	     */
	  }, {
	    key: "write",
	    value: function write(newVal) {
	      // TODO(cais): Once  TF.js Core supports Tensor.dtype, check dtype match.
	      this.assertNotDisposed();
	      checkShapesMatch(this.val, newVal);
	      // Skip updating if this is the exact same tensor.
	      if (this.val.id !== newVal.id) {
	        this.val.assign(newVal);
	        if (this.constraint != null) {
	          this.val.assign(this.constraint.apply(this.val));
	        }
	      }
	      return this;
	    }
	    /**
	     * Dispose this LayersVariable instance from memory.
	     */
	  }, {
	    key: "dispose",
	    value: function dispose() {
	      this.assertNotDisposed();
	      this.val.dispose();
	    }
	  }, {
	    key: "assertNotDisposed",
	    value: function assertNotDisposed() {
	      if (this.val.isDisposed) {
	        throw new Error("LayersVariable ".concat(this.name, " is already disposed."));
	      }
	    }
	  }, {
	    key: "trainable",
	    get: function get() {
	      return this.trainable_;
	    },
	    set: function set(trainable) {
	      this.trainable_ = trainable;
	      this.val.trainable = trainable;
	    }
	  }]);
	  return LayerVariable;
	}();
	function checkShapesMatch(x, y) {
	  if (x.shape.toString() !== y.shape.toString()) {
	    throw new Error('Shape mismatch: ' + JSON.stringify(x.shape) + ' vs. ' + JSON.stringify(y.shape));
	  }
	}
	/**
	 * Create a Variable.
	 * @param x The initial value of the `Variable`.
	 * @param dtype optional, the type of the variable.
	 * @param name optional, the name of the variable, default provided by
	 * Variable.
	 * @param constraint optional, a constraint to be applied after every update.
	 * @return The newly instantiated `Variable`.
	 */
	function variable(x, dtype, name, constraint) {
	  return new LayerVariable(x, dtype, name, true, constraint);
	}
	/**
	 * Instantiates an all-zeros Variable and returns it.
	 *
	 * @param shape Shape of the tensor.
	 * @param dtype DType of the tensor.
	 * @param name Name of the tensor.
	 * @return An all-zero Variable.
	 */
	function zerosVariable(shape, dtype, name) {
	  // TODO(cais): Implement logic for dtype.
	  return new LayerVariable(zeros$2(shape), dtype, name);
	}
	/**
	 * Instantiates an all-zeros tensor of the same shape as another tensor.
	 *
	 * @param x The other tensor.
	 * @param dtype DType of the tensor.
	 * @param name Name of the tensor.
	 * @return A newly instantiated Variable.
	 */
	function zerosLike$2(x, dtype, name) {
	  return new LayerVariable(zerosLike$3(x), dtype, name);
	}
	/**
	 * Instantiates an all-ones tensor and returns it.
	 *
	 * @param shape Shape of the tensor.
	 * @param dtype DType of the tensor.
	 * @param name Name of the tensor.
	 * @return An all-ones Variable.
	 */
	function onesVariable(shape, dtype, name) {
	  // TODO(cais): Implement logic for dtype.
	  var allocated = ones$1(shape);
	  return new LayerVariable(allocated, dtype, name);
	}
	/**
	 * Instantiates an all-ones tensor of the same shape as another tensor.
	 *
	 * @param x The other tensor.
	 * @param dtype DType of the tensor.
	 * @param name Name of the tensor.
	 * @return A newly instantiated Variable.
	 */
	function onesLike$2(x, dtype, name) {
	  var allocated = onesLike$3(x);
	  return new LayerVariable(allocated, dtype, name);
	}
	/**
	 * Instantiate an identity matrix and returns it, as a Variable
	 *
	 * @param size Number of rows/columns.
	 * @param dtype Data type of returned Variable.
	 * @param name Name of returned Variable.
	 * @return A Variable, an identity matrix.
	 */
	function eyeVariable(size, dtype, name) {
	  return new LayerVariable(eye(size), dtype, name);
	}
	/**
	 * Get a Variable with uniform distribution of values.
	 * @param shape Shape of the tensor.
	 * @param minval Lower bound of the uniform distribution.
	 * @param maxval Upper bound of the uniform distribution.
	 * @param dtype
	 * @param seed
	 * @param name Optional name.
	 * @return The uniform-random Variable.
	 */
	function randomUniformVariable(shape, minval, maxval, dtype, seed) {
	  var name = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : 'randomUniform';
	  return new LayerVariable(randomUniform$1(shape, minval, maxval, dtype), dtype, name);
	}
	/**
	 * Get a Variable with truncated-normal distribution of values.
	 * @param shape Shape of the tensor.
	 * @param mean mean value of the normal distribution.
	 * @param stddev standard deviation of the normal distribution.
	 * @param dtype
	 * @param seed
	 * @param name Optional name.
	 * @return The truncated-normal-random Variable.
	 */
	function truncatedNormalVariable(shape) {
	  var mean = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0.0;
	  var stddev = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1.0;
	  var dtype = arguments.length > 3 ? arguments[3] : undefined;
	  var seed = arguments.length > 4 ? arguments[4] : undefined;
	  var name = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : 'truncatedNormal';
	  // TODO(cais): Implement logic for dtype and seed once they are supported
	  // by deeplearn.js.
	  dtype = dtype || 'float32';
	  if (dtype !== 'float32' && dtype !== 'int32') {
	    throw new NotImplementedError("randomNormal does not support dType ".concat(dtype, "."));
	  }
	  return new LayerVariable(truncatedNormal$1(shape, mean, stddev, dtype, seed), dtype, name);
	}
	/**
	 * Get a Variable with normal distribution of values.
	 * @param shape Shape of the tensor.
	 * @param mean mean value of the normal distribution.
	 * @param stddev standard deviation of the normal distribution.
	 * @param dtype
	 * @param seed
	 * @param name Optional name.
	 * @return The truncated-normal-random Variable.
	 */
	function randomNormalVariable(shape) {
	  var mean = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0.0;
	  var stddev = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1.0;
	  var dtype = arguments.length > 3 ? arguments[3] : undefined;
	  var seed = arguments.length > 4 ? arguments[4] : undefined;
	  var name = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : 'randomNormal';
	  dtype = dtype || 'float32';
	  if (dtype !== 'float32' && dtype !== 'int32') {
	    throw new NotImplementedError("randomNormalVariable does not support dType ".concat(dtype, "."));
	  }
	  return new LayerVariable(randomNormal$2(shape, mean, stddev, dtype, seed), dtype, name);
	}
	/**
	 * Update the value of a Variable.
	 * @param x The Variable to be updated.
	 * @param xNew The new value to update to.
	 * @return The Variable updated.
	 */
	function update(x, xNew) {
	  return x.write(xNew);
	}
	/**
	 * Update the value of a Variable by adding an increment.
	 * @param x The Variable to be updated.
	 * @param increment The incrment to add to `x`.
	 * @return The Variable updated.
	 */
	function updateAdd(x, increment) {
	  return x.write(add$3(x.read(), increment));
	}
	/**
	 * Update the value of a Variable by subtracting a decrement.
	 * @param x The Variable to be updated.
	 * @param decrement The decrement to subtract from `x`.
	 * @return The Variable updated.
	 */
	function updateSub(x, decrement) {
	  return x.write(sub$2(x.read(), decrement));
	}
	/**
	 * Get the values of an array of Variables.
	 *
	 * @param tensors An `Array` of `Variable`s to get the values of.
	 * @return The values of the inputs, as an `Array` of`tf.Tensor`s.
	 */
	function batchGetValue(xs) {
	  return xs.map(function (x) {
	    return x.read();
	  });
	}
	/**
	 * Update the value of multiple Variables at once.
	 *
	 * @param variablesAndValues An `Array`, each element is of type
	 *   [Variable, Tensor]. The first item is the
	 *   `Variable` of which the value is to be updated. The second item
	 *   carries the new value.
	 */
	function batchSetValue(variablesAndValues) {
	  variablesAndValues.forEach(function (variableAndValue) {
	    var variable = variableAndValue[0];
	    variable.write(variableAndValue[1]);
	  });
	}
	/**
	 * Returns the gradients of `variables` w.r.t. the return value of `lossFn`.
	 * @param lossFn A function which returns a Scalar to be used as the function
	 *   value (i.e., numerator) for differentiation.
	 * @param variables List of variables to be used as the independent variables
	 *   (i.e., denominator) for differentiation.
	 * @returns An Array of gradients tensors.
	 */
	function gradients(lossFn, variables) {
	  // TODO(cais): The return type signature can be simplified if deeplearn makes
	  //   the corresponding type public.
	  var variableList = variables.map(function (variable) {
	    return variable.read();
	  });
	  var valudAndGrads = variableGrads(lossFn, variableList);
	  return variables.map(function (variable) {
	    return valudAndGrads.grads[variable.name];
	  });
	}

	/**
	 * Specifies the ndim, dtype and shape of every input to a layer.
	 *
	 * Every layer should expose (if appropriate) an `inputSpec` attribute:
	 * a list of instances of InputSpec (one per input tensor).
	 *
	 * A null entry in a shape is compatible with any dimension,
	 * a null shape is compatible with any shape.
	 */
	var InputSpec = /*#__PURE__*/_createClass(function InputSpec(args) {
	  _classCallCheck(this, InputSpec);
	  this.dtype = args.dtype;
	  this.shape = args.shape;
	  /*
	    TODO(michaelterry): Could throw error if ndim and shape are both defined
	      (then backport).
	  */
	  if (args.shape != null) {
	    this.ndim = args.shape.length;
	  } else {
	    this.ndim = args.ndim;
	  }
	  this.maxNDim = args.maxNDim;
	  this.minNDim = args.minNDim;
	  this.axes = args.axes || {};
	});
	/**
	 * `tf.SymbolicTensor` is a placeholder for a Tensor without any concrete value.
	 *
	 * They are most often encountered when building a graph of `Layer`s for a
	 * `tf.LayersModel` and the input data's shape, but not values are known.
	 *
	 * @doc {heading: 'Models', 'subheading': 'Classes'}
	 */
	var SymbolicTensor = /*#__PURE__*/_createClass(
	/**
	 *
	 * @param dtype
	 * @param shape
	 * @param sourceLayer The Layer that produced this symbolic tensor.
	 * @param inputs The inputs passed to sourceLayer's __call__() method.
	 * @param nodeIndex
	 * @param tensorIndex
	 * @param callArgs The keyword arguments passed to the __call__() method.
	 * @param name
	 * @param outputTensorIndex The index of this tensor in the list of outputs
	 *   returned by apply().
	 */
	function SymbolicTensor(dtype, shape, sourceLayer, inputs, callArgs, name, outputTensorIndex) {
	  _classCallCheck(this, SymbolicTensor);
	  this.dtype = dtype;
	  this.shape = shape;
	  this.sourceLayer = sourceLayer;
	  this.inputs = inputs;
	  this.callArgs = callArgs;
	  this.outputTensorIndex = outputTensorIndex;
	  this.id = getNextUniqueTensorId();
	  if (name != null) {
	    this.originalName = getScopedTensorName(name);
	    this.name = getUniqueTensorName(this.originalName);
	  }
	  this.rank = shape.length;
	});
	var _nextNodeID = 0;
	/**
	 * A `Node` describes the connectivity between two layers.
	 *
	 * Each time a layer is connected to some new input,
	 * a node is added to `layer.inboundNodes`.
	 *
	 * Each time the output of a layer is used by another layer,
	 * a node is added to `layer.outboundNodes`.
	 *
	 * `nodeIndices` and `tensorIndices` are basically fine-grained coordinates
	 * describing the origin of the `inputTensors`, verifying the following:
	 *
	 * `inputTensors[i] ==
	 * inboundLayers[i].inboundNodes[nodeIndices[i]].outputTensors[
	 *   tensorIndices[i]]`
	 *
	 * A node from layer A to layer B is added to:
	 *     A.outboundNodes
	 *     B.inboundNodes
	 */
	var Node = /*#__PURE__*/function () {
	  function Node(args,
	  // TODO(michaelterry): Define actual type for this.
	  callArgs) {
	    _classCallCheck(this, Node);
	    this.callArgs = callArgs;
	    this.id = _nextNodeID++;
	    /*
	      Layer instance (NOT a list).
	      this is the layer that takes a list of input tensors
	      and turns them into a list of output tensors.
	      the current node will be added to
	      the inboundNodes of outboundLayer.
	    */
	    this.outboundLayer = args.outboundLayer;
	    /*
	        The following 3 properties describe where
	        the input tensors come from: which layers,
	        and for each layer, which node and which
	        tensor output of each node.
	    */
	    // List of layer instances.
	    this.inboundLayers = args.inboundLayers;
	    // List of integers, 1:1 mapping with inboundLayers.
	    this.nodeIndices = args.nodeIndices;
	    // List of integers, 1:1 mapping with inboundLayers.
	    this.tensorIndices = args.tensorIndices;
	    /*
	        Following 2 properties:
	        tensor inputs and outputs of outboundLayer.
	    */
	    // List of tensors. 1:1 mapping with inboundLayers.
	    this.inputTensors = args.inputTensors;
	    // List of tensors, created by outboundLayer.call().
	    this.outputTensors = args.outputTensors;
	    /*
	        Following 2 properties: input and output masks.
	        List of tensors, 1:1 mapping with inputTensor.
	    */
	    this.inputMasks = args.inputMasks;
	    // List of tensors, created by outboundLayer.computeMask().
	    this.outputMasks = args.outputMasks;
	    // Following 2 properties: input and output shapes.
	    // List of shape tuples, shapes of inputTensors.
	    this.inputShapes = args.inputShapes;
	    // List of shape tuples, shapes of outputTensors.
	    this.outputShapes = args.outputShapes;
	    // Add nodes to all layers involved.
	    var _iterator = _createForOfIteratorHelper(args.inboundLayers),
	      _step;
	    try {
	      for (_iterator.s(); !(_step = _iterator.n()).done;) {
	        var layer = _step.value;
	        if (layer != null) {
	          layer.outboundNodes.push(this);
	        }
	      }
	    } catch (err) {
	      _iterator.e(err);
	    } finally {
	      _iterator.f();
	    }
	    args.outboundLayer.inboundNodes.push(this);
	  }
	  _createClass(Node, [{
	    key: "getConfig",
	    value: function getConfig() {
	      var inboundNames = [];
	      var _iterator2 = _createForOfIteratorHelper(this.inboundLayers),
	        _step2;
	      try {
	        for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	          var layer = _step2.value;
	          if (layer != null) {
	            inboundNames.push(layer.name);
	          } else {
	            inboundNames.push(null);
	          }
	        }
	      } catch (err) {
	        _iterator2.e(err);
	      } finally {
	        _iterator2.f();
	      }
	      return {
	        outboundLayer: this.outboundLayer ? this.outboundLayer.name : null,
	        inboundLayers: inboundNames,
	        nodeIndices: this.nodeIndices,
	        tensorIndices: this.tensorIndices
	      };
	    }
	  }]);
	  return Node;
	}();
	var _nextLayerID = 0;
	/**
	 * A layer is a grouping of operations and weights that can be composed to
	 * create a `tf.LayersModel`.
	 *
	 * Layers are constructed by using the functions under the
	 * [tf.layers](#Layers-Basic) namespace.
	 *
	 * @doc {heading: 'Layers', subheading: 'Classes', namespace: 'layers'}
	 */
	var Layer = /*#__PURE__*/function (_serialization$Serial) {
	  _inherits(Layer, _serialization$Serial);
	  var _super = _createSuper(Layer);
	  function Layer() {
	    var _this;
	    var args = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
	    _classCallCheck(this, Layer);
	    _this = _super.call(this);
	    _this._callHook = null;
	    _this._addedWeightNames = [];
	    // Porting Notes: PyKeras does not have this property in this base Layer
	    //   class. Instead lets Layer subclass set it dynamically and checks the
	    //   value with `hasattr`. In tfjs-layers, we let this be a member of this
	    //   base class.
	    _this._stateful = false;
	    _this.id = _nextLayerID++;
	    _this.activityRegularizer = null;
	    _this.inputSpec = null;
	    _this.supportsMasking = false;
	    // These properties will be set upon call of this.build()
	    _this._trainableWeights = [];
	    _this._nonTrainableWeights = [];
	    _this._losses = [];
	    _this._updates = [];
	    _this._built = false;
	    /*
	      These lists will be filled via successive calls
	      to this.addInboundNode().
	     */
	    _this.inboundNodes = [];
	    _this.outboundNodes = [];
	    var name = args.name;
	    if (!name) {
	      var prefix = _this.getClassName();
	      name = toSnakeCase(prefix) + '_' + getUid(prefix);
	    }
	    _this.name = name;
	    _this.trainable_ = args.trainable == null ? true : args.trainable;
	    if (args.inputShape != null || args.batchInputShape != null) {
	      /*
	        In this case we will later create an input layer
	        to insert before the current layer
	       */
	      var batchInputShape;
	      if (args.batchInputShape != null) {
	        batchInputShape = args.batchInputShape;
	      } else if (args.inputShape != null) {
	        var batchSize = null;
	        if (args.batchSize != null) {
	          batchSize = args.batchSize;
	        }
	        batchInputShape = [batchSize].concat(args.inputShape);
	      }
	      _this.batchInputShape = batchInputShape;
	      // Set dtype.
	      var dtype = args.dtype;
	      if (dtype == null) {
	        dtype = args.inputDType;
	      }
	      if (dtype == null) {
	        dtype = 'float32';
	      }
	      _this.dtype = dtype;
	    }
	    if (args.weights != null) {
	      _this.initialWeights = args.weights;
	    } else {
	      _this.initialWeights = null;
	    }
	    // The value of `_refCount` is initialized to null. When the layer is used
	    // in a symbolic way for the first time, it will be set to 1.
	    _this._refCount = null;
	    _this.fastWeightInitDuringBuild = false;
	    return _this;
	  }
	  /**
	   * Converts a layer and its index to a unique (immutable type) name.
	   * This function is used internally with `this.containerNodes`.
	   * @param layer The layer.
	   * @param nodeIndex The layer's position (e.g. via enumerate) in a list of
	   *   nodes.
	   *
	   * @returns The unique name.
	   */
	  _createClass(Layer, [{
	    key: "getNodeAtIndex",
	    value:
	    /**
	     * Returns this.inboundNode at index nodeIndex.
	     *
	     * Porting note: This is a replacement for _get_node_attribute_at_index()
	     * @param nodeIndex
	     * @param attrName The name of the attribute related to request for this node.
	     */
	    function getNodeAtIndex(nodeIndex, attrName) {
	      if (this.inboundNodes.length === 0) {
	        throw new RuntimeError('The layer has never been called ' + "and thus has no defined ".concat(attrName, "."));
	      }
	      if (this.inboundNodes.length <= nodeIndex) {
	        throw new ValueError("Asked to get ".concat(attrName, " at node ").concat(nodeIndex, ", ") + "but the layer has only ".concat(this.inboundNodes.length, " inbound nodes."));
	      }
	      return this.inboundNodes[nodeIndex];
	    }
	    /**
	     * Retrieves the input tensor(s) of a layer at a given node.
	     *
	     * @param nodeIndex Integer, index of the node from which to retrieve the
	     *   attribute. E.g. `nodeIndex=0` will correspond to the first time the layer
	     *   was called.
	     *
	     * @return A tensor (or list of tensors if the layer has multiple inputs).
	     */
	  }, {
	    key: "getInputAt",
	    value: function getInputAt(nodeIndex) {
	      return singletonOrArray(this.getNodeAtIndex(nodeIndex, 'input').inputTensors);
	    }
	    /**
	     * Retrieves the output tensor(s) of a layer at a given node.
	     *
	     * @param nodeIndex Integer, index of the node from which to retrieve the
	     *   attribute. E.g. `nodeIndex=0` will correspond to the first time the layer
	     *   was called.
	     *
	     * @return A tensor (or list of tensors if the layer has multiple outputs).
	     */
	  }, {
	    key: "getOutputAt",
	    value: function getOutputAt(nodeIndex) {
	      return singletonOrArray(this.getNodeAtIndex(nodeIndex, 'output').outputTensors);
	    }
	    // Properties
	    /**
	     * Retrieves the input tensor(s) of a layer.
	     *
	     * Only applicable if the layer has exactly one inbound node,
	     * i.e. if it is connected to one incoming layer.
	     *
	     * @return Input tensor or list of input tensors.
	     *
	     * @exception AttributeError if the layer is connected to more than one
	     *   incoming layers.
	     */
	  }, {
	    key: "input",
	    get: function get() {
	      if (this.inboundNodes.length > 1) {
	        throw new AttributeError("Layer ".concat(this.name) + ' has multiple inbound nodes, ' + 'hence the notion of "layer input" ' + 'is ill-defined. ' + 'Use `getInputAt(nodeIndex)` instead.');
	      } else if (this.inboundNodes.length === 0) {
	        throw new AttributeError("Layer ".concat(this.name) + ' is not connected, no input to return.');
	      }
	      return singletonOrArray(this.getNodeAtIndex(0, 'input').inputTensors);
	    }
	    /**
	     * Retrieves the output tensor(s) of a layer.
	     *
	     * Only applicable if the layer has exactly one inbound node,
	     * i.e. if it is connected to one incoming layer.
	     *
	     * @return Output tensor or list of output tensors.
	     *
	     * @exception AttributeError if the layer is connected to more than one
	     *   incoming layers.
	     */
	  }, {
	    key: "output",
	    get: function get() {
	      if (this.inboundNodes.length === 0) {
	        throw new AttributeError("Layer ".concat(this.name) + ' has no inbound nodes.');
	      }
	      if (this.inboundNodes.length > 1) {
	        throw new AttributeError("Layer ".concat(this.name) + ' has multiple inbound nodes, ' + 'hence the notion of "layer output" ' + 'is ill-defined. ' + 'Use `getOutputAt(nodeIndex)` instead.');
	      }
	      return singletonOrArray(this.getNodeAtIndex(0, 'output').outputTensors);
	    }
	  }, {
	    key: "losses",
	    get: function get() {
	      return this._losses;
	    }
	    /**
	     * Retrieves the Layer's current loss values.
	     *
	     * Used for regularizers during training.
	     */
	  }, {
	    key: "calculateLosses",
	    value: function calculateLosses() {
	      // Porting Node: This is an augmentation to Layer.loss in PyKeras.
	      //   In PyKeras, Layer.loss returns symbolic tensors. Here a concrete
	      //   Tensor (specifically Scalar) values are returned. This is due to the
	      //   imperative backend.
	      return this.losses.map(function (lossFn) {
	        return lossFn();
	      });
	    }
	  }, {
	    key: "updates",
	    get: function get() {
	      return this._updates;
	    }
	  }, {
	    key: "built",
	    get: function get() {
	      return this._built;
	    },
	    set: function set(built) {
	      this._built = built;
	    }
	  }, {
	    key: "trainable",
	    get: function get() {
	      return this.trainable_;
	    },
	    set: function set(trainable) {
	      this._trainableWeights.forEach(function (w) {
	        return w.trainable = trainable;
	      });
	      this.trainable_ = trainable;
	    }
	  }, {
	    key: "trainableWeights",
	    get: function get() {
	      if (this.trainable_) {
	        return this._trainableWeights.filter(function (w) {
	          return w.trainable;
	        });
	      } else {
	        return [];
	      }
	    },
	    set: function set(weights) {
	      this._trainableWeights = weights;
	    }
	  }, {
	    key: "nonTrainableWeights",
	    get: function get() {
	      if (this.trainable) {
	        return this._trainableWeights.filter(function (w) {
	          return !w.trainable;
	        }).concat(this._nonTrainableWeights);
	      } else {
	        return this._trainableWeights.concat(this._nonTrainableWeights);
	      }
	    },
	    set: function set(weights) {
	      this._nonTrainableWeights = weights;
	    }
	    /**
	     * The concatenation of the lists trainableWeights and nonTrainableWeights
	     * (in this order).
	     */
	  }, {
	    key: "weights",
	    get: function get() {
	      return this.trainableWeights.concat(this.nonTrainableWeights);
	    }
	  }, {
	    key: "stateful",
	    get: function get() {
	      return this._stateful;
	    }
	    /**
	     * Reset the states of the layer.
	     *
	     * This method of the base Layer class is essentially a no-op.
	     * Subclasses that are stateful (e.g., stateful RNNs) should override this
	     * method.
	     */
	  }, {
	    key: "resetStates",
	    value: function resetStates() {
	      if (!this.stateful) {
	        throw new Error('Cannot call the resetStates() method of a non-stateful Layer ' + 'object.');
	      }
	    }
	    /**
	     * Checks compatibility between the layer and provided inputs.
	     *
	     * This checks that the tensor(s) `input`
	     * verify the input assumptions of the layer
	     * (if any). If not, exceptions are raised.
	     *
	     * @param inputs Input tensor or list of input tensors.
	     *
	     * @exception ValueError in case of mismatch between
	     *   the provided inputs and the expectations of the layer.
	     */
	  }, {
	    key: "assertInputCompatibility",
	    value: function assertInputCompatibility(inputs) {
	      var inputsList = toList(inputs);
	      if (this.inputSpec == null || this.inputSpec.length === 0) {
	        return;
	      }
	      var inputSpec = toList(this.inputSpec);
	      if (inputsList.length !== inputSpec.length) {
	        throw new ValueError("Layer ".concat(this.name, " expects ").concat(inputSpec.length, " inputs, ") + "but it received ".concat(inputsList.length, " input tensors. ") + "Input received: ".concat(inputs));
	      }
	      for (var inputIndex = 0; inputIndex < inputsList.length; inputIndex++) {
	        var x = inputsList[inputIndex];
	        var spec = inputSpec[inputIndex];
	        if (spec == null) {
	          continue;
	        }
	        // Check ndim.
	        var ndim = x.rank;
	        if (spec.ndim != null) {
	          if (ndim !== spec.ndim) {
	            throw new ValueError("Input ".concat(inputIndex, " is incompatible with layer ").concat(this.name, ": ") + "expected ndim=".concat(spec.ndim, ", found ndim=").concat(ndim));
	          }
	        }
	        if (spec.maxNDim != null) {
	          if (ndim > spec.maxNDim) {
	            throw new ValueError("Input ".concat(inputIndex, " is incompatible with layer ").concat(this.name) + ": expected max_ndim=".concat(spec.maxNDim, ", found ndim=").concat(ndim));
	          }
	        }
	        if (spec.minNDim != null) {
	          if (ndim < spec.minNDim) {
	            throw new ValueError("Input ".concat(inputIndex, " is incompatible with layer ").concat(this.name) + ": expected min_ndim=".concat(spec.minNDim, ", found ndim=").concat(ndim, "."));
	          }
	        }
	        // Check dtype.
	        if (spec.dtype != null) {
	          if (x.dtype !== spec.dtype) {
	            throw new ValueError("Input ".concat(inputIndex, " is incompatible with layer ").concat(this.name, " ") + ": expected dtype=".concat(spec.dtype, ", found dtype=").concat(x.dtype, "."));
	          }
	        }
	        // Check specific shape axes.
	        if (spec.axes) {
	          var xShape = x.shape;
	          for (var key in spec.axes) {
	            var axis = Number(key);
	            var value = spec.axes[key];
	            // Perform Python-style slicing in case axis < 0;
	            // TODO(cais): Use https://github.com/alvivi/typescript-underscore to
	            // ensure type safety through Underscore calls.
	            var xShapeAtAxis = axis >= 0 ? xShape[axis] : xShape[xShape.length + axis];
	            if (value != null && [value, null].indexOf(xShapeAtAxis) === -1) {
	              throw new ValueError("Input ".concat(inputIndex, " is incompatible with layer ") + "".concat(this.name, ": expected axis ").concat(axis, " of input shape to ") + "have value ".concat(value, " but got shape ").concat(xShape, "."));
	            }
	          }
	        }
	        // Check shape.
	        if (spec.shape != null) {
	          for (var i = 0; i < spec.shape.length; ++i) {
	            var specDim = spec.shape[i];
	            var dim = x.shape[i];
	            if (specDim != null && dim != null) {
	              if (specDim !== dim) {
	                throw new ValueError("Input ".concat(inputIndex, " is incompatible with layer ") + "".concat(this.name, ": expected shape=").concat(spec.shape, ", ") + "found shape=".concat(x.shape, "."));
	              }
	            }
	          }
	        }
	      }
	    }
	    /**
	     * This is where the layer's logic lives.
	     *
	     * @param inputs Input tensor, or list/tuple of input tensors.
	     * @param kwargs Additional keyword arguments.
	     *
	     * @return A tensor or list/tuple of tensors.
	     */
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      return inputs;
	    }
	  }, {
	    key: "invokeCallHook",
	    value: function invokeCallHook(inputs, kwargs) {
	      if (this._callHook != null) {
	        this._callHook(inputs, kwargs);
	      }
	    }
	    /**
	     * Set call hook.
	     * This is currently used for testing only.
	     * @param callHook
	     */
	  }, {
	    key: "setCallHook",
	    value: function setCallHook(callHook) {
	      this._callHook = callHook;
	    }
	    /**
	     * Clear call hook.
	     * This is currently used for testing only.
	     */
	  }, {
	    key: "clearCallHook",
	    value: function clearCallHook() {
	      this._callHook = null;
	    }
	    /**
	     * Builds or executes a `Layer`'s logic.
	     *
	     * When called with `tf.Tensor`(s), execute the `Layer`'s computation and
	     * return Tensor(s). For example:
	     *
	     * ```js
	     * const denseLayer = tf.layers.dense({
	     *   units: 1,
	     *   kernelInitializer: 'zeros',
	     *   useBias: false
	     * });
	     *
	     * // Invoke the layer's apply() method with a `tf.Tensor` (with concrete
	     * // numeric values).
	     * const input = tf.ones([2, 2]);
	     * const output = denseLayer.apply(input);
	     *
	     * // The output's value is expected to be [[0], [0]], due to the fact that
	     * // the dense layer has a kernel initialized to all-zeros and does not have
	     * // a bias.
	     * output.print();
	     * ```
	     *
	     * When called with `tf.SymbolicTensor`(s), this will prepare the layer for
	     * future execution.  This entails internal book-keeping on shapes of
	     * expected Tensors, wiring layers together, and initializing weights.
	     *
	     * Calling `apply` with `tf.SymbolicTensor`s are typically used during the
	     * building of non-`tf.Sequential` models. For example:
	     *
	     * ```js
	     * const flattenLayer = tf.layers.flatten();
	     * const denseLayer = tf.layers.dense({units: 1});
	     *
	     * // Use tf.layers.input() to obtain a SymbolicTensor as input to apply().
	     * const input = tf.input({shape: [2, 2]});
	     * const output1 = flattenLayer.apply(input);
	     *
	     * // output1.shape is [null, 4]. The first dimension is the undetermined
	     * // batch size. The second dimension comes from flattening the [2, 2]
	     * // shape.
	     * console.log(JSON.stringify(output1.shape));
	     *
	     * // The output SymbolicTensor of the flatten layer can be used to call
	     * // the apply() of the dense layer:
	     * const output2 = denseLayer.apply(output1);
	     *
	     * // output2.shape is [null, 1]. The first dimension is the undetermined
	     * // batch size. The second dimension matches the number of units of the
	     * // dense layer.
	     * console.log(JSON.stringify(output2.shape));
	     *
	     * // The input and output can be used to construct a model that consists
	     * // of the flatten and dense layers.
	     * const model = tf.model({inputs: input, outputs: output2});
	     * ```
	     *
	     * @param inputs a `tf.Tensor` or `tf.SymbolicTensor` or an Array of them.
	     * @param kwargs Additional keyword arguments to be passed to `call()`.
	     *
	     * @return Output of the layer's `call` method.
	     *
	     * @exception ValueError error in case the layer is missing shape information
	     *   for its `build` call.
	     *
	     * @doc {heading: 'Models', 'subheading': 'Classes'}
	     */
	    // Porting Note: This is a replacement for __call__() in Python.
	  }, {
	    key: "apply",
	    value: function apply(inputs, kwargs) {
	      var _this2 = this;
	      kwargs = kwargs || {};
	      this.assertNotDisposed();
	      // Ensure inputs are all the same type.
	      var inputsList = toList(inputs);
	      var allAreSymbolic = checkAllSymbolic(inputs);
	      var noneAreSymbolic = checkNoneSymbolic(inputs);
	      if (allAreSymbolic === noneAreSymbolic) {
	        throw new ValueError('Arguments to apply() must be all ' + 'SymbolicTensors or all Tensors');
	      }
	      // TODO(michaelterry): nameScope() may not be necessary.
	      return nameScope(this.name, function () {
	        // Handle laying building (weight creating, input spec locking).
	        if (!_this2.built) {
	          /*
	            Throw exceptions in case the input is not compatible
	            with the inputSpec specified in the layer constructor.
	           */
	          _this2.assertInputCompatibility(inputs);
	          // Collect input shapes to build layer.
	          var inputShapes = [];
	          var _iterator3 = _createForOfIteratorHelper(toList(inputs)),
	            _step3;
	          try {
	            for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
	              var xElem = _step3.value;
	              inputShapes.push(xElem.shape);
	            }
	          } catch (err) {
	            _iterator3.e(err);
	          } finally {
	            _iterator3.f();
	          }
	          _this2.build(singletonOrArray(inputShapes));
	          _this2.built = true;
	          // Load weights that were specified at layer instantiation.
	          if (_this2.initialWeights) {
	            _this2.setWeights(_this2.initialWeights);
	          }
	          if (_this2._refCount === null && noneAreSymbolic) {
	            // The first use of this layer is a non-symbolic call, set ref count
	            // to 1 so the Layer can be properly disposed if its dispose() method
	            // is called.
	            _this2._refCount = 1;
	          }
	        }
	        /*
	          Throw exceptions in case the input is not compatible
	          with the inputSpec set at build time.
	        */
	        _this2.assertInputCompatibility(inputs);
	        // Handle mask propagation.
	        // TODO(michaelterry): Mask propagation not currently implemented.
	        // Actually call the layer, collecting output(s), mask(s), and shape(s).
	        if (noneAreSymbolic) {
	          var output = _this2.call(inputs, kwargs);
	          // Apply masks to the output tensors if the layer supports it.
	          if (_this2.supportsMasking) {
	            // TODO(mattsoulanille): pass the input tensors' masks to computeMask
	            _this2.setMaskMetadata(inputs, output);
	          }
	          // If the layer returns tensors from its inputs, unmodified,
	          // we copy them to avoid loss of tensor metadata.
	          var outputList = toList(output);
	          var outputListCopy = [];
	          // TODO(michaelterry): This copying may not be necessary given our eager
	          // backend.
	          var _iterator4 = _createForOfIteratorHelper(outputList),
	            _step4;
	          try {
	            for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
	              var x = _step4.value;
	              if (inputsList.indexOf(x) !== -1) {
	                x = x.clone();
	              }
	              outputListCopy.push(x);
	            }
	          } catch (err) {
	            _iterator4.e(err);
	          } finally {
	            _iterator4.f();
	          }
	          output = singletonOrArray(outputListCopy);
	          if (_this2.activityRegularizer != null) {
	            throw new NotImplementedError('Layer invocation in the presence of activity ' + 'regularizer(s) is not supported yet.');
	          }
	          // TODO(michaelterry): Call addInboundNode()?
	          return output;
	        } else {
	          var inputShape = collectInputShape(inputs);
	          var outputShape = _this2.computeOutputShape(inputShape);
	          var _output;
	          var outputDType = guessOutputDType(inputs);
	          _this2.warnOnIncompatibleInputShape(Array.isArray(inputs) ? inputShape[0] : inputShape);
	          if (outputShape != null && outputShape.length > 0 && Array.isArray(outputShape[0])) {
	            // We have multiple output shapes. Create multiple output tensors.
	            _output = outputShape.map(function (shape, index) {
	              return new SymbolicTensor(outputDType, shape, _this2, toList(inputs), kwargs, _this2.name, index);
	            });
	          } else {
	            _output = new SymbolicTensor(outputDType, outputShape, _this2, toList(inputs), kwargs, _this2.name);
	          }
	          /*
	            Add an inbound node to the layer, so that it keeps track
	            of the call and of all new variables created during the call.
	            This also updates the layer history of the output tensor(s).
	            If the input tensor(s) had no previous history,
	            this does nothing.
	          */
	          _this2.addInboundNode(inputs, _output, null, null, inputShape, outputShape, kwargs);
	          _this2._refCount++;
	          if (_this2.activityRegularizer != null) {
	            throw new NotImplementedError('Layer invocation in the presence of activity ' + 'regularizer(s) is not supported yet.');
	          }
	          return _output;
	        }
	      });
	    }
	    /**
	     * Check compatibility between input shape and this layer's batchInputShape.
	     *
	     * Print warning if any incompatibility is found.
	     *
	     * @param inputShape Input shape to be checked.
	     */
	  }, {
	    key: "warnOnIncompatibleInputShape",
	    value: function warnOnIncompatibleInputShape(inputShape) {
	      if (this.batchInputShape == null) {
	        return;
	      } else if (inputShape.length !== this.batchInputShape.length) {
	        console.warn("The rank of the input tensor provided (shape: " + "".concat(JSON.stringify(inputShape), ") does not match that of the ") + "batchInputShape (".concat(JSON.stringify(this.batchInputShape), ") ") + "of the layer ".concat(this.name));
	      } else {
	        var dimMismatch = false;
	        this.batchInputShape.forEach(function (dimension, i) {
	          if (dimension != null && inputShape[i] != null && inputShape[i] !== dimension) {
	            dimMismatch = true;
	          }
	        });
	        if (dimMismatch) {
	          console.warn("The shape of the input tensor " + "(".concat(JSON.stringify(inputShape), ") does not ") + "match the expectation of layer ".concat(this.name, ": ") + "".concat(JSON.stringify(this.batchInputShape)));
	        }
	      }
	    }
	    /**
	     * Retrieves the output shape(s) of a layer.
	     *
	     * Only applicable if the layer has only one inbound node, or if all inbound
	     * nodes have the same output shape.
	     *
	     * @returns Output shape or shapes.
	     * @throws AttributeError: if the layer is connected to more than one incoming
	     *   nodes.
	     *
	     * @doc {heading: 'Models', 'subheading': 'Classes'}
	     */
	  }, {
	    key: "outputShape",
	    get: function get() {
	      if (this.inboundNodes == null || this.inboundNodes.length === 0) {
	        throw new AttributeError("The layer ".concat(this.name, " has never been called and thus has no ") + "defined output shape.");
	      }
	      var allOutputShapes = [];
	      var _iterator5 = _createForOfIteratorHelper(this.inboundNodes),
	        _step5;
	      try {
	        for (_iterator5.s(); !(_step5 = _iterator5.n()).done;) {
	          var node = _step5.value;
	          var shapeString = JSON.stringify(node.outputShapes);
	          if (allOutputShapes.indexOf(shapeString) === -1) {
	            allOutputShapes.push(shapeString);
	          }
	        }
	      } catch (err) {
	        _iterator5.e(err);
	      } finally {
	        _iterator5.f();
	      }
	      if (allOutputShapes.length === 1) {
	        var outputShapes = this.inboundNodes[0].outputShapes;
	        if (Array.isArray(outputShapes) && Array.isArray(outputShapes[0]) && outputShapes.length === 1) {
	          return outputShapes[0];
	        } else {
	          return outputShapes;
	        }
	      } else {
	        throw new AttributeError("The layer ".concat(this.name, " has multiple inbound nodes with different ") + "output shapes. Hence the notion of \"output shape\" is ill-defined " + "for the layer.");
	        // TODO(cais): Implement getOutputShapeAt().
	      }
	    }
	    /**
	     * Counts the total number of numbers (e.g., float32, int32) in the
	     * weights.
	     *
	     * @returns An integer count.
	     * @throws RuntimeError: If the layer is not built yet (in which case its
	     *   weights are not defined yet.)
	     *
	     * @doc {heading: 'Models', 'subheading': 'Classes'}
	     */
	  }, {
	    key: "countParams",
	    value: function countParams() {
	      if (!this.built) {
	        throw new RuntimeError("You tried to call countParams() on ".concat(this.name, ", ") + "but the layer is not built yet. Build it first by calling " + "build(batchInputShape).");
	      }
	      return countParamsInWeights(this.weights);
	    }
	    /**
	     * Creates the layer weights.
	     *
	     * Must be implemented on all layers that have weights.
	     *
	     * Called when apply() is called to construct the weights.
	     *
	     * @param inputShape A `Shape` or array of `Shape` (unused).
	     *
	     * @doc {heading: 'Models', 'subheading': 'Classes'}
	     */
	  }, {
	    key: "build",
	    value: function build(inputShape) {
	      this.built = true;
	    }
	    /**
	     * Returns the current values of the weights of the layer.
	     *
	     * @param trainableOnly Whether to get the values of only trainable weights.
	     * @returns Weight values as an `Array` of `tf.Tensor`s.
	     *
	     * @doc {heading: 'Models', 'subheading': 'Classes'}
	     */
	  }, {
	    key: "getWeights",
	    value: function getWeights() {
	      var trainableOnly = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
	      return batchGetValue(trainableOnly ? this.trainableWeights : this.weights);
	    }
	    /**
	     * Sets the weights of the layer, from Tensors.
	     *
	     * @param weights a list of Tensors. The number of arrays and their shape
	     *   must match number of the dimensions of the weights of the layer (i.e.
	     *   it should match the output of `getWeights`).
	     *
	     * @exception ValueError If the provided weights list does not match the
	     *   layer's specifications.
	     *
	     * @doc {heading: 'Models', 'subheading': 'Classes'}
	     */
	  }, {
	    key: "setWeights",
	    value: function setWeights(weights) {
	      var _this3 = this;
	      tidy(function () {
	        var params = _this3.weights;
	        if (params.length !== weights.length) {
	          // TODO(cais): Restore the following and use `providedWeights`, instead
	          // of `weights` in the error message, once the deeplearn.js bug is
	          // fixed: https://github.com/PAIR-code/deeplearnjs/issues/498 const
	          // providedWeights = JSON.stringify(weights).slice(0, 50);
	          throw new ValueError("You called setWeights(weights) on layer \"".concat(_this3.name, "\" ") + "with a weight list of length ".concat(weights.length, ", ") + "but the layer was expecting ".concat(params.length, " weights. ") + "Provided weights: ".concat(weights, "..."));
	        }
	        if (params.length === 0) {
	          return;
	        }
	        var weightValueTuples = [];
	        var paramValues = batchGetValue(params);
	        for (var i = 0; i < paramValues.length; ++i) {
	          var pv = paramValues[i];
	          var p = params[i];
	          var w = weights[i];
	          if (!arraysEqual(pv.shape, w.shape)) {
	            throw new ValueError("Layer weight shape ".concat(pv.shape, " ") + "not compatible with provided weight shape ".concat(w.shape));
	          }
	          weightValueTuples.push([p, w]);
	        }
	        batchSetValue(weightValueTuples);
	      });
	    }
	    /**
	     * Adds a weight variable to the layer.
	     *
	     * @param name Name of the new weight variable.
	     * @param shape The shape of the weight.
	     * @param dtype The dtype of the weight.
	     * @param initializer An initializer instance.
	     * @param regularizer A regularizer instance.
	     * @param trainable Whether the weight should be trained via backprop or not
	     *   (assuming that the layer itself is also trainable).
	     * @param constraint An optional trainable.
	     * @return The created weight variable.
	     *
	     * @doc {heading: 'Models', 'subheading': 'Classes'}
	     */
	  }, {
	    key: "addWeight",
	    value: function addWeight(name, shape, dtype, initializer, regularizer, trainable, constraint, getInitializerFunc) {
	      // Reject duplicate weight names.
	      if (this._addedWeightNames.indexOf(name) !== -1) {
	        throw new ValueError("Duplicate weight name ".concat(name, " for layer ").concat(this.name));
	      }
	      this._addedWeightNames.push(name);
	      if (dtype == null) {
	        dtype = 'float32';
	      }
	      if (this.fastWeightInitDuringBuild) {
	        initializer = getInitializerFunc != null ? getInitializerFunc() : getInitializer('zeros');
	      }
	      var initValue = initializer.apply(shape, dtype);
	      var weight = new LayerVariable(initValue, dtype, name, trainable, constraint);
	      initValue.dispose();
	      // Request backend not to dispose the weights of the model on scope() exit.
	      if (regularizer != null) {
	        this.addLoss(function () {
	          return regularizer.apply(weight.read());
	        });
	      }
	      if (trainable == null) {
	        trainable = true;
	      }
	      if (trainable) {
	        this._trainableWeights.push(weight);
	      } else {
	        this._nonTrainableWeights.push(weight);
	      }
	      return weight;
	    }
	    /**
	     * Set the fast-weight-initialization flag.
	     *
	     * In cases where the initialized weight values will be immediately
	     * overwritten by loaded weight values during model loading, setting
	     * the flag to `true` saves unnecessary calls to potentially expensive
	     * initializers and speeds up the loading process.
	     *
	     * @param value Target value of the flag.
	     */
	  }, {
	    key: "setFastWeightInitDuringBuild",
	    value: function setFastWeightInitDuringBuild(value) {
	      this.fastWeightInitDuringBuild = value;
	    }
	    /**
	     * Add losses to the layer.
	     *
	     * The loss may potentially be conditional on some inputs tensors,
	     * for instance activity losses are conditional on the layer's inputs.
	     *
	     * @doc {heading: 'Models', 'subheading': 'Classes'}
	     */
	  }, {
	    key: "addLoss",
	    value: function addLoss(losses) {
	      if (losses == null || Array.isArray(losses) && losses.length === 0) {
	        return;
	      }
	      // Update this.losses
	      losses = toList(losses);
	      if (this._losses !== undefined && this._losses !== null) {
	        var _this$losses;
	        (_this$losses = this.losses).push.apply(_this$losses, _toConsumableArray(losses));
	      }
	    }
	    /**
	     * Computes the output shape of the layer.
	     *
	     * Assumes that the layer will be built to match that input shape provided.
	     *
	     * @param inputShape A shape (tuple of integers) or a list of shape tuples
	     *   (one per output tensor of the layer). Shape tuples can include null for
	     *   free dimensions, instead of an integer.
	     *
	     * @doc {heading: 'Models', 'subheading': 'Classes'}
	     */
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      return inputShape;
	    }
	    /**
	     * Computes an output mask tensor.
	     *
	     * @param inputs Tensor or list of tensors.
	     * @param mask Tensor or list of tensors.
	     *
	     * @return null or a tensor (or list of tensors, one per output tensor of the
	     * layer).
	     */
	  }, {
	    key: "computeMask",
	    value: function computeMask(inputs, mask) {
	      var _this4 = this;
	      if (!this.supportsMasking) {
	        if (mask != null) {
	          if (Array.isArray(mask)) {
	            mask.forEach(function (maskElement) {
	              if (maskElement != null) {
	                throw new TypeError("Layer ".concat(_this4.name, " does not support masking, ") + 'but was passed an inputMask.');
	              }
	            });
	          } else {
	            throw new TypeError("Layer ".concat(this.name, " does not support masking, ") + 'but was passed an inputMask.');
	          }
	        }
	        // masking not explicitly supported: return null as mask
	        return null;
	      }
	      // if masking is explictly supported, by default
	      // carry over the input mask
	      return mask;
	    }
	  }, {
	    key: "setMaskMetadata",
	    value: function setMaskMetadata(inputs, outputs, previousMask) {
	      if (!this.supportsMasking) {
	        return;
	      }
	      var outputMasks = this.computeMask(inputs, previousMask);
	      var outputsList = toList(outputs);
	      var outputMasksList = toList(outputMasks);
	      if (outputsList.length !== outputMasksList.length) {
	        throw new Error("".concat(this.name, " outputs ").concat(outputsList.length, " tensors ") + "but ".concat(outputsList.length, " masks for those tensors"));
	      }
	      for (var i = 0; i < outputsList.length; i++) {
	        outputsList[i].kerasMask = outputMasksList[i];
	      }
	    }
	    /**
	     * Internal method to create an inbound node for the layer.
	     *
	     * @param inputTensors List of input tensors.
	     * @param outputTensors List of output tensors.
	     * @param inputMasks List of input masks (a mask can be a tensor, or null).
	     * @param outputMasks List of output masks (a mask can be a tensor, or null).
	     * @param inputShapes List of input shape tuples.
	     * @param outputShapes List of output shape tuples.
	     * @param kwargs Dictionary of keyword arguments that were passed to the
	     *   `call` method of the layer at the call that created the node.
	     */
	  }, {
	    key: "addInboundNode",
	    value: function addInboundNode(inputTensors, outputTensors, inputMasks, outputMasks, inputShapes, outputShapes) {
	      var kwargs = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : null;
	      var inputTensorList = toList(inputTensors);
	      outputTensors = toList(outputTensors);
	      inputMasks = toList(inputMasks);
	      outputMasks = toList(outputMasks);
	      inputShapes = normalizeShapeList(inputShapes);
	      outputShapes = normalizeShapeList(outputShapes);
	      // Collect input tensor(s) coordinates.
	      var inboundLayers = [];
	      var nodeIndices = [];
	      var tensorIndices = [];
	      var _iterator6 = _createForOfIteratorHelper(inputTensorList),
	        _step6;
	      try {
	        for (_iterator6.s(); !(_step6 = _iterator6.n()).done;) {
	          var x = _step6.value;
	          /*
	           * TODO(michaelterry): Keras adds this value to tensors; it's not
	           * clear whether we'll use this or not.
	           */
	          inboundLayers.push(x.sourceLayer);
	          nodeIndices.push(x.nodeIndex);
	          tensorIndices.push(x.tensorIndex);
	        }
	        // Create node, add it to inbound nodes.
	        // (This call has side effects.)
	        // tslint:disable-next-line:no-unused-expression
	      } catch (err) {
	        _iterator6.e(err);
	      } finally {
	        _iterator6.f();
	      }
	      new Node({
	        outboundLayer: this,
	        inboundLayers: inboundLayers,
	        nodeIndices: nodeIndices,
	        tensorIndices: tensorIndices,
	        inputTensors: inputTensorList,
	        outputTensors: outputTensors,
	        inputMasks: inputMasks,
	        outputMasks: outputMasks,
	        inputShapes: inputShapes,
	        outputShapes: outputShapes
	      }, kwargs);
	      // Update tensor history
	      for (var i = 0; i < outputTensors.length; i++) {
	        // TODO(michaelterry: _uses_learning_phase not tracked.
	        outputTensors[i].sourceLayer = this;
	        outputTensors[i].nodeIndex = this.inboundNodes.length - 1;
	        outputTensors[i].tensorIndex = i;
	      }
	    }
	    /**
	     * Returns the config of the layer.
	     *
	     * A layer config is a TS dictionary (serializable)
	     * containing the configuration of a layer.
	     * The same layer can be reinstantiated later
	     * (without its trained weights) from this configuration.
	     *
	     * The config of a layer does not include connectivity
	     * information, nor the layer class name.  These are handled
	     * by 'Container' (one layer of abstraction above).
	     *
	     * Porting Note: The TS dictionary follows TS naming standards for
	     * keys, and uses tfjs-layers type-safe Enums.  Serialization methods
	     * should use a helper function to convert to the pythonic storage
	     * standard. (see serialization_utils.convertTsToPythonic)
	     *
	     * @returns TS dictionary of configuration.
	     *
	     * @doc {heading: 'Models', 'subheading': 'Classes'}
	     */
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        name: this.name,
	        trainable: this.trainable
	      };
	      if (this.batchInputShape != null) {
	        config['batchInputShape'] = this.batchInputShape;
	      }
	      if (this.dtype != null) {
	        config['dtype'] = this.dtype;
	      }
	      return config;
	    }
	    /**
	     * Dispose the weight variables that this Layer instance holds.
	     *
	     * @returns {number} Number of disposed variables.
	     */
	  }, {
	    key: "disposeWeights",
	    value: function disposeWeights() {
	      this.weights.forEach(function (weight) {
	        return weight.dispose();
	      });
	      return this.weights.length;
	    }
	  }, {
	    key: "assertNotDisposed",
	    value: function assertNotDisposed() {
	      if (this._refCount === 0) {
	        throw new Error("Layer '".concat(this.name, "' is already disposed."));
	      }
	    }
	    /**
	     * Attempt to dispose layer's weights.
	     *
	     * This method decreases the reference count of the Layer object by 1.
	     *
	     * A Layer is reference-counted. Its reference count is incremented by 1
	     * the first item its `apply()` method is called and when it becomes a part
	     * of a new `Node` (through calling the `apply()` method on a
	     * `tf.SymbolicTensor`).
	     *
	     * If the reference count of a Layer becomes 0, all the weights will be
	     * disposed and the underlying memory (e.g., the textures allocated in WebGL)
	     * will be freed.
	     *
	     * Note: If the reference count is greater than 0 after the decrement, the
	     * weights of the Layer will *not* be disposed.
	     *
	     * After a Layer is disposed, it cannot be used in calls such as `apply()`,
	     * `getWeights()` or `setWeights()` anymore.
	     *
	     * @returns A DisposeResult Object with the following fields:
	     *   - refCountAfterDispose: The reference count of the Container after this
	     *     `dispose()` call.
	     *   - numDisposedVariables: Number of `tf.Variable`s (i.e., weights) disposed
	     *     during this `dispose()` call.
	     * @throws {Error} If the layer is not built yet, or if the layer has already
	     *   been disposed.
	     *
	     * @doc {heading: 'Models', 'subheading': 'Classes'}
	     */
	  }, {
	    key: "dispose",
	    value: function dispose() {
	      if (!this.built) {
	        throw new Error("Cannot dispose Layer ".concat(this.name, " because it has not been ") + "built yet.");
	      }
	      if (this._refCount === null) {
	        throw new Error("Cannot dispose Layer ".concat(this.name, " because it has not been used ") + "yet.");
	      }
	      this.assertNotDisposed();
	      var numDisposedVariables = 0;
	      if (--this._refCount === 0) {
	        numDisposedVariables = this.disposeWeights();
	      }
	      return {
	        refCountAfterDispose: this._refCount,
	        numDisposedVariables: numDisposedVariables
	      };
	    }
	  }], [{
	    key: "nodeKey",
	    value: function nodeKey(layer, nodeIndex) {
	      return layer.name + '_ib-' + nodeIndex.toString();
	    }
	  }]);
	  return Layer;
	}(Serializable);
	/**
	 * Collects the input shape(s) of a list of `tf.Tensor`s or
	 * `tf.SymbolicTensor`s.
	 *
	 * TODO(michaelterry): Update PyKeras docs (backport).
	 *
	 * @param inputTensors List of input tensors (or single input tensor).
	 *
	 * @return List of shape tuples (or single tuple), one tuple per input.
	 */
	function collectInputShape(inputTensors) {
	  inputTensors = toList(inputTensors);
	  var shapes = [];
	  var _iterator7 = _createForOfIteratorHelper(inputTensors),
	    _step7;
	  try {
	    for (_iterator7.s(); !(_step7 = _iterator7.n()).done;) {
	      var x = _step7.value;
	      shapes.push(x.shape);
	    }
	  } catch (err) {
	    _iterator7.e(err);
	  } finally {
	    _iterator7.f();
	  }
	  return singletonOrArray(shapes);
	}
	/**
	 * Guesses output dtype based on inputs.
	 *
	 * At present, just returns 'float32' for any input.
	 *
	 * @param inputTensors List of input tensors (or single input tensor).
	 *
	 * @return The guessed DType. At present, always returns 'float32'.
	 */
	function guessOutputDType(inputTensors) {
	  return 'float32';
	}
	/**
	 * Returns the list of input tensors necessary to compute `tensor`.
	 *
	 * Output will always be a list of tensors (potentially with 1 element).
	 *
	 * @param tensor The tensor to start from.
	 * @param layer Origin layer of the tensor.
	 * @param nodeIndex Origin node index of the tensor.
	 *
	 * @return Array of input tensors.
	 */
	function getSourceInputs(tensor, layer, nodeIndex) {
	  if (layer == null || nodeIndex != null && nodeIndex > 0) {
	    layer = tensor.sourceLayer;
	    nodeIndex = tensor.nodeIndex;
	  }
	  if (layer.inboundNodes.length === 0) {
	    return [tensor];
	  } else {
	    var node = layer.inboundNodes[nodeIndex];
	    if (node.inboundLayers.length === 0) {
	      return node.inputTensors;
	    } else {
	      var sourceTensors = [];
	      for (var i = 0; i < node.inboundLayers.length; i++) {
	        var x = node.inputTensors[i];
	        var _layer = node.inboundLayers[i];
	        var _nodeIndex = node.nodeIndices[i];
	        var previousSources = getSourceInputs(x, _layer, _nodeIndex);
	        // Avoid input redundancy.
	        var _iterator8 = _createForOfIteratorHelper(previousSources),
	          _step8;
	        try {
	          for (_iterator8.s(); !(_step8 = _iterator8.n()).done;) {
	            var _x = _step8.value;
	            if (sourceTensors.indexOf(_x) === -1) {
	              sourceTensors.push(_x);
	            }
	          }
	        } catch (err) {
	          _iterator8.e(err);
	        } finally {
	          _iterator8.f();
	        }
	      }
	      return sourceTensors;
	    }
	  }
	}
	function checkAllSymbolic(tensors) {
	  var allAreSymbolic = true;
	  var _iterator9 = _createForOfIteratorHelper(toList(tensors)),
	    _step9;
	  try {
	    for (_iterator9.s(); !(_step9 = _iterator9.n()).done;) {
	      var tensor = _step9.value;
	      if (!(tensor instanceof SymbolicTensor)) {
	        allAreSymbolic = false;
	        break;
	      }
	    }
	  } catch (err) {
	    _iterator9.e(err);
	  } finally {
	    _iterator9.f();
	  }
	  return allAreSymbolic;
	}
	function checkNoneSymbolic(tensors) {
	  var noneAreSymbolic = true;
	  var _iterator10 = _createForOfIteratorHelper(toList(tensors)),
	    _step10;
	  try {
	    for (_iterator10.s(); !(_step10 = _iterator10.n()).done;) {
	      var tensor = _step10.value;
	      if (tensor instanceof SymbolicTensor) {
	        noneAreSymbolic = false;
	        break;
	      }
	    }
	  } catch (err) {
	    _iterator10.e(err);
	  } finally {
	    _iterator10.f();
	  }
	  return noneAreSymbolic;
	}

	var InputLayer = /*#__PURE__*/function (_Layer) {
	  _inherits(InputLayer, _Layer);
	  var _super = _createSuper(InputLayer);
	  function InputLayer(args) {
	    var _this;
	    _classCallCheck(this, InputLayer);
	    _this = _super.call(this, {
	      dtype: args.dtype,
	      name: args.name != null ? args.name : getUid('input').toString()
	    });
	    // Normalize config.batchSize and config.sparse
	    if (args.batchSize == null) {
	      args.batchSize = null;
	    }
	    if (args.sparse == null) {
	      args.sparse = false;
	    }
	    _this.trainable = false;
	    _this.built = true;
	    _this.sparse = args.sparse;
	    if (args.inputShape != null && args.batchInputShape != null) {
	      throw new ValueError('Only provide the inputShape OR ' + 'batchInputShape argument to inputLayer, not both at the same time.');
	    }
	    var batchInputShape = args.batchInputShape;
	    if (batchInputShape == null) {
	      if (args.inputShape == null) {
	        throw new ValueError('An InputLayer should be passed either a ' + '`batchInputShape` or an `inputShape`.');
	      } else {
	        batchInputShape = [args.batchSize].concat(args.inputShape);
	      }
	    } else {
	      // TODO(michaelterry): Backport to PyKeras
	      if (args.batchSize != null) {
	        throw new ValueError('Cannot specify batchSize if batchInputShape is ' + 'specified when creating an InputLayer.');
	      }
	    }
	    var dtype = args.dtype || 'float32';
	    _this.batchInputShape = batchInputShape;
	    _this.dtype = dtype;
	    // TODO(michaelterry): Backport this to PyKeras?
	    _this.inputSpec = [{
	      shape: batchInputShape
	    }];
	    var inputTensor = new SymbolicTensor(_this.dtype, _this.batchInputShape, _assertThisInitialized(_this), [], {}, _this.name);
	    inputTensor.nodeIndex = 0;
	    inputTensor.tensorIndex = 0;
	    // Create an input node to add to this.outboundNode.
	    // (This call has side effects.)
	    // tslint:disable-next-line:no-unused-expression
	    new Node({
	      outboundLayer: _assertThisInitialized(_this),
	      inboundLayers: [],
	      nodeIndices: [],
	      tensorIndices: [],
	      inputTensors: [inputTensor],
	      outputTensors: [inputTensor],
	      inputMasks: [null],
	      outputMasks: [null],
	      inputShapes: [batchInputShape],
	      outputShapes: [batchInputShape]
	    });
	    return _this;
	  }
	  _createClass(InputLayer, [{
	    key: "apply",
	    value: function apply(inputs, kwargs) {
	      throw new ValueError('Cannot pass any input to an ' + "InputLayer's apply() method. InputLayer name: ".concat(this.name));
	    }
	  }, {
	    key: "dispose",
	    value: function dispose() {
	      // dispose() for InputLayer is overridden as no-op.
	      return {
	        refCountAfterDispose: this._refCount,
	        numDisposedVariables: 0
	      };
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        batchInputShape: this.batchInputShape,
	        dtype: this.dtype,
	        sparse: this.sparse,
	        name: this.name
	      };
	    }
	  }]);
	  return InputLayer;
	}(Layer);
	/** @nocollapse */
	InputLayer.className = 'InputLayer';
	registerClass(InputLayer);
	function Input(config) {
	  if (config.batchShape == null && config.shape == null) {
	    throw new Error('Please provide to Input either a `shape`' + ' or a `batchShape` argument. Note that ' + '`shape` does not include the batch ' + 'dimension.');
	  }
	  if (config.batchShape != null && config.shape != null) {
	    // TODO(michaelterry): Backport to PyKeras.
	    throw new ValueError('Please provide either a `shape` or `batchShape` ' + 'argument to Input, but not both.');
	  }
	  var batchShape = config.batchShape;
	  if (config.shape != null && batchShape == null) {
	    batchShape = [null].concat(config.shape);
	  }
	  var dtype = config.dtype;
	  if (dtype == null) {
	    dtype = 'float32';
	  }
	  var inputLayer = new InputLayer({
	    batchInputShape: batchShape,
	    name: config.name,
	    dtype: dtype,
	    sparse: config.sparse
	  });
	  var outputs = inputLayer.inboundNodes[0].outputTensors;
	  return outputs[0];
	}

	/**
	 * Helper function to check the dtype and shape compatibility of a feed value.
	 */
	function assertFeedCompatibility(key, val) {
	  // Check dtype compatibility.
	  if (key.dtype == null || key.dtype === val.dtype) {
	    //  a.  If types match, return val tensor as is.
	    return val;
	  }
	  try {
	    //  b. Attempt to convert to expected type.
	    return cast$3(val, key.dtype);
	  } catch (err) {
	    //  c. If conversion fails, return helpful error.
	    throw new ValueError("The dtype of the feed (".concat(val.dtype, ") can not be cast to the dtype ") + "of the key '".concat(key.name, "' (").concat(key.dtype, ")."));
	  }
	}
	/**
	 * FeedDict: A mapping from unique SymbolicTensors to feed values for them.
	 * A feed value is a concrete value represented as an `Tensor`.
	 */
	var FeedDict = /*#__PURE__*/function () {
	  /**
	   * Constructor, optionally does copy-construction.
	   * @param feeds An Array of `Feed`s, or another `FeedDict`, in which case
	   *   copy-construction will be performed.
	   */
	  function FeedDict(feeds) {
	    _classCallCheck(this, FeedDict);
	    this.id2Value = {};
	    this.id2Mask = {};
	    this.name2Id = {};
	    if (feeds instanceof FeedDict) {
	      for (var id in feeds.id2Value) {
	        this.id2Value[id] = feeds.id2Value[id];
	        if (id in feeds.id2Mask) {
	          this.id2Mask[id] = feeds.id2Mask[id];
	        }
	      }
	    } else {
	      if (feeds == null) {
	        return;
	      }
	      var _iterator = _createForOfIteratorHelper(feeds),
	        _step;
	      try {
	        for (_iterator.s(); !(_step = _iterator.n()).done;) {
	          var feed = _step.value;
	          this.add(feed.key, feed.value);
	        }
	      } catch (err) {
	        _iterator.e(err);
	      } finally {
	        _iterator.f();
	      }
	    }
	  }
	  /**
	   * Add a key-value pair to the FeedDict.
	   *
	   * @param key The key of the feed.
	   * @param value The value of the tensor feed.
	   * @param mask The value of the mask feed (optional).
	   * @returns This `FeedDict`.
	   * @throws ValueError: If the key `SymbolicTensor` already exists in the
	   *   `FeedDict`.
	   */
	  _createClass(FeedDict, [{
	    key: "add",
	    value: function add(key, value, mask) {
	      if (this.id2Value[key.id] == null) {
	        this.id2Value[key.id] = assertFeedCompatibility(key, value);
	        this.name2Id[key.name] = key.id;
	        if (mask != null) {
	          this.id2Mask[key.id] = mask;
	        }
	      } else {
	        throw new ValueError("Duplicate key: name=".concat(key.name, ", id=").concat(key.id));
	      }
	      return this;
	    }
	    /**
	     * Add a Feed to the FeedDict.
	     * @param feed The new `Feed` to add.
	     * @returns This `FeedDict`.
	     */
	  }, {
	    key: "addFeed",
	    value: function addFeed(feed) {
	      this.add(feed.key, feed.value);
	    }
	    /**
	     * Probe whether a key already exists in the FeedDict.
	     * @param key
	     */
	  }, {
	    key: "hasKey",
	    value: function hasKey(key) {
	      return this.id2Value[key.id] != null;
	    }
	    /**
	     * Get all the SymbolicTensor available in this FeedDict.
	     */
	  }, {
	    key: "names",
	    value: function names() {
	      return Object.keys(this.name2Id);
	    }
	    /**
	     * Get the feed value for given key.
	     * @param key The SymbolicTensor, or its name (as a string), of which the
	     *     value is sought.
	     * @returns If `key` exists, the corresponding feed value.
	     * @throws ValueError: If `key` does not exist in this `FeedDict`.
	     */
	  }, {
	    key: "getValue",
	    value: function getValue(key) {
	      if (key instanceof SymbolicTensor) {
	        if (this.id2Value[key.id] == null) {
	          throw new ValueError("Nonexistent key: ".concat(key.name));
	        } else {
	          return this.id2Value[key.id];
	        }
	      } else {
	        var id = this.name2Id[key];
	        if (id == null) {
	          throw new ValueError("Feed dict has no SymbolicTensor name: ".concat(key));
	        }
	        return this.id2Value[id];
	      }
	    }
	    /**
	     * Get the feed mask for given key.
	     * @param key The SymbolicTensor, or its name (as a string), of which the
	     *     value is sought.
	     * @returns If `key` exists, the corresponding feed mask.
	     * @throws ValueError: If `key` does not exist in this `FeedDict`.
	     */
	  }, {
	    key: "getMask",
	    value: function getMask(key) {
	      if (key instanceof SymbolicTensor) {
	        if (this.id2Value[key.id] == null) {
	          throw new ValueError("Nonexistent key: ".concat(key.name));
	        } else {
	          return this.id2Mask[key.id];
	        }
	      } else {
	        var id = this.name2Id[key];
	        if (id == null) {
	          throw new ValueError("Feed dict has no SymbolicTensor name: ".concat(key));
	        }
	        return this.id2Mask[id];
	      }
	    }
	    /** Dispose all mask Tensors held by this object. */
	  }, {
	    key: "disposeMasks",
	    value: function disposeMasks() {
	      if (this.id2Mask != null) {
	        dispose(this.id2Mask);
	      }
	    }
	  }]);
	  return FeedDict;
	}();
	// Cache for topologically sorted SymbolicTensors for given execution
	// targets (i.e., fetches).
	var cachedSorted = new LruCache();
	// Cache for recipient count maps for given execution targets (i.e., fetches).
	var cachedRecipientCounts = new LruCache();
	function updateCacheMaxEntries(maxEntries) {
	  if (cachedSorted != null) {
	    cachedSorted.setMaxEntries(maxEntries);
	  }
	  if (cachedRecipientCounts != null) {
	    cachedRecipientCounts.setMaxEntries(maxEntries);
	  }
	}
	/**
	 * Execute a SymbolicTensor by using concrete feed values.
	 *
	 * A `SymbolicTensor` object is a node in a computation graph of TF.js
	 * Layers. The object is backed by a source layer and input
	 * `SymbolicTensor`s to the source layer. This method evaluates
	 * the `call()` method of the source layer, using concrete values of the
	 * inputs obtained from either
	 * * `feedDict`, if the input key exists in `feedDict`, or else,
	 * * a recursive call to `execute()` itself.
	 *
	 * @param x: The `SymbolicTensor` to execute.
	 * @param feedDict: The feed values, as base condition of the recursion.
	 *   execution.
	 * @param kwargs: Optional keyword arguments.
	 * @param probe: A probe object (of interface `ExecutionProbe`) used for
	 *   testing memory footprint of `execute` calls.
	 * @returns Result of the execution.
	 * @throws ValueError: If any `SymbolicTensor`s from `InputLayer`s
	 *   encountered during the execution lacks a feed value in `feedDict`.
	 */
	function execute(fetches, feedDict, kwargs, probe) {
	  var training = kwargs == null ? false : kwargs['training'];
	  var arrayFetches = Array.isArray(fetches);
	  var fetchArray = arrayFetches ? fetches : [fetches];
	  var outputNames = fetchArray.map(function (t) {
	    return t.name;
	  });
	  var finalOutputs = [];
	  var feedNames = feedDict.names();
	  var _iterator2 = _createForOfIteratorHelper(outputNames),
	    _step2;
	  try {
	    for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	      var outputName = _step2.value;
	      if (feedNames.indexOf(outputName) !== -1) {
	        finalOutputs.push(feedDict.getValue(outputName));
	      } else {
	        finalOutputs.push(null);
	      }
	    }
	  } catch (err) {
	    _iterator2.e(err);
	  } finally {
	    _iterator2.f();
	  }
	  if (probe != null) {
	    // For optional probing of memory footprint during execution.
	    probe.maxNumTensors = -Infinity;
	    probe.minNumTensors = Infinity;
	  }
	  // Check cache.
	  var fetchAndFeedKey = outputNames.join(',') + '|' + feedDict.names().sort().join(',');
	  var sorted = cachedSorted.get(fetchAndFeedKey);
	  var recipientCounts;
	  if (sorted == null) {
	    // Cache doesn't contain the desired combination of fetches. Compute
	    // topological sort for the combination for the first time.
	    var out = getTopologicalSortAndRecipientCounts(fetchArray, feedDict);
	    sorted = out.sorted;
	    recipientCounts = out.recipientCounts;
	    // Store results in cache for future use.
	    cachedSorted.put(fetchAndFeedKey, sorted);
	    cachedRecipientCounts.put(fetchAndFeedKey, recipientCounts);
	  }
	  recipientCounts = {};
	  if (!training) {
	    Object.assign(recipientCounts, cachedRecipientCounts.get(fetchAndFeedKey));
	  }
	  var internalFeedDict = new FeedDict(feedDict);
	  // Start iterative execution on the topologically-sorted SymbolicTensors.
	  for (var i = 0; i < sorted.length; ++i) {
	    if (probe != null) {
	      // For optional probing of memory usage during execution.
	      var numTensors = memory().numTensors;
	      if (numTensors > probe.maxNumTensors) {
	        probe.maxNumTensors = numTensors;
	      }
	      if (numTensors < probe.minNumTensors) {
	        probe.minNumTensors = numTensors;
	      }
	    }
	    var symbolic = sorted[i];
	    var srcLayer = symbolic.sourceLayer;
	    if (srcLayer instanceof InputLayer) {
	      continue;
	    }
	    var inputValues = [];
	    var inputMasks = [];
	    var tensorsToDispose = [];
	    var maskExists = false;
	    var _iterator3 = _createForOfIteratorHelper(symbolic.inputs),
	      _step3;
	    try {
	      for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
	        var input = _step3.value;
	        var value = internalFeedDict.getValue(input);
	        var mask = internalFeedDict.getMask(input);
	        inputValues.push(value);
	        inputMasks.push(mask);
	        if (mask != null) {
	          maskExists = true;
	        }
	        if (!training) {
	          recipientCounts[input.name]--;
	          if (recipientCounts[input.name] === 0 && !feedDict.hasKey(input) && outputNames.indexOf(input.name) === -1 && !value.isDisposed && input.sourceLayer.stateful !== true) {
	            tensorsToDispose.push(value);
	          }
	        }
	      }
	    } catch (err) {
	      _iterator3.e(err);
	    } finally {
	      _iterator3.f();
	    }
	    if (maskExists) {
	      kwargs = kwargs || {};
	      kwargs['mask'] = inputMasks[0];
	    }
	    var outputTensors = toList(srcLayer.apply(inputValues, kwargs));
	    var outputMask = null;
	    if (srcLayer.supportsMasking) {
	      outputMask = srcLayer.computeMask(inputValues, inputMasks);
	    }
	    var layerOutputs = getNodeOutputs(symbolic);
	    var outputSymbolicTensors = Array.isArray(layerOutputs) ? layerOutputs : [layerOutputs];
	    for (var _i = 0; _i < outputSymbolicTensors.length; ++_i) {
	      if (!internalFeedDict.hasKey(outputSymbolicTensors[_i])) {
	        internalFeedDict.add(outputSymbolicTensors[_i], outputTensors[_i], Array.isArray(outputMask) ? outputMask[0] : outputMask);
	      }
	      var index = outputNames.indexOf(outputSymbolicTensors[_i].name);
	      if (index !== -1) {
	        finalOutputs[index] = outputTensors[_i];
	      }
	    }
	    if (!training) {
	      // Clean up Tensors that are no longer needed.
	      dispose(tensorsToDispose);
	    }
	  }
	  // NOTE(cais): Unlike intermediate tensors, we don't discard mask
	  // tensors as we go, because these tensors are sometimes passed over a
	  // series of mutliple layers, i.e., not obeying the immediate input
	  // relations in the graph. If this becomes a memory-usage concern,
	  // we can improve this in the future.
	  internalFeedDict.disposeMasks();
	  return arrayFetches ? finalOutputs : finalOutputs[0];
	}
	/**
	 * Sort the `SymbolicTensor`s topologically, for an array of fetches.
	 *
	 * This function calls getTopologicalSortAndRecipientCountsForOneFetch and
	 * merges their results.
	 *
	 * @param fetch The array of fetches requested. Must be a non-empty array.
	 * @param feedDict The dictionary of fed values.
	 * @returns sorted: Topologically-sorted array of SymbolicTensors.
	 *   recipientCounts: Recipient counts for all SymbolicTensors in `sorted`.
	 */
	function getTopologicalSortAndRecipientCounts(fetches, feedDict) {
	  assert$1(fetches != null && fetches.length > 0, function () {
	    return "Expected at least one fetch, got none";
	  });
	  var finalSorted = [];
	  var finalRecipientMap = {};
	  if (fetches.length === 1) {
	    // Special-casing 1 fetch for efficiency.
	    var out = getTopologicalSortAndRecipientCountsForOneFetch(fetches[0], feedDict);
	    finalSorted = out.sorted;
	    finalRecipientMap = out.recipientMap;
	  } else {
	    var visited = new Set();
	    var _iterator4 = _createForOfIteratorHelper(fetches),
	      _step4;
	    try {
	      for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
	        var fetch = _step4.value;
	        var _getTopologicalSortAn = getTopologicalSortAndRecipientCountsForOneFetch(fetch, feedDict),
	          sorted = _getTopologicalSortAn.sorted,
	          recipientMap = _getTopologicalSortAn.recipientMap;
	        // Merge sorted SymbolicTensor Arrays.
	        var _iterator5 = _createForOfIteratorHelper(sorted),
	          _step5;
	        try {
	          for (_iterator5.s(); !(_step5 = _iterator5.n()).done;) {
	            var symbolicTensor = _step5.value;
	            if (!visited.has(symbolicTensor.name)) {
	              finalSorted.push(symbolicTensor);
	              visited.add(symbolicTensor.name);
	            }
	          }
	          // Merge recipient maps.
	        } catch (err) {
	          _iterator5.e(err);
	        } finally {
	          _iterator5.f();
	        }
	        var _loop = function _loop(name) {
	          if (finalRecipientMap[name] == null) {
	            finalRecipientMap[name] = new Set();
	          }
	          recipientMap[name].forEach(function (recipient) {
	            return finalRecipientMap[name].add(recipient);
	          });
	        };
	        for (var name in recipientMap) {
	          _loop(name);
	        }
	      }
	    } catch (err) {
	      _iterator4.e(err);
	    } finally {
	      _iterator4.f();
	    }
	  }
	  return {
	    sorted: finalSorted,
	    recipientCounts: recipientMap2Counts(finalRecipientMap)
	  };
	}
	function recipientMap2Counts(recipientMap) {
	  var recipientCounts = {};
	  for (var name in recipientMap) {
	    recipientCounts[name] = recipientMap[name].size;
	  }
	  return recipientCounts;
	}
	/**
	 * Sort the `SymbolicTensor`s topologically, for a single fetch.
	 *
	 * This helper function processes the upstream SymbolicTensors of a single
	 * fetch.
	 *
	 * @param fetch The single fetch requested.
	 * @param feedDict The dictionary of fed values.
	 * @returns sorted: Topologically-sorted array of SymbolicTensors.
	 *   recipientMap: Recipient names for all SymbolicTensors in `sorted`.
	 */
	function getTopologicalSortAndRecipientCountsForOneFetch(fetch, feedDict) {
	  var visited = new Set();
	  var sorted = [];
	  var recipientMap = {};
	  // Put keys of the feedDict into visited first, so they don't have to be
	  // walked. This is needed in case where there are feeds for intermediate
	  // SymbolicTensors of the graph.
	  var _iterator6 = _createForOfIteratorHelper(feedDict.names()),
	    _step6;
	  try {
	    for (_iterator6.s(); !(_step6 = _iterator6.n()).done;) {
	      var key = _step6.value;
	      visited.add(key);
	    }
	  } catch (err) {
	    _iterator6.e(err);
	  } finally {
	    _iterator6.f();
	  }
	  var stack = [];
	  var marks = [];
	  // Initial population of stack and marks.
	  stack.push(fetch);
	  while (stack.length > 0) {
	    var top = stack[stack.length - 1];
	    if (visited.has(top.name)) {
	      stack.pop();
	      continue;
	    }
	    var topIsMarked = marks[marks.length - 1] === stack.length - 1;
	    if (top.inputs.length === 0 || topIsMarked) {
	      // Input SymbolicTensor or all children have been visited.
	      stack.pop();
	      sorted.push(top);
	      visited.add(top.name);
	      if (topIsMarked) {
	        marks.pop();
	      }
	    } else {
	      // A non-input SymbolicTensor whose upstream SymbolicTensors haven't
	      // been visited yet. Push them onto the stack.
	      marks.push(stack.length - 1);
	      var _iterator7 = _createForOfIteratorHelper(top.inputs),
	        _step7;
	      try {
	        for (_iterator7.s(); !(_step7 = _iterator7.n()).done;) {
	          var input = _step7.value;
	          // Increment the recipient count. Note that this needs to happen
	          // regardless of whether the SymbolicTensor has been visited before.
	          if (recipientMap[input.name] == null) {
	            recipientMap[input.name] = new Set();
	          }
	          recipientMap[input.name].add(top.name);
	          if (visited.has(input.name)) {
	            continue; // Avoid repeated visits to the same SymbolicTensor.
	          }

	          stack.push(input);
	        }
	      } catch (err) {
	        _iterator7.e(err);
	      } finally {
	        _iterator7.f();
	      }
	    }
	  }
	  return {
	    sorted: sorted,
	    recipientMap: recipientMap
	  };
	}
	/**
	 * Get the symbolic output tensors of the node to which a given fetch belongs.
	 * @param fetch The fetched symbolic tensor.
	 * @returns The Array of symbolic tensors output by the node to which `fetch`
	 *   belongs.
	 */
	function getNodeOutputs(fetch) {
	  var layerOutputs;
	  if (fetch.sourceLayer.inboundNodes.length === 1) {
	    layerOutputs = fetch.sourceLayer.output;
	  } else {
	    var nodeIndex = null;
	    for (var i = 0; i < fetch.sourceLayer.inboundNodes.length; ++i) {
	      var _iterator8 = _createForOfIteratorHelper(fetch.sourceLayer.inboundNodes[i].outputTensors),
	        _step8;
	      try {
	        for (_iterator8.s(); !(_step8 = _iterator8.n()).done;) {
	          var outputTensor = _step8.value;
	          if (outputTensor.id === fetch.id) {
	            nodeIndex = i;
	            break;
	          }
	        }
	      } catch (err) {
	        _iterator8.e(err);
	      } finally {
	        _iterator8.f();
	      }
	    }
	    layerOutputs = fetch.sourceLayer.getOutputAt(nodeIndex);
	  }
	  return layerOutputs;
	}

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ENV$2 = env();
	/** The max number of entries for the caches of layers' topological sort. */
	ENV$2.registerFlag('TOPOLOGICAL_SORT_CACHE_MAX_ENTRIES', function () {
	  return 100;
	}, updateCacheMaxEntries);

	/**
	 * Helper function used by many of the Constraints to find the L2Norms.
	 */
	function calcL2Norms(w, axis) {
	  return tidy(function () {
	    return sqrt$2(sum$3(mul(w, w), axis, true));
	  });
	}
	/**
	 * Base class for functions that impose constraints on weight values
	 *
	 * @doc {
	 *   heading: 'Constraints',
	 *   subheading: 'Classes',
	 *   namespace: 'constraints'
	 * }
	 */
	var Constraint = /*#__PURE__*/function (_serialization$Serial) {
	  _inherits(Constraint, _serialization$Serial);
	  var _super = _createSuper(Constraint);
	  function Constraint() {
	    _classCallCheck(this, Constraint);
	    return _super.apply(this, arguments);
	  }
	  _createClass(Constraint, [{
	    key: "getConfig",
	    value: function getConfig() {
	      return {};
	    }
	  }]);
	  return Constraint;
	}(Serializable);
	var MaxNorm = /*#__PURE__*/function (_Constraint) {
	  _inherits(MaxNorm, _Constraint);
	  var _super2 = _createSuper(MaxNorm);
	  function MaxNorm(args) {
	    var _this;
	    _classCallCheck(this, MaxNorm);
	    _this = _super2.call(this);
	    _this.defaultMaxValue = 2;
	    _this.defaultAxis = 0;
	    _this.maxValue = args.maxValue != null ? args.maxValue : _this.defaultMaxValue;
	    _this.axis = args.axis != null ? args.axis : _this.defaultAxis;
	    return _this;
	  }
	  _createClass(MaxNorm, [{
	    key: "apply",
	    value: function apply(w) {
	      var _this2 = this;
	      return tidy(function () {
	        var norms = calcL2Norms(w, _this2.axis);
	        var desired = clipByValue$2(norms, 0, _this2.maxValue);
	        return mul(w, div$1(desired, add$3(epsilon$1(), norms)));
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        maxValue: this.maxValue,
	        axis: this.axis
	      };
	    }
	  }]);
	  return MaxNorm;
	}(Constraint);
	/** @nocollapse */
	MaxNorm.className = 'MaxNorm';
	registerClass(MaxNorm);
	var UnitNorm = /*#__PURE__*/function (_Constraint2) {
	  _inherits(UnitNorm, _Constraint2);
	  var _super3 = _createSuper(UnitNorm);
	  function UnitNorm(args) {
	    var _this3;
	    _classCallCheck(this, UnitNorm);
	    _this3 = _super3.call(this);
	    _this3.defaultAxis = 0;
	    _this3.axis = args.axis != null ? args.axis : _this3.defaultAxis;
	    return _this3;
	  }
	  _createClass(UnitNorm, [{
	    key: "apply",
	    value: function apply(w) {
	      var _this4 = this;
	      return tidy(function () {
	        return div$1(w, add$3(epsilon$1(), calcL2Norms(w, _this4.axis)));
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        axis: this.axis
	      };
	    }
	  }]);
	  return UnitNorm;
	}(Constraint);
	/** @nocollapse */
	UnitNorm.className = 'UnitNorm';
	registerClass(UnitNorm);
	var NonNeg = /*#__PURE__*/function (_Constraint3) {
	  _inherits(NonNeg, _Constraint3);
	  var _super4 = _createSuper(NonNeg);
	  function NonNeg() {
	    _classCallCheck(this, NonNeg);
	    return _super4.apply(this, arguments);
	  }
	  _createClass(NonNeg, [{
	    key: "apply",
	    value: function apply(w) {
	      return relu$2(w);
	    }
	  }]);
	  return NonNeg;
	}(Constraint);
	/** @nocollapse */
	NonNeg.className = 'NonNeg';
	registerClass(NonNeg);
	var MinMaxNorm = /*#__PURE__*/function (_Constraint4) {
	  _inherits(MinMaxNorm, _Constraint4);
	  var _super5 = _createSuper(MinMaxNorm);
	  function MinMaxNorm(args) {
	    var _this5;
	    _classCallCheck(this, MinMaxNorm);
	    _this5 = _super5.call(this);
	    _this5.defaultMinValue = 0.0;
	    _this5.defaultMaxValue = 1.0;
	    _this5.defaultRate = 1.0;
	    _this5.defaultAxis = 0;
	    _this5.minValue = args.minValue != null ? args.minValue : _this5.defaultMinValue;
	    _this5.maxValue = args.maxValue != null ? args.maxValue : _this5.defaultMaxValue;
	    _this5.rate = args.rate != null ? args.rate : _this5.defaultRate;
	    _this5.axis = args.axis != null ? args.axis : _this5.defaultAxis;
	    return _this5;
	  }
	  _createClass(MinMaxNorm, [{
	    key: "apply",
	    value: function apply(w) {
	      var _this6 = this;
	      return tidy(function () {
	        var norms = calcL2Norms(w, _this6.axis);
	        var desired = add$3(mul(_this6.rate, clipByValue$2(norms, _this6.minValue, _this6.maxValue)), mul(1.0 - _this6.rate, norms));
	        return mul(w, div$1(desired, add$3(epsilon$1(), norms)));
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        minValue: this.minValue,
	        maxValue: this.maxValue,
	        rate: this.rate,
	        axis: this.axis
	      };
	    }
	  }]);
	  return MinMaxNorm;
	}(Constraint);
	/** @nocollapse */
	MinMaxNorm.className = 'MinMaxNorm';
	registerClass(MinMaxNorm);
	// Maps the JavaScript-like identifier keys to the corresponding registry
	// symbols.
	var CONSTRAINT_IDENTIFIER_REGISTRY_SYMBOL_MAP = {
	  'maxNorm': 'MaxNorm',
	  'minMaxNorm': 'MinMaxNorm',
	  'nonNeg': 'NonNeg',
	  'unitNorm': 'UnitNorm'
	};
	function serializeConstraint(constraint) {
	  return serializeKerasObject(constraint);
	}
	function deserializeConstraint(config) {
	  var customObjects = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	  return deserializeKerasObject(config, SerializationMap.getMap().classNameMap, customObjects, 'constraint');
	}
	function getConstraint(identifier) {
	  if (identifier == null) {
	    return null;
	  }
	  if (typeof identifier === 'string') {
	    var className = identifier in CONSTRAINT_IDENTIFIER_REGISTRY_SYMBOL_MAP ? CONSTRAINT_IDENTIFIER_REGISTRY_SYMBOL_MAP[identifier] : identifier;
	    var config = {
	      className: className,
	      config: {}
	    };
	    return deserializeConstraint(config);
	  } else if (identifier instanceof Constraint) {
	    return identifier;
	  } else {
	    return deserializeConstraint(identifier);
	  }
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	/**
	 * MaxNorm weight constraint.
	 *
	 * Constrains the weights incident to each hidden unit
	 * to have a norm less than or equal to a desired value.
	 *
	 * References
	 *       - [Dropout: A Simple Way to Prevent Neural Networks from Overfitting
	 * Srivastava, Hinton, et al.
	 * 2014](http://www.cs.toronto.edu/~rsalakhu/papers/srivastava14a.pdf)
	 *
	 * @doc {heading: 'Constraints',namespace: 'constraints'}
	 */
	function maxNorm(args) {
	  return new MaxNorm(args);
	}
	/**
	 * Constrains the weights incident to each hidden unit to have unit norm.
	 *
	 * @doc {heading: 'Constraints', namespace: 'constraints'}
	 */
	function unitNorm(args) {
	  return new UnitNorm(args);
	}
	/**
	 * Constrains the weight to be non-negative.
	 *
	 * @doc {heading: 'Constraints', namespace: 'constraints'}
	 */
	function nonNeg() {
	  return new NonNeg();
	}
	/** @doc {heading: 'Constraints', namespace: 'constraints'} */
	function minMaxNorm(config) {
	  return new MinMaxNorm(config);
	}

	var exports_constraints = {
		__proto__: null,
		maxNorm: maxNorm,
		minMaxNorm: minMaxNorm,
		nonNeg: nonNeg,
		unitNorm: unitNorm
	};

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	/**
	 * Initializer that generates tensors initialized to 0.
	 *
	 * @doc {heading: 'Initializers', namespace: 'initializers'}
	 */
	function zeros$1() {
	  return new Zeros();
	}
	/**
	 * Initializer that generates tensors initialized to 1.
	 *
	 * @doc {heading: 'Initializers', namespace: 'initializers'}
	 */
	function ones() {
	  return new Ones();
	}
	/**
	 * Initializer that generates values initialized to some constant.
	 *
	 * @doc {heading: 'Initializers', namespace: 'initializers'}
	 */
	function constant(args) {
	  return new Constant(args);
	}
	/**
	 * Initializer that generates random values initialized to a uniform
	 * distribution.
	 *
	 * Values will be distributed uniformly between the configured minval and
	 * maxval.
	 *
	 * @doc {heading: 'Initializers', namespace: 'initializers'}
	 */
	function randomUniform(args) {
	  return new RandomUniform(args);
	}
	/**
	 * Initializer that generates random values initialized to a normal
	 * distribution.
	 *
	 * @doc {heading: 'Initializers', namespace: 'initializers'}
	 */
	function randomNormal(args) {
	  return new RandomNormal(args);
	}
	/**
	 * Initializer that generates random values initialized to a truncated normal
	 * distribution.
	 *
	 * These values are similar to values from a `RandomNormal` except that values
	 * more than two standard deviations from the mean are discarded and re-drawn.
	 * This is the recommended initializer for neural network weights and filters.
	 *
	 * @doc {heading: 'Initializers', namespace: 'initializers'}
	 */
	function truncatedNormal(args) {
	  return new TruncatedNormal(args);
	}
	/**
	 * Initializer that generates the identity matrix.
	 * Only use for square 2D matrices.
	 *
	 * @doc {heading: 'Initializers', namespace: 'initializers'}
	 */
	function identity$2(args) {
	  return new Identity(args);
	}
	/**
	 * Initializer capable of adapting its scale to the shape of weights.
	 * With distribution=NORMAL, samples are drawn from a truncated normal
	 * distribution centered on zero, with `stddev = sqrt(scale / n)` where n is:
	 *   - number of input units in the weight tensor, if mode = FAN_IN.
	 *   - number of output units, if mode = FAN_OUT.
	 *   - average of the numbers of input and output units, if mode = FAN_AVG.
	 * With distribution=UNIFORM,
	 * samples are drawn from a uniform distribution
	 * within [-limit, limit], with `limit = sqrt(3 * scale / n)`.
	 *
	 * @doc {heading: 'Initializers',namespace: 'initializers'}
	 */
	function varianceScaling(config) {
	  return new VarianceScaling(config);
	}
	/**
	 * Glorot uniform initializer, also called Xavier uniform initializer.
	 * It draws samples from a uniform distribution within [-limit, limit]
	 * where `limit` is `sqrt(6 / (fan_in + fan_out))`
	 * where `fan_in` is the number of input units in the weight tensor
	 * and `fan_out` is the number of output units in the weight tensor
	 *
	 * Reference:
	 *   Glorot & Bengio, AISTATS 2010
	 *       http://jmlr.org/proceedings/papers/v9/glorot10a/glorot10a.pdf.
	 *
	 * @doc {heading: 'Initializers', namespace: 'initializers'}
	 */
	function glorotUniform(args) {
	  return new GlorotUniform(args);
	}
	/**
	 * Glorot normal initializer, also called Xavier normal initializer.
	 * It draws samples from a truncated normal distribution centered on 0
	 * with `stddev = sqrt(2 / (fan_in + fan_out))`
	 * where `fan_in` is the number of input units in the weight tensor
	 * and `fan_out` is the number of output units in the weight tensor.
	 *
	 * Reference:
	 *   Glorot & Bengio, AISTATS 2010
	 *       http://jmlr.org/proceedings/papers/v9/glorot10a/glorot10a.pdf
	 *
	 * @doc {heading: 'Initializers', namespace: 'initializers'}
	 */
	function glorotNormal(args) {
	  return new GlorotNormal(args);
	}
	/**
	 * He normal initializer.
	 *
	 * It draws samples from a truncated normal distribution centered on 0
	 * with `stddev = sqrt(2 / fanIn)`
	 * where `fanIn` is the number of input units in the weight tensor.
	 *
	 * Reference:
	 *     He et al., http://arxiv.org/abs/1502.01852
	 *
	 * @doc {heading: 'Initializers', namespace: 'initializers'}
	 */
	function heNormal(args) {
	  return new HeNormal(args);
	}
	/**
	 * He uniform initializer.
	 *
	 * It draws samples from a uniform distribution within [-limit, limit]
	 * where `limit` is `sqrt(6 / fan_in)`
	 * where `fanIn` is the number of input units in the weight tensor.
	 *
	 * Reference:
	 *     He et al., http://arxiv.org/abs/1502.01852
	 *
	 * @doc {heading: 'Initializers',namespace: 'initializers'}
	 */
	function heUniform(args) {
	  return new HeUniform(args);
	}
	/**
	 * LeCun normal initializer.
	 *
	 * It draws samples from a truncated normal distribution centered on 0
	 * with `stddev = sqrt(1 / fanIn)`
	 * where `fanIn` is the number of input units in the weight tensor.
	 *
	 * References:
	 *   [Self-Normalizing Neural Networks](https://arxiv.org/abs/1706.02515)
	 *   [Efficient Backprop](http://yann.lecun.com/exdb/publis/pdf/lecun-98b.pdf)
	 *
	 * @doc {heading: 'Initializers', namespace: 'initializers'}
	 */
	function leCunNormal(args) {
	  return new LeCunNormal(args);
	}
	/**
	 * LeCun uniform initializer.
	 *
	 * It draws samples from a uniform distribution in the interval
	 * `[-limit, limit]` with `limit = sqrt(3 / fanIn)`,
	 * where `fanIn` is the number of input units in the weight tensor.
	 *
	 * @doc {heading: 'Initializers', namespace: 'initializers'}
	 */
	function leCunUniform(args) {
	  return new LeCunUniform(args);
	}
	/**
	 * Initializer that generates a random orthogonal matrix.
	 *
	 * Reference:
	 * [Saxe et al., http://arxiv.org/abs/1312.6120](http://arxiv.org/abs/1312.6120)
	 *
	 * @doc {heading: 'Initializers', namespace: 'initializers'}
	 */
	function orthogonal(args) {
	  return new Orthogonal(args);
	}

	var exports_initializers = {
		__proto__: null,
		constant: constant,
		glorotNormal: glorotNormal,
		glorotUniform: glorotUniform,
		heNormal: heNormal,
		heUniform: heUniform,
		identity: identity$2,
		leCunNormal: leCunNormal,
		leCunUniform: leCunUniform,
		ones: ones,
		orthogonal: orthogonal,
		randomNormal: randomNormal,
		randomUniform: randomUniform,
		truncatedNormal: truncatedNormal,
		varianceScaling: varianceScaling,
		zeros: zeros$1
	};

	/**
	 * Turn any Scalar values in a Logs object into actual number values.
	 *
	 * @param logs The `Logs` object to be resolved in place.
	 */
	function resolveScalarsInLogs(_x) {
	  return _resolveScalarsInLogs.apply(this, arguments);
	}
	/**
	 * Dispose all Tensors in an UnresolvedLogs object.
	 *
	 * @param logs An `UnresolvedLogs` object potentially containing `tf.Tensor`s in
	 *   places where the values can be `tf.Tensor` or `number`.
	 */
	function _resolveScalarsInLogs() {
	  _resolveScalarsInLogs = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(logs) {
	    var promises, keys, scalarsToDispose, key, value, valueScalar, values, i;
	    return _regeneratorRuntime().wrap(function _callee$(_context) {
	      while (1) switch (_context.prev = _context.next) {
	        case 0:
	          if (!(logs == null)) {
	            _context.next = 2;
	            break;
	          }
	          return _context.abrupt("return");
	        case 2:
	          promises = [];
	          keys = [];
	          scalarsToDispose = [];
	          for (key in logs) {
	            value = logs[key];
	            if (typeof value !== 'number') {
	              valueScalar = value;
	              promises.push(valueScalar.data());
	              keys.push(key);
	              scalarsToDispose.push(valueScalar);
	            }
	          }
	          if (!(promises.length > 0)) {
	            _context.next = 12;
	            break;
	          }
	          _context.next = 9;
	          return Promise.all(promises);
	        case 9:
	          values = _context.sent;
	          for (i = 0; i < values.length; ++i) {
	            logs[keys[i]] = values[i][0];
	          }
	          // Dispose the original scalar tensors.
	          dispose(scalarsToDispose);
	        case 12:
	        case "end":
	          return _context.stop();
	      }
	    }, _callee);
	  }));
	  return _resolveScalarsInLogs.apply(this, arguments);
	}
	function disposeTensorsInLogs(logs) {
	  if (logs == null) {
	    return;
	  }
	  for (var key in logs) {
	    var value = logs[key];
	    if (typeof value !== 'number') {
	      value.dispose();
	    }
	  }
	}

	/** Verbosity logging level when fitting a model. */
	var ModelLoggingVerbosity;
	(function (ModelLoggingVerbosity) {
	  ModelLoggingVerbosity[ModelLoggingVerbosity["SILENT"] = 0] = "SILENT";
	  ModelLoggingVerbosity[ModelLoggingVerbosity["VERBOSE"] = 1] = "VERBOSE";
	})(ModelLoggingVerbosity || (ModelLoggingVerbosity = {}));
	/** How often to yield to the main thread when training (in ms). */
	var DEFAULT_YIELD_EVERY_MS = 125;
	/**
	 * Abstract base class used to build new callbacks.
	 *
	 * The `logs` dictionary that callback methods take as argument will contain
	 * keys for quantities relevant to the current batch or epoch.
	 *
	 * Currently, the `.fit()` method of the `Sequential` model class
	 * will include the following quantities in the `logs` that
	 * it passes to its callbacks:
	 *
	 * onEpochEnd: Logs include `acc` and `loss`, and optionally include `valLoss`
	 *   (if validation is enabled in `fit`), and `valAcc` (if validation and
	 *   accuracy monitoring are enabled).
	 * onBatchBegin: Logs include `size`, the number of samples in the current
	 *   batch.
	 * onBatchEnd: Logs include `loss`, and optionally `acc` (if accuracy monitoring
	 *   is enabled).
	 */
	var BaseCallback = /*#__PURE__*/function () {
	  function BaseCallback() {
	    _classCallCheck(this, BaseCallback);
	    // TODO(michaelterry): This type is a best guess.
	    this.validationData = null;
	  }
	  _createClass(BaseCallback, [{
	    key: "setParams",
	    value: function setParams(params) {
	      this.params = params;
	    }
	  }, {
	    key: "onEpochBegin",
	    value: function () {
	      var _onEpochBegin = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(epoch, logs) {
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee);
	      }));
	      function onEpochBegin(_x, _x2) {
	        return _onEpochBegin.apply(this, arguments);
	      }
	      return onEpochBegin;
	    }()
	  }, {
	    key: "onEpochEnd",
	    value: function () {
	      var _onEpochEnd = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(epoch, logs) {
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2);
	      }));
	      function onEpochEnd(_x3, _x4) {
	        return _onEpochEnd.apply(this, arguments);
	      }
	      return onEpochEnd;
	    }()
	  }, {
	    key: "onBatchBegin",
	    value: function () {
	      var _onBatchBegin = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3(batch, logs) {
	        return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	          while (1) switch (_context3.prev = _context3.next) {
	            case 0:
	            case "end":
	              return _context3.stop();
	          }
	        }, _callee3);
	      }));
	      function onBatchBegin(_x5, _x6) {
	        return _onBatchBegin.apply(this, arguments);
	      }
	      return onBatchBegin;
	    }()
	  }, {
	    key: "onBatchEnd",
	    value: function () {
	      var _onBatchEnd = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4(batch, logs) {
	        return _regeneratorRuntime().wrap(function _callee4$(_context4) {
	          while (1) switch (_context4.prev = _context4.next) {
	            case 0:
	            case "end":
	              return _context4.stop();
	          }
	        }, _callee4);
	      }));
	      function onBatchEnd(_x7, _x8) {
	        return _onBatchEnd.apply(this, arguments);
	      }
	      return onBatchEnd;
	    }()
	  }, {
	    key: "onTrainBegin",
	    value: function () {
	      var _onTrainBegin = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee5(logs) {
	        return _regeneratorRuntime().wrap(function _callee5$(_context5) {
	          while (1) switch (_context5.prev = _context5.next) {
	            case 0:
	            case "end":
	              return _context5.stop();
	          }
	        }, _callee5);
	      }));
	      function onTrainBegin(_x9) {
	        return _onTrainBegin.apply(this, arguments);
	      }
	      return onTrainBegin;
	    }()
	  }, {
	    key: "onTrainEnd",
	    value: function () {
	      var _onTrainEnd = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee6(logs) {
	        return _regeneratorRuntime().wrap(function _callee6$(_context6) {
	          while (1) switch (_context6.prev = _context6.next) {
	            case 0:
	            case "end":
	              return _context6.stop();
	          }
	        }, _callee6);
	      }));
	      function onTrainEnd(_x10) {
	        return _onTrainEnd.apply(this, arguments);
	      }
	      return onTrainEnd;
	    }() // LayersModel needs to call Callback.setModel(), but cannot actually depend
	    // on Callback because that creates a cyclic dependency.  Providing this no-op
	    // method on BaseCallback breaks the cycle: this way LayersModel can depend on
	    // BaseCallback but not on Callback.  The argument is typed as `Container`
	    // (the superclass of LayersModel) to avoid recapitulating the cycle. Callback
	    // overrides this method and enforces that the argument is really a
	    // LayersModel.
	  }, {
	    key: "setModel",
	    value: function setModel(model) {
	      // Do nothing. Use Callback instead of BaseCallback to track the model.
	    }
	  }]);
	  return BaseCallback;
	}();
	/**
	 * Container abstracting a list of callbacks.
	 */
	var CallbackList = /*#__PURE__*/function () {
	  // TODO(cais): When the need arises, uncomment the following lines and
	  // implement the queue for time values.
	  // private deltaTBatch: number;
	  // private deltaTsBatchBegin: Array<number>;
	  // private deltaTsBatchEnd: Array<number>;
	  /**
	   * Constructor of CallbackList.
	   * @param callbacks Array of `Callback` instances.
	   * @param queueLength Queue length for keeping running statistics over
	   *   callback execution time.
	   */
	  function CallbackList(callbacks) {
	    var queueLength = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 10;
	    _classCallCheck(this, CallbackList);
	    // TODO(cais): Make use of queueLength when implementing the queue for time
	    // values.
	    if (callbacks == null) {
	      callbacks = [];
	    }
	    this.callbacks = callbacks;
	    this.queueLength = queueLength;
	  }
	  _createClass(CallbackList, [{
	    key: "append",
	    value: function append(callback) {
	      this.callbacks.push(callback);
	    }
	  }, {
	    key: "setParams",
	    value: function setParams(params) {
	      var _iterator = _createForOfIteratorHelper(this.callbacks),
	        _step;
	      try {
	        for (_iterator.s(); !(_step = _iterator.n()).done;) {
	          var callback = _step.value;
	          callback.setParams(params);
	        }
	      } catch (err) {
	        _iterator.e(err);
	      } finally {
	        _iterator.f();
	      }
	    }
	  }, {
	    key: "setModel",
	    value: function setModel(model) {
	      var _iterator2 = _createForOfIteratorHelper(this.callbacks),
	        _step2;
	      try {
	        for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	          var callback = _step2.value;
	          callback.setModel(model);
	        }
	      } catch (err) {
	        _iterator2.e(err);
	      } finally {
	        _iterator2.f();
	      }
	    }
	    /**
	     * Called at the start of an epoch.
	     * @param epoch Index of epoch.
	     * @param logs Dictionary of logs.
	     */
	  }, {
	    key: "onEpochBegin",
	    value: function () {
	      var _onEpochBegin2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee7(epoch, logs) {
	        var _iterator3, _step3, callback;
	        return _regeneratorRuntime().wrap(function _callee7$(_context7) {
	          while (1) switch (_context7.prev = _context7.next) {
	            case 0:
	              if (logs == null) {
	                logs = {};
	              }
	              _iterator3 = _createForOfIteratorHelper(this.callbacks);
	              _context7.prev = 2;
	              _iterator3.s();
	            case 4:
	              if ((_step3 = _iterator3.n()).done) {
	                _context7.next = 10;
	                break;
	              }
	              callback = _step3.value;
	              _context7.next = 8;
	              return callback.onEpochBegin(epoch, logs);
	            case 8:
	              _context7.next = 4;
	              break;
	            case 10:
	              _context7.next = 15;
	              break;
	            case 12:
	              _context7.prev = 12;
	              _context7.t0 = _context7["catch"](2);
	              _iterator3.e(_context7.t0);
	            case 15:
	              _context7.prev = 15;
	              _iterator3.f();
	              return _context7.finish(15);
	            case 18:
	            case "end":
	              return _context7.stop();
	          }
	        }, _callee7, this, [[2, 12, 15, 18]]);
	      }));
	      function onEpochBegin(_x11, _x12) {
	        return _onEpochBegin2.apply(this, arguments);
	      }
	      return onEpochBegin;
	    }()
	    /**
	     * Called at the end of an epoch.
	     * @param epoch Index of epoch.
	     * @param logs Dictionary of logs.
	     */
	  }, {
	    key: "onEpochEnd",
	    value: function () {
	      var _onEpochEnd2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee8(epoch, logs) {
	        var _iterator4, _step4, callback;
	        return _regeneratorRuntime().wrap(function _callee8$(_context8) {
	          while (1) switch (_context8.prev = _context8.next) {
	            case 0:
	              if (logs == null) {
	                logs = {};
	              }
	              _iterator4 = _createForOfIteratorHelper(this.callbacks);
	              _context8.prev = 2;
	              _iterator4.s();
	            case 4:
	              if ((_step4 = _iterator4.n()).done) {
	                _context8.next = 10;
	                break;
	              }
	              callback = _step4.value;
	              _context8.next = 8;
	              return callback.onEpochEnd(epoch, logs);
	            case 8:
	              _context8.next = 4;
	              break;
	            case 10:
	              _context8.next = 15;
	              break;
	            case 12:
	              _context8.prev = 12;
	              _context8.t0 = _context8["catch"](2);
	              _iterator4.e(_context8.t0);
	            case 15:
	              _context8.prev = 15;
	              _iterator4.f();
	              return _context8.finish(15);
	            case 18:
	            case "end":
	              return _context8.stop();
	          }
	        }, _callee8, this, [[2, 12, 15, 18]]);
	      }));
	      function onEpochEnd(_x13, _x14) {
	        return _onEpochEnd2.apply(this, arguments);
	      }
	      return onEpochEnd;
	    }()
	    /**
	     * Called  right before processing a batch.
	     * @param batch Index of batch within the current epoch.
	     * @param logs Dictionary of logs.
	     */
	  }, {
	    key: "onBatchBegin",
	    value: function () {
	      var _onBatchBegin2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee9(batch, logs) {
	        var _iterator5, _step5, callback;
	        return _regeneratorRuntime().wrap(function _callee9$(_context9) {
	          while (1) switch (_context9.prev = _context9.next) {
	            case 0:
	              if (logs == null) {
	                logs = {};
	              }
	              _iterator5 = _createForOfIteratorHelper(this.callbacks);
	              _context9.prev = 2;
	              _iterator5.s();
	            case 4:
	              if ((_step5 = _iterator5.n()).done) {
	                _context9.next = 10;
	                break;
	              }
	              callback = _step5.value;
	              _context9.next = 8;
	              return callback.onBatchBegin(batch, logs);
	            case 8:
	              _context9.next = 4;
	              break;
	            case 10:
	              _context9.next = 15;
	              break;
	            case 12:
	              _context9.prev = 12;
	              _context9.t0 = _context9["catch"](2);
	              _iterator5.e(_context9.t0);
	            case 15:
	              _context9.prev = 15;
	              _iterator5.f();
	              return _context9.finish(15);
	            case 18:
	            case "end":
	              return _context9.stop();
	          }
	        }, _callee9, this, [[2, 12, 15, 18]]);
	      }));
	      function onBatchBegin(_x15, _x16) {
	        return _onBatchBegin2.apply(this, arguments);
	      }
	      return onBatchBegin;
	    }()
	    /**
	     * Called at the end of a batch.
	     * @param batch Index of batch within the current epoch.
	     * @param logs Dictionary of logs.
	     */
	  }, {
	    key: "onBatchEnd",
	    value: function () {
	      var _onBatchEnd2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee10(batch, logs) {
	        var _iterator6, _step6, callback;
	        return _regeneratorRuntime().wrap(function _callee10$(_context10) {
	          while (1) switch (_context10.prev = _context10.next) {
	            case 0:
	              if (logs == null) {
	                logs = {};
	              }
	              _iterator6 = _createForOfIteratorHelper(this.callbacks);
	              _context10.prev = 2;
	              _iterator6.s();
	            case 4:
	              if ((_step6 = _iterator6.n()).done) {
	                _context10.next = 10;
	                break;
	              }
	              callback = _step6.value;
	              _context10.next = 8;
	              return callback.onBatchEnd(batch, logs);
	            case 8:
	              _context10.next = 4;
	              break;
	            case 10:
	              _context10.next = 15;
	              break;
	            case 12:
	              _context10.prev = 12;
	              _context10.t0 = _context10["catch"](2);
	              _iterator6.e(_context10.t0);
	            case 15:
	              _context10.prev = 15;
	              _iterator6.f();
	              return _context10.finish(15);
	            case 18:
	            case "end":
	              return _context10.stop();
	          }
	        }, _callee10, this, [[2, 12, 15, 18]]);
	      }));
	      function onBatchEnd(_x17, _x18) {
	        return _onBatchEnd2.apply(this, arguments);
	      }
	      return onBatchEnd;
	    }()
	    /**
	     * Called at the beginning of training.
	     * @param logs Dictionary of logs.
	     */
	  }, {
	    key: "onTrainBegin",
	    value: function () {
	      var _onTrainBegin2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee11(logs) {
	        var _iterator7, _step7, callback;
	        return _regeneratorRuntime().wrap(function _callee11$(_context11) {
	          while (1) switch (_context11.prev = _context11.next) {
	            case 0:
	              if (logs == null) {
	                logs = {};
	              }
	              _iterator7 = _createForOfIteratorHelper(this.callbacks);
	              _context11.prev = 2;
	              _iterator7.s();
	            case 4:
	              if ((_step7 = _iterator7.n()).done) {
	                _context11.next = 10;
	                break;
	              }
	              callback = _step7.value;
	              _context11.next = 8;
	              return callback.onTrainBegin(logs);
	            case 8:
	              _context11.next = 4;
	              break;
	            case 10:
	              _context11.next = 15;
	              break;
	            case 12:
	              _context11.prev = 12;
	              _context11.t0 = _context11["catch"](2);
	              _iterator7.e(_context11.t0);
	            case 15:
	              _context11.prev = 15;
	              _iterator7.f();
	              return _context11.finish(15);
	            case 18:
	            case "end":
	              return _context11.stop();
	          }
	        }, _callee11, this, [[2, 12, 15, 18]]);
	      }));
	      function onTrainBegin(_x19) {
	        return _onTrainBegin2.apply(this, arguments);
	      }
	      return onTrainBegin;
	    }()
	    /**
	     * Called at the end of training.
	     * @param logs Dictionary of logs.
	     */
	  }, {
	    key: "onTrainEnd",
	    value: function () {
	      var _onTrainEnd2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee12(logs) {
	        var _iterator8, _step8, callback;
	        return _regeneratorRuntime().wrap(function _callee12$(_context12) {
	          while (1) switch (_context12.prev = _context12.next) {
	            case 0:
	              if (logs == null) {
	                logs = {};
	              }
	              _iterator8 = _createForOfIteratorHelper(this.callbacks);
	              _context12.prev = 2;
	              _iterator8.s();
	            case 4:
	              if ((_step8 = _iterator8.n()).done) {
	                _context12.next = 10;
	                break;
	              }
	              callback = _step8.value;
	              _context12.next = 8;
	              return callback.onTrainEnd(logs);
	            case 8:
	              _context12.next = 4;
	              break;
	            case 10:
	              _context12.next = 15;
	              break;
	            case 12:
	              _context12.prev = 12;
	              _context12.t0 = _context12["catch"](2);
	              _iterator8.e(_context12.t0);
	            case 15:
	              _context12.prev = 15;
	              _iterator8.f();
	              return _context12.finish(15);
	            case 18:
	            case "end":
	              return _context12.stop();
	          }
	        }, _callee12, this, [[2, 12, 15, 18]]);
	      }));
	      function onTrainEnd(_x20) {
	        return _onTrainEnd2.apply(this, arguments);
	      }
	      return onTrainEnd;
	    }()
	  }]);
	  return CallbackList;
	}();
	/**
	 * Callback that accumulates epoch averages of metrics.
	 *
	 * This callback is automatically applied to every LayersModel.
	 */
	var BaseLogger = /*#__PURE__*/function (_BaseCallback) {
	  _inherits(BaseLogger, _BaseCallback);
	  var _super = _createSuper(BaseLogger);
	  function BaseLogger() {
	    _classCallCheck(this, BaseLogger);
	    return _super.call(this);
	  }
	  _createClass(BaseLogger, [{
	    key: "onEpochBegin",
	    value: function () {
	      var _onEpochBegin3 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee13(epoch) {
	        return _regeneratorRuntime().wrap(function _callee13$(_context13) {
	          while (1) switch (_context13.prev = _context13.next) {
	            case 0:
	              this.seen = 0;
	              this.totals = {};
	            case 2:
	            case "end":
	              return _context13.stop();
	          }
	        }, _callee13, this);
	      }));
	      function onEpochBegin(_x21) {
	        return _onEpochBegin3.apply(this, arguments);
	      }
	      return onEpochBegin;
	    }()
	  }, {
	    key: "onBatchEnd",
	    value: function () {
	      var _onBatchEnd3 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee14(batch, logs) {
	        var _this = this;
	        var batchSize, _loop, key;
	        return _regeneratorRuntime().wrap(function _callee14$(_context15) {
	          while (1) switch (_context15.prev = _context15.next) {
	            case 0:
	              if (logs == null) {
	                logs = {};
	              }
	              batchSize = logs['size'] == null ? 0 : logs['size'];
	              this.seen += batchSize;
	              _loop = /*#__PURE__*/_regeneratorRuntime().mark(function _loop(key) {
	                var value, oldTotalsToDispose, total;
	                return _regeneratorRuntime().wrap(function _loop$(_context14) {
	                  while (1) switch (_context14.prev = _context14.next) {
	                    case 0:
	                      value = logs[key];
	                      if (typeof value === 'number') {
	                        if (!_this.totals.hasOwnProperty(key)) {
	                          _this.totals[key] = 0;
	                        }
	                        _this.totals[key] = _this.totals[key] + value * batchSize;
	                      } else {
	                        if (key in _this.totals) {
	                          oldTotalsToDispose = _this.totals[key];
	                        } else {
	                          _this.totals[key] = 0;
	                        }
	                        total = tidy(function () {
	                          return add$3(_this.totals[key], mul(value, batchSize));
	                        });
	                        _this.totals[key] = total;
	                        if (oldTotalsToDispose != null) {
	                          oldTotalsToDispose.dispose();
	                        }
	                      }
	                    case 2:
	                    case "end":
	                      return _context14.stop();
	                  }
	                }, _loop);
	              });
	              _context15.t0 = _regeneratorRuntime().keys(logs);
	            case 5:
	              if ((_context15.t1 = _context15.t0()).done) {
	                _context15.next = 10;
	                break;
	              }
	              key = _context15.t1.value;
	              return _context15.delegateYield(_loop(key), "t2", 8);
	            case 8:
	              _context15.next = 5;
	              break;
	            case 10:
	            case "end":
	              return _context15.stop();
	          }
	        }, _callee14, this);
	      }));
	      function onBatchEnd(_x22, _x23) {
	        return _onBatchEnd3.apply(this, arguments);
	      }
	      return onBatchEnd;
	    }()
	  }, {
	    key: "onEpochEnd",
	    value: function () {
	      var _onEpochEnd3 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee15(epoch, logs) {
	        var _this2 = this;
	        var _iterator9, _step9, _loop2, _ret;
	        return _regeneratorRuntime().wrap(function _callee15$(_context17) {
	          while (1) switch (_context17.prev = _context17.next) {
	            case 0:
	              if (!(logs != null)) {
	                _context17.next = 20;
	                break;
	              }
	              _iterator9 = _createForOfIteratorHelper(this.params['metrics']);
	              _context17.prev = 2;
	              _loop2 = /*#__PURE__*/_regeneratorRuntime().mark(function _loop2() {
	                var key;
	                return _regeneratorRuntime().wrap(function _loop2$(_context16) {
	                  while (1) switch (_context16.prev = _context16.next) {
	                    case 0:
	                      key = _step9.value;
	                      if (!(_this2.totals[key] == null)) {
	                        _context16.next = 3;
	                        break;
	                      }
	                      return _context16.abrupt("return", "continue");
	                    case 3:
	                      if (typeof _this2.totals[key] === 'number') {
	                        logs[key] = _this2.totals[key] / _this2.seen;
	                      } else {
	                        tidy(function () {
	                          var log = mul(div$1(1, _this2.seen), _this2.totals[key]);
	                          logs[key] = log;
	                          _this2.totals[key].dispose();
	                          keep(logs[key]);
	                        });
	                      }
	                    case 4:
	                    case "end":
	                      return _context16.stop();
	                  }
	                }, _loop2);
	              });
	              _iterator9.s();
	            case 5:
	              if ((_step9 = _iterator9.n()).done) {
	                _context17.next = 12;
	                break;
	              }
	              return _context17.delegateYield(_loop2(), "t0", 7);
	            case 7:
	              _ret = _context17.t0;
	              if (!(_ret === "continue")) {
	                _context17.next = 10;
	                break;
	              }
	              return _context17.abrupt("continue", 10);
	            case 10:
	              _context17.next = 5;
	              break;
	            case 12:
	              _context17.next = 17;
	              break;
	            case 14:
	              _context17.prev = 14;
	              _context17.t1 = _context17["catch"](2);
	              _iterator9.e(_context17.t1);
	            case 17:
	              _context17.prev = 17;
	              _iterator9.f();
	              return _context17.finish(17);
	            case 20:
	            case "end":
	              return _context17.stop();
	          }
	        }, _callee15, this, [[2, 14, 17, 20]]);
	      }));
	      function onEpochEnd(_x24, _x25) {
	        return _onEpochEnd3.apply(this, arguments);
	      }
	      return onEpochEnd;
	    }()
	  }]);
	  return BaseLogger;
	}(BaseCallback);
	/**
	 * Callback that records events into a `History` object. This callback is
	 * automatically applied to every TF.js Layers model. The `History` object
	 * gets returned by the `fit` method of models.
	 */
	var History = /*#__PURE__*/function (_BaseCallback2) {
	  _inherits(History, _BaseCallback2);
	  var _super2 = _createSuper(History);
	  function History() {
	    _classCallCheck(this, History);
	    return _super2.apply(this, arguments);
	  }
	  _createClass(History, [{
	    key: "onTrainBegin",
	    value: function () {
	      var _onTrainBegin3 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee16(logs) {
	        return _regeneratorRuntime().wrap(function _callee16$(_context18) {
	          while (1) switch (_context18.prev = _context18.next) {
	            case 0:
	              this.epoch = [];
	              this.history = {};
	            case 2:
	            case "end":
	              return _context18.stop();
	          }
	        }, _callee16, this);
	      }));
	      function onTrainBegin(_x26) {
	        return _onTrainBegin3.apply(this, arguments);
	      }
	      return onTrainBegin;
	    }()
	  }, {
	    key: "onEpochEnd",
	    value: function () {
	      var _onEpochEnd4 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee17(epoch, logs) {
	        var key;
	        return _regeneratorRuntime().wrap(function _callee17$(_context19) {
	          while (1) switch (_context19.prev = _context19.next) {
	            case 0:
	              if (logs == null) {
	                logs = {};
	              }
	              this.epoch.push(epoch);
	              for (key in logs) {
	                if (this.history[key] == null) {
	                  this.history[key] = [];
	                }
	                this.history[key].push(logs[key]);
	              }
	            case 3:
	            case "end":
	              return _context19.stop();
	          }
	        }, _callee17, this);
	      }));
	      function onEpochEnd(_x27, _x28) {
	        return _onEpochEnd4.apply(this, arguments);
	      }
	      return onEpochEnd;
	    }()
	    /**
	     * Await the values of all losses and metrics.
	     */
	  }, {
	    key: "syncData",
	    value: function () {
	      var _syncData = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee18() {
	        var promises, keys, indices, key, valueArray, i, valueScalar, values, n, tensorToDispose;
	        return _regeneratorRuntime().wrap(function _callee18$(_context20) {
	          while (1) switch (_context20.prev = _context20.next) {
	            case 0:
	              promises = [];
	              keys = [];
	              indices = [];
	              for (key in this.history) {
	                valueArray = this.history[key];
	                for (i = 0; i < valueArray.length; ++i) {
	                  if (typeof valueArray[i] !== 'number') {
	                    valueScalar = valueArray[i];
	                    promises.push(valueScalar.data());
	                    keys.push(key);
	                    indices.push(i);
	                  }
	                }
	              }
	              _context20.next = 6;
	              return Promise.all(promises);
	            case 6:
	              values = _context20.sent;
	              for (n = 0; n < values.length; ++n) {
	                tensorToDispose = this.history[keys[n]][indices[n]];
	                tensorToDispose.dispose();
	                this.history[keys[n]][indices[n]] = values[n][0];
	              }
	            case 8:
	            case "end":
	              return _context20.stop();
	          }
	        }, _callee18, this);
	      }));
	      function syncData() {
	        return _syncData.apply(this, arguments);
	      }
	      return syncData;
	    }()
	  }]);
	  return History;
	}(BaseCallback);
	/**
	 * Custom callback for training.
	 */
	var CustomCallback = /*#__PURE__*/function (_BaseCallback3) {
	  _inherits(CustomCallback, _BaseCallback3);
	  var _super3 = _createSuper(CustomCallback);
	  function CustomCallback(args, yieldEvery) {
	    var _this3;
	    _classCallCheck(this, CustomCallback);
	    _this3 = _super3.call(this);
	    _this3.currentEpoch = 0;
	    _this3.nowFunc = args.nowFunc;
	    _this3.nextFrameFunc = args.nextFrameFunc || nextFrame;
	    _this3.yieldEvery = yieldEvery || 'auto';
	    if (_this3.yieldEvery === 'auto') {
	      _this3.yieldEvery = DEFAULT_YIELD_EVERY_MS;
	    }
	    if (_this3.yieldEvery === 'never' && args.onYield != null) {
	      throw new Error('yieldEvery is `never` but you provided an `onYield` callback. ' + 'Either change `yieldEvery` or remove the callback');
	    }
	    if (isNumber(_this3.yieldEvery)) {
	      // Decorate `maybeWait` so it will be called at most once every
	      // `yieldEvery` ms.
	      _this3.maybeWait = debounce(_this3.maybeWait.bind(_assertThisInitialized(_this3)), _this3.yieldEvery, _this3.nowFunc);
	    }
	    _this3.trainBegin = args.onTrainBegin;
	    _this3.trainEnd = args.onTrainEnd;
	    _this3.epochBegin = args.onEpochBegin;
	    _this3.epochEnd = args.onEpochEnd;
	    _this3.batchBegin = args.onBatchBegin;
	    _this3.batchEnd = args.onBatchEnd;
	    _this3.yield = args.onYield;
	    return _this3;
	  }
	  _createClass(CustomCallback, [{
	    key: "maybeWait",
	    value: function () {
	      var _maybeWait = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee19(epoch, batch, logs) {
	        var ps;
	        return _regeneratorRuntime().wrap(function _callee19$(_context21) {
	          while (1) switch (_context21.prev = _context21.next) {
	            case 0:
	              ps = [];
	              if (!(this.yield != null)) {
	                _context21.next = 5;
	                break;
	              }
	              _context21.next = 4;
	              return resolveScalarsInLogs(logs);
	            case 4:
	              ps.push(this.yield(epoch, batch, logs));
	            case 5:
	              ps.push(this.nextFrameFunc());
	              _context21.next = 8;
	              return Promise.all(ps);
	            case 8:
	            case "end":
	              return _context21.stop();
	          }
	        }, _callee19, this);
	      }));
	      function maybeWait(_x29, _x30, _x31) {
	        return _maybeWait.apply(this, arguments);
	      }
	      return maybeWait;
	    }()
	  }, {
	    key: "onEpochBegin",
	    value: function () {
	      var _onEpochBegin4 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee20(epoch, logs) {
	        return _regeneratorRuntime().wrap(function _callee20$(_context22) {
	          while (1) switch (_context22.prev = _context22.next) {
	            case 0:
	              this.currentEpoch = epoch;
	              if (!(this.epochBegin != null)) {
	                _context22.next = 6;
	                break;
	              }
	              _context22.next = 4;
	              return resolveScalarsInLogs(logs);
	            case 4:
	              _context22.next = 6;
	              return this.epochBegin(epoch, logs);
	            case 6:
	            case "end":
	              return _context22.stop();
	          }
	        }, _callee20, this);
	      }));
	      function onEpochBegin(_x32, _x33) {
	        return _onEpochBegin4.apply(this, arguments);
	      }
	      return onEpochBegin;
	    }()
	  }, {
	    key: "onEpochEnd",
	    value: function () {
	      var _onEpochEnd5 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee21(epoch, logs) {
	        var ps;
	        return _regeneratorRuntime().wrap(function _callee21$(_context23) {
	          while (1) switch (_context23.prev = _context23.next) {
	            case 0:
	              ps = [];
	              if (!(this.epochEnd != null)) {
	                _context23.next = 5;
	                break;
	              }
	              _context23.next = 4;
	              return resolveScalarsInLogs(logs);
	            case 4:
	              ps.push(this.epochEnd(epoch, logs));
	            case 5:
	              if (this.yieldEvery === 'epoch') {
	                ps.push(this.nextFrameFunc());
	              }
	              _context23.next = 8;
	              return Promise.all(ps);
	            case 8:
	            case "end":
	              return _context23.stop();
	          }
	        }, _callee21, this);
	      }));
	      function onEpochEnd(_x34, _x35) {
	        return _onEpochEnd5.apply(this, arguments);
	      }
	      return onEpochEnd;
	    }()
	  }, {
	    key: "onBatchBegin",
	    value: function () {
	      var _onBatchBegin3 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee22(batch, logs) {
	        return _regeneratorRuntime().wrap(function _callee22$(_context24) {
	          while (1) switch (_context24.prev = _context24.next) {
	            case 0:
	              if (!(this.batchBegin != null)) {
	                _context24.next = 5;
	                break;
	              }
	              _context24.next = 3;
	              return resolveScalarsInLogs(logs);
	            case 3:
	              _context24.next = 5;
	              return this.batchBegin(batch, logs);
	            case 5:
	            case "end":
	              return _context24.stop();
	          }
	        }, _callee22, this);
	      }));
	      function onBatchBegin(_x36, _x37) {
	        return _onBatchBegin3.apply(this, arguments);
	      }
	      return onBatchBegin;
	    }()
	  }, {
	    key: "onBatchEnd",
	    value: function () {
	      var _onBatchEnd4 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee23(batch, logs) {
	        var ps;
	        return _regeneratorRuntime().wrap(function _callee23$(_context25) {
	          while (1) switch (_context25.prev = _context25.next) {
	            case 0:
	              ps = [];
	              if (!(this.batchEnd != null)) {
	                _context25.next = 5;
	                break;
	              }
	              _context25.next = 4;
	              return resolveScalarsInLogs(logs);
	            case 4:
	              ps.push(this.batchEnd(batch, logs));
	            case 5:
	              if (this.yieldEvery === 'batch') {
	                ps.push(this.nextFrameFunc());
	              } else if (isNumber(this.yieldEvery)) {
	                ps.push(this.maybeWait(this.currentEpoch, batch, logs));
	              }
	              _context25.next = 8;
	              return Promise.all(ps);
	            case 8:
	            case "end":
	              return _context25.stop();
	          }
	        }, _callee23, this);
	      }));
	      function onBatchEnd(_x38, _x39) {
	        return _onBatchEnd4.apply(this, arguments);
	      }
	      return onBatchEnd;
	    }()
	  }, {
	    key: "onTrainBegin",
	    value: function () {
	      var _onTrainBegin4 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee24(logs) {
	        return _regeneratorRuntime().wrap(function _callee24$(_context26) {
	          while (1) switch (_context26.prev = _context26.next) {
	            case 0:
	              if (!(this.trainBegin != null)) {
	                _context26.next = 5;
	                break;
	              }
	              _context26.next = 3;
	              return resolveScalarsInLogs(logs);
	            case 3:
	              _context26.next = 5;
	              return this.trainBegin(logs);
	            case 5:
	            case "end":
	              return _context26.stop();
	          }
	        }, _callee24, this);
	      }));
	      function onTrainBegin(_x40) {
	        return _onTrainBegin4.apply(this, arguments);
	      }
	      return onTrainBegin;
	    }()
	  }, {
	    key: "onTrainEnd",
	    value: function () {
	      var _onTrainEnd3 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee25(logs) {
	        return _regeneratorRuntime().wrap(function _callee25$(_context27) {
	          while (1) switch (_context27.prev = _context27.next) {
	            case 0:
	              if (!(this.trainEnd != null)) {
	                _context27.next = 5;
	                break;
	              }
	              _context27.next = 3;
	              return resolveScalarsInLogs(logs);
	            case 3:
	              _context27.next = 5;
	              return this.trainEnd(logs);
	            case 5:
	            case "end":
	              return _context27.stop();
	          }
	        }, _callee25, this);
	      }));
	      function onTrainEnd(_x41) {
	        return _onTrainEnd3.apply(this, arguments);
	      }
	      return onTrainEnd;
	    }()
	  }]);
	  return CustomCallback;
	}(BaseCallback);
	/**
	 * Standardize callbacks or configurations of them to an Array of callbacks.
	 */
	function standardizeCallbacks(callbacks, yieldEvery) {
	  if (callbacks == null) {
	    callbacks = {};
	  }
	  if (callbacks instanceof BaseCallback) {
	    return [callbacks];
	  }
	  if (Array.isArray(callbacks) && callbacks[0] instanceof BaseCallback) {
	    return callbacks;
	  }
	  // Convert custom callback configs to custom callback objects.
	  var callbackConfigs = toList(callbacks);
	  return callbackConfigs.map(function (callbackConfig) {
	    return new CustomCallback(callbackConfig, yieldEvery);
	  });
	}
	/**
	 * A global registry for callback constructors to be used during
	 * LayersModel.fit().
	 */
	var CallbackConstructorRegistry = /*#__PURE__*/function () {
	  /**
	   * Blocks public access to constructor.
	   */
	  function CallbackConstructorRegistry() {
	    _classCallCheck(this, CallbackConstructorRegistry);
	  }
	  /**
	   * Register a tf.LayersModel.fit() callback constructor.
	   *
	   * The registered callback constructor will be used to instantiate
	   * callbacks for every tf.LayersModel.fit() call afterwards.
	   *
	   * @param verbosityLevel Level of verbosity at which the `callbackConstructor`
	   *   is to be reigstered.
	   * @param callbackConstructor A no-arg constructor for `tf.Callback`.
	   * @throws Error, if the same callbackConstructor has been registered before,
	   *   either at the same or a different `verbosityLevel`.
	   */
	  _createClass(CallbackConstructorRegistry, null, [{
	    key: "registerCallbackConstructor",
	    value: function registerCallbackConstructor(verbosityLevel, callbackConstructor) {
	      assert$1(verbosityLevel >= 0 && Number.isInteger(verbosityLevel), function () {
	        return "Verbosity level is expected to be an integer >= 0, " + "but got ".concat(verbosityLevel);
	      });
	      CallbackConstructorRegistry.checkForDuplicate(callbackConstructor);
	      if (CallbackConstructorRegistry.constructors[verbosityLevel] == null) {
	        CallbackConstructorRegistry.constructors[verbosityLevel] = [];
	      }
	      CallbackConstructorRegistry.constructors[verbosityLevel].push(callbackConstructor);
	    }
	  }, {
	    key: "checkForDuplicate",
	    value: function checkForDuplicate(callbackConstructor) {
	      for (var levelName in CallbackConstructorRegistry.constructors) {
	        var constructors = CallbackConstructorRegistry.constructors[+levelName];
	        constructors.forEach(function (ctor) {
	          if (ctor === callbackConstructor) {
	            throw new ValueError('Duplicate callback constructor.');
	          }
	        });
	      }
	    }
	    /**
	     * Clear all registered callback constructors.
	     */
	  }, {
	    key: "clear",
	    value: function clear() {
	      CallbackConstructorRegistry.constructors = {};
	    }
	    /**
	     * Create callbacks using the registered callback constructors.
	     *
	     * Given `verbosityLevel`, all constructors registered at that level or above
	     * will be called and the instantiated callbacks will be used.
	     *
	     * @param verbosityLevel: Level of verbosity.
	     */
	  }, {
	    key: "createCallbacks",
	    value: function createCallbacks(verbosityLevel) {
	      var constructors = [];
	      for (var levelName in CallbackConstructorRegistry.constructors) {
	        var level = +levelName;
	        if (verbosityLevel >= level) {
	          constructors.push.apply(constructors, _toConsumableArray(CallbackConstructorRegistry.constructors[level]));
	        }
	      }
	      return constructors.map(function (ctor) {
	        return new ctor();
	      });
	    }
	  }]);
	  return CallbackConstructorRegistry;
	}();
	CallbackConstructorRegistry.constructors = {};
	function configureCallbacks(callbacks, verbose, epochs, initialEpoch, numTrainSamples, stepsPerEpoch, batchSize, doValidation, callbackMetrics) {
	  var history = new History();
	  var actualCallbacks = [new BaseLogger()].concat(_toConsumableArray(CallbackConstructorRegistry.createCallbacks(verbose)));
	  if (callbacks != null) {
	    actualCallbacks.push.apply(actualCallbacks, _toConsumableArray(callbacks));
	  }
	  actualCallbacks.push(history);
	  var callbackList = new CallbackList(actualCallbacks);
	  // TODO(cais): Figure out when this LayersModel instance can have a
	  // dynamically
	  //   set property called 'callback_model' as in PyKeras.
	  callbackList.setParams({
	    epochs: epochs,
	    initialEpoch: initialEpoch,
	    samples: numTrainSamples,
	    steps: stepsPerEpoch,
	    batchSize: batchSize,
	    verbose: verbose,
	    doValidation: doValidation,
	    metrics: callbackMetrics
	  });
	  return {
	    callbackList: callbackList,
	    history: history
	  };
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	/**
	 * Instantiate a layer from a config dictionary.
	 * @param config dict of the form {class_name: str, config: dict}
	 * @param customObjects dict mapping class names (or function names)
	 *   of custom (non-Keras) objects to class/functions
	 * @param fastWeightInit Optional flag to use fast weight initialization
	 *   during deserialization. This is applicable to cases in which
	 *   the initialization will be immediately overwritten by loaded weight
	 *   values. Default: `false`.
	 * @returns Layer instance (may be LayersModel, Sequential, Layer...)
	 */
	function deserialize(config) {
	  var customObjects = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	  var fastWeightInit = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  return deserializeKerasObject(config, SerializationMap.getMap().classNameMap, customObjects, 'layer', fastWeightInit);
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	/**
	 * Normalizes a tensor wrt the L2 norm alongside the specified axis.
	 * @param x
	 * @param axis Axis along which to perform normalization.
	 */
	function l2Normalize(x, axis) {
	  return tidy(function () {
	    if (x.dtype !== 'float32') {
	      x = cast$3(x, 'float32');
	    }
	    var squareSum = sum$3(square$1(x), axis, true);
	    var epsilonTensor = fill$2(squareSum.shape, epsilon$1());
	    var norm = sqrt$2(maximum$4(squareSum, epsilonTensor));
	    return div$1(x, norm);
	  });
	}
	function meanSquaredError$1(yTrue, yPred) {
	  return tidy(function () {
	    return mean$3(square$1(sub$2(yPred, yTrue)), -1);
	  });
	}
	function meanAbsoluteError$1(yTrue, yPred) {
	  return tidy(function () {
	    return mean$3(abs$2(sub$2(yPred, yTrue)), -1);
	  });
	}
	function meanAbsolutePercentageError$1(yTrue, yPred) {
	  return tidy(function () {
	    var diff = sub$2(yTrue, yPred);
	    var clippedTrue = clipByValue$2(abs$2(yTrue), epsilon$1(), Number.MAX_VALUE);
	    var absResult = abs$2(div$1(diff, clippedTrue));
	    return mul(100, mean$3(absResult, -1));
	  });
	}
	function meanSquaredLogarithmicError(yTrue, yPred) {
	  return tidy(function () {
	    var clippedPred = clipByValue$2(yPred, epsilon$1(), Number.MAX_VALUE);
	    var firstLog = log$2(add$3(1, clippedPred));
	    var clippedTrue = clipByValue$2(yTrue, epsilon$1(), Number.MAX_VALUE);
	    var secondLog = log$2(add$3(1, clippedTrue));
	    return mean$3(square$1(sub$2(firstLog, secondLog)), -1);
	  });
	}
	function squaredHinge(yTrue, yPred) {
	  return tidy(function () {
	    var maxResult = maximum$4(0, sub$2(1, mul(yTrue, yPred)));
	    return mean$3(square$1(maxResult), -1);
	  });
	}
	function hinge(yTrue, yPred) {
	  return tidy(function () {
	    var maxResult = maximum$4(0, sub$2(1, mul(yTrue, yPred)));
	    return mean$3(maxResult, -1);
	  });
	}
	function categoricalHinge(yTrue, yPred) {
	  return tidy(function () {
	    var pos = sum$3(mul(yTrue, yPred), -1);
	    var neg = max$3(mul(sub$2(1, yTrue), yPred), -1);
	    return maximum$4(0, add$3(1, sub$2(neg, pos)));
	  });
	}
	/**
	 * Logarithm of the hyperbolic cosine of the prediction error.
	 *
	 * `log(cosh(x))` is approximately equal to `(x ** 2) / 2` for small `x` and
	 * to `abs(x) - log(2)` for large `x`. This means that 'logcosh' works mostly
	 * like the mean squared error, but will not be so strongly affected by the
	 * occasional wildly incorrect prediction.
	 */
	function logcosh(yTrue, yPred) {
	  return tidy(function () {
	    var log2 = Math.log(2);
	    var predictionDiff = sub$2(yPred, yTrue);
	    var logcoshResult = sub$2(add$3(predictionDiff, softplus$2(mul(-2, predictionDiff))), log2);
	    return mean$3(logcoshResult, -1);
	  });
	}
	function categoricalCrossentropy$2(target, output) {
	  var fromLogits = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  return tidy(function () {
	    if (fromLogits) {
	      output = softmax$3(output);
	    } else {
	      // scale preds so that the class probabilities of each sample sum to 1.
	      var outputSum = sum$3(output, output.shape.length - 1, true);
	      output = div$1(output, outputSum);
	    }
	    output = clipByValue$2(output, epsilon$1(), 1 - epsilon$1());
	    return neg$2(sum$3(mul(cast$3(target, 'float32'), log$2(output)), output.shape.length - 1));
	  });
	}
	/**
	 * Categorical crossentropy with integer targets.
	 *
	 * @param target An integer tensor.
	 * @param output A tensor resulting from a softmax (unless `fromLogits` is
	 *  `true`, in which case `output` is expected to be the logits).
	 * @param fromLogits Boolean, whether `output` is the result of a softmax, or is
	 *   a tensor of logits.
	 */
	function sparseCategoricalCrossentropy$1(target, output) {
	  var fromLogits = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  return tidy(function () {
	    var flatTarget = cast$3(floor$2(flatten$1(target)), 'int32');
	    output = clipByValue$2(output, epsilon$1(), 1 - epsilon$1());
	    var outputShape = output.shape;
	    var oneHotTarget = reshape$3(oneHot$3(flatTarget, outputShape[outputShape.length - 1]), outputShape);
	    return categoricalCrossentropy$2(oneHotTarget, output, fromLogits);
	  });
	}
	/**
	 * From TensorFlow's implementation in nn_impl.py:
	 *
	 * For brevity, let `x = logits`, `z = labels`.  The logistic loss is
	 *      z * -log(sigmoid(x)) + (1 - z) * -log(1 - sigmoid(x))
	 *    = z * -log(1 / (1 + exp(-x))) + (1 - z) * -log(exp(-x) / (1 + exp(-x)))
	 *    = z * log(1 + exp(-x)) + (1 - z) * (-log(exp(-x)) + log(1 + exp(-x)))
	 *    = z * log(1 + exp(-x)) + (1 - z) * (x + log(1 + exp(-x))
	 *    = (1 - z) * x + log(1 + exp(-x))
	 *    = x - x * z + log(1 + exp(-x))
	 * For x < 0, to avoid overflow in exp(-x), we reformulate the above
	 *      x - x * z + log(1 + exp(-x))
	 *    = log(exp(x)) - x * z + log(1 + exp(-x))
	 *    = - x * z + log(1 + exp(x))
	 * Hence, to ensure stability and avoid overflow, the implementation uses this
	 * equivalent formulation
	 *    max(x, 0) - x * z + log(1 + exp(-abs(x)))
	 *
	 * @param labels The labels.
	 * @param logits The logits.
	 */
	function sigmoidCrossEntropyWithLogits(labels, logits) {
	  if (!arraysEqual(labels.shape, logits.shape)) {
	    throw new ValueError("logits and labels must have the same shape, but got shapes " + "".concat(JSON.stringify(labels.shape), " and ").concat(JSON.stringify(logits.shape)));
	  }
	  return tidy(function () {
	    // The logistic loss formula from above is
	    //   x - x * z + log(1 + exp(-x))
	    // For x < 0, a more numerically stable formula is
	    //   -x * z + log(1 + exp(x))
	    // Note that these two expressions can be combined into the following:
	    //   max(x, 0) - x * z + log(1 + exp(-abs(x)))
	    var reluLogits = relu$2(logits);
	    var negAbsLogits = neg$2(abs$2(logits));
	    return add$3(sub$2(reluLogits, mul(logits, labels)), log1p$2(exp$2(negAbsLogits)));
	  });
	}
	function binaryCrossentropy$2(yTrue, yPred) {
	  return tidy(function () {
	    var y;
	    y = clipByValue$2(yPred, epsilon$1(), 1 - epsilon$1());
	    y = log$2(div$1(y, sub$2(1, y)));
	    return mean$3(sigmoidCrossEntropyWithLogits(yTrue, y), -1);
	  });
	}
	function kullbackLeiblerDivergence(yTrue, yPred) {
	  return tidy(function () {
	    var clippedTrue = clipByValue$2(yTrue, epsilon$1(), 1);
	    var clippedPred = clipByValue$2(yPred, epsilon$1(), 1);
	    return sum$3(mul(yTrue, log$2(div$1(clippedTrue, clippedPred))), -1);
	  });
	}
	function poisson(yTrue, yPred) {
	  return tidy(function () {
	    var logPred = log$2(add$3(epsilon$1(), yPred));
	    return mean$3(sub$2(yPred, mul(yTrue, logPred)), -1);
	  });
	}
	function cosineProximity$1(yTrue, yPred) {
	  return tidy(function () {
	    var trueNormalized = l2Normalize(yTrue, -1);
	    var predNormalized = l2Normalize(yPred, -1);
	    var trueXPred = mul(trueNormalized, predNormalized);
	    return neg$2(sum$3(trueXPred, -1));
	  });
	}
	var mse$2 = meanSquaredError$1;
	var MSE$2 = meanSquaredError$1;
	var mae$1 = meanAbsoluteError$1;
	var MAE$1 = meanAbsoluteError$1;
	var mape$2 = meanAbsolutePercentageError$1;
	var MAPE$2 = meanAbsolutePercentageError$1;
	var msle = meanSquaredLogarithmicError;
	var MSLE = meanSquaredLogarithmicError;
	var kld = kullbackLeiblerDivergence;
	var KLD = kullbackLeiblerDivergence;
	var cosine$1 = cosineProximity$1;
	// TODO(michaelterry): Add deserialize() function.
	var lossesMap = {
	  meanSquaredError: meanSquaredError$1,
	  meanAbsoluteError: meanAbsoluteError$1,
	  meanAbsolutePercentageError: meanAbsolutePercentageError$1,
	  meanSquaredLogarithmicError: meanSquaredLogarithmicError,
	  squaredHinge: squaredHinge,
	  hinge: hinge,
	  categoricalHinge: categoricalHinge,
	  logcosh: logcosh,
	  categoricalCrossentropy: categoricalCrossentropy$2,
	  sparseCategoricalCrossentropy: sparseCategoricalCrossentropy$1,
	  binaryCrossentropy: binaryCrossentropy$2,
	  kullbackLeiblerDivergence: kullbackLeiblerDivergence,
	  poisson: poisson,
	  cosineProximity: cosineProximity$1
	};
	// Porting note: This diverges from the PyKeras implementation and may need to
	// change based on (de)serialization requirements.
	function get$1(identifierOrFn) {
	  if (typeof identifierOrFn === 'string') {
	    if (identifierOrFn in lossesMap) {
	      return lossesMap[identifierOrFn];
	    }
	    var errMsg = "Unknown loss ".concat(identifierOrFn);
	    if (identifierOrFn.toLowerCase().includes('softmaxcrossentropy')) {
	      errMsg = "Unknown loss ".concat(identifierOrFn, ". ") + 'Use "categoricalCrossentropy" as the string name for ' + 'tf.losses.softmaxCrossEntropy';
	    }
	    throw new ValueError(errMsg);
	  } else {
	    return identifierOrFn;
	  }
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	function binaryAccuracy$1(yTrue, yPred) {
	  return tidy(function () {
	    var threshold = mul(.5, onesLike$3(yPred));
	    var yPredThresholded = cast$2(greater$3(yPred, threshold), yTrue.dtype);
	    return mean$3(equal$2(yTrue, yPredThresholded), -1);
	  });
	}
	function categoricalAccuracy$1(yTrue, yPred) {
	  return tidy(function () {
	    return cast$2(equal$2(argMax$2(yTrue, -1), argMax$2(yPred, -1)), 'float32');
	  });
	}
	function truePositives(yTrue, yPred) {
	  return tidy(function () {
	    return cast$3(sum$3(logicalAnd$2(equal$2(yTrue, 1), equal$2(yPred, 1))), 'float32');
	  });
	}
	function falseNegatives(yTrue, yPred) {
	  return tidy(function () {
	    return cast$3(sum$3(logicalAnd$2(equal$2(yTrue, 1), equal$2(yPred, 0))), 'float32');
	  });
	}
	function falsePositives(yTrue, yPred) {
	  return tidy(function () {
	    return cast$3(sum$3(logicalAnd$2(equal$2(yTrue, 0), equal$2(yPred, 1))), 'float32');
	  });
	}
	function precision$1(yTrue, yPred) {
	  return tidy(function () {
	    var tp = truePositives(yTrue, yPred);
	    var fp = falsePositives(yTrue, yPred);
	    var denominator = add$3(tp, fp);
	    return cast$3(where(greater$3(denominator, 0), div$1(tp, denominator), 0), 'float32');
	  });
	}
	function recall$1(yTrue, yPred) {
	  return tidy(function () {
	    var tp = truePositives(yTrue, yPred);
	    var fn = falseNegatives(yTrue, yPred);
	    var denominator = add$3(tp, fn);
	    return cast$3(where(greater$3(denominator, 0), div$1(tp, denominator), 0), 'float32');
	  });
	}
	function binaryCrossentropy$1(yTrue, yPred) {
	  return binaryCrossentropy$2(yTrue, yPred);
	}
	function sparseCategoricalAccuracy$1(yTrue, yPred) {
	  if (yTrue.rank === yPred.rank) {
	    yTrue = squeeze(yTrue, [yTrue.rank - 1]);
	  }
	  yPred = argMax$2(yPred, -1);
	  if (yPred.dtype !== yTrue.dtype) {
	    yPred = cast$3(yPred, yTrue.dtype);
	  }
	  return cast$3(equal$2(yTrue, yPred), 'float32');
	}
	function topKCategoricalAccuracy(yTrue, yPred) {
	  throw new NotImplementedError();
	}
	function sparseTopKCategoricalAccuracy(yTrue, yPred) {
	  throw new NotImplementedError();
	}
	function r2Score$1(yTrue, yPred) {
	  return tidy(function () {
	    var sumSquaresResiduals = yTrue.sub(yPred).square().sum();
	    var sumSquares = yTrue.sub(yTrue.mean()).square().sum();
	    return scalar(1).sub(sumSquaresResiduals.div(sumSquares));
	  });
	}
	// Aliases.
	var mse$1 = meanSquaredError$1;
	var MSE$1 = meanSquaredError$1;
	var mae = meanAbsoluteError$1;
	var MAE = meanAbsoluteError$1;
	var mape$1 = meanAbsolutePercentageError$1;
	var MAPE$1 = meanAbsolutePercentageError$1;
	var categoricalCrossentropy$1 = categoricalCrossentropy$2;
	var cosine = cosineProximity$1;
	var sparseCategoricalCrossentropy = sparseCategoricalCrossentropy$1;
	// TODO(cais, nielsene): Add serialize().
	var metricsMap = {
	  binaryAccuracy: binaryAccuracy$1,
	  categoricalAccuracy: categoricalAccuracy$1,
	  precision: precision$1,
	  categoricalCrossentropy: categoricalCrossentropy$1,
	  sparseCategoricalCrossentropy: sparseCategoricalCrossentropy,
	  mse: mse$1,
	  MSE: MSE$1,
	  mae: mae,
	  MAE: MAE,
	  mape: mape$1,
	  MAPE: MAPE$1,
	  cosine: cosine
	};
	function get(identifier) {
	  if (typeof identifier === 'string' && identifier in metricsMap) {
	    return metricsMap[identifier];
	  } else if (typeof identifier !== 'string' && identifier != null) {
	    return identifier;
	  } else {
	    throw new ValueError("Unknown metric ".concat(identifier));
	  }
	}
	/**
	 * Get the shortcut function name.
	 *
	 * If the fn name is a string,
	 *   directly return the string name.
	 * If the function is included in metricsMap or lossesMap,
	 *   return key of the map.
	 *   - If the function relative to multiple keys,
	 *     return the first found key as the function name.
	 *   - If the function exists in both lossesMap and metricsMap,
	 *     search lossesMap first.
	 * If the function is not included in metricsMap or lossesMap,
	 *   return the function name.
	 *
	 * @param fn loss function, metric function, or short cut name.
	 * @returns Loss or Metric name in string.
	 */
	function getLossOrMetricName(fn) {
	  assert(fn !== null, "Unknown LossOrMetricFn ".concat(fn));
	  if (typeof fn === 'string') {
	    return fn;
	  } else {
	    var fnName;
	    for (var _i = 0, _Object$keys = Object.keys(lossesMap); _i < _Object$keys.length; _i++) {
	      var key = _Object$keys[_i];
	      if (lossesMap[key] === fn) {
	        fnName = key;
	        break;
	      }
	    }
	    if (fnName !== undefined) {
	      return fnName;
	    }
	    for (var _i2 = 0, _Object$keys2 = Object.keys(metricsMap); _i2 < _Object$keys2.length; _i2++) {
	      var _key = _Object$keys2[_i2];
	      if (metricsMap[_key] === fn) {
	        fnName = _key;
	        break;
	      }
	    }
	    if (fnName !== undefined) {
	      return fnName;
	    }
	    return fn.name;
	  }
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	// Add (de)serialize()
	// Porting note: This diverges from the PyKeras implementation and may need to
	// change based on (de)serialization requirements.
	function getOptimizer(identifier) {
	  var optimizerMap = {
	    'Adagrad': function Adagrad() {
	      return train.adagrad(0.01);
	    },
	    'Adadelta': function Adadelta() {
	      return train.adadelta(1, 0.95, epsilon$1());
	    },
	    'Adam': function Adam() {
	      return train.adam(0.001, 0.9, 0.999, epsilon$1());
	    },
	    'Adamax': function Adamax() {
	      return train.adamax(0.002, 0.9, 0.999, epsilon$1(), 0);
	    },
	    'RMSProp': function RMSProp() {
	      return train.rmsprop(0.001, 0.9, 0, epsilon$1());
	    },
	    'SGD': function SGD() {
	      return train.sgd(0.01);
	    }
	  };
	  optimizerMap['adagrad'] = optimizerMap['Adagrad'];
	  optimizerMap['adadelta'] = optimizerMap['Adadelta'];
	  optimizerMap['adam'] = optimizerMap['Adam'];
	  optimizerMap['adamax'] = optimizerMap['Adamax'];
	  optimizerMap['rmsprop'] = optimizerMap['RMSProp'];
	  optimizerMap['sgd'] = optimizerMap['SGD'];
	  if (identifier in optimizerMap) {
	    return optimizerMap[identifier]();
	  }
	  throw new ValueError("Unknown Optimizer ".concat(identifier));
	}

	/**
	 * @license
	 * Copyright 2019 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	/** Utility functions related to user-defined metadata. */
	// Maximum recommended serialized size for user-defined metadata.
	// Beyond this limit, a warning message will be printed during model loading and
	// saving.
	var MAX_USER_DEFINED_METADATA_SERIALIZED_LENGTH = 1 * 1024 * 1024;
	/**
	 * Check validity of user-defined metadata.
	 *
	 * @param userDefinedMetadata
	 * @param modelName Name of the model that the user-defined metadata belongs to.
	 *   Used during construction of error messages.
	 * @param checkSize Whether to check the size of the metadata is under
	 *   recommended limit. Default: `false`. If `true`, will try stringify the
	 *   JSON object and print a console warning if the serialzied size is above the
	 *   limit.
	 * @throws Error if `userDefinedMetadata` is not a plain JSON object.
	 */
	function checkUserDefinedMetadata(userDefinedMetadata, modelName) {
	  var checkSize = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  if (userDefinedMetadata == null || _typeof(userDefinedMetadata) !== 'object' || Object.getPrototypeOf(userDefinedMetadata) !== Object.prototype || !plainObjectCheck(userDefinedMetadata)) {
	    throw new Error('User-defined metadata is expected to be a JSON object, but is not.');
	  }
	  if (checkSize) {
	    var out = JSON.stringify(userDefinedMetadata);
	    if (out.length > MAX_USER_DEFINED_METADATA_SERIALIZED_LENGTH) {
	      console.warn("User-defined metadata of model \"".concat(modelName, "\" is too large in ") + "size (length=".concat(out.length, " when serialized). It is not ") + "recommended to store such large objects in user-defined metadata. " + "Please make sure its serialized length is <= " + "".concat(MAX_USER_DEFINED_METADATA_SERIALIZED_LENGTH, "."));
	    }
	  }
	}
	/**
	 * Check if an input is plain JSON object or any valid subfield of it.
	 *
	 * @param x The input to be checked.
	 * @param assertObject Whether to assert `x` is a JSON object, i.e., reject
	 *   cases of arrays and primitives.
	 * @return Returns `true` if and only if `x` is a plain JSON object,
	 *   a JSON-valid primitive including string, number, boolean and null,
	 *   or an array of the said types.
	 */
	// tslint:disable-next-line:no-any
	function plainObjectCheck(x) {
	  if (x === null) {
	    // Note: typeof `null` is 'object', and `null` is valid in JSON.
	    return true;
	  } else if (_typeof(x) === 'object') {
	    if (Object.getPrototypeOf(x) === Object.prototype) {
	      // `x` is a JavaScript object and its prototype is Object.
	      var keys = Object.keys(x);
	      for (var _i = 0, _keys = keys; _i < _keys.length; _i++) {
	        var key = _keys[_i];
	        if (typeof key !== 'string') {
	          // JSON keys must be strings.
	          return false;
	        }
	        if (!plainObjectCheck(x[key])) {
	          // Recursive call.
	          return false;
	        }
	      }
	      return true;
	    } else {
	      // `x` is a JavaScript object but its prototype is not Object.
	      if (Array.isArray(x)) {
	        // `x` is a JavaScript array.
	        var _iterator = _createForOfIteratorHelper(x),
	          _step;
	        try {
	          for (_iterator.s(); !(_step = _iterator.n()).done;) {
	            var item = _step.value;
	            if (!plainObjectCheck(item)) {
	              // Recursive call.
	              return false;
	            }
	          }
	        } catch (err) {
	          _iterator.e(err);
	        } finally {
	          _iterator.f();
	        }
	        return true;
	      } else {
	        // `x` is a JavaScript object and its prototype is not Object,
	        // and it's not an Array. I.e., it's a complex object such as
	        // `Error` and `Date`.
	        return false;
	      }
	    }
	  } else {
	    // `x` is not a JavaScript object or `null`.
	    var xType = _typeof(x);
	    return xType === 'string' || xType === 'number' || xType === 'boolean';
	  }
	}

	/**
	 * Print the summary of a LayersModel object.
	 *
	 * @param model tf.LayersModel instance.
	 * @param lineLength Total length of printed lines. Set this to adapt to the
	 *   display to different terminal or console sizes.
	 * @param positions Relative or absolute positions of log elements in each
	 *   line. Each number corresponds to right-most (i.e., ending) position of a
	 *   column.
	 *   If not provided, defaults to `[0.45, 0.85, 1]` for sequential-like
	 *   models and `[0.33, 0.55, 0.67, 1]` for non-sequential like models.
	 * @param printFn Print function to use.
	 *   It will be called on each line of the summary. You can provide a custom
	 *   function in order to capture the string summary. Defaults to `console.log`.
	 */
	function printSummary(model, lineLength, positions) {
	  var printFn = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : console.log;
	  var sequentialLike = isModelSequentialLike(model);
	  // Header names for different log elements.
	  var toDisplay = ['Layer (type)', 'Input Shape', 'Output shape', 'Param #'];
	  if (sequentialLike) {
	    lineLength = lineLength || 90;
	    positions = positions || [0.32, 0.61, 0.89, 1];
	  } else {
	    lineLength = lineLength || 115;
	    positions = positions || [0.24, 0.48, 0.70, 0.80, 1];
	    // Header names for different log elements.
	  }

	  if (positions[positions.length - 1] <= 1) {
	    // `positions` is relative. Convert it to absolute positioning.
	    positions = positions.map(function (p) {
	      return Math.floor(lineLength * p);
	    });
	  }
	  var relevantNodes;
	  if (!sequentialLike) {
	    toDisplay.push('Receives inputs');
	    relevantNodes = [];
	    for (var depth in model.nodesByDepth) {
	      var _relevantNodes;
	      (_relevantNodes = relevantNodes).push.apply(_relevantNodes, _toConsumableArray(model.nodesByDepth[depth]));
	    }
	  }
	  printFn('_'.repeat(lineLength));
	  printRow(toDisplay, positions, printFn);
	  printFn('='.repeat(lineLength));
	  var layers = model.layers;
	  for (var i = 0; i < layers.length; ++i) {
	    if (sequentialLike) {
	      printLayerSummary(layers[i], positions, printFn);
	    } else {
	      printLayerSummaryWithConnections(layers[i], positions, relevantNodes, printFn);
	    }
	    printFn((i === layers.length - 1 ? '=' : '_').repeat(lineLength));
	  }
	  // tslint:disable-next-line:no-any
	  model.checkTrainableWeightsConsistency();
	  var trainableCount = countTrainableParams(model);
	  var nonTrainableCount = countParamsInWeights(model.nonTrainableWeights);
	  printFn("Total params: ".concat(trainableCount + nonTrainableCount));
	  printFn("Trainable params: ".concat(trainableCount));
	  printFn("Non-trainable params: ".concat(nonTrainableCount));
	  printFn('_'.repeat(lineLength));
	}
	function countTrainableParams(model) {
	  var trainableCount;
	  // tslint:disable:no-any
	  if (model.collectedTrainableWeights != null) {
	    trainableCount = countParamsInWeights(model.collectedTrainableWeights);
	  } else {
	    trainableCount = countParamsInWeights(model.trainableWeights);
	  }
	  // tslint:enable:no-any
	  return trainableCount;
	}
	function isModelSequentialLike(model) {
	  var sequentialLike = true;
	  var nodesByDepth = [];
	  var nodes = [];
	  for (var depth in model.nodesByDepth) {
	    nodesByDepth.push(model.nodesByDepth[depth]);
	  }
	  for (var _i = 0, _nodesByDepth = nodesByDepth; _i < _nodesByDepth.length; _i++) {
	    var depthNodes = _nodesByDepth[_i];
	    if (depthNodes.length > 1 || depthNodes.length === 1 && depthNodes[0].inboundLayers.length > 1) {
	      sequentialLike = false;
	      break;
	    }
	    nodes.push.apply(nodes, _toConsumableArray(depthNodes));
	  }
	  if (sequentialLike) {
	    // Search for shared layers.
	    var _iterator = _createForOfIteratorHelper(model.layers),
	      _step;
	    try {
	      for (_iterator.s(); !(_step = _iterator.n()).done;) {
	        var layer = _step.value;
	        var flag = false;
	        var _iterator2 = _createForOfIteratorHelper(layer.inboundNodes),
	          _step2;
	        try {
	          for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	            var node = _step2.value;
	            if (nodes.indexOf(node) !== -1) {
	              if (flag) {
	                sequentialLike = false;
	                break;
	              } else {
	                flag = true;
	              }
	            }
	          }
	        } catch (err) {
	          _iterator2.e(err);
	        } finally {
	          _iterator2.f();
	        }
	        if (!sequentialLike) {
	          break;
	        }
	      }
	    } catch (err) {
	      _iterator.e(err);
	    } finally {
	      _iterator.f();
	    }
	  }
	  return sequentialLike;
	}
	function printRow(fields, positions) {
	  var printFn = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : console.log;
	  var line = '';
	  for (var i = 0; i < fields.length; ++i) {
	    if (i > 0) {
	      line = line.slice(0, line.length - 1) + ' ';
	    }
	    line += fields[i];
	    line = line.slice(0, positions[i]);
	    line += ' '.repeat(positions[i] - line.length);
	  }
	  printFn(line);
	}
	/**
	 * Prints a summary for a single Layer, without connectivity information.
	 *
	 * @param layer: Layer instance to print.
	 */
	function printLayerSummary(layer, positions,
	// tslint:disable-next-line:no-any
	printFn) {
	  var outputShape;
	  var inputShape;
	  try {
	    inputShape = layer.inboundNodes.map(function (x) {
	      return JSON.stringify(x.inputShapes);
	    }).join(',');
	  } catch (err) {
	    inputShape = 'multiple';
	  }
	  try {
	    outputShape = JSON.stringify(layer.outputShape);
	  } catch (err) {
	    outputShape = 'multiple';
	  }
	  var name = layer.name;
	  var className = layer.getClassName();
	  var fields = ["".concat(name, " (").concat(className, ")"), inputShape, outputShape, layer.countParams().toString()];
	  printRow(fields, positions, printFn);
	}
	/**
	 * Prints a summary for a single Layer, with connectivity information.
	 */
	function printLayerSummaryWithConnections(layer, positions, relevantNodes,
	// tslint:disable-next-line:no-any
	printFn) {
	  var outputShape;
	  var inputShape;
	  try {
	    inputShape = layer.inboundNodes.map(function (x) {
	      return JSON.stringify(x.inputShapes);
	    }).join(',');
	  } catch (err) {
	    inputShape = 'multiple';
	  }
	  try {
	    outputShape = JSON.stringify(layer.outputShape);
	  } catch (err) {
	    outputShape = 'multiple';
	  }
	  var connections = [];
	  var _iterator3 = _createForOfIteratorHelper(layer.inboundNodes),
	    _step3;
	  try {
	    for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
	      var node = _step3.value;
	      if (relevantNodes != null && relevantNodes.length > 0 && relevantNodes.indexOf(node) === -1) {
	        continue;
	      }
	      for (var _i2 = 0; _i2 < node.inboundLayers.length; ++_i2) {
	        var inboundLayer = node.inboundLayers[_i2].name;
	        var inboundLayerIndex = node.nodeIndices[_i2];
	        var inboundTensorIndex = node.tensorIndices[_i2];
	        connections.push("".concat(inboundLayer, "[").concat(inboundLayerIndex, "][").concat(inboundTensorIndex, "]"));
	      }
	    }
	  } catch (err) {
	    _iterator3.e(err);
	  } finally {
	    _iterator3.f();
	  }
	  var name = layer.name;
	  var className = layer.getClassName();
	  var firstConnection = connections.length === 0 ? '' : connections[0];
	  var fields = ["".concat(name, " (").concat(className, ")"), inputShape, outputShape, layer.countParams().toString(), firstConnection];
	  printRow(fields, positions, printFn);
	  for (var i = 1; i < connections.length; ++i) {
	    printRow(['', '', '', '', connections[i]], positions, printFn);
	  }
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	// tslint:enable
	/**
	 * Test whether a value in an array is the name of a LayersModel or Layer.
	 * @param key The key name that the value is found under. Note that the key
	 *   may not be at the level immediately above the value, if the value is in a
	 *   nested array.
	 * @param index Index of the value in the Array that it is found in.
	 * @param value The value object.
	 * @returns A boolean indicating whether value is a name.
	 */
	function isArrayItemInputOrOutputName(key, index, value) {
	  return (key === 'inboundNodes' || key === 'outputLayers' || key === 'inputLayers') && index === 0 && typeof value === 'string';
	}
	/**
	 * Convert a Pythonic config object to TypeScript config object.
	 * @param pythonicConfig The config object to convert.
	 * @param key Optional key name of the object being converted.
	 * @returns Result of the conversion.
	 */
	function convertPythonicToTs(pythonicConfig, key) {
	  if (pythonicConfig === null) {
	    return null;
	  } else if (typeof pythonicConfig === 'string') {
	    return toCamelCase(pythonicConfig);
	  } else if (typeof pythonicConfig === 'number' || typeof pythonicConfig === 'boolean') {
	    return pythonicConfig;
	  } else if (pythonicConfig instanceof Array) {
	    var tsArray = [];
	    var arrayLength = pythonicConfig.length;
	    for (var i = 0; i < arrayLength; ++i) {
	      var item = pythonicConfig[i];
	      if (isArrayItemInputOrOutputName(key, i, item)) {
	        tsArray.push(item);
	      } else {
	        tsArray.push(convertPythonicToTs(item, key));
	      }
	    }
	    return tsArray;
	  } else {
	    var tsDict = {};
	    for (var _i = 0, _Object$keys = Object.keys(pythonicConfig); _i < _Object$keys.length; _i++) {
	      var pythonicKey = _Object$keys[_i];
	      var pythonicValue = pythonicConfig[pythonicKey];
	      if (pythonicKey === 'name' && typeof pythonicValue === 'string') {
	        // Special case the 'name' key with a string value. Name values, such as
	        // the names of LayersModel and Layer instances, should not undergo the
	        // camel-case conversion.
	        tsDict[pythonicKey] = pythonicValue;
	      } else {
	        var tsKey = toCamelCase(pythonicKey);
	        tsDict[tsKey] = convertPythonicToTs(pythonicValue, tsKey);
	      }
	    }
	    return tsDict;
	  }
	}
	/**
	 * Convert a TypeScript config object to Python config object.
	 * @param tsConfig The config object to convert.
	 * @param key Optional key name of the object being converted.
	 * @returns Result of the conversion.
	 */
	function convertTsToPythonic(tsConfig, key) {
	  if (tsConfig === null || tsConfig === undefined) {
	    return null;
	  } else if (typeof tsConfig === 'string') {
	    return toSnakeCase(tsConfig);
	  } else if (typeof tsConfig === 'number' || typeof tsConfig === 'boolean') {
	    return tsConfig;
	  } else if (tsConfig instanceof Array) {
	    var pyArray = [];
	    var arrayLength = tsConfig.length;
	    for (var i = 0; i < arrayLength; ++i) {
	      var item = tsConfig[i];
	      if (isArrayItemInputOrOutputName(key, i, item)) {
	        pyArray.push(item);
	      } else {
	        pyArray.push(convertTsToPythonic(item, key));
	      }
	    }
	    return pyArray;
	  } else {
	    var pyDict = {};
	    for (var _i2 = 0, _Object$keys2 = Object.keys(tsConfig); _i2 < _Object$keys2.length; _i2++) {
	      var tsKey = _Object$keys2[_i2];
	      var tsValue = tsConfig[tsKey];
	      var pyKey = toSnakeCase(tsKey);
	      if ((tsKey === 'name' || tsKey === 'className') && typeof tsValue === 'string') {
	        // Special case the 'name' key with a string value. Name values, such as
	        // the names of LayersModel and Layer instances, should not undergo the
	        // snake-case conversion.
	        pyDict[pyKey] = tsValue;
	      } else {
	        pyDict[pyKey] = convertTsToPythonic(tsValue, tsKey);
	      }
	    }
	    return pyDict;
	  }
	}

	/** @license See the LICENSE file. */
	// This code is auto-generated, do not modify this file!
	var version$6 = '4.22.0';

	// get weights key from tensor map in order to check if it is from keras v3.
	// e.g. dense/0
	var isKerasSavedModelFormat = function isKerasSavedModelFormat(weights) {
	  var keys = Object.keys(weights);
	  if (keys.length === 0) {
	    return false;
	  }
	  var key = keys[0].split('/');
	  return !isNaN(parseInt(key[key.length - 1], 10));
	};
	/**
	 * A Container is a directed acyclic graph of layers.
	 *
	 * It is the topological form of a "model". A LayersModel
	 * is simply a Container with added training routines.
	 *
	 */
	var Container = /*#__PURE__*/function (_Layer) {
	  _inherits(Container, _Layer);
	  var _super = _createSuper(Container);
	  function Container(args) {
	    var _this;
	    _classCallCheck(this, Container);
	    // No args passed to super's constructor.
	    _this = _super.call(this, {});
	    _this.containerNodes = new Set();
	    _this.name = args.name;
	    if (_this.name == null) {
	      var prefix = _this.getClassName().toLowerCase();
	      _this.name = getUid(prefix);
	    }
	    _this.supportsMasking = false;
	    _this.trainable_ = true;
	    // TODO(michaelterry): Initialize perInputLosses/Updates here.
	    // Container-specific properties.
	    if (Array.isArray(args.inputs)) {
	      _this.inputs = args.inputs.slice();
	    } else {
	      _this.inputs = [args.inputs];
	    }
	    if (Array.isArray(args.outputs)) {
	      _this.outputs = args.outputs.slice();
	    } else {
	      _this.outputs = [args.outputs];
	    }
	    // Check for redundancy in inputs.
	    if (unique$2(_this.inputs).length !== _this.inputs.length) {
	      throw new ValueError('The list of inputs passed to the model is ' + 'redundant. All inputs should only appear once. Found: ' + "".concat(_this.inputs.map(function (x) {
	        return x.name;
	      })));
	    }
	    // Check for redundancy in outputs.
	    if (unique$2(_this.outputs).length !== _this.outputs.length) {
	      console.warn('The list of outputs passed to the model is redundant. ' + 'All outputs should only appear once. Found: ' + "".concat(_this.outputs.map(function (x) {
	        return x.name;
	      })));
	    }
	    /*
	      List of initial layers (1 to 1 mapping with this.inputs, hence the same
	      layer might appear twice)
	    */
	    _this.inputLayers = [];
	    _this.inputLayersNodeIndices = [];
	    _this.inputLayersTensorIndices = [];
	    /*
	      List of layers (1 to 1 mapping with this.outputs, hence the same layer
	      might appear twice)
	    */
	    _this.outputLayers = [];
	    _this.outputLayersNodeIndices = [];
	    _this.outputLayersTensorIndices = [];
	    /*
	      All layers in order of horizontal graph traversal. Entries are unique.
	      Includes input and output layers.
	    */
	    _this.layers = [];
	    /*
	      References to container layers that were constructed internally. We need
	      these to properly dispose of tensors from nested containers.
	    */
	    _this.internalContainerRefs = [];
	    // TODO(michaelterry): Determine if caching still needed with eager
	    // backend.
	    /*
	      This is for performance optimization when calling the Container on new
	      inputs. Every time the Container is called on a set on input tensors,
	      we compute the output tensors, output masks and output shapes in one pass,
	      then cache them here. When one of these outputs is queried later,
	      we retrieve it from there instead of recomputing it.
	    */
	    // this.outputTensorCache = {};
	    // this.outputShapeCache = {};
	    // Build this.outputLayers:
	    var _iterator = _createForOfIteratorHelper(_this.outputs),
	      _step;
	    try {
	      for (_iterator.s(); !(_step = _iterator.n()).done;) {
	        var x = _step.value;
	        var _layer2 = x.sourceLayer;
	        var nodeIndex = x.nodeIndex;
	        var tensorIndex = x.tensorIndex;
	        _this.outputLayers.push(_layer2);
	        _this.outputLayersNodeIndices.push(nodeIndex);
	        _this.outputLayersTensorIndices.push(tensorIndex);
	      }
	      // TODO(michaelterry): Add output mask cache code.
	      // Build this.inputLayers:
	    } catch (err) {
	      _iterator.e(err);
	    } finally {
	      _iterator.f();
	    }
	    var _iterator2 = _createForOfIteratorHelper(_this.inputs),
	      _step2;
	    try {
	      for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	        var _x = _step2.value;
	        var _layer3 = _x.sourceLayer;
	        var _nodeIndex2 = _x.nodeIndex;
	        var _tensorIndex2 = _x.tensorIndex;
	        /*
	          It's supposed to be an input layer, so only one node
	          and one tensor output.
	        */
	        assert(_nodeIndex2 === 0, 'input layer has >1 nodes');
	        assert(_tensorIndex2 === 0, 'input layer has >1 tensors');
	        _this.inputLayers.push(_layer3);
	        _this.inputLayersNodeIndices.push(_nodeIndex2);
	        _this.inputLayersTensorIndices.push(_tensorIndex2);
	      }
	      // Build this.inputNames and this.outputNames.
	    } catch (err) {
	      _iterator2.e(err);
	    } finally {
	      _iterator2.f();
	    }
	    _this.inputNames = [];
	    _this.outputNames = [];
	    _this.feedInputShapes = [];
	    _this.feedInputNames = [];
	    _this.feedOutputNames = [];
	    for (var i = 0; i < _this.inputLayers.length; i++) {
	      var layer = _this.inputLayers[i];
	      // Check that layer is an InputLayer.
	      if (!(layer instanceof InputLayer)) {
	        throw new TypeError('Input layers to a LayersModel must be InputLayer objects. ' + "Received inputs: ".concat(args.inputs, ". ") + "Input ".concat(i, " (0-based) originates ") + "from layer type ".concat(layer.getClassName(), "."));
	      }
	      _this.inputNames.push(layer.name);
	      _this.feedInputShapes.push(layer.batchInputShape);
	      _this.feedInputNames.push(layer.name);
	    }
	    var _iterator3 = _createForOfIteratorHelper(_this.outputLayers),
	      _step3;
	    try {
	      for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
	        var _layer4 = _step3.value;
	        _this.outputNames.push(_layer4.name);
	      }
	    } catch (err) {
	      _iterator3.e(err);
	    } finally {
	      _iterator3.f();
	    }
	    _this.internalInputShapes = _this.inputs.map(function (x) {
	      return x.shape;
	    });
	    _this.internalOutputShapes = _this.outputs.map(function (x) {
	      return x.shape;
	    });
	    /*
	      Container_nodes: set of nodes included in the graph (not all nodes
	      included in the layers are relevant to the current graph).
	    */
	    // ids of all nodes relevant to the Container:
	    var nodesDepths = {};
	    // To recover nodes from their ID.
	    var nodeIDToNode = {};
	    var layersDepths = {};
	    // To layers from their ID.
	    var layerIDToLayer = {};
	    var layerIndices = {};
	    var nodesInDecreasingDepth = [];
	    /**
	     * Builds a map of the graph of layers.
	     *
	     * This recursively updates the map `layerIndices`,
	     * the list `nodesInDecreasingDepth` and the set `containerNodes`.
	     *
	     * @param tensor Some tensor in a graph.
	     * @param finishedNodes Set of nodes whose subgraphs have been traversed
	     *         completely. Useful to prevent duplicated work.
	     * @param nodesInProgress Set of nodes that are currently active on the
	     *         recursion stack. Useful to detect cycles.
	     * @param layer Layer from which `tensor` comes from. If not provided,
	     *   will be obtained from tensor.sourceLayer.
	     * @param nodeIndex Node index from which `tensor` comes from.
	     * @param tensorIndex TensorIndex from which `tensor` comes from.
	     *
	     * @exception RuntimeError if a cycle is detected.
	     */
	    var buildMapOfGraph = function buildMapOfGraph(tensor, finishedNodes, nodesInProgress, layer, nodeIndex, tensorIndex) {
	      if (layer == null || nodeIndex == null || tensorIndex == null) {
	        layer = tensor.sourceLayer;
	        nodeIndex = tensor.nodeIndex;
	        tensorIndex = tensor.tensorIndex;
	      }
	      var node = layer.inboundNodes[nodeIndex];
	      // Prevent cycles.
	      if (nodesInProgress.indexOf(node) !== -1) {
	        throw new RuntimeError("The tensor ".concat(tensor.name, " at layer \"").concat(layer.name, "\" ") + 'is part of a cycle.');
	      }
	      // Don't repeat work for shared subgraphs
	      if (finishedNodes.indexOf(node) !== -1) {
	        return;
	      }
	      // Update containerNodes.
	      _this.containerNodes.add(Container.nodeKey(layer, nodeIndex));
	      // Store the traversal order for layer sorting.
	      if (!(layer.id in layerIndices)) {
	        layerIndices[layer.id] = Object.keys(layerIndices).length;
	      }
	      if (nodesInProgress.indexOf(node) === -1) {
	        nodesInProgress.push(node);
	      }
	      // Propagate to all previous tensors connected to this node.
	      var numInboundLayers = node.inboundLayers.length;
	      for (var _i = 0; _i < numInboundLayers; _i++) {
	        var x = node.inputTensors[_i];
	        var _layer = node.inboundLayers[_i];
	        var _nodeIndex = node.nodeIndices[_i];
	        var _tensorIndex = node.tensorIndices[_i];
	        buildMapOfGraph(x, finishedNodes, nodesInProgress, _layer, _nodeIndex, _tensorIndex);
	      }
	      finishedNodes.push(node);
	      while (nodesInProgress.indexOf(node) >= 0) {
	        nodesInProgress.splice(nodesInProgress.indexOf(node), 1);
	      }
	      nodesInDecreasingDepth.push(node);
	    };
	    var finishedNodes = [];
	    var nodesInProgress = [];
	    var _iterator4 = _createForOfIteratorHelper(_this.outputs),
	      _step4;
	    try {
	      for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
	        var _x2 = _step4.value;
	        buildMapOfGraph(_x2, finishedNodes, nodesInProgress);
	      }
	    } catch (err) {
	      _iterator4.e(err);
	    } finally {
	      _iterator4.f();
	    }
	    var reversedNodesInDecreasingDepth = nodesInDecreasingDepth.slice().reverse();
	    var _iterator5 = _createForOfIteratorHelper(reversedNodesInDecreasingDepth),
	      _step5;
	    try {
	      for (_iterator5.s(); !(_step5 = _iterator5.n()).done;) {
	        var node = _step5.value;
	        nodeIDToNode[node.id] = node;
	        // If the depth is not set, the node has no outbound nodes (depth 0).
	        if (!(node.id in nodesDepths)) {
	          nodesDepths[node.id] = 0;
	        }
	        var _depth2 = nodesDepths[node.id];
	        // Update the depth of the corresponding layer
	        var previousDepth = layersDepths[node.outboundLayer.id] == null ? 0 : layersDepths[node.outboundLayer.id];
	        /*
	          If we've seen this layer before at a higher depth, we should use that
	          depth instead of the node depth.  This is necessary for shared layers
	          that have inputs at different depth levels in the graph.
	        */
	        _depth2 = Math.max(_depth2, previousDepth);
	        layersDepths[node.outboundLayer.id] = _depth2;
	        layerIDToLayer[node.outboundLayer.id] = node.outboundLayer;
	        nodesDepths[node.id] = _depth2;
	        // Update the depth of inbound nodes.
	        for (var _i2 = 0; _i2 < node.inboundLayers.length; _i2++) {
	          var inboundLayer = node.inboundLayers[_i2];
	          var _nodeIndex3 = node.nodeIndices[_i2];
	          var inboundNode = inboundLayer.inboundNodes[_nodeIndex3];
	          var _previousDepth = nodesDepths[inboundNode.id] == null ? 0 : nodesDepths[inboundNode.id];
	          nodesDepths[inboundNode.id] = Math.max(_depth2 + 1, _previousDepth);
	          nodeIDToNode[inboundNode.id] = inboundNode;
	        }
	      }
	      // Build a dict {depth: list of nodes with this depth}
	    } catch (err) {
	      _iterator5.e(err);
	    } finally {
	      _iterator5.f();
	    }
	    var nodesByDepth = {};
	    for (var nodeID in nodesDepths) {
	      var depth = nodesDepths[nodeID];
	      if (!(depth in nodesByDepth)) {
	        nodesByDepth[depth] = [];
	      }
	      nodesByDepth[depth].push(nodeIDToNode[nodeID]);
	    }
	    // Build a dict {depth: list of layers with this depth}
	    var layersByDepth = {};
	    for (var layerID in layersDepths) {
	      var _depth = layersDepths[layerID];
	      if (!(_depth in layersByDepth)) {
	        layersByDepth[_depth] = [];
	      }
	      layersByDepth[_depth].push(layerIDToLayer[layerID]);
	    }
	    // Get sorted list of layer depths.
	    var depthKeys = Object.keys(layersByDepth).map(function (x) {
	      return parseInt(x, 10);
	    }).sort(reverseNumberCompare);
	    // Set this.layers and this.layersByDepth.
	    _this.layers = [];
	    var _iterator6 = _createForOfIteratorHelper(depthKeys),
	      _step6;
	    try {
	      for (_iterator6.s(); !(_step6 = _iterator6.n()).done;) {
	        var _depth3 = _step6.value;
	        var layersForDepth = layersByDepth[_depth3];
	        // Container.layers needs to have a deterministic order:
	        // here we order them by traversal order.
	        layersForDepth.sort(function (a, b) {
	          var aIndex = layerIndices[a.id];
	          var bIndex = layerIndices[b.id];
	          if (aIndex < bIndex) {
	            return -1;
	          }
	          if (aIndex > bIndex) {
	            return 1;
	          }
	          return 0;
	        });
	        var _iterator9 = _createForOfIteratorHelper(layersForDepth),
	          _step9;
	        try {
	          for (_iterator9.s(); !(_step9 = _iterator9.n()).done;) {
	            var _layer5 = _step9.value;
	            if (_layer5 instanceof Container) {
	              _this.internalContainerRefs.push(_layer5);
	            }
	            _this.layers.push(_layer5);
	          }
	        } catch (err) {
	          _iterator9.e(err);
	        } finally {
	          _iterator9.f();
	        }
	      }
	    } catch (err) {
	      _iterator6.e(err);
	    } finally {
	      _iterator6.f();
	    }
	    _this.layersByDepth = layersByDepth;
	    // Get sorted list of node depths;
	    depthKeys = Object.keys(nodesByDepth).map(function (x) {
	      return parseInt(x, 10);
	    }).sort(reverseNumberCompare);
	    // Check that all tensors required are computable.
	    // computable_tensors: all tensors in the graph
	    // that can be computed from the inputs provided.
	    var computableTensors = _this.inputs.slice();
	    // To provide a better error msg.
	    var layersWithCompleteInput = [];
	    var _iterator7 = _createForOfIteratorHelper(depthKeys),
	      _step7;
	    try {
	      for (_iterator7.s(); !(_step7 = _iterator7.n()).done;) {
	        var _depth4 = _step7.value;
	        var _iterator10 = _createForOfIteratorHelper(nodesByDepth[_depth4]),
	          _step10;
	        try {
	          for (_iterator10.s(); !(_step10 = _iterator10.n()).done;) {
	            var _node = _step10.value;
	            var _layer6 = _node.outboundLayer;
	            if (_layer6 != null) {
	              var _iterator11 = _createForOfIteratorHelper(_node.inputTensors),
	                _step11;
	              try {
	                for (_iterator11.s(); !(_step11 = _iterator11.n()).done;) {
	                  var _x3 = _step11.value;
	                  if (computableTensors.indexOf(_x3) === -1) {
	                    throw new RuntimeError("Graph disconnected: cannot obtain value for tensor ".concat(_x3) + " at layer \"".concat(_layer6.name, "\". ") + 'The following previous layers were accessed without ' + "issue: ".concat(layersWithCompleteInput));
	                  }
	                }
	              } catch (err) {
	                _iterator11.e(err);
	              } finally {
	                _iterator11.f();
	              }
	              var _iterator12 = _createForOfIteratorHelper(_node.outputTensors),
	                _step12;
	              try {
	                for (_iterator12.s(); !(_step12 = _iterator12.n()).done;) {
	                  var _x4 = _step12.value;
	                  computableTensors.push(_x4);
	                }
	              } catch (err) {
	                _iterator12.e(err);
	              } finally {
	                _iterator12.f();
	              }
	              layersWithCompleteInput.push(_layer6.name);
	            }
	          }
	        } catch (err) {
	          _iterator10.e(err);
	        } finally {
	          _iterator10.f();
	        }
	      }
	      // Set this.containerNodes and this.nodesByDepth.
	    } catch (err) {
	      _iterator7.e(err);
	    } finally {
	      _iterator7.f();
	    }
	    _this.nodesByDepth = nodesByDepth;
	    // Ensure name unicity, which will be crucial for serialization
	    // (since serialized nodes refer to layers by their name).
	    var allNames = _this.layers.map(function (x) {
	      return x.name;
	    });
	    var _iterator8 = _createForOfIteratorHelper(allNames),
	      _step8;
	    try {
	      var _loop = function _loop() {
	        var name = _step8.value;
	        var numOccurrences = allNames.filter(function (x) {
	          return x === name;
	        }).length;
	        if (numOccurrences !== 1) {
	          throw new RuntimeError("The name \"".concat(name, "\" is used ").concat(numOccurrences, " times ") + 'in the model. All layer names should be unique. Layer names: ' + JSON.stringify(allNames));
	        }
	      };
	      for (_iterator8.s(); !(_step8 = _iterator8.n()).done;) {
	        _loop();
	      }
	      // Layer parameters.
	      // The new container starts with a single inbound node
	      // for its inputs, and no outbound nodes.
	      // Will be appended to by future calls to apply().
	    } catch (err) {
	      _iterator8.e(err);
	    } finally {
	      _iterator8.f();
	    }
	    _this.outboundNodes = [];
	    // Will be appended to below, and by future calls to apply().
	    _this.inboundNodes = [];
	    // Create the node linking internal inputs to internal outputs.
	    // (This call has side effects.)
	    // tslint:disable-next-line:no-unused-expression
	    new Node({
	      outboundLayer: _assertThisInitialized(_this),
	      inboundLayers: [],
	      nodeIndices: [],
	      tensorIndices: [],
	      inputTensors: _this.inputs,
	      outputTensors: _this.outputs,
	      inputMasks: _this.inputs.map(function (x) {
	        return null;
	      }),
	      outputMasks: _this.outputs.map(function (x) {
	        return null;
	      }),
	      inputShapes: _this.inputs.map(function (x) {
	        return x.shape;
	      }),
	      outputShapes: _this.outputs.map(function (x) {
	        return x.shape;
	      })
	    });
	    _this.built = true;
	    _this._refCount = 1; // The ref count of a container always start at 1.
	    return _this;
	  }
	  _createClass(Container, [{
	    key: "assertNotDisposed",
	    value: function assertNotDisposed() {
	      if (this._refCount === 0) {
	        throw new Error("Container '".concat(this.name, "' is already disposed."));
	      }
	    }
	    /**
	     * Attempt to dispose a LayersModel's weights.
	     *
	     * This method decrease the reference count of the LayersModel object by 1.
	     *
	     * A LayersModel is reference-counted. Its reference count is incremented by 1
	     * when it is first constructed and when it is used as a Layer of another
	     * LayersModel.
	     *
	     * If the reference count of a LayersModel becomes 0, the `dispose` method of
	     * all its constituent `Layer`s will be called.
	     *
	     * Note: If the reference count is greater than 0 after the decrement, the
	     * `dispose` method of its constituent `Layer`s will *not* be called.
	     *
	     * After a LayersModel is disposed, it cannot be used in calls such as
	     * 'predict`, `evaluate` or `fit` anymore.
	     *
	     * @returns A DisposeResult Object with the following fields:
	     *   - refCountAfterDispose: The reference count of the LayersModel after this
	     *     `dispose()` call.
	     *   - numDisposedVariables: Number of `tf.Variable`s (i.e., weights) disposed
	     *     during this `dispose()` call.
	     * @throws {Error} If the layer is not built yet, or if the LayersModel has
	     *   already been disposed.
	     */
	  }, {
	    key: "dispose",
	    value: function dispose() {
	      this.assertNotDisposed();
	      var result = {
	        refCountAfterDispose: null,
	        numDisposedVariables: 0
	      };
	      if (--this._refCount === 0) {
	        var _iterator13 = _createForOfIteratorHelper(this.layers),
	          _step13;
	        try {
	          for (_iterator13.s(); !(_step13 = _iterator13.n()).done;) {
	            var layer = _step13.value;
	            result.numDisposedVariables += layer.dispose().numDisposedVariables;
	          }
	          // Call dispose on each internally created container layer again to ensure
	          // their refCounts hit zero and their tensors are subsequently deleted.
	        } catch (err) {
	          _iterator13.e(err);
	        } finally {
	          _iterator13.f();
	        }
	        var _iterator14 = _createForOfIteratorHelper(this.internalContainerRefs),
	          _step14;
	        try {
	          for (_iterator14.s(); !(_step14 = _iterator14.n()).done;) {
	            var container = _step14.value;
	            result.numDisposedVariables += container.dispose().numDisposedVariables;
	          }
	        } catch (err) {
	          _iterator14.e(err);
	        } finally {
	          _iterator14.f();
	        }
	      }
	      result.refCountAfterDispose = this._refCount;
	      return result;
	    }
	  }, {
	    key: "trainable",
	    get: function get() {
	      return this.trainable_;
	    },
	    set: function set(trainable) {
	      this.layers.forEach(function (layer) {
	        // tslint:disable-next-line:no-any
	        layer._trainableWeights.forEach(function (w) {
	          return w.trainable = trainable;
	        });
	      });
	      this.trainable_ = trainable;
	    }
	  }, {
	    key: "trainableWeights",
	    get: function get() {
	      // Porting Note: This check below is to prevent errors where the
	      //   _trainableWeights inherited from the parent class (Layer) gets
	      //   inadvertently used.
	      if (this._trainableWeights.length > 0) {
	        throw new ValueError('Container instance unexpectedly contains _trainableWeights.' + 'The trainable weights of a Container are a union of the ' + 'trainable weights of its consituent Layers. Its own ' + '_trainableWeights must remain an empty Array.');
	      }
	      if (!this.trainable) {
	        return [];
	      }
	      var weights = [];
	      var _iterator15 = _createForOfIteratorHelper(this.layers),
	        _step15;
	      try {
	        for (_iterator15.s(); !(_step15 = _iterator15.n()).done;) {
	          var layer = _step15.value;
	          weights = weights.concat(layer.trainableWeights);
	        }
	      } catch (err) {
	        _iterator15.e(err);
	      } finally {
	        _iterator15.f();
	      }
	      return weights;
	    }
	  }, {
	    key: "nonTrainableWeights",
	    get: function get() {
	      var weights = [];
	      var _iterator16 = _createForOfIteratorHelper(this.layers),
	        _step16;
	      try {
	        for (_iterator16.s(); !(_step16 = _iterator16.n()).done;) {
	          var _layer7 = _step16.value;
	          weights.push.apply(weights, _toConsumableArray(_layer7.nonTrainableWeights));
	        }
	      } catch (err) {
	        _iterator16.e(err);
	      } finally {
	        _iterator16.f();
	      }
	      if (!this.trainable) {
	        var trainableWeights = [];
	        var _iterator17 = _createForOfIteratorHelper(this.layers),
	          _step17;
	        try {
	          for (_iterator17.s(); !(_step17 = _iterator17.n()).done;) {
	            var layer = _step17.value;
	            trainableWeights.push.apply(trainableWeights, _toConsumableArray(layer.trainableWeights));
	          }
	        } catch (err) {
	          _iterator17.e(err);
	        } finally {
	          _iterator17.f();
	        }
	        return trainableWeights.concat(weights);
	      }
	      return weights;
	    }
	  }, {
	    key: "weights",
	    get: function get() {
	      return this.trainableWeights.concat(this.nonTrainableWeights);
	    }
	    /**
	     * Loads all layer weights from a JSON object.
	     *
	     * Porting Note: HDF5 weight files cannot be directly loaded in JavaScript /
	     *   TypeScript. The utility script at `scripts/pykeras.py` offers means
	     *   to convert them into JSON strings compatible with this method.
	     * Porting Note: TensorFlow.js Layers supports only loading by name currently.
	     *
	     * @param weights A JSON mapping weight names to weight values as nested
	     *   arrays of numbers, or a `NamedTensorMap`, i.e., a JSON mapping weight
	     *   names to `tf.Tensor` objects.
	     * @param strict Require that the provided weights exactly match those
	     *   required by the container.  Default: `true`.  Passing `false` means that
	     *   extra weights and missing weights will be silently ignored.
	     */
	  }, {
	    key: "loadWeights",
	    value: function loadWeights(weights) {
	      var strict = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
	      var nameToWeight = {};
	      var totalWeightsCount = 0;
	      var modelIsKerasSavedModelFormat = isKerasSavedModelFormat(weights);
	      if (modelIsKerasSavedModelFormat) {
	        this.parseWeights(weights);
	      }
	      // Check if weights from keras v3.
	      var _iterator18 = _createForOfIteratorHelper(this.layers),
	        _step18;
	      try {
	        for (_iterator18.s(); !(_step18 = _iterator18.n()).done;) {
	          var layer = _step18.value;
	          var _iterator19 = _createForOfIteratorHelper(layer.weights.entries()),
	            _step19;
	          try {
	            for (_iterator19.s(); !(_step19 = _iterator19.n()).done;) {
	              var _step19$value = _slicedToArray(_step19.value, 2),
	                index = _step19$value[0],
	                weight = _step19$value[1];
	              // Parse the name to layerName/index.
	              // e.g. dense/0, dense/1, dense_1/0, dense_1/1
	              var parsedName = modelIsKerasSavedModelFormat ? "".concat(weight.name.split('/').slice(0, -1).join('/') + '/').concat(index) : weight.originalName;
	              if (nameToWeight[parsedName] != null) {
	                throw new ValueError("Duplicate weight name: ".concat(parsedName));
	              }
	              nameToWeight[parsedName] = weight;
	              totalWeightsCount++;
	            }
	          } catch (err) {
	            _iterator19.e(err);
	          } finally {
	            _iterator19.f();
	          }
	        }
	      } catch (err) {
	        _iterator18.e(err);
	      } finally {
	        _iterator18.f();
	      }
	      var weightValueTuples = [];
	      for (var name in weights) {
	        // TF 2.2.0 added cell name to the weight name in the format of
	        // layer_name/cell_name/weight_name, we need to remove
	        // the inner cell name.
	        var validatedName = name;
	        if (nameToWeight[name] == null) {
	          var tokens = name.split('/');
	          var shortenNameArray = tokens.slice(0, -2).concat([tokens[tokens.length - 1]]);
	          validatedName = shortenNameArray.join('/');
	        }
	        if (nameToWeight[validatedName] != null) {
	          weightValueTuples.push([nameToWeight[validatedName], weights[name]]);
	        } else if (strict) {
	          throw new ValueError("Provided weight data has no target variable: ".concat(name));
	        }
	        delete nameToWeight[validatedName];
	      }
	      if (strict) {
	        // Check that all weights are set.
	        var unsetNames = [];
	        for (var _name in nameToWeight) {
	          unsetNames.push(_name);
	        }
	        if (unsetNames.length > 0) {
	          throw new ValueError("".concat(unsetNames.length, " of ").concat(totalWeightsCount, " weights are not set: ") + "".concat(unsetNames));
	        }
	      }
	      batchSetValue(weightValueTuples);
	    }
	  }, {
	    key: "parseWeights",
	    value: function parseWeights(weights) {
	      var _loop2 = function _loop2() {
	        var listParts = key.split('/');
	        var list = ['vars', 'layer_checkpoint_dependencies'];
	        // For keras v3, the weights name are saved based on the folder structure.
	        // e.g. _backbone/_layer_checkpoint_dependencies/transformer/_self../
	        // _output_dense/vars/0
	        // Therefore we discard the `vars` and `layer_checkpoint_depencies` within
	        // the saved name and only keeps the layer name and weights.
	        // This can help to mapping the actual name of the layers and load each
	        // weight accordingly.
	        var newKey = listParts.map(function (str) {
	          if (str.startsWith('_')) {
	            return str.slice(1);
	          }
	          return str;
	        }).filter(function (str) {
	          return !list.includes(str);
	        }).join('/');
	        if (newKey !== key) {
	          weights[newKey] = weights[key];
	          delete weights[key];
	        }
	      };
	      for (var key in Object.keys(weights)) {
	        _loop2();
	      }
	    }
	    /**
	     * Util shared between different serialization methods.
	     * @returns LayersModel config with Keras version information added.
	     */
	  }, {
	    key: "updatedConfig",
	    value: function updatedConfig() {
	      var theConfig = this.getConfig();
	      var modelConfig = {};
	      modelConfig['className'] = this.getClassName();
	      modelConfig['config'] = theConfig;
	      modelConfig['kerasVersion'] = "tfjs-layers ".concat(version$6);
	      // TODO(nielsene): Replace something like K.backend() once
	      // possible.
	      modelConfig['backend'] = 'TensorFlow.js';
	      return modelConfig;
	    }
	    /**
	     * Returns a JSON string containing the network configuration.
	     *
	     * To load a network from a JSON save file, use
	     * models.modelFromJSON(jsonString);
	     * @param extraJsonArgs Unused in tfjs-layers, maintained for PyKeras
	     * @param returnString Whether the return value should be stringified
	     *    (default: `true`).
	     * @returns a JSON string if `returnString` (default), or a JSON object if
	     *   `!returnString`.
	     */
	    // tslint:disable-next-line:no-any
	  }, {
	    key: "toJSON",
	    value: function toJSON(unused) {
	      var returnString = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
	      var modelConfig = convertTsToPythonic(this.updatedConfig());
	      return returnString ? JSON.stringify(modelConfig) : modelConfig;
	    }
	    /**
	     * Call the model on new inputs.
	     *
	     * In this case `call` just reapplies all ops in the graph to the new inputs
	     * (e.g. build a new computational graph from the provided inputs).
	     *
	     * @param inputs A tensor or list of tensors.
	     * @param mask A mask or list of masks. A mask can be either a tensor or null
	     *   (no mask).
	     *
	     * @return A tensor if there is a single output, or a list of tensors if there
	     *   are more than one outputs.
	     */
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this2 = this;
	      return tidy(function () {
	        inputs = toList(inputs);
	        var feedDict = new FeedDict();
	        for (var i = 0; i < _this2.inputs.length; ++i) {
	          feedDict.add(_this2.inputs[i], inputs[i]);
	        }
	        return execute(_this2.outputs, feedDict, kwargs);
	      });
	    }
	    /**
	     * Computes an output mask tensor.
	     *
	     * @param inputs Tensor or list of tensors.
	     * @param mask Tensor or list of tensors.
	     *
	     * @return null or a tensor (or list of tensors, one per output tensor of the
	     * layer).
	     */
	  }, {
	    key: "computeMask",
	    value: function computeMask(inputs, mask) {
	      var _this3 = this;
	      return tidy(function () {
	        inputs = toList(inputs);
	        var masks;
	        if (mask == null) {
	          masks = pyListRepeat(null, inputs.length);
	        } else {
	          masks = toList(mask);
	        }
	        // TODO(michaelterry): Add support for mask caching.
	        return _this3.runInternalGraph(inputs, masks)[1];
	      });
	    }
	    /**
	     * Computes the output shape of the layer.
	     *
	     * Assumes that the layer will be built to match that input shape provided.
	     *
	     * @param inputShape A shape (tuple of integers) or a list of shape tuples
	     *   (one per output tensor of the layer). Shape tuples can include null for
	     *   free dimensions, instead of an integer.
	     */
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      var inputShapes = normalizeShapeList(inputShape);
	      if (inputShapes.length !== this.inputLayers.length) {
	        throw new ValueError("Invalid inputShape argument ".concat(inputShape, ": ") + "model has ".concat(this.inputLayers.length, " tensor inputs."));
	      }
	      // TODO(michaelterry): Add caching
	      var layersToOutputShapes = {};
	      for (var i = 0; i < inputShapes.length; i++) {
	        var layer = this.inputLayers[i];
	        var _inputShape = inputShapes[i];
	        // It's an input layer: computeOutputShape is identity,
	        // and there is only one node and one tensor output.
	        var shapeKey = layer.name + '_0_0';
	        layersToOutputShapes[shapeKey] = _inputShape;
	      }
	      var depthKeys = Object.keys(this.nodesByDepth).map(function (x) {
	        return parseInt(x, 10);
	      }).sort(reverseNumberCompare);
	      // Iterate over nodes, by depth level.
	      if (depthKeys.length > 1) {
	        var _iterator20 = _createForOfIteratorHelper(depthKeys),
	          _step20;
	        try {
	          for (_iterator20.s(); !(_step20 = _iterator20.n()).done;) {
	            var depth = _step20.value;
	            var nodes = this.nodesByDepth[depth];
	            var _iterator21 = _createForOfIteratorHelper(nodes),
	              _step21;
	            try {
	              for (_iterator21.s(); !(_step21 = _iterator21.n()).done;) {
	                var node = _step21.value;
	                // This is always a single layer, never a list.
	                var _layer8 = node.outboundLayer;
	                if (this.inputLayers.map(function (x) {
	                  return x.id;
	                }).indexOf(_layer8.id) !== -1) {
	                  // We've already covered the input layers a few lines above.
	                  continue;
	                }
	                // Potentially redundant list, same size of node.inputTensors.
	                var _inputShapes = [];
	                for (var j = 0; j < node.inboundLayers.length; j++) {
	                  var inboundLayer = node.inboundLayers[j];
	                  var _nodeIndex4 = node.nodeIndices[j];
	                  var tensorIndex = node.tensorIndices[j];
	                  var _shapeKey = "".concat(inboundLayer.name, "_").concat(_nodeIndex4, "_").concat(tensorIndex);
	                  var _inputShape2 = layersToOutputShapes[_shapeKey];
	                  _inputShapes.push(_inputShape2);
	                }
	                var outputShape = _layer8.computeOutputShape(singletonOrArray(_inputShapes));
	                var _outputShapes = normalizeShapeList(outputShape);
	                var nodeIndex = _layer8.inboundNodes.indexOf(node);
	                for (var _j = 0; _j < _outputShapes.length; _j++) {
	                  var _shapeKey2 = "".concat(_layer8.name, "_").concat(nodeIndex, "_").concat(_j);
	                  layersToOutputShapes[_shapeKey2] = _outputShapes[_j];
	                }
	              }
	            } catch (err) {
	              _iterator21.e(err);
	            } finally {
	              _iterator21.f();
	            }
	          }
	        } catch (err) {
	          _iterator20.e(err);
	        } finally {
	          _iterator20.f();
	        }
	      }
	      // Read final output shapes from layersToOutputShapes.
	      var outputShapes = [];
	      var outputShapeKeys = [];
	      for (var _i3 = 0; _i3 < this.outputLayers.length; _i3++) {
	        var _layer9 = this.outputLayers[_i3];
	        var _nodeIndex5 = this.outputLayersNodeIndices[_i3];
	        var _tensorIndex3 = this.outputLayersTensorIndices[_i3];
	        var _shapeKey3 = "".concat(_layer9.name, "_").concat(_nodeIndex5, "_").concat(_tensorIndex3);
	        outputShapeKeys.push(_shapeKey3);
	      }
	      for (var _i4 = 0; _i4 < outputShapeKeys.length; _i4++) {
	        var key = outputShapeKeys[_i4];
	        assert(key in layersToOutputShapes);
	        outputShapes.push(layersToOutputShapes[key]);
	      }
	      // TODO(michaelterry): Update cache
	      return singletonOrArray(outputShapes);
	    }
	    /**
	     * Computes output tensors for new inputs.
	     *
	     * Note:
	     *   - Expects `inputs` to be a list (potentially with 1 element).
	     *
	     * @param inputs List of tensors
	     * @param masks List of masks (tensors or null).
	     * @return Three lists: outputTensors, outputMasks, outputShapes
	     */
	  }, {
	    key: "runInternalGraph",
	    value: function runInternalGraph(inputs, masks) {
	      if (masks == null) {
	        masks = pyListRepeat(null, inputs.length);
	      }
	      // Dictionary mapping reference tensors to tuples
	      // (computed tensor, compute mask)
	      // we assume a 1:1 mapping from tensor to mask
	      // TODO: raise exception when a `.computeMask()` call
	      // does not return a list the same size as `call`
	      var tensorMap = {};
	      for (var i = 0; i < this.inputs.length; ++i) {
	        var x = this.inputs[i];
	        var y = inputs[i];
	        var mask = masks[i];
	        tensorMap[x.id] = [y, mask];
	      }
	      var depthKeys = Object.keys(this.nodesByDepth).map(function (x) {
	        return parseInt(x, 10);
	      }).sort(reverseNumberCompare);
	      var _iterator22 = _createForOfIteratorHelper(depthKeys),
	        _step22;
	      try {
	        for (_iterator22.s(); !(_step22 = _iterator22.n()).done;) {
	          var depth = _step22.value;
	          var nodes = this.nodesByDepth[depth];
	          var _iterator24 = _createForOfIteratorHelper(nodes),
	            _step24;
	          try {
	            for (_iterator24.s(); !(_step24 = _iterator24.n()).done;) {
	              var node = _step24.value;
	              // This is always a single layer, never a list.
	              var layer = node.outboundLayer;
	              var referenceInputTensors = node.inputTensors;
	              var referenceOutputTensors = node.outputTensors;
	              // If all previous input tensors are available in tensorMap,
	              // then call node.inboundLayer on them.
	              // List of tuples [input, mask]:
	              var computedData = new Array();
	              var _iterator25 = _createForOfIteratorHelper(referenceInputTensors),
	                _step25;
	              try {
	                for (_iterator25.s(); !(_step25 = _iterator25.n()).done;) {
	                  var _x6 = _step25.value;
	                  if (_x6.id in tensorMap) {
	                    computedData.push(tensorMap[_x6.id]);
	                  }
	                }
	              } catch (err) {
	                _iterator25.e(err);
	              } finally {
	                _iterator25.f();
	              }
	              if (computedData.length === referenceInputTensors.length) {
	                // TODO(michaelterry): Add K.name_scope here, if we need it.
	                var kwargs = {};
	                var computedTensors = void 0;
	                var computedMasks = void 0;
	                var _outputTensors = void 0;
	                var _outputMasks = void 0;
	                // call layer
	                if (node.callArgs != null) {
	                  kwargs = node.callArgs;
	                }
	                if (computedData.length === 1) {
	                  var _computedData$ = _slicedToArray(computedData[0], 2),
	                    computedTensor = _computedData$[0],
	                    computedMask = _computedData$[1];
	                  if (kwargs['mask'] == null) {
	                    kwargs['mask'] = computedMask;
	                  }
	                  _outputTensors = toList(layer.call(computedTensor, kwargs));
	                  _outputMasks = toList(layer.computeMask(computedTensor, computedMask));
	                  computedTensors = [computedTensor];
	                  computedMasks = [computedMask];
	                } else {
	                  computedTensors = computedData.map(function (x) {
	                    return x[0];
	                  });
	                  computedMasks = computedData.map(function (x) {
	                    return x[1];
	                  });
	                  if (kwargs['mask'] == null) {
	                    kwargs['mask'] = computedMasks;
	                  }
	                  _outputTensors = toList(layer.call(computedTensors, kwargs));
	                  _outputMasks = toList(layer.computeMask(computedTensors, computedMasks));
	                }
	                if (layer.activityRegularizer) {
	                  throw new NotImplementedError('LayersModel invocation with concrete Tensor value(s) in the ' + 'presence of activity regularizer(s) is not supported yet.');
	                }
	                // TODO(michaelterry): Add model updates and losses
	                // Update tensor map.
	                for (var _i5 = 0; _i5 < referenceOutputTensors.length; ++_i5) {
	                  var _x5 = referenceOutputTensors[_i5];
	                  var _y = _outputTensors[_i5];
	                  var _mask = _outputMasks[_i5];
	                  tensorMap[_x5.id] = [_y, _mask];
	                }
	              }
	            }
	          } catch (err) {
	            _iterator24.e(err);
	          } finally {
	            _iterator24.f();
	          }
	        }
	      } catch (err) {
	        _iterator22.e(err);
	      } finally {
	        _iterator22.f();
	      }
	      var outputTensors = [];
	      var outputMasks = [];
	      var outputShapes = [];
	      var _iterator23 = _createForOfIteratorHelper(this.outputs),
	        _step23;
	      try {
	        for (_iterator23.s(); !(_step23 = _iterator23.n()).done;) {
	          var _x7 = _step23.value;
	          assert(_x7.id in tensorMap, "Could not compute output ".concat(_x7.name, " : ").concat(_x7.id));
	          var _tensorMap$_x7$id = _slicedToArray(tensorMap[_x7.id], 2),
	            tensor = _tensorMap$_x7$id[0],
	            _mask2 = _tensorMap$_x7$id[1];
	          outputShapes.push(tensor.shape);
	          outputTensors.push(tensor);
	          outputMasks.push(_mask2);
	        }
	        // TODO(michaelterry): Add support for caches.
	      } catch (err) {
	        _iterator23.e(err);
	      } finally {
	        _iterator23.f();
	      }
	      return [outputTensors, outputMasks, outputShapes];
	    }
	    /**
	     * Builds a map of internal node keys to node ordering.
	     * Used in serializaion a node orderings may change as unused nodes are
	     * dropped. Porting Note:  This helper method was pulled out of getConfig to
	     * improve readability.
	     * @param layers An array of Layers in the model.
	     * @returns Map of Node Keys to index order within the layer.
	     */
	  }, {
	    key: "buildNodeConversionMap",
	    value: function buildNodeConversionMap(layers) {
	      var nodeConversionMap = {};
	      var keptNodes;
	      var _iterator26 = _createForOfIteratorHelper(this.layers),
	        _step26;
	      try {
	        for (_iterator26.s(); !(_step26 = _iterator26.n()).done;) {
	          var layer = _step26.value;
	          keptNodes = layer instanceof Container ? 1 : 0;
	          for (var originalNodeIndex = 0; originalNodeIndex < layer.inboundNodes.length; originalNodeIndex++) {
	            var nodeKey = Container.nodeKey(layer, originalNodeIndex);
	            if (this.containerNodes.has(nodeKey)) {
	              // i.e. we mark it to be saved
	              nodeConversionMap[nodeKey] = keptNodes;
	              keptNodes += 1;
	            }
	          }
	        }
	      } catch (err) {
	        _iterator26.e(err);
	      } finally {
	        _iterator26.f();
	      }
	      return nodeConversionMap;
	    }
	  }, {
	    key: "getLayer",
	    value: function getLayer(nameOrIndex, index) {
	      if (index != null) {
	        return this.findLayer(index);
	      } else {
	        if (nameOrIndex == null) {
	          throw new ValueError('Provide either a layer name or layer index');
	        }
	        if (typeof nameOrIndex === 'number') {
	          return this.findLayer(nameOrIndex);
	        }
	      }
	      var _iterator27 = _createForOfIteratorHelper(this.layers),
	        _step27;
	      try {
	        for (_iterator27.s(); !(_step27 = _iterator27.n()).done;) {
	          var layer = _step27.value;
	          if (layer.name === nameOrIndex) {
	            return layer;
	          }
	        }
	      } catch (err) {
	        _iterator27.e(err);
	      } finally {
	        _iterator27.f();
	      }
	      throw new ValueError("No such layer: ".concat(nameOrIndex));
	    }
	  }, {
	    key: "findLayer",
	    value: function findLayer(index) {
	      if (this.layers.length <= index) {
	        throw new ValueError("Was asked to retrieve layer at index ".concat(index, ", but model only ") + "has ".concat(this.layers.length, " layer(s)."));
	      } else {
	        return this.layers[index];
	      }
	    }
	    /**
	     * Retrieves the Container's current loss values.
	     *
	     * Used for regularizers during training.
	     */
	  }, {
	    key: "calculateLosses",
	    value: function calculateLosses() {
	      var _this4 = this;
	      // Porting Node: This is an augmentation to Container.loss in PyKeras.
	      //   In PyKeras, Container.loss returns symbolic tensors. Here a concrete
	      //   Tensor (specifically Scalar) values are returned. This is due to the
	      //   imperative backend.
	      return tidy(function () {
	        var losses = [];
	        var _iterator28 = _createForOfIteratorHelper(_this4.layers),
	          _step28;
	        try {
	          for (_iterator28.s(); !(_step28 = _iterator28.n()).done;) {
	            var layer = _step28.value;
	            for (var nodeIndex = 0; nodeIndex < layer.inboundNodes.length; ++nodeIndex) {
	              var nodeKey = Container.nodeKey(layer, nodeIndex);
	              if (_this4.containerNodes.has(nodeKey)) {
	                losses.push.apply(losses, _toConsumableArray(layer.calculateLosses()));
	              }
	            }
	          }
	          // TODO(cais): Add any unconditional model-level losses?
	        } catch (err) {
	          _iterator28.e(err);
	        } finally {
	          _iterator28.f();
	        }
	        return losses;
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        name: this.name
	      };
	      // Build a map from layer unique name (self._node_key)
	      // to the index of the nodes that are saved in the config.
	      // Only nodes in container_nodes are saved.
	      var nodeConversionMap = this.buildNodeConversionMap(this.layers);
	      // Serialize and save the layers in layerConfigs
	      var layerConfigs = [];
	      var _iterator29 = _createForOfIteratorHelper(this.layers),
	        _step29;
	      try {
	        for (_iterator29.s(); !(_step29 = _iterator29.n()).done;) {
	          var _layer11 = _step29.value;
	          var layerClassName = _layer11.getClassName();
	          var layerConfig = _layer11.getConfig();
	          var filteredInboundNodes = [];
	          for (var originalNodeIndex = 0; originalNodeIndex < _layer11.inboundNodes.length; originalNodeIndex++) {
	            var node = _layer11.inboundNodes[originalNodeIndex];
	            var _nodeKey2 = Container.nodeKey(_layer11, originalNodeIndex);
	            var kwargs = {};
	            if (this.containerNodes.has(_nodeKey2)) {
	              // The node is relevant to the model:
	              // add to filteredInboundNodes.
	              if (node.callArgs) {
	                try {
	                  JSON.stringify(node.callArgs);
	                  kwargs = node.callArgs;
	                } catch (err) {
	                  console.warn("Layer ".concat(_layer11.name, " was passed ") + "non-serializable keyword arguments: " + "".concat(node.callArgs, ". They will not be included ") + "in the serialized model (and thus will be " + "missing at deserialization time).");
	                  kwargs = {};
	                }
	              }
	              if (node.inboundLayers.length > 0) {
	                var nodeData = [];
	                for (var _i7 = 0; _i7 < node.inboundLayers.length; _i7++) {
	                  var inboundLayer = node.inboundLayers[_i7];
	                  var _nodeIndex7 = node.nodeIndices[_i7];
	                  var _tensorIndex5 = node.tensorIndices[_i7];
	                  var _nodeKey3 = Container.nodeKey(inboundLayer, _nodeIndex7);
	                  var _newNodeIndex2 = nodeConversionMap[_nodeKey3];
	                  if (_newNodeIndex2 == null) {
	                    _newNodeIndex2 = 0;
	                  }
	                  nodeData.push([inboundLayer.name, _newNodeIndex2, _tensorIndex5, kwargs]);
	                }
	                filteredInboundNodes.push(nodeData);
	              }
	            }
	          }
	          var dict = {};
	          dict['name'] = _layer11.name;
	          dict['className'] = layerClassName;
	          dict['config'] = layerConfig;
	          dict['inboundNodes'] = filteredInboundNodes;
	          layerConfigs.push(dict);
	        }
	      } catch (err) {
	        _iterator29.e(err);
	      } finally {
	        _iterator29.f();
	      }
	      config['layers'] = layerConfigs;
	      // Gather info about inputs and outputs
	      var modelInputs = [];
	      for (var i = 0; i < this.inputLayers.length; i++) {
	        var layer = this.inputLayers[i];
	        var nodeIndex = this.inputLayersNodeIndices[i];
	        var nodeKey = Container.nodeKey(layer, nodeIndex);
	        if (!this.containerNodes.has(nodeKey)) {
	          continue;
	        }
	        var newNodeIndex = nodeConversionMap[nodeKey];
	        if (newNodeIndex === null || newNodeIndex === undefined) {
	          newNodeIndex = 0;
	        }
	        var tensorIndex = this.inputLayersTensorIndices[i];
	        modelInputs.push([layer.name, newNodeIndex, tensorIndex]);
	      }
	      config['inputLayers'] = modelInputs;
	      var modelOutputs = [];
	      for (var _i6 = 0; _i6 < this.outputLayers.length; _i6++) {
	        var _layer10 = this.outputLayers[_i6];
	        var _nodeIndex6 = this.outputLayersNodeIndices[_i6];
	        var _nodeKey = Container.nodeKey(_layer10, _nodeIndex6);
	        if (!this.containerNodes.has(_nodeKey)) {
	          continue;
	        }
	        var _newNodeIndex = nodeConversionMap[_nodeKey];
	        if (_newNodeIndex === null || _newNodeIndex === undefined) {
	          _newNodeIndex = 0;
	        }
	        var _tensorIndex4 = this.outputLayersTensorIndices[_i6];
	        modelOutputs.push([_layer10.name, _newNodeIndex, _tensorIndex4]);
	      }
	      config['outputLayers'] = modelOutputs;
	      return config;
	    }
	    /**
	     * Instantiates a LayersModel from its config (output of `get_config()`).
	     * @param cls the class to create
	     * @param config LayersModel config dictionary.
	     * @param customObjects An optional dictionary of custom objects.
	     * @param fastWeightInit Optional flag to use fast weight initialization
	     *   during deserialization. This is applicable to cases in which
	     *   the initialization will be immediately overwritten by loaded weight
	     *   values. Default: `false`.
	     * @returns A LayersModel instance.
	     * @throws ValueError: In case of improperly formatted config dict.
	     */
	    /** @nocollapse */
	  }, {
	    key: "stateful",
	    get:
	    /**
	     * Determine whether the container is stateful.
	     *
	     * Porting Note: this is the equivalent of the stateful @property of
	     *   the Container class in PyKeras.
	     */
	    function get() {
	      // Porting Note: This check is to prevent inadvertent setting of the
	      //   _stateful property of the Container instance.
	      if (this._stateful) {
	        throw new ValueError('Container instance unexpectedly has _stateful = true. The ' + 'statefulness of a Container is determined by the Layers it ' + 'contains. Its _stateful property must remain the default false.');
	      }
	      var _iterator30 = _createForOfIteratorHelper(this.layers),
	        _step30;
	      try {
	        for (_iterator30.s(); !(_step30 = _iterator30.n()).done;) {
	          var layer = _step30.value;
	          if (layer.stateful) {
	            return true;
	          }
	        }
	      } catch (err) {
	        _iterator30.e(err);
	      } finally {
	        _iterator30.f();
	      }
	      return false;
	    }
	    /**
	     * Reset the state of all stateful constituent layers (if any).
	     *
	     * Examples of stateful layers include RNN layers whose `stateful` property
	     * is set as `true`.
	     */
	  }, {
	    key: "resetStates",
	    value: function resetStates() {
	      var _this5 = this;
	      tidy(function () {
	        _this5.layers.forEach(function (layer) {
	          // tslint:disable:no-any
	          if (layer.stateful) {
	            layer.resetStates();
	          }
	          // tslint:enable:no-any
	        });
	      });
	    }
	  }], [{
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      var customObjects = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
	      var fastWeightInit = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	      // Layer instances created during
	      // the graph reconstruction process
	      var createdLayers = {};
	      // Dictionary mapping layer instances to
	      // node data that specifies a layer call.
	      // It acts as a queue that maintains any unprocessed
	      // layer call until it becomes possible to process it
	      // (i.e. until the input tensors to the call all exist).
	      var unprocessedNodes = {};
	      function addUnprocessedNode(layer, nodeData) {
	        if (!(layer.name in unprocessedNodes)) {
	          unprocessedNodes[layer.name] = [nodeData];
	        } else {
	          unprocessedNodes[layer.name].push(nodeData);
	        }
	      }
	      function processNode(layer, nodeData) {
	        var inputTensors = [];
	        var kwargs;
	        var _iterator31 = _createForOfIteratorHelper(nodeData),
	          _step31;
	        try {
	          for (_iterator31.s(); !(_step31 = _iterator31.n()).done;) {
	            var inputData = _step31.value;
	            var inboundLayerName = inputData[0];
	            var inboundNodeIndex = inputData[1];
	            var inboundTensorIndex = inputData[2];
	            kwargs = inputData[3] == null ? {} : inputData[3];
	            if (!(inboundLayerName in createdLayers)) {
	              addUnprocessedNode(layer, nodeData);
	              return;
	            }
	            var inboundLayer = createdLayers[inboundLayerName];
	            if (inboundLayer.inboundNodes.length <= inboundNodeIndex) {
	              addUnprocessedNode(layer, nodeData);
	              return;
	            }
	            var inboundNode = inboundLayer.inboundNodes[inboundNodeIndex];
	            inputTensors.push(inboundNode.outputTensors[inboundTensorIndex]);
	          }
	          // Call layer on its inputs, thus creating the node
	          // and building the layer if needed.
	          // Note: This has Eager vs Graph Implications.
	        } catch (err) {
	          _iterator31.e(err);
	        } finally {
	          _iterator31.f();
	        }
	        if (inputTensors.length > 0) {
	          layer.apply(singletonOrArray(inputTensors), kwargs); // was ** kwargs
	        }
	      }
	      /**
	       * Deserialize a layer, then call it on appropriate inputs.
	       * @param layerData: layer config dict.
	       * @throws ValueError: In case of improperly formatted `layer_data`
	       * dict.
	       */
	      function processLayer(layerData) {
	        var layerName = layerData['name'];
	        // Instantiate layer.
	        var layer = deserialize(layerData, config['customObjects'] != null ? config['customObjects'] : {});
	        layer.setFastWeightInitDuringBuild(fastWeightInit);
	        createdLayers[layerName] = layer;
	        // Gather layer inputs.
	        var inboundNodesData = layerData['inboundNodes'];
	        inboundNodesData.forEach(function (nodeData) {
	          if (!(nodeData instanceof Array)) {
	            throw new ValueError("Corrupted configuration, expected array for nodeData: ".concat(nodeData));
	          }
	          // We don't process nodes (i.e. make layer calls)
	          // on the fly because the inbound node may not yet exist,
	          // in case of layer shared at different topological depths
	          // (e.g.a model such as A(B(A(B(x)))))
	          addUnprocessedNode(layer, nodeData);
	        });
	      }
	      // First, we create all layers and enqueue nodes to be processed.
	      var name = config['name'];
	      var layersFromConfig = config['layers'];
	      var _iterator32 = _createForOfIteratorHelper(layersFromConfig),
	        _step32;
	      try {
	        for (_iterator32.s(); !(_step32 = _iterator32.n()).done;) {
	          var _layerData = _step32.value;
	          processLayer(_layerData);
	        }
	        // Then we process nodes in order of layer depth.
	        // Nodes that cannot yet be processed(if the inbound node
	        // does not yet exist) are re - enqueued, and the process
	        // is repeated until all nodes are processed.
	      } catch (err) {
	        _iterator32.e(err);
	      } finally {
	        _iterator32.f();
	      }
	      while (!isObjectEmpty(unprocessedNodes)) {
	        var _iterator33 = _createForOfIteratorHelper(layersFromConfig),
	          _step33;
	        try {
	          for (_iterator33.s(); !(_step33 = _iterator33.n()).done;) {
	            var layerData = _step33.value;
	            var layer = createdLayers[layerData['name']];
	            if (layer.name in unprocessedNodes) {
	              var currentUnprocessedNodesForLayer = unprocessedNodes[layer.name];
	              delete unprocessedNodes[layer.name];
	              var _iterator34 = _createForOfIteratorHelper(currentUnprocessedNodesForLayer),
	                _step34;
	              try {
	                for (_iterator34.s(); !(_step34 = _iterator34.n()).done;) {
	                  var nodeData = _step34.value;
	                  processNode(layer, nodeData);
	                }
	              } catch (err) {
	                _iterator34.e(err);
	              } finally {
	                _iterator34.f();
	              }
	            }
	          }
	        } catch (err) {
	          _iterator33.e(err);
	        } finally {
	          _iterator33.f();
	        }
	      }
	      var inputTensors = [];
	      var outputTensors = [];
	      var inputLayersFromConfig = config['inputLayers'];
	      var _iterator35 = _createForOfIteratorHelper(inputLayersFromConfig),
	        _step35;
	      try {
	        for (_iterator35.s(); !(_step35 = _iterator35.n()).done;) {
	          var _layerData2 = _step35.value;
	          var layerName = _layerData2[0];
	          var nodeIndex = _layerData2[1];
	          var tensorIndex = _layerData2[2];
	          assert(layerName in createdLayers);
	          var _layer12 = createdLayers[layerName];
	          var layerOutputTensors = _layer12.inboundNodes[nodeIndex].outputTensors;
	          inputTensors.push(layerOutputTensors[tensorIndex]);
	        }
	      } catch (err) {
	        _iterator35.e(err);
	      } finally {
	        _iterator35.f();
	      }
	      var outputLayersFromConfig = config['outputLayers'];
	      var _iterator36 = _createForOfIteratorHelper(outputLayersFromConfig),
	        _step36;
	      try {
	        for (_iterator36.s(); !(_step36 = _iterator36.n()).done;) {
	          var _layerData3 = _step36.value;
	          var _layerName = _layerData3[0];
	          var _nodeIndex8 = _layerData3[1];
	          var _tensorIndex6 = _layerData3[2];
	          assert(_layerName in createdLayers);
	          var _layer13 = createdLayers[_layerName];
	          var _layerOutputTensors = _layer13.inboundNodes[_nodeIndex8].outputTensors;
	          outputTensors.push(_layerOutputTensors[_tensorIndex6]);
	        }
	      } catch (err) {
	        _iterator36.e(err);
	      } finally {
	        _iterator36.f();
	      }
	      return new cls({
	        inputs: inputTensors,
	        outputs: outputTensors,
	        name: name
	      });
	    }
	  }]);
	  return Container;
	}(Layer);

	function standardizeSampleOrClassWeights(xWeight, outputNames, weightType) {
	  var numOutputs = outputNames.length;
	  if (xWeight == null || Array.isArray(xWeight) && xWeight.length === 0) {
	    return outputNames.map(function (name) {
	      return null;
	    });
	  }
	  if (numOutputs === 1) {
	    if (Array.isArray(xWeight) && xWeight.length === 1) {
	      return xWeight;
	    } else if (_typeof(xWeight) === 'object' && outputNames[0] in xWeight) {
	      return [xWeight[outputNames[0]]];
	    } else {
	      return [xWeight];
	    }
	  }
	  if (Array.isArray(xWeight)) {
	    if (xWeight.length !== numOutputs) {
	      throw new Error("Provided ".concat(weightType, " is an array of ").concat(xWeight.length, " ") + "element(s), but the model has ".concat(numOutputs, " outputs. ") + "Make sure a set of weights is provided for each model output.");
	    }
	    return xWeight;
	  } else if (_typeof(xWeight) === 'object' && Object.keys(xWeight).length > 0 && _typeof(xWeight[Object.keys(xWeight)[0]]) === 'object') {
	    var output = [];
	    outputNames.forEach(function (outputName) {
	      if (outputName in xWeight) {
	        output.push(xWeight[outputName]);
	      } else {
	        output.push(null);
	      }
	    });
	    return output;
	  } else {
	    throw new Error("The model has multiple (".concat(numOutputs, ") outputs, ") + "so ".concat(weightType, " must be either an array with ") + "".concat(numOutputs, " elements or an object with ").concat(outputNames, " keys. ") + "Provided ".concat(weightType, " not understood: ").concat(JSON.stringify(xWeight)));
	  }
	}
	/**
	 * Standardize class weighting objects.
	 *
	 * This function takes a single class-weighting object, an array of them,
	 * or a map from output name to class-weighting object. It compares it to the
	 * output name(s) of the model, base on which it outputs an array of
	 * class-weighting objects of which the length matches the number of outputs.
	 *
	 * @param classWeight Input class-weighting object(s).
	 * @param outputNames All output name(s) of the model.
	 * @return An array of class-weighting objects. The length of the array matches
	 *   the model's number of outputs.
	 */
	function standardizeClassWeights(classWeight, outputNames) {
	  return standardizeSampleOrClassWeights(classWeight, outputNames, 'classWeight');
	}
	function standardizeSampleWeights(classWeight, outputNames) {
	  return standardizeSampleOrClassWeights(classWeight, outputNames, 'sampleWeight');
	}
	/**
	 * Standardize by-sample and/or by-class weights for training.
	 *
	 * Note that this function operates on one model output at a time. For a model
	 * with multiple outputs, you must call this function multiple times.
	 *
	 * @param y The target tensor that the by-sample and/or by-class weight is for.
	 *     The values of y are assumed to encode the classes, either directly
	 *     as an integer index, or as one-hot encoding.
	 * @param sampleWeight By-sample weights.
	 * @param classWeight By-class weights: an object mapping class indices
	 *     (integers) to a weight (float) to apply to the model's loss for the
	 *     samples from this class during training. This can be useful to tell the
	 *     model to "pay more attention" to samples from an under-represented class.
	 * @param sampleWeightMode The mode for the sample weights.
	 * @return A Promise of weight tensor, of which the size of the first dimension
	 *     matches that of `y`.
	 */
	function standardizeWeights(_x, _x2, _x3, _x4) {
	  return _standardizeWeights.apply(this, arguments);
	}
	/**
	 * Apply per-sample weights on the loss values from a number of samples.
	 *
	 * @param losses Loss tensor of shape `[batchSize]`.
	 * @param sampleWeights Per-sample weight tensor of shape `[batchSize]`.
	 * @returns Tensor of the same shape as`losses`.
	 */
	function _standardizeWeights() {
	  _standardizeWeights = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(y, sampleWeight, classWeight, sampleWeightMode) {
	    var yClasses, yClassIndices, classSampleWeight;
	    return _regeneratorRuntime().wrap(function _callee$(_context) {
	      while (1) switch (_context.prev = _context.next) {
	        case 0:
	          if (!(sampleWeight != null || sampleWeightMode != null)) {
	            _context.next = 2;
	            break;
	          }
	          throw new Error('Support sampleWeight is not implemented yet');
	        case 2:
	          if (!(classWeight != null)) {
	            _context.next = 15;
	            break;
	          }
	          // Apply class weights per sample.
	          yClasses = tidy(function () {
	            if (y.shape.length === 1) {
	              // Assume class indices.
	              return clone(y);
	            } else if (y.shape.length === 2) {
	              if (y.shape[1] > 1) {
	                // Assume one-hot encoding of classes.
	                var axis = 1;
	                return argMax$2(y, axis);
	              } else if (y.shape[1] === 1) {
	                // Class index.
	                return reshape$3(y, [y.shape[0]]);
	              } else {
	                throw new Error("Encountered unexpected last-dimension size (".concat(y.shape[1], ") ") + "during handling of class weights. The size is expected to be " + ">= 1.");
	              }
	            } else {
	              throw new Error("Unexpected rank of target (y) tensor (".concat(y.rank, ") during ") + "handling of class weights. The rank is expected to be 1 or 2.");
	            }
	          });
	          _context.t0 = Array;
	          _context.next = 7;
	          return yClasses.data();
	        case 7:
	          _context.t1 = _context.sent;
	          yClassIndices = _context.t0.from.call(_context.t0, _context.t1);
	          dispose(yClasses);
	          classSampleWeight = [];
	          yClassIndices.forEach(function (classIndex) {
	            if (classWeight[classIndex] == null) {
	              throw new Error("classWeight must contain all classes in the training data. " + "The class ".concat(classIndex, " exists in the data but not in ") + "classWeight");
	            } else {
	              classSampleWeight.push(classWeight[classIndex]);
	            }
	          });
	          return _context.abrupt("return", tensor1d(classSampleWeight, 'float32'));
	        case 15:
	          return _context.abrupt("return", null);
	        case 16:
	        case "end":
	          return _context.stop();
	      }
	    }, _callee);
	  }));
	  return _standardizeWeights.apply(this, arguments);
	}
	function computeWeightedLoss(losses, sampleWeights) {
	  return mul(losses, sampleWeights);
	}

	// Default batch size used during tensor-based validation.
	var DEFAULT_VALIDATION_BATCH_SIZE = 32;
	/**
	 * Standardize the output of a dataset iterator for use by
	 * LayersModel.fitDataset().
	 *
	 * @param model: A `tf.LayersModel` object.
	 * @param iteratorOut The output of a dataset iterator. It is required to be
	 *   an object of the form `{xs: TensorOrArrayOrMap, ys:
	 * TensorOrArrayOrMap}`, where `TensorOrArrayOrMap` is a single `tf.Tensor`,
	 * a `tf.Tensor[]`, or a flat map from string names to `tf.Tensor`s.
	 * @returns A flat array of `tf.Tensor` objects: the input `tf.Tensor`s
	 *   followed by the target `tf.Tensor`s.  When `tf.Tensor`s are provided
	 *   as a map, the order in the resulting array is taken from the `inputNames`
	 *   and `outputNames` of the model.
	 */
	function standardizeDataIteratorOutput(
	// Type `model` as `any` here to avoid circular dependency w/
	// training.ts.
	// tslint:disable-next-line:no-any
	model, iteratorOut) {
	  var xs;
	  var ys;
	  var iteratorOutObj = iteratorOut;
	  xs = iteratorOutObj['xs'];
	  ys = iteratorOutObj['ys'];
	  assert$1(xs != null && ys != null, function () {
	    return 'A Dataset iterator for fitDataset() is expected to generate ' + 'objects of the form `{xs: xVal, ys: yVal}`, where the two ' + 'values may be `tf.Tensor`, an array of Tensors, or a map of ' + 'string to Tensor.  The provided Dataset instead generates ' + "".concat(iteratorOut);
	  });
	  var flattenedXs = flattenTensorOrArrayOrMap('input', model.inputNames, xs);
	  var flattenedYs = flattenTensorOrArrayOrMap('output', model.outputNames, ys);
	  var batchSize = flattenedXs[0].shape[0];
	  assert$1(flattenedXs.length === model.inputs.length, function () {
	    return "LayersModel has ".concat(model.inputs.length, " inputs, but the dataset ") + "provides ".concat(flattenedXs.length, " inputs.  (Expected input keys: ") + "".concat(JSON.stringify(model.inputNames), ")");
	  });
	  assert$1(flattenedYs.length === model.outputs.length, function () {
	    return "LayersModel has ".concat(model.outputs.length, " outputs, but the dataset ") + "provides ".concat(flattenedYs.length, " outputs.  (Expected output keys: ") + "".concat(JSON.stringify(model.outputNames), ")");
	  });
	  var _loop = function _loop(xIndex) {
	    assert$1(flattenedXs[xIndex].shape[0] === batchSize, function () {
	      return "Batch size mismatch: input " + "".concat(model.inputNames[xIndex], " has ").concat(flattenedXs[xIndex].shape[0], "; ") + "expected  ".concat(batchSize, " based on input ").concat(model.inputNames[0], ".");
	    });
	  };
	  for (var xIndex = 0; xIndex < flattenedXs.length; xIndex++) {
	    _loop(xIndex);
	  }
	  var _loop2 = function _loop2(yIndex) {
	    assert$1(flattenedYs[yIndex].shape[0] === batchSize, function () {
	      return "Batch size mismatch: output " + "".concat(model.outputNames[yIndex], " has ").concat(flattenedYs[yIndex].shape[0], "; ") + "expected  ".concat(batchSize, " based on input ").concat(model.inputNames[0], ".");
	    });
	  };
	  for (var yIndex = 0; yIndex < flattenedYs.length; yIndex++) {
	    _loop2(yIndex);
	  }
	  return {
	    xs: flattenedXs,
	    ys: flattenedYs
	  };
	}
	function flattenTensorOrArrayOrMap(inputOrOutput, names, values) {
	  if (values instanceof Tensor) {
	    return [values];
	  } else if (Array.isArray(values)) {
	    assert$1(values.length === names.length, function () {
	      return "Received an array of ".concat(values.length, " Tensors, but expected ").concat(names.length, " to match the ").concat(inputOrOutput, " keys ").concat(names, ".");
	    });
	    return values;
	  } else {
	    var result = [];
	    // Check that all the required keys are available.
	    var _iterator = _createForOfIteratorHelper(names),
	      _step;
	    try {
	      for (_iterator.s(); !(_step = _iterator.n()).done;) {
	        var name = _step.value;
	        if (values[name] == null) {
	          throw new ValueError("The feature data generated by the dataset lacks the required " + "".concat(inputOrOutput, " key '").concat(name, "'."));
	        }
	        result.push(values[name]);
	      }
	    } catch (err) {
	      _iterator.e(err);
	    } finally {
	      _iterator.f();
	    }
	    return result;
	  }
	}
	function standardizeTensorValidationData(data) {
	  if (data.length === 3) {
	    throw new NotImplementedError('Validation with sample weights is not implemented yet.');
	  }
	  return {
	    xs: data[0],
	    ys: data[1]
	  };
	}
	function fitDataset(_x, _x2, _x3) {
	  return _fitDataset.apply(this, arguments);
	}
	/** Helper function that determines number of steps (batches) per epoch. */
	function _fitDataset() {
	  _fitDataset = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(
	  // Type `model` as `any` here to avoid circular dependency w/
	  // training.ts.
	  // tslint:disable-next-line:no-any
	  model, dataset, args) {
	    var hasBatchesPerEpoch, doValidation, valXs, valYs, validationData, trainFunction, outLabels, callbackMetrics, callbacks, verbose, _configureCallbacks, callbackList, history, epoch, dataIterator, epochLogs, stepsDone, batchIndex, iteratorOut, _standardizeDataItera, xs, ys, batchLogs, sampleWeights, standardClassWeights, i, ins, outs, _i, label, out, valOuts, _i2;
	    return _regeneratorRuntime().wrap(function _callee$(_context) {
	      while (1) switch (_context.prev = _context.next) {
	        case 0:
	          hasBatchesPerEpoch = args.batchesPerEpoch != null;
	          assert$1(model.optimizer != null, function () {
	            return 'You must compile a model before training/testing. Use ' + 'LayersModel.compile(modelCompileConfig).';
	          });
	          assert$1(args != null, function () {
	            return "For fitDataset(), the 2nd argument (config) is required, " + "but it is not provided in this call.";
	          });
	          assert$1(args.epochs != null && args.epochs > 0 && Number.isInteger(args.epochs), function () {
	            return "For fitDataset(), config.epochs is expected to be a positive " + "integer, but got ".concat(args.epochs);
	          });
	          assert$1(!hasBatchesPerEpoch || args.batchesPerEpoch > 0 && Number.isInteger(args.batchesPerEpoch), function () {
	            return "For fitDataset(), config.batchesPerEpoch is expected to be a " + "positive integer if specified, but got ".concat(args.batchesPerEpoch);
	          });
	          assert$1(
	          // tslint:disable-next-line:no-any
	          args['validationSplit'] == null, function () {
	            return '`validationSplit` is not supported by `fitDataset()`. ' + 'Use validationData instead.';
	          });
	          if (!model.isTraining) {
	            _context.next = 8;
	            break;
	          }
	          throw new Error('Cannot start training because another fit() call is ongoing.');
	        case 8:
	          model.isTraining = true;
	          _context.prev = 9;
	          doValidation = args.validationData != null;
	          if (doValidation) {
	            if (isDatasetObject(args.validationData)) {
	              assert$1(args.validationBatches == null || args.validationBatches > 0 && Number.isInteger(args.validationBatches), function () {
	                return "For fitDataset() with dataset-based validation, " + "config.validationBatches is expected not to be provided, " + "or to be a positive integer, " + "but got ".concat(args.validationBatches);
	              });
	            } else {
	              validationData = standardizeTensorValidationData(args.validationData);
	              valXs = validationData.xs;
	              valYs = validationData.ys;
	            }
	          }
	          trainFunction = model.makeTrainFunction();
	          outLabels = model.getDedupedMetricsNames();
	          if (doValidation) {
	            callbackMetrics = outLabels.slice().concat(outLabels.map(function (n) {
	              return 'val_' + n;
	            }));
	          } else {
	            callbackMetrics = outLabels.slice();
	          }
	          callbacks = standardizeCallbacks(args.callbacks, args.yieldEvery);
	          verbose = args.verbose == null ? 1 : args.verbose;
	          _configureCallbacks = configureCallbacks(callbacks, verbose, args.epochs, null, null, getStepsPerEpoch(dataset, args), null,
	          // Batch size determined by the dataset itself.
	          doValidation, callbackMetrics), callbackList = _configureCallbacks.callbackList, history = _configureCallbacks.history;
	          callbackList.setModel(model);
	          model.history = history;
	          _context.next = 22;
	          return callbackList.onTrainBegin();
	        case 22:
	          model.stopTraining_ = false;
	          epoch = args.initialEpoch == null ? 0 : args.initialEpoch;
	          _context.next = 26;
	          return dataset.iterator();
	        case 26:
	          dataIterator = _context.sent;
	        case 27:
	          if (!(epoch < args.epochs)) {
	            _context.next = 98;
	            break;
	          }
	          epochLogs = {};
	          _context.next = 31;
	          return callbackList.onEpochBegin(epoch);
	        case 31:
	          stepsDone = 0;
	          batchIndex = 0;
	          if (hasBatchesPerEpoch) {
	            _context.next = 37;
	            break;
	          }
	          _context.next = 36;
	          return dataset.iterator();
	        case 36:
	          dataIterator = _context.sent;
	        case 37:
	          if (!(hasBatchesPerEpoch ? stepsDone < args.batchesPerEpoch : true)) {
	            _context.next = 91;
	            break;
	          }
	          _context.next = 40;
	          return dataIterator.next();
	        case 40:
	          iteratorOut = _context.sent;
	          if (!(hasBatchesPerEpoch && iteratorOut.done)) {
	            _context.next = 44;
	            break;
	          }
	          console.warn('You provided `batchesPerEpoch` as ' + "".concat(args.batchesPerEpoch, ", ") + 'but your dataset iterator ran out of data after ' + "".concat(stepsDone, " batches; ") + 'interrupting training. Make sure that your ' + 'dataset can generate at least `batchesPerEpoch * epochs` ' + 'batches (in this case, ' + "".concat(args.batchesPerEpoch * args.epochs, " batches). ") + 'You may need to use the repeat() function when building ' + 'your dataset.');
	          return _context.abrupt("break", 91);
	        case 44:
	          if (!(iteratorOut.value != null)) {
	            _context.next = 73;
	            break;
	          }
	          _standardizeDataItera = standardizeDataIteratorOutput(model, iteratorOut.value), xs = _standardizeDataItera.xs, ys = _standardizeDataItera.ys;
	          batchLogs = {};
	          batchLogs['batch'] = batchIndex;
	          batchLogs['size'] = xs[0].shape[0];
	          _context.next = 51;
	          return callbackList.onBatchBegin(batchIndex, batchLogs);
	        case 51:
	          sampleWeights = [];
	          if (!(args.classWeight != null)) {
	            _context.next = 64;
	            break;
	          }
	          standardClassWeights = standardizeClassWeights(args.classWeight, model.outputNames);
	          i = 0;
	        case 55:
	          if (!(i < standardClassWeights.length)) {
	            _context.next = 64;
	            break;
	          }
	          _context.t0 = sampleWeights;
	          _context.next = 59;
	          return standardizeWeights(ys[i], null, standardClassWeights[i]);
	        case 59:
	          _context.t1 = _context.sent;
	          _context.t0.push.call(_context.t0, _context.t1);
	        case 61:
	          ++i;
	          _context.next = 55;
	          break;
	        case 64:
	          // Train on batch.
	          ins = xs.concat(ys).concat(sampleWeights);
	          outs = trainFunction(ins);
	          dispose(ins);
	          for (_i = 0; _i < outLabels.length; ++_i) {
	            label = outLabels[_i];
	            out = outs[_i];
	            batchLogs[label] = out;
	            keep(out);
	          }
	          _context.next = 70;
	          return callbackList.onBatchEnd(batchIndex, batchLogs);
	        case 70:
	          disposeTensorsInLogs(batchLogs);
	          batchIndex++;
	          stepsDone++;
	        case 73:
	          if (!(hasBatchesPerEpoch ? stepsDone >= args.batchesPerEpoch : iteratorOut.done)) {
	            _context.next = 87;
	            break;
	          }
	          if (!doValidation) {
	            _context.next = 86;
	            break;
	          }
	          valOuts = void 0;
	          if (!isDatasetObject(args.validationData)) {
	            _context.next = 84;
	            break;
	          }
	          _context.t2 = toList;
	          _context.next = 80;
	          return model.evaluateDataset(args.validationData, {
	            batches: args.validationBatches
	          });
	        case 80:
	          _context.t3 = _context.sent;
	          valOuts = (0, _context.t2)(_context.t3);
	          _context.next = 85;
	          break;
	        case 84:
	          valOuts = toList(model.evaluate(valXs, valYs, {
	            batchSize: args.validationBatchSize == null ? DEFAULT_VALIDATION_BATCH_SIZE : args.validationBatchSize,
	            verbose: 0
	          }));
	        case 85:
	          for (_i2 = 0; _i2 < model.metricsNames.length; ++_i2) {
	            epochLogs["val_".concat(model.metricsNames[_i2])] = valOuts[_i2];
	          }
	        case 86:
	          return _context.abrupt("break", 91);
	        case 87:
	          if (!model.stopTraining_) {
	            _context.next = 89;
	            break;
	          }
	          return _context.abrupt("break", 91);
	        case 89:
	          _context.next = 37;
	          break;
	        case 91:
	          _context.next = 93;
	          return callbackList.onEpochEnd(epoch, epochLogs);
	        case 93:
	          epoch++;
	          if (!model.stopTraining_) {
	            _context.next = 96;
	            break;
	          }
	          return _context.abrupt("break", 98);
	        case 96:
	          _context.next = 27;
	          break;
	        case 98:
	          _context.next = 100;
	          return callbackList.onTrainEnd();
	        case 100:
	          _context.next = 102;
	          return model.history.syncData();
	        case 102:
	          return _context.abrupt("return", model.history);
	        case 103:
	          _context.prev = 103;
	          model.isTraining = false;
	          return _context.finish(103);
	        case 106:
	        case "end":
	          return _context.stop();
	      }
	    }, _callee, null, [[9,, 103, 106]]);
	  }));
	  return _fitDataset.apply(this, arguments);
	}
	function getStepsPerEpoch(dataset, args) {
	  // Attempt to determine # of batches in an epoch.
	  var stepsPerEpoch = null;
	  if (args.batchesPerEpoch != null) {
	    stepsPerEpoch = args.batchesPerEpoch;
	  } else if (Number.isFinite(dataset.size)) {
	    stepsPerEpoch = dataset.size;
	  }
	  return stepsPerEpoch;
	}
	// Check if provided object is a Dataset object by checking its .iterator
	// element.
	function isDatasetObject(dataset) {
	  return typeof dataset.iterator === 'function';
	}
	// Check if provided object is a LazyIterator object by checking it's .next
	// element.
	function isLazyIteratorObject(iterator) {
	  return typeof iterator.next === 'function';
	}
	function evaluateDataset(_x4, _x5, _x6) {
	  return _evaluateDataset.apply(this, arguments);
	}
	function _evaluateDataset() {
	  _evaluateDataset = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(
	  // Type `model` as `any` here to avoid circular dependency w/
	  // training.ts.
	  // tslint:disable-next-line:no-any
	  model, dataset, args) {
	    var hasBatches, f, outs, dataIterator, numExamples, batch, _loop3, _ret, i, oldScalar;
	    return _regeneratorRuntime().wrap(function _callee2$(_context3) {
	      while (1) switch (_context3.prev = _context3.next) {
	        case 0:
	          args = args || {};
	          hasBatches = args.batches != null;
	          f = model.testFunction;
	          outs = [];
	          if (!(args.verbose > 0)) {
	            _context3.next = 6;
	            break;
	          }
	          throw new NotImplementedError('Verbose mode is not implemented yet.');
	        case 6:
	          assert$1(!hasBatches || args.batches > 0 && Number.isInteger(args.batches), function () {
	            return 'Test loop expects `batches` to be a positive integer, but ' + "received ".concat(JSON.stringify(args.batches));
	          });
	          if (!isLazyIteratorObject(dataset)) {
	            _context3.next = 11;
	            break;
	          }
	          _context3.t0 = dataset;
	          _context3.next = 14;
	          break;
	        case 11:
	          _context3.next = 13;
	          return dataset.iterator();
	        case 13:
	          _context3.t0 = _context3.sent;
	        case 14:
	          dataIterator = _context3.t0;
	          // Keeps track of number of examples used in this evaluation.
	          numExamples = 0;
	          batch = 0;
	          _loop3 = /*#__PURE__*/_regeneratorRuntime().mark(function _loop3() {
	            var iteratorOut;
	            return _regeneratorRuntime().wrap(function _loop3$(_context2) {
	              while (1) switch (_context2.prev = _context2.next) {
	                case 0:
	                  _context2.next = 2;
	                  return dataIterator.next();
	                case 2:
	                  iteratorOut = _context2.sent;
	                  outs = tidy(function () {
	                    if (iteratorOut.value) {
	                      // TODO(cais): Once real dataset is available, use
	                      //   `map(x => standardizeDataIteratorOutput(model, x).map(f)`.
	                      var _standardizeDataItera2 = standardizeDataIteratorOutput(model, iteratorOut.value),
	                        xs = _standardizeDataItera2.xs,
	                        ys = _standardizeDataItera2.ys;
	                      var xsAndYs = xs.concat(ys);
	                      var batchOuts = tidy(function () {
	                        return f(xsAndYs);
	                      });
	                      dispose(xsAndYs);
	                      if (batch === 0) {
	                        for (var _i3 = 0; _i3 < batchOuts.length; ++_i3) {
	                          outs.push(scalar(0));
	                        }
	                      }
	                      var batchSize = xsAndYs[0].shape[0];
	                      var _loop4 = function _loop4(_i4) {
	                        var batchOut = batchOuts[_i4];
	                        var oldScalar = outs[_i4];
	                        outs[_i4] = tidy(function () {
	                          return add$3(outs[_i4], mul(batchSize, batchOut));
	                        });
	                        if (batch > 0) {
	                          dispose(oldScalar);
	                        }
	                      };
	                      for (var _i4 = 0; _i4 < batchOuts.length; ++_i4) {
	                        _loop4(_i4);
	                      }
	                      dispose(batchOuts);
	                      numExamples += batchSize;
	                      ++batch;
	                    }
	                    return outs;
	                  });
	                  if (!iteratorOut.done) {
	                    _context2.next = 7;
	                    break;
	                  }
	                  if (hasBatches) {
	                    console.warn('Your dataset iterator ran out of data during evaluateDataset(). ' + 'Interrupting evalution. Make sure that your ' + 'dataset can generate at least `batches` ' + "batches (in this case, ".concat(args.batches, " batches). ") + 'You may need to use the repeat() function when building ' + 'your dataset.');
	                  }
	                  return _context2.abrupt("return", "break");
	                case 7:
	                case "end":
	                  return _context2.stop();
	              }
	            }, _loop3);
	          });
	        case 18:
	          if (!(hasBatches ? batch < args.batches : true)) {
	            _context3.next = 25;
	            break;
	          }
	          return _context3.delegateYield(_loop3(), "t1", 20);
	        case 20:
	          _ret = _context3.t1;
	          if (!(_ret === "break")) {
	            _context3.next = 23;
	            break;
	          }
	          return _context3.abrupt("break", 25);
	        case 23:
	          _context3.next = 18;
	          break;
	        case 25:
	          for (i = 0; i < outs.length; ++i) {
	            oldScalar = outs[i];
	            outs[i] = div$1(outs[i], numExamples);
	            dispose(oldScalar);
	          }
	          return _context3.abrupt("return", singletonOrArray(outs));
	        case 27:
	        case "end":
	          return _context3.stop();
	      }
	    }, _callee2);
	  }));
	  return _evaluateDataset.apply(this, arguments);
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	function checkBatchSize(batchSize) {
	  assert$1(batchSize > 0 && Number.isInteger(batchSize), function () {
	    return "batchSize is required to be a positive integer, but got ".concat(batchSize);
	  });
	}
	/**
	 * Slice a Tensor or an Array of Tensors, by start and stop indices.
	 *
	 * Porting Note: The `_slice_arrays` function in PyKeras is covered by this
	 *   function and `sliceArraysByIndices()` together.
	 *
	 * @param arrays: the input.
	 * @param start: the starting index (inclusive).
	 * @param stop: the stopping index (exclusive).
	 * @returns The result of the slicing. If `arrays` is an `Array` of
	 *   `tf.Tensor`s, the slicing will be applied to all elements of the `Array`
	 *   in the same way.
	 */
	function sliceArrays(arrays, start, stop) {
	  if (arrays == null) {
	    return [null];
	  } else if (Array.isArray(arrays)) {
	    return arrays.map(function (array) {
	      return sliceAlongFirstAxis(array, start, stop - start);
	    });
	  } else {
	    // Tensor.
	    return sliceAlongFirstAxis(arrays, start, stop - start);
	  }
	}
	/**
	 * Slice a Tensor or an Array of Tensors, by random-order indices.
	 *
	 * Porting Note: The `_slice_arrays` function in PyKeras is covered by this
	 *   function and `sliceArrays()` together.
	 *
	 * @param arrays The input `tf.Tensor` or `Array` of `tf.Tensor`s to slice.
	 *   If an `Array` of `tf.Tensor`s, all `tf.Tensor`s will be sliced in the
	 *   same fashion.
	 * @param indices The indices to use for slicing along the first (batch)
	 *   dimension.
	 * @returns Result(s) of the slicing.
	 */
	function sliceArraysByIndices(arrays, indices) {
	  return tidy(function () {
	    if (arrays == null) {
	      return null;
	    } else if (Array.isArray(arrays)) {
	      return arrays.map(function (array) {
	        return sliceArraysByIndices(array, indices);
	      });
	    } else {
	      // TODO(cais): indices should be a pre-constructed Tensor1D to avoid
	      //   tensor1d() calls.
	      return gather(arrays, indices.dtype === 'int32' ? indices : cast$3(indices, 'int32'));
	    }
	  });
	}
	/**
	 * Returns a list of batch indices (tuples of indices).
	 * @param size: Integer, total size of the data to slice into batches.
	 * @param batchSize: Integer, batch size.
	 * @returns An Array of [batchStart, batchEnd] tuples. batchStart is
	 *   inclusive; batchEnd is exclusive. I.e., each batch consists of indices x
	 *   that satisfy batchStart <= x < batchEnd.
	 */
	function makeBatches(size, batchSize) {
	  var output = [];
	  var batchStart = 0;
	  var batchEnd = null;
	  while (batchStart < size) {
	    batchEnd = batchStart + batchSize;
	    if (batchEnd >= size) {
	      batchEnd = size;
	    }
	    output.push([batchStart, batchEnd]);
	    batchStart = batchEnd;
	  }
	  return output;
	}
	/**
	 * Ensure tensors all have a rank of at least 2.
	 *
	 * If a tensor has a rank of 1, it is dimension-expanded to rank 2.
	 * If any tensor has a rank of 0 (i.e., is a scalar), an error will be thrown.
	 */
	function ensureTensorsRank2OrHigher(tensors) {
	  var outs = [];
	  if (tensors instanceof Tensor) {
	    tensors = [tensors];
	  }
	  // Make Tensors at least 2D.
	  for (var i = 0; i < tensors.length; ++i) {
	    var tensor = tensors[i];
	    if (tensor.rank === 1) {
	      outs.push(expandDims$2(tensor, 1));
	    } else if (tensor.rank === 0) {
	      throw new Error('Expected tensor to be at least 1D, but received a 0D tensor ' + '(scalar).');
	    } else {
	      outs.push(tensor);
	    }
	  }
	  return outs;
	}
	/**
	 * Compare a set of tensors with a reference (old) set, discard the ones
	 * in the new set that are not present in the reference set.
	 *
	 * This method is used for memory clenaup during calls such as
	 * LayersModel.fit().
	 *
	 * @param tensors New set which may contain Tensors not present in
	 *   `refTensors`.
	 * @param refTensors Reference Tensor set.
	 */
	// TODO(cais, kangyizhang): Deduplicate with tfjs-data.
	function disposeNewTensors(tensors, refTensors) {
	  if (tensors == null) {
	    return;
	  }
	  var oldTensorIds = [];
	  if (refTensors instanceof Tensor) {
	    oldTensorIds.push(refTensors.id);
	  } else if (Array.isArray(refTensors)) {
	    refTensors.forEach(function (t) {
	      return oldTensorIds.push(t.id);
	    });
	  } else if (refTensors != null) {
	    // `oldTensors` is a map from string name to Tensor.
	    for (var name in refTensors) {
	      var oldTensor = refTensors[name];
	      oldTensorIds.push(oldTensor.id);
	    }
	  }
	  var tensorsToDispose = [];
	  if (tensors instanceof Tensor) {
	    if (oldTensorIds.indexOf(tensors.id) === -1) {
	      tensorsToDispose.push(tensors);
	    }
	  } else if (Array.isArray(tensors)) {
	    tensors.forEach(function (t) {
	      if (oldTensorIds.indexOf(t.id) === -1) {
	        tensorsToDispose.push(t);
	      }
	    });
	  } else if (tensors != null) {
	    // `oldTensors` is a map from string name to Tensor.
	    for (var _name in tensors) {
	      var tensor = tensors[_name];
	      if (oldTensorIds.indexOf(tensor.id) === -1) {
	        tensorsToDispose.push(tensor);
	      }
	    }
	  }
	  tensorsToDispose.forEach(function (t) {
	    if (!t.isDisposed) {
	      t.dispose();
	    }
	  });
	}

	/**
	 * Helper function for polymorphic input data: 1. singleton Tensor.
	 */
	function isDataTensor(x) {
	  return x instanceof Tensor;
	}
	/**
	 * Helper function for polymorphic input data: 2. Array of Tensor.
	 */
	function isDataArray(x) {
	  return Array.isArray(x);
	}
	/**
	 * Helper function for polymorphic input data: 3. "dict" of Tensor.
	 */
	function isDataDict(x) {
	  return !isDataTensor(x) && !isDataArray(x);
	}
	/**
	 * Normalizes inputs and targets provided by users.
	 * @param data User-provided input data (polymorphic).
	 * @param names An Array of expected Tensor names.
	 * @param shapes Optional Array of expected Tensor shapes.
	 * @param checkBatchAxis Whether to check that the batch axis of the arrays
	 *   match  the expected value found in `shapes`.
	 * @param exceptionPrefix String prefix used for exception formatting.
	 * @returns List of standardized input Tensors (one Tensor per model input).
	 * @throws ValueError: in case of improperly formatted user data.
	 */
	function standardizeInputData(data, names, shapes) {
	  var checkBatchAxis = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : true;
	  var exceptionPrefix = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : '';
	  if (names == null || names.length === 0) {
	    // Check for the case where the model expected no data, but some data got
	    // sent.
	    if (data != null) {
	      var gotUnexpectedData = false;
	      if (isDataArray(data) && data.length > 0) {
	        gotUnexpectedData = true;
	      } else if (isDataDict(data)) {
	        for (var key in data) {
	          if (data.hasOwnProperty(key)) {
	            gotUnexpectedData = true;
	            break;
	          }
	        }
	      } else {
	        // `data` is a singleton Tensor in this case.
	        gotUnexpectedData = true;
	      }
	      if (gotUnexpectedData) {
	        throw new ValueError("Error when checking model ".concat(exceptionPrefix, " expected no data, ") + "but got ".concat(data));
	      }
	    }
	    return [];
	  }
	  if (data == null) {
	    return names.map(function (name) {
	      return null;
	    });
	  }
	  var arrays;
	  if (isDataDict(data)) {
	    data = data;
	    arrays = [];
	    var _iterator = _createForOfIteratorHelper(names),
	      _step;
	    try {
	      for (_iterator.s(); !(_step = _iterator.n()).done;) {
	        var name = _step.value;
	        if (data[name] == null) {
	          throw new ValueError("No data provided for \"".concat(name, "\". Need data for each key in: ") + "".concat(names));
	        }
	        arrays.push(data[name]);
	      }
	    } catch (err) {
	      _iterator.e(err);
	    } finally {
	      _iterator.f();
	    }
	  } else if (isDataArray(data)) {
	    data = data;
	    if (data.length !== names.length) {
	      throw new ValueError("Error when checking model ".concat(exceptionPrefix, ": the Array of ") + "Tensors that you are passing to your model is not the size the " + "model expected. Expected to see ".concat(names.length, " Tensor(s), but ") + "instead got the following list of Tensor(s): ".concat(data));
	    }
	    arrays = data;
	  } else {
	    data = data;
	    if (names.length > 1) {
	      throw new ValueError("The model ".concat(exceptionPrefix, " expects ").concat(names.length, " Tensor(s), ") + "but only received one Tensor. Found: Tensor with shape ".concat(data.shape));
	    }
	    arrays = [data];
	  }
	  arrays = ensureTensorsRank2OrHigher(arrays);
	  // Check shape compatibility.
	  if (shapes != null) {
	    for (var i = 0; i < names.length; ++i) {
	      if (shapes[i] == null) {
	        continue;
	      }
	      var array = arrays[i];
	      if (array.shape.length !== shapes[i].length) {
	        throw new ValueError("Error when checking ".concat(exceptionPrefix, ": expected ").concat(names[i], " ") + "to have ".concat(shapes[i].length, " dimension(s). but got array with ") + "shape ".concat(array.shape));
	      }
	      for (var j = 0; j < shapes[i].length; ++j) {
	        if (j === 0 && !checkBatchAxis) {
	          // Skip the first (batch) axis.
	          continue;
	        }
	        var dim = array.shape[j];
	        var refDim = shapes[i][j];
	        if (refDim != null && refDim >= 0 && dim !== refDim) {
	          throw new ValueError("".concat(exceptionPrefix, " expected a batch of elements where each ") + "example has shape [".concat(shapes[i].slice(1, shapes[i].length), "] ") + "(i.e.,tensor shape [*,".concat(shapes[i].slice(1, shapes[i].length), "])") + " but the ".concat(exceptionPrefix, " received an input with ").concat(array.shape[0]) + " examples, each with shape [".concat(array.shape.slice(1, array.shape.length), "]") + " (tensor shape [".concat(array.shape, "])"));
	        }
	      }
	    }
	  }
	  return arrays;
	}
	/**
	 * User input validation for Tensors.
	 * @param inputs `Array` of `tf.Tensor`s for inputs.
	 * @param targets `Array` of `tf.Tensor`s for targets.
	 * @param weights Optional `Array` of `tf.Tensor`s for sample weights.
	 * @throws ValueError: in case of incorrectly formatted data.
	 */
	function checkArrayLengths(inputs, targets, weights) {
	  var setX = unique$2(inputs.map(function (input) {
	    return input.shape[0];
	  }));
	  setX.sort();
	  var setY = unique$2(targets.map(function (target) {
	    return target.shape[0];
	  }));
	  setY.sort();
	  // TODO(cais): Check `weights` as well.
	  if (setX.length > 1) {
	    throw new ValueError("All input Tensors (x) should have the same number of samples. " + "Got array shapes: " + "".concat(JSON.stringify(inputs.map(function (input) {
	      return input.shape;
	    }))));
	  }
	  if (setY.length > 1) {
	    throw new ValueError("All target Tensors (y) should have the same number of samples. " + "Got array shapes: " + "".concat(JSON.stringify(targets.map(function (target) {
	      return target.shape;
	    }))));
	  }
	  if (setX.length > 0 && setY.length > 0 && !arraysEqual(setX, setY)) {
	    throw new ValueError("Input Tensors should have the same number of samples as target " + "Tensors. Found ".concat(setX[0], " input sample(s) and ").concat(setY[0], " target ") + "sample(s).");
	  }
	}
	/**
	 * Validation on the compatibility of targes and loss functions.
	 *
	 * This helps prevent users from using loss functions incorrectly.
	 *
	 * @param targets `Array` of `tf.Tensor`s of targets.
	 * @param lossFns `Array` of loss functions.
	 * @param outputShapes `Array` of shapes of model outputs.
	 */
	function checkLossAndTargetCompatibility(targets, lossFns, outputShapes) {
	  // TODO(cais): Dedicated test coverage?
	  var keyLosses = [meanSquaredError$1, binaryCrossentropy$2, categoricalCrossentropy$2];
	  for (var i = 0; i < targets.length; ++i) {
	    var y = targets[i];
	    var loss = lossFns[i];
	    var shape = outputShapes[i];
	    if (loss == null) {
	      continue;
	    }
	    if (loss === categoricalCrossentropy$2) {
	      if (y.shape[y.shape.length - 1] === 1) {
	        throw new ValueError("You are passing a target array of shape ".concat(y.shape, " while using ") + "a loss 'categorical_crossentropy'. 'categorical_crossentropy'" + "expects targets to be binary matrices (1s and 0s) of shape " + "[samples, classes].");
	        // TODO(cais): Example code in error message.
	      }
	    }

	    if (keyLosses.indexOf(loss) !== -1) {
	      var slicedYShape = y.shape.slice(1);
	      var slicedShape = shape.slice(1);
	      for (var j = 0; j < slicedYShape.length; ++j) {
	        var targetDim = slicedYShape[j];
	        var outDim = slicedShape[j];
	        if (outDim != null && targetDim !== outDim) {
	          throw new ValueError("A target Tensor with shape ".concat(y.shape, " was passed for an ") + "output of shape ".concat(shape, ", while using a loss function that ") + "expects targets to have the same shape as the output.");
	        }
	      }
	    }
	  }
	}
	/**
	 * Check inputs provided by the user.
	 *
	 * Porting Note: This corresponds to _standardize_input_data() in Python
	 *   Keras. Because of the strong typing in TF.js, we do not need to convert
	 *   the data. Specifically:
	 *   1) in PyKeras, `data` can be `DataFrame` instances from pandas, for
	 *      example. We don't need to worry about that here because there is no
	 *      widely popular javascript/typesdcript equivalent of pandas (so far).
	 *      If one becomes available in the future, we can add support.
	 *   2) in PyKeras, inputs can be Python dict. But here we are stipulating
	 * that the data is either a single `tf.Tensor` or an Array of `tf.Tensor`s. We
	 * may add support for `Object` data inputs in the future when the need
	 * arises.
	 *
	 * Instead, we perform basic checks for number of parameters and shapes.
	 *
	 * @param data: The input data.
	 * @param names: Name for the inputs, from the model.
	 * @param shapes: Expected shapes for the input data, from the model.
	 * @param checkBatchAxis: Whether the size along the batch axis (i.e., the
	 *   first dimension) will be checked for matching.
	 * @param exceptionPrefix: Execption prefix message, used in generating error
	 *   messages.
	 * @throws ValueError: on incorrect number of inputs or mismatches in shapes.
	 */
	function checkInputData(data, names, shapes) {
	  var checkBatchAxis = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : true;
	  var exceptionPrefix = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : '';
	  var arrays;
	  if (Array.isArray(data)) {
	    if (data.length !== names.length) {
	      throw new ValueError("Error when checking model ".concat(exceptionPrefix, ": the Array of ") + "Tensors that you are passing to your model is not the size the " + "the model expected. Expected to see ".concat(names.length, " Tensor(s),") + " but instead got ".concat(data.length, " Tensors(s)."));
	    }
	    arrays = data;
	  } else {
	    if (names.length > 1) {
	      throw new ValueError("The model expects ".concat(names.length, " ").concat(exceptionPrefix, " Tensors, ") + "but only received one Tensor. Found: array with shape " + "".concat(JSON.stringify(data.shape), "."));
	    }
	    arrays = [data];
	  }
	  if (shapes != null) {
	    for (var i = 0; i < names.length; ++i) {
	      if (shapes[i] == null) {
	        continue;
	      }
	      var array = arrays[i];
	      if (array.shape.length !== shapes[i].length) {
	        throw new ValueError("Error when checking ".concat(exceptionPrefix, ": expected ").concat(names[i], " ") + "to have ".concat(shapes[i].length, " dimension(s), but got array with ") + "shape ".concat(JSON.stringify(array.shape)));
	      }
	      for (var j = 0; j < shapes[i].length; ++j) {
	        if (j === 0 && !checkBatchAxis) {
	          continue;
	        }
	        var dim = array.shape[j];
	        var refDim = shapes[i][j];
	        if (refDim != null) {
	          if (refDim !== dim) {
	            throw new ValueError("Error when checking ".concat(exceptionPrefix, ": expected ") + "".concat(names[i], " to have shape ").concat(JSON.stringify(shapes[i]), " but ") + "got array with shape ".concat(JSON.stringify(array.shape), "."));
	          }
	        }
	      }
	    }
	  }
	}
	/**
	 * Maps metric functions to model outputs.
	 * @param metrics An shortcut strings name, metric function, `Array` or dict
	 *   (`Object`) of metric functions.
	 * @param outputNames An `Array` of the names of model outputs.
	 * @returns An `Array` (one entry per model output) of `Array` of metric
	 *   functions. For instance, if the model has 2 outputs, and for the first
	 *   output we want to compute `binaryAccuracy` and `binaryCrossentropy`,
	 *   and just `binaryAccuracy` for the second output, the `Array` would look
	 *   like:
	 *     `[[binaryAccuracy, binaryCrossentropy],  [binaryAccuracy]]`
	 * @throws TypeError: incompatible metrics format.
	 */
	function collectMetrics(metrics, outputNames) {
	  if (metrics == null || Array.isArray(metrics) && metrics.length === 0) {
	    return outputNames.map(function (name) {
	      return [];
	    });
	  }
	  var wrappedMetrics;
	  if (typeof metrics === 'string' || typeof metrics === 'function') {
	    wrappedMetrics = [metrics];
	  } else if (Array.isArray(metrics) || _typeof(metrics) === 'object') {
	    wrappedMetrics = metrics;
	  } else {
	    throw new TypeError('Type of metrics argument not understood. Expected an string,' + "function, Array, or Object, found: ".concat(metrics));
	  }
	  if (Array.isArray(wrappedMetrics)) {
	    // We then apply all metrics to all outputs.
	    return outputNames.map(function (name) {
	      return wrappedMetrics;
	    });
	  } else {
	    // In this case, metrics is a dict.
	    var nestedMetrics = [];
	    var _iterator2 = _createForOfIteratorHelper(outputNames),
	      _step2;
	    try {
	      for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	        var name = _step2.value;
	        var outputMetrics = wrappedMetrics.hasOwnProperty(name) ? wrappedMetrics[name] : [];
	        if (!Array.isArray(outputMetrics)) {
	          outputMetrics = [outputMetrics];
	        }
	        nestedMetrics.push(outputMetrics);
	      }
	    } catch (err) {
	      _iterator2.e(err);
	    } finally {
	      _iterator2.f();
	    }
	    return nestedMetrics;
	  }
	}
	var LAYERS_MODEL_FORMAT_NAME = 'layers-model';
	/**
	 * A `tf.LayersModel` is a directed, acyclic graph of `tf.Layer`s plus methods
	 * for training, evaluation, prediction and saving.
	 *
	 * `tf.LayersModel` is the basic unit of training, inference and evaluation in
	 * TensorFlow.js. To create a `tf.LayersModel`, use `tf.LayersModel`.
	 *
	 * See also:
	 *   `tf.Sequential`, `tf.loadLayersModel`.
	 *
	 * @doc {heading: 'Models', subheading: 'Classes'}
	 */
	var LayersModel = /*#__PURE__*/function (_Container) {
	  _inherits(LayersModel, _Container);
	  var _super = _createSuper(LayersModel);
	  function LayersModel(args) {
	    var _this;
	    _classCallCheck(this, LayersModel);
	    _this = _super.call(this, args);
	    _this.isTraining = false;
	    return _this;
	  }
	  /**
	   * Print a text summary of the model's layers.
	   *
	   * The summary includes
	   * - Name and type of all layers that comprise the model.
	   * - Output shape(s) of the layers
	   * - Number of weight parameters of each layer
	   * - If the model has non-sequential-like topology, the inputs each layer
	   *   receives
	   * - The total number of trainable and non-trainable parameters of the model.
	   *
	   * ```js
	   * const input1 = tf.input({shape: [10]});
	   * const input2 = tf.input({shape: [20]});
	   * const dense1 = tf.layers.dense({units: 4}).apply(input1);
	   * const dense2 = tf.layers.dense({units: 8}).apply(input2);
	   * const concat = tf.layers.concatenate().apply([dense1, dense2]);
	   * const output =
	   *     tf.layers.dense({units: 3, activation: 'softmax'}).apply(concat);
	   *
	   * const model = tf.model({inputs: [input1, input2], outputs: output});
	   * model.summary();
	   * ```
	   *
	   * @param lineLength Custom line length, in number of characters.
	   * @param positions Custom widths of each of the columns, as either
	   *   fractions of `lineLength` (e.g., `[0.5, 0.75, 1]`) or absolute number
	   *   of characters (e.g., `[30, 50, 65]`). Each number corresponds to
	   *   right-most (i.e., ending) position of a column.
	   * @param printFn Custom print function. Can be used to replace the default
	   *   `console.log`. For example, you can use `x => {}` to mute the printed
	   *   messages in the console.
	   *
	   * @doc {heading: 'Models', subheading: 'Classes'}
	   */
	  _createClass(LayersModel, [{
	    key: "summary",
	    value: function summary(lineLength, positions) {
	      var printFn = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : console.log;
	      if (!this.built) {
	        throw new ValueError("This model has never been called, thus its weights have not been " + "created yet. So no summary can be displayed. Build the model " + "first (e.g., by calling it on some test data).");
	      }
	      printSummary(this, lineLength, positions, printFn);
	    }
	    /**
	     * Configures and prepares the model for training and evaluation.  Compiling
	     * outfits the model with an optimizer, loss, and/or metrics.  Calling `fit`
	     * or `evaluate` on an un-compiled model will throw an error.
	     *
	     * @param args a `ModelCompileArgs` specifying the loss, optimizer, and
	     * metrics to be used for fitting and evaluating this model.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "compile",
	    value: function compile(args) {
	      var _this2 = this;
	      if (args.loss == null) {
	        args.loss = [];
	      }
	      this.loss = args.loss;
	      if (typeof args.optimizer === 'string') {
	        this.optimizer_ = getOptimizer(args.optimizer);
	        this.isOptimizerOwned = true;
	      } else {
	        if (!(args.optimizer instanceof Optimizer)) {
	          throw new ValueError("User-defined optimizer must be an instance of tf.Optimizer.");
	        }
	        this.optimizer_ = args.optimizer;
	        this.isOptimizerOwned = false;
	      }
	      // TODO(cais): Add lossWeights.
	      // TODO(cais): Add sampleWeightMode.
	      // Prepare loss functions.
	      var lossFunctions = [];
	      if (!Array.isArray(args.loss) && typeof args.loss !== 'string' && typeof args.loss !== 'function') {
	        args.loss = args.loss;
	        for (var name in args.loss) {
	          if (this.outputNames.indexOf(name) === -1) {
	            throw new ValueError("Unknown entry in loss dictionary: \"".concat(name, "\". ") + "Only expected the following keys: ".concat(this.outputNames));
	          }
	        }
	        var _iterator3 = _createForOfIteratorHelper(this.outputNames),
	          _step3;
	        try {
	          for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
	            var _name = _step3.value;
	            if (args.loss[_name] == null) {
	              console.warn("Output \"".concat(_name, "\" is missing from loss dictionary. We assume ") + "this was done on purpose, and we will not be expecting data " + "to be passed to ".concat(_name, " during training"));
	            }
	            lossFunctions.push(get$1(args.loss[_name]));
	          }
	        } catch (err) {
	          _iterator3.e(err);
	        } finally {
	          _iterator3.f();
	        }
	      } else if (Array.isArray(args.loss)) {
	        if (args.loss.length !== this.outputs.length) {
	          throw new ValueError("When passing an Array as loss, it should have one entry per " + "model output. The model has ".concat(this.outputs.length, " output(s), ") + "but you passed loss=".concat(args.loss, "."));
	        }
	        var theLosses = args.loss;
	        lossFunctions = theLosses.map(function (l) {
	          return get$1(l);
	        });
	      } else {
	        var lossFunction = get$1(args.loss);
	        this.outputs.forEach(function (_) {
	          lossFunctions.push(lossFunction);
	        });
	      }
	      this.lossFunctions = lossFunctions;
	      this.feedOutputNames = [];
	      this.feedOutputShapes = [];
	      this.feedLossFns = [];
	      for (var i = 0; i < this.outputs.length; ++i) {
	        // TODO(cais): Logic for skipping target(s).
	        var shape = this.internalOutputShapes[i];
	        var _name2 = this.outputNames[i];
	        this.feedOutputNames.push(_name2);
	        this.feedOutputShapes.push(shape);
	        this.feedLossFns.push(this.lossFunctions[i]);
	      }
	      // TODO(cais): Add logic for output masks.
	      // TODO(cais): Add logic for sample weights.
	      var skipTargetIndices = [];
	      // Prepare metrics.
	      this.metrics = args.metrics;
	      // TODO(cais): Add weightedMetrics.
	      this.metricsNames = ['loss'];
	      this.metricsTensors = [];
	      // Compute total loss.
	      // Porting Note: In PyKeras, metrics_tensors are symbolic tensor objects.
	      //   Here, metricsTensors are TypeScript functions. This difference is due
	      //   to the difference in symbolic/imperative property of the backends.
	      nameScope('loss', function () {
	        for (var _i = 0; _i < _this2.outputs.length; ++_i) {
	          if (skipTargetIndices.indexOf(_i) !== -1) {
	            continue;
	          }
	          // TODO(cais): Add weightedLoss, sampleWeight and mask.
	          //   The following line should be weightedLoss
	          var weightedLoss = _this2.lossFunctions[_i];
	          if (_this2.outputs.length > 1) {
	            _this2.metricsTensors.push([weightedLoss, _i]);
	            _this2.metricsNames.push(_this2.outputNames[_i] + '_loss');
	          }
	        }
	        // Porting Note: Due to the imperative nature of the backend, we calculate
	        //   the regularizer penalties in the totalLossFunction, instead of here.
	      });

	      var nestedMetrics = collectMetrics(args.metrics, this.outputNames);
	      // TODO(cais): Add nestedWeightedMetrics.
	      /**
	       * Helper function used in loop below.
	       */
	      var appendMetric = function appendMetric(outputIndex, metricName, metricTensor) {
	        if (_this2.outputNames.length > 1) {
	          metricName = _this2.outputNames[outputIndex] + '_' + metricName;
	        }
	        _this2.metricsNames.push(metricName);
	        _this2.metricsTensors.push([metricTensor, outputIndex]);
	      };
	      nameScope('metric', function () {
	        var _loop = function _loop(_i2) {
	          if (skipTargetIndices.indexOf(_i2) !== -1) {
	            return "continue";
	          }
	          var outputMetrics = nestedMetrics[_i2];
	          // TODO(cais): Add weights and outputWeightedMetrics.
	          // TODO(cais): Add optional arg `weights` to the following function.
	          var handleMetrics = function handleMetrics(metrics) {
	            var metricNamePrefix = '';
	            var metricName;
	            var accFn;
	            var weightedMetricFn;
	            //  TODO(cais): Use 'weights_' for weighted metrics.
	            var _iterator4 = _createForOfIteratorHelper(metrics),
	              _step4;
	            try {
	              var _loop2 = function _loop2() {
	                var metric = _step4.value;
	                if (typeof metric === 'string' && ['accuracy', 'acc', 'crossentropy', 'ce'].indexOf(metric) !== -1) {
	                  var outputShape = _this2.internalOutputShapes[_i2];
	                  if (outputShape[outputShape.length - 1] === 1 || _this2.lossFunctions[_i2] === binaryCrossentropy$2) {
	                    // case: binary accuracy/crossentropy.
	                    if (['accuracy', 'acc'].indexOf(metric) !== -1) {
	                      accFn = binaryAccuracy$1;
	                    } else if (['crossentropy', 'ce'].indexOf(metric) !== -1) {
	                      accFn = binaryCrossentropy$1;
	                    }
	                  } else if (_this2.lossFunctions[_i2] === sparseCategoricalCrossentropy$1) {
	                    // case: categorical accuracy / crossentropy with sparse
	                    // targets.
	                    if (['accuracy', 'acc'].indexOf(metric) !== -1) {
	                      accFn = sparseCategoricalAccuracy$1;
	                    } else if (['crossentropy', 'ce'].indexOf(metric) !== -1) {
	                      accFn = sparseCategoricalCrossentropy;
	                    }
	                  } else {
	                    // case: categorical accuracy / crossentropy.
	                    if (['accuracy', 'acc'].indexOf(metric) !== -1) {
	                      accFn = categoricalAccuracy$1;
	                    } else if (['crossentropy', 'ce'].indexOf(metric) !== -1) {
	                      accFn = categoricalCrossentropy$1;
	                    }
	                  }
	                  var suffix;
	                  if (['accuracy', 'acc'].indexOf(metric) !== -1) {
	                    suffix = 'acc';
	                  } else if (['crossentropy', 'ce'].indexOf(metric) !== -1) {
	                    suffix = 'ce';
	                  }
	                  // TODO(cais): Add weighting actually.
	                  weightedMetricFn = accFn;
	                  metricName = metricNamePrefix + suffix;
	                } else {
	                  var metricFn = get(metric);
	                  // TODO(cais): Add weighting actually.
	                  weightedMetricFn = metricFn;
	                  metricName = metricNamePrefix + getLossOrMetricName(metric);
	                }
	                // TODO(cais): Add weighting and masking to metricResult.
	                var metricResult;
	                nameScope(metricName, function () {
	                  metricResult = weightedMetricFn;
	                });
	                appendMetric(_i2, metricName, metricResult);
	              };
	              for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
	                _loop2();
	              }
	            } catch (err) {
	              _iterator4.e(err);
	            } finally {
	              _iterator4.f();
	            }
	          };
	          handleMetrics(outputMetrics);
	          // TODO(cais): Call handleMetrics with weights.
	        };
	        for (var _i2 = 0; _i2 < _this2.outputs.length; ++_i2) {
	          var _ret = _loop(_i2);
	          if (_ret === "continue") continue;
	        }
	      });
	      // Porting Notes: Given the imperative backend of tfjs-core,
	      //   there is no need for constructing the symbolic graph and placeholders.
	      this.collectedTrainableWeights = this.trainableWeights;
	    }
	    /**
	     * Check trainable weights count consistency.
	     *
	     * This will raise a warning if `this.trainableWeights` and
	     * `this.collectedTrainableWeights` are inconsistent (i.e., have different
	     * numbers of parameters).
	     * Inconsistency will typically arise when one modifies `model.trainable`
	     * without calling `model.compile()` again.
	     */
	  }, {
	    key: "checkTrainableWeightsConsistency",
	    value: function checkTrainableWeightsConsistency() {
	      if (this.collectedTrainableWeights == null) {
	        return;
	      }
	      if (this.trainableWeights.length !== this.collectedTrainableWeights.length) {
	        console.warn('Discrepancy between trainableweights and collected trainable ' + 'weights. Did you set `model.trainable` without calling ' + '`model.compile()` afterwards?');
	      }
	    }
	    /**
	     * Returns the loss value & metrics values for the model in test mode.
	     *
	     * Loss and metrics are specified during `compile()`, which needs to happen
	     * before calls to `evaluate()`.
	     *
	     * Computation is done in batches.
	     *
	     * ```js
	     * const model = tf.sequential({
	     *   layers: [tf.layers.dense({units: 1, inputShape: [10]})]
	     * });
	     * model.compile({optimizer: 'sgd', loss: 'meanSquaredError'});
	     * const result = model.evaluate(
	     *     tf.ones([8, 10]), tf.ones([8, 1]), {batchSize: 4});
	     * result.print();
	     * ```
	     *
	     * @param x `tf.Tensor` of test data, or an `Array` of `tf.Tensor`s if the
	     * model has multiple inputs.
	     * @param y `tf.Tensor` of target data, or an `Array` of `tf.Tensor`s if the
	     * model has multiple outputs.
	     * @param args A `ModelEvaluateArgs`, containing optional fields.
	     *
	     * @return `Scalar` test loss (if the model has a single output and no
	     *   metrics) or `Array` of `Scalar`s (if the model has multiple outputs
	     *   and/or metrics). The attribute `model.metricsNames`
	     *   will give you the display labels for the scalar outputs.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "evaluate",
	    value: function evaluate(x, y) {
	      var args = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
	      var batchSize = args.batchSize == null ? 32 : args.batchSize;
	      checkBatchSize(batchSize);
	      // TODO(cais): Standardize `config.sampleWeights` as well.
	      // Validate user data.
	      var checkBatchAxis = true;
	      var standardizedOuts = this.standardizeUserDataXY(x, y, checkBatchAxis, batchSize);
	      try {
	        // TODO(cais): If uses `useLearningPhase`, set the corresponding element
	        // of the input to 0.
	        var ins = standardizedOuts[0].concat(standardizedOuts[1]);
	        this.makeTestFunction();
	        var f = this.testFunction;
	        var testOuts = this.testLoop(f, ins, batchSize, args.verbose, args.steps);
	        return singletonOrArray(testOuts);
	      } finally {
	        disposeNewTensors(standardizedOuts[0], x);
	        disposeNewTensors(standardizedOuts[1], y);
	      }
	    }
	    // TODO(cais): Add code snippet below once real dataset objects are
	    //   available.
	    /**
	     * Evaluate model using a dataset object.
	     *
	     * Note: Unlike `evaluate()`, this method is asynchronous (`async`).
	     *
	     * @param dataset A dataset object. Its `iterator()` method is expected
	     *   to generate a dataset iterator object, the `next()` method of which
	     *   is expected to produce data batches for evaluation. The return value
	     *   of the `next()` call ought to contain a boolean `done` field and a
	     *   `value` field. The `value` field is expected to be an array of two
	     *   `tf.Tensor`s or an array of two nested `tf.Tensor` structures. The former
	     *   case is for models with exactly one input and one output (e.g.
	     *   a sequential model). The latter case is for models with multiple
	     *   inputs and/or multiple outputs. Of the two items in the array, the
	     *   first is the input feature(s) and the second is the output target(s).
	     * @param args A configuration object for the dataset-based evaluation.
	     * @returns Loss and metric values as an Array of `Scalar` objects.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "evaluateDataset",
	    value: function () {
	      var _evaluateDataset2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(dataset, args) {
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              this.makeTestFunction();
	              return _context.abrupt("return", evaluateDataset(this, dataset, args));
	            case 2:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function evaluateDataset$1(_x, _x2) {
	        return _evaluateDataset2.apply(this, arguments);
	      }
	      return evaluateDataset$1;
	    }()
	    /**
	     * Get number of samples provided for training, evaluation or prediction.
	     *
	     * @param ins Input `tf.Tensor`.
	     * @param batchSize Integer batch size, optional.
	     * @param steps Total number of steps (batches of samples) before
	     * declaring loop finished. Optional.
	     * @param stepsName The public API's parameter name for `steps`.
	     * @returns Number of samples provided.
	     */
	  }, {
	    key: "checkNumSamples",
	    value: function checkNumSamples(ins, batchSize, steps) {
	      var stepsName = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'steps';
	      var numSamples;
	      if (steps != null) {
	        numSamples = null;
	        if (batchSize != null) {
	          throw new ValueError("If ".concat(stepsName, " is set, batchSize must be null or undefined.") + "Got batchSize = ".concat(batchSize));
	        }
	      } else if (ins != null) {
	        if (Array.isArray(ins)) {
	          numSamples = ins[0].shape[0];
	        } else {
	          numSamples = ins.shape[0];
	        }
	      } else {
	        throw new ValueError("Either the input data should have a defined shape, or " + "".concat(stepsName, " shoud be specified."));
	      }
	      return numSamples;
	    }
	    /**
	     * Execute internal tensors of the model with input data feed.
	     * @param inputs Input data feed. Must match the inputs of the model.
	     * @param outputs Names of the output tensors to be fetched. Must match
	     *   names of the SymbolicTensors that belong to the graph.
	     * @returns Fetched values for `outputs`.
	     */
	  }, {
	    key: "execute",
	    value: function execute$1(inputs, outputs) {
	      if (Array.isArray(outputs) && outputs.length === 0) {
	        throw new ValueError('`outputs` is an empty Array, which is not allowed.');
	      }
	      var outputsIsArray = Array.isArray(outputs);
	      var outputNames = outputsIsArray ? outputs : [outputs];
	      var outputSymbolicTensors = this.retrieveSymbolicTensors(outputNames);
	      // Format the input into a FeedDict.
	      var feedDict = new FeedDict();
	      if (inputs instanceof Tensor) {
	        inputs = [inputs];
	      }
	      if (Array.isArray(inputs)) {
	        if (inputs.length !== this.inputs.length) {
	          throw new ValueError("The number of inputs provided (".concat(inputs.length, ") ") + "does not match the number of inputs of this model " + "(".concat(this.inputs.length, ")."));
	        }
	        for (var i = 0; i < this.inputs.length; ++i) {
	          feedDict.add(this.inputs[i], inputs[i]);
	        }
	      } else {
	        var _iterator5 = _createForOfIteratorHelper(this.inputs),
	          _step5;
	        try {
	          for (_iterator5.s(); !(_step5 = _iterator5.n()).done;) {
	            var input = _step5.value;
	            var tensorValue = inputs[input.name];
	            if (tensorValue == null) {
	              throw new ValueError("No value is provided for the model's input ".concat(input.name));
	            }
	            feedDict.add(input, tensorValue);
	          }
	        } catch (err) {
	          _iterator5.e(err);
	        } finally {
	          _iterator5.f();
	        }
	      }
	      // Run execution.
	      var executeOutputs = execute(outputSymbolicTensors, feedDict);
	      return outputsIsArray ? executeOutputs : executeOutputs[0];
	    }
	    /**
	     * Retrieve the model's internal symbolic tensors from symbolic-tensor names.
	     */
	  }, {
	    key: "retrieveSymbolicTensors",
	    value: function retrieveSymbolicTensors(symbolicTensorNames) {
	      var outputSymbolicTensors = pyListRepeat(null, symbolicTensorNames.length);
	      var outputsRemaining = symbolicTensorNames.length;
	      var _iterator6 = _createForOfIteratorHelper(this.layers),
	        _step6;
	      try {
	        for (_iterator6.s(); !(_step6 = _iterator6.n()).done;) {
	          var layer = _step6.value;
	          var layerOutputs = Array.isArray(layer.output) ? layer.output : [layer.output];
	          var layerOutputNames = layerOutputs.map(function (output) {
	            return output.name;
	          });
	          for (var i = 0; i < symbolicTensorNames.length; ++i) {
	            var index = layerOutputNames.indexOf(symbolicTensorNames[i]);
	            if (index !== -1) {
	              outputSymbolicTensors[i] = layerOutputs[index];
	              outputsRemaining--;
	            }
	            if (outputsRemaining === 0) {
	              break;
	            }
	          }
	          if (outputsRemaining === 0) {
	            break;
	          }
	        }
	      } catch (err) {
	        _iterator6.e(err);
	      } finally {
	        _iterator6.f();
	      }
	      if (outputsRemaining > 0) {
	        var remainingNames = [];
	        outputSymbolicTensors.forEach(function (tensor, i) {
	          if (tensor == null) {
	            remainingNames.push(symbolicTensorNames[i]);
	          }
	        });
	        throw new ValueError("Cannot find SymbolicTensors for output name(s): " + "".concat(JSON.stringify(remainingNames)));
	      }
	      return outputSymbolicTensors;
	    }
	    /**
	     * Helper method to loop over some data in batches.
	     *
	     * Porting Note: Not using the functional approach in the Python equivalent
	     *   due to the imperative backend.
	     * Porting Note: Does not support step mode currently.
	     *
	     * @param ins: input data
	     * @param batchSize: integer batch size.
	     * @param verbose: verbosity model
	     * @returns: Predictions as `tf.Tensor` (if a single output) or an `Array` of
	     *   `tf.Tensor` (if multipe outputs).
	     */
	  }, {
	    key: "predictLoop",
	    value: function predictLoop(ins) {
	      var _this3 = this;
	      var batchSize = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 32;
	      var verbose = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	      return tidy(function () {
	        var numSamples = _this3.checkNumSamples(ins);
	        if (verbose) {
	          throw new NotImplementedError('Verbose predictLoop() is not implemented yet.');
	        }
	        // Sample-based predictions.
	        // Porting Note: Tensor currently does not support sliced assignments as
	        //   in numpy, e.g., x[1:3] = y. Therefore we use concatenation while
	        //   iterating over the batches.
	        var batches = makeBatches(numSamples, batchSize);
	        var outsBatches = _this3.outputs.map(function (output) {
	          return [];
	        });
	        // TODO(cais): Can the scope() be pushed down inside the for loop?
	        var _loop3 = function _loop3(batchIndex) {
	          var batchOuts = tidy(function () {
	            var batchStart = batches[batchIndex][0];
	            var batchEnd = batches[batchIndex][1];
	            // TODO(cais): Take care of the case of the last element is a flag for
	            //   training/test.
	            var insBatch = sliceArrays(ins, batchStart, batchEnd);
	            // Construct the feeds for execute();
	            var feeds = [];
	            if (Array.isArray(insBatch)) {
	              for (var i = 0; i < insBatch.length; ++i) {
	                feeds.push({
	                  key: _this3.inputs[i],
	                  value: insBatch[i]
	                });
	              }
	            } else {
	              feeds.push({
	                key: _this3.inputs[0],
	                value: insBatch
	              });
	            }
	            var feedDict = new FeedDict(feeds);
	            return execute(_this3.outputs, feedDict);
	          });
	          batchOuts.forEach(function (batchOut, i) {
	            return outsBatches[i].push(batchOut);
	          });
	        };
	        for (var batchIndex = 0; batchIndex < batches.length; ++batchIndex) {
	          _loop3(batchIndex);
	        }
	        return singletonOrArray(outsBatches.map(function (batches) {
	          return concat$2(batches, 0);
	        }));
	      });
	    }
	    /**
	     * Generates output predictions for the input samples.
	     *
	     * Computation is done in batches.
	     *
	     * Note: the "step" mode of predict() is currently not supported.
	     *   This is because the TensorFlow.js core backend is imperative only.
	     *
	     * ```js
	     * const model = tf.sequential({
	     *   layers: [tf.layers.dense({units: 1, inputShape: [10]})]
	     * });
	     * model.predict(tf.ones([8, 10]), {batchSize: 4}).print();
	     * ```
	     *
	     * @param x The input data, as a Tensor, or an `Array` of `tf.Tensor`s if
	     *   the model has multiple inputs.
	     * @param args A `ModelPredictArgs` object containing optional fields.
	     *
	     * @return Prediction results as a `tf.Tensor`(s).
	     *
	     * @exception ValueError In case of mismatch between the provided input data
	     *   and the model's expectations, or in case a stateful model receives a
	     *   number of samples that is not a multiple of the batch size.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "predict",
	    value: function predict(x) {
	      var args = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	      var xsRank2OrHigher = ensureTensorsRank2OrHigher(x);
	      checkInputData(xsRank2OrHigher, this.inputNames, this.feedInputShapes, false);
	      try {
	        // TODO(cais): Take care of stateful models.
	        //   if (this.stateful) ...
	        // TODO(cais): Take care of the learning_phase boolean flag.
	        //   if (this.useLearningPhase) ...
	        var batchSize = args.batchSize == null ? 32 : args.batchSize;
	        checkBatchSize(batchSize);
	        return this.predictLoop(xsRank2OrHigher, batchSize);
	      } finally {
	        disposeNewTensors(xsRank2OrHigher, x);
	      }
	    }
	    /**
	     * Returns predictions for a single batch of samples.
	     *
	     * ```js
	     * const model = tf.sequential({
	     *   layers: [tf.layers.dense({units: 1, inputShape: [10]})]
	     * });
	     * model.predictOnBatch(tf.ones([8, 10])).print();
	     * ```
	     * @param x: Input samples, as a Tensor (for models with exactly one
	     *   input) or an array of Tensors (for models with more than one input).
	     * @return Tensor(s) of predictions
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "predictOnBatch",
	    value: function predictOnBatch(x) {
	      checkInputData(x, this.inputNames, this.feedInputShapes, true);
	      // TODO(cais): Take care of the learning_phase boolean flag.
	      //   if (this.useLearningPhase) ...
	      var batchSize = (Array.isArray(x) ? x[0] : x).shape[0];
	      return this.predictLoop(x, batchSize);
	    }
	  }, {
	    key: "standardizeUserDataXY",
	    value: function standardizeUserDataXY(x, y) {
	      var checkBatchAxis = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
	      var batchSize = arguments.length > 3 ? arguments[3] : undefined;
	      // TODO(cais): Add sampleWeight, classWeight
	      if (this.optimizer_ == null) {
	        throw new RuntimeError('You must compile a model before training/testing. Use ' + 'LayersModel.compile(modelCompileArgs).');
	      }
	      var outputShapes = [];
	      for (var i = 0; i < this.feedOutputShapes.length; ++i) {
	        var outputShape = this.feedOutputShapes[i];
	        var lossFn = this.feedLossFns[i];
	        if (lossFn === sparseCategoricalCrossentropy$1) {
	          outputShapes.push(outputShape.slice(0, outputShape.length - 1).concat([1]));
	        } else {
	          // Porting Note: Because of strong typing `lossFn` must be a function.
	          outputShapes.push(outputShape);
	        }
	      }
	      x = standardizeInputData(x, this.feedInputNames, this.feedInputShapes, false, 'input');
	      y = standardizeInputData(y, this.feedOutputNames, outputShapes, false, 'target');
	      // TODO(cais): Standardize sampleWeights & classWeights.
	      checkArrayLengths(x, y, null);
	      // TODO(cais): Check sampleWeights as well.
	      checkLossAndTargetCompatibility(y, this.feedLossFns, this.feedOutputShapes);
	      if (this.stateful && batchSize != null && batchSize > 0) {
	        if (x[0].shape[0] % batchSize !== 0) {
	          throw new ValueError("In a stateful network, you should only pass inputs with a " + "number of samples that is divisible by the batch size " + "".concat(batchSize, ". Found: ").concat(x[0].shape[0], " sample(s)."));
	        }
	      }
	      return [x, y];
	    }
	  }, {
	    key: "standardizeUserData",
	    value: function () {
	      var _standardizeUserData = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(x, y, sampleWeight, classWeight) {
	        var checkBatchAxis,
	          batchSize,
	          _this$standardizeUser,
	          _this$standardizeUser2,
	          standardXs,
	          standardYs,
	          standardSampleWeights,
	          classWeights,
	          i,
	          _args2 = arguments;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              checkBatchAxis = _args2.length > 4 && _args2[4] !== undefined ? _args2[4] : true;
	              batchSize = _args2.length > 5 ? _args2[5] : undefined;
	              _this$standardizeUser = this.standardizeUserDataXY(x, y, checkBatchAxis, batchSize), _this$standardizeUser2 = _slicedToArray(_this$standardizeUser, 2), standardXs = _this$standardizeUser2[0], standardYs = _this$standardizeUser2[1]; // TODO(cais): Handle sampleWeights.
	              if (!(sampleWeight != null)) {
	                _context2.next = 5;
	                break;
	              }
	              throw new Error('sample weight is not supported yet.');
	            case 5:
	              standardSampleWeights = null;
	              if (!(classWeight != null)) {
	                _context2.next = 19;
	                break;
	              }
	              classWeights = standardizeClassWeights(classWeight, this.outputNames);
	              standardSampleWeights = [];
	              i = 0;
	            case 10:
	              if (!(i < classWeights.length)) {
	                _context2.next = 19;
	                break;
	              }
	              _context2.t0 = standardSampleWeights;
	              _context2.next = 14;
	              return standardizeWeights(standardYs[i], null, classWeights[i]);
	            case 14:
	              _context2.t1 = _context2.sent;
	              _context2.t0.push.call(_context2.t0, _context2.t1);
	            case 16:
	              ++i;
	              _context2.next = 10;
	              break;
	            case 19:
	              return _context2.abrupt("return", [standardXs, standardYs, standardSampleWeights]);
	            case 20:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function standardizeUserData(_x3, _x4, _x5, _x6) {
	        return _standardizeUserData.apply(this, arguments);
	      }
	      return standardizeUserData;
	    }()
	    /**
	     * Loop over some test data in batches.
	     * @param f A Function returning a list of tensors.
	     * @param ins Array of tensors to be fed to `f`.
	     * @param batchSize Integer batch size or `null` / `undefined`.
	     * @param verbose verbosity mode.
	     * @param steps Total number of steps (batches of samples) before
	     * declaring test finished. Ignored with the default value of `null` /
	     * `undefined`.
	     * @returns Array of Scalars.
	     */
	  }, {
	    key: "testLoop",
	    value: function testLoop(f, ins, batchSize) {
	      var _this4 = this;
	      var verbose = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 0;
	      var steps = arguments.length > 4 ? arguments[4] : undefined;
	      return tidy(function () {
	        var numSamples = _this4.checkNumSamples(ins, batchSize, steps, 'steps');
	        var outs = [];
	        if (verbose > 0) {
	          throw new NotImplementedError('Verbose mode is not implemented yet.');
	        }
	        // TODO(cais): Use `indicesForConversionToDense' to prevent slow down.
	        if (steps != null) {
	          throw new NotImplementedError('steps mode in testLoop() is not implemented yet');
	        } else {
	          var batches = makeBatches(numSamples, batchSize);
	          var indexArray = tensor1d(range$2(0, numSamples));
	          for (var batchIndex = 0; batchIndex < batches.length; ++batchIndex) {
	            var batchStart = batches[batchIndex][0];
	            var batchEnd = batches[batchIndex][1];
	            var batchIds = sliceAlongFirstAxis(indexArray, batchStart, batchEnd - batchStart);
	            // TODO(cais): In ins, train flag can be a number, instead of an
	            //   Tensor? Do we need to handle this in tfjs-layers?
	            var insBatch = sliceArraysByIndices(ins, batchIds);
	            var batchOuts = f(insBatch);
	            if (batchIndex === 0) {
	              for (var i = 0; i < batchOuts.length; ++i) {
	                outs.push(scalar(0));
	              }
	            }
	            for (var _i3 = 0; _i3 < batchOuts.length; ++_i3) {
	              var batchOut = batchOuts[_i3];
	              outs[_i3] = add$3(outs[_i3], mul(batchEnd - batchStart, batchOut));
	            }
	          }
	          for (var _i4 = 0; _i4 < outs.length; ++_i4) {
	            outs[_i4] = div$1(outs[_i4], numSamples);
	          }
	        }
	        return outs;
	      });
	    }
	  }, {
	    key: "getDedupedMetricsNames",
	    value: function getDedupedMetricsNames() {
	      var outLabels = this.metricsNames;
	      // Rename duplicated metrics names (can happen with an output layer
	      // shared among multiple dataflows).
	      var dedupedOutLabels = [];
	      for (var i = 0; i < outLabels.length; ++i) {
	        var label = outLabels[i];
	        var newLabel = label;
	        if (count(outLabels, label) > 1) {
	          var dupIndex = count(outLabels.slice(0, i), label);
	          newLabel += "_".concat(dupIndex);
	        }
	        dedupedOutLabels.push(newLabel);
	      }
	      return dedupedOutLabels;
	    }
	    /**
	     * Creates a function that performs the following actions:
	     *
	     * 1. computes the losses
	     * 2. sums them to get the total loss
	     * 3. call the optimizer computes the gradients of the LayersModel's
	     *    trainable weights w.r.t. the total loss and update the variables
	     * 4. calculates the metrics
	     * 5. returns the values of the losses and metrics.
	     */
	  }, {
	    key: "makeTrainFunction",
	    value: function makeTrainFunction() {
	      var _this5 = this;
	      return function (data) {
	        var lossValues = [];
	        var inputs = data.slice(0, _this5.inputs.length);
	        var targets = data.slice(_this5.inputs.length, _this5.inputs.length + _this5.outputs.length);
	        var sampleWeights = data.slice(_this5.inputs.length + _this5.outputs.length, _this5.inputs.length + _this5.outputs.length * 2);
	        var metricsValues = [];
	        // Create a function that computes the total loss based on the
	        // inputs. This function is used for obtaining gradients through
	        // backprop.
	        var totalLossFunction = function totalLossFunction() {
	          var feeds = [];
	          for (var i = 0; i < _this5.inputs.length; ++i) {
	            feeds.push({
	              key: _this5.inputs[i],
	              value: inputs[i]
	            });
	          }
	          var feedDict = new FeedDict(feeds);
	          var outputs = execute(_this5.outputs, feedDict, {
	            'training': true
	          });
	          // TODO(cais): Take care of the case of multiple outputs from a
	          //   single layer?
	          var totalLoss;
	          for (var _i5 = 0; _i5 < _this5.lossFunctions.length; ++_i5) {
	            var lossFunction = _this5.lossFunctions[_i5];
	            var loss = lossFunction(targets[_i5], outputs[_i5]);
	            if (sampleWeights[_i5] != null) {
	              loss = computeWeightedLoss(loss, sampleWeights[_i5]);
	            }
	            // TODO(cais): push Scalar instead.
	            var meanLoss = mean$3(loss);
	            // TODO(cais): Use a scope() instead, to avoid ownership.
	            lossValues.push(meanLoss);
	            if (_i5 === 0) {
	              totalLoss = loss;
	            } else {
	              totalLoss = add$3(totalLoss, loss);
	            }
	          }
	          // Compute the metrics.
	          // TODO(cais): These should probably be calculated outside
	          //   totalLossFunction to benefit speed?
	          for (var _i6 = 0; _i6 < _this5.metricsTensors.length; ++_i6) {
	            var weightedMetric = void 0;
	            if (_this5.outputs.length > 1 && _i6 < _this5.outputs.length) {
	              weightedMetric = lossValues[_i6];
	            } else {
	              var metric = _this5.metricsTensors[_i6][0];
	              var outputIndex = _this5.metricsTensors[_i6][1];
	              weightedMetric = mean$3(metric(targets[outputIndex], outputs[outputIndex]));
	            }
	            keep(weightedMetric);
	            // TODO(cais): Use a scope() instead, to avoid ownership.
	            metricsValues.push(weightedMetric);
	          }
	          totalLoss = mean$3(totalLoss);
	          // Add regularizer penalties.
	          _this5.calculateLosses().forEach(function (regularizerLoss) {
	            totalLoss = add$3(totalLoss, regularizerLoss);
	          });
	          return totalLoss;
	        };
	        var variables = _this5.collectedTrainableWeights.map(function (param) {
	          return param.read();
	        });
	        var returnCost = true;
	        var totalLossValue = _this5.optimizer_.minimize(totalLossFunction, returnCost, variables);
	        return [totalLossValue].concat(metricsValues);
	      };
	    }
	    /**
	     * Create a function which, when invoked with an array of `tf.Tensor`s as a
	     * batch of inputs, returns the prespecified loss and metrics of the model
	     * under the batch of input data.
	     */
	  }, {
	    key: "makeTestFunction",
	    value: function makeTestFunction() {
	      var _this6 = this;
	      this.testFunction = function (data) {
	        return tidy(function () {
	          var valOutputs = [];
	          var totalLoss;
	          var inputs = data.slice(0, _this6.inputs.length);
	          var targets = data.slice(_this6.inputs.length, _this6.inputs.length + _this6.outputs.length);
	          var feeds = [];
	          for (var i = 0; i < _this6.inputs.length; ++i) {
	            feeds.push({
	              key: _this6.inputs[i],
	              value: inputs[i]
	            });
	          }
	          var feedDict = new FeedDict(feeds);
	          var outputs = execute(_this6.outputs, feedDict);
	          // Compute total loss.
	          for (var _i7 = 0; _i7 < _this6.lossFunctions.length; ++_i7) {
	            var lossFunction = _this6.lossFunctions[_i7];
	            // TODO(cais): Add sample weighting and replace the simple
	            // averaging.
	            var loss = mean$3(lossFunction(targets[_i7], outputs[_i7]));
	            if (_i7 === 0) {
	              totalLoss = loss;
	            } else {
	              totalLoss = add$3(totalLoss, loss);
	            }
	            valOutputs.push(totalLoss);
	          }
	          // Compute the metrics.
	          for (var _i8 = 0; _i8 < _this6.metricsTensors.length; ++_i8) {
	            var metric = _this6.metricsTensors[_i8][0];
	            var outputIndex = _this6.metricsTensors[_i8][1];
	            // TODO(cais): Replace K.mean() with a proper weighting function.
	            var meanMetric = mean$3(metric(targets[outputIndex], outputs[outputIndex]));
	            valOutputs.push(meanMetric);
	          }
	          return valOutputs;
	        });
	      };
	    }
	    /**
	     * Trains the model for a fixed number of epochs (iterations on a
	     * dataset).
	     *
	     * ```js
	     * const model = tf.sequential({
	     *     layers: [tf.layers.dense({units: 1, inputShape: [10]})]
	     * });
	     * model.compile({optimizer: 'sgd', loss: 'meanSquaredError'});
	     * for (let i = 1; i < 5 ; ++i) {
	     *   const h = await model.fit(tf.ones([8, 10]), tf.ones([8, 1]), {
	     *       batchSize: 4,
	     *       epochs: 3
	     *   });
	     *   console.log("Loss after Epoch " + i + " : " + h.history.loss[0]);
	     * }
	     * ```
	     *
	     * @param x `tf.Tensor` of training data, or an array of `tf.Tensor`s if the
	     * model has multiple inputs. If all inputs in the model are named, you
	     * can also pass a dictionary mapping input names to `tf.Tensor`s.
	     * @param y `tf.Tensor` of target (label) data, or an array of `tf.Tensor`s if
	     * the model has multiple outputs. If all outputs in the model are named,
	     * you can also pass a dictionary mapping output names to `tf.Tensor`s.
	     * @param args A `ModelFitArgs`, containing optional fields.
	     *
	     * @return A `History` instance. Its `history` attribute contains all
	     *   information collected during training.
	     *
	     * @exception ValueError In case of mismatch between the provided input
	     * data and what the model expects.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "fit",
	    value: function () {
	      var _fit = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3(x, y) {
	        var args,
	          inputs,
	          targets,
	          originalInputs,
	          originalTargets,
	          inputValX,
	          inputValY,
	          valX,
	          valY,
	          sampleWeights,
	          batchSize,
	          checkBatchAxis,
	          standardizedOuts,
	          doValidation,
	          valIns,
	          _checkBatchAxis,
	          valStandardized,
	          splitAt,
	          originalBatchSize,
	          ins,
	          trainFunction,
	          outLabels,
	          valFunction,
	          callbackMetrics,
	          callbacks,
	          out,
	          _args3 = arguments;
	        return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	          while (1) switch (_context3.prev = _context3.next) {
	            case 0:
	              args = _args3.length > 2 && _args3[2] !== undefined ? _args3[2] : {};
	              if (!this.isTraining) {
	                _context3.next = 3;
	                break;
	              }
	              throw new Error('Cannot start training because another fit() call is ongoing.');
	            case 3:
	              this.isTraining = true;
	              _context3.prev = 4;
	              batchSize = args.batchSize == null ? 32 : args.batchSize;
	              checkBatchSize(batchSize);
	              // Validate user data.
	              // TODO(cais): Support sampleWeight.
	              checkBatchAxis = false;
	              _context3.next = 10;
	              return this.standardizeUserData(x, y, args.sampleWeight, args.classWeight, checkBatchAxis, batchSize);
	            case 10:
	              standardizedOuts = _context3.sent;
	              inputs = standardizedOuts[0];
	              targets = standardizedOuts[1];
	              sampleWeights = standardizedOuts[2];
	              // Prepare validation data.
	              doValidation = false;
	              if (!(args.validationData != null && args.validationData.length > 0)) {
	                _context3.next = 36;
	                break;
	              }
	              doValidation = true;
	              if (!(args.validationData.length === 2)) {
	                _context3.next = 22;
	                break;
	              }
	              // config.validationData consists of valX and valY.
	              inputValX = args.validationData[0];
	              inputValY = args.validationData[1];
	              _context3.next = 27;
	              break;
	            case 22:
	              if (!(args.validationData.length === 3)) {
	                _context3.next = 26;
	                break;
	              }
	              throw new NotImplementedError('validationData including sample weights is not supported yet.');
	            case 26:
	              throw new ValueError("When passing validation data, it must contain 2 (valX, valY) " + "or 3 (valX, valY, valSampleWeight) items; " + "".concat(args.validationData, " is invalid."));
	            case 27:
	              _checkBatchAxis = true;
	              _context3.next = 30;
	              return this.standardizeUserData(inputValX, inputValY, null, /** Unused sample weights. */null, /** Unused class weights. */_checkBatchAxis, batchSize);
	            case 30:
	              valStandardized = _context3.sent;
	              valX = valStandardized[0];
	              valY = valStandardized[1];
	              valIns = valX.concat(valY);
	              // TODO(cais): Add useLearningPhase data properly.
	              _context3.next = 37;
	              break;
	            case 36:
	              if (args.validationSplit != null && args.validationSplit > 0 && args.validationSplit < 1) {
	                doValidation = true;
	                // Porting Note: In tfjs-layers, inputs[0] is always a Tensor.
	                splitAt = Math.floor(inputs[0].shape[0] * (1 - args.validationSplit));
	                originalBatchSize = inputs[0].shape[0];
	                valX = sliceArrays(inputs, splitAt, originalBatchSize);
	                originalInputs = inputs;
	                inputs = sliceArrays(inputs, 0, splitAt);
	                valY = sliceArrays(targets, splitAt, originalBatchSize);
	                originalTargets = targets;
	                targets = sliceArrays(targets, 0, splitAt);
	                // TODO(cais): Once sampleWeights becomes available, slice it to get
	                //   valSampleWeights.
	                valIns = valX.concat(valY);
	                // TODO(cais): Add useLearningPhase data properly.
	              } else if (args.validationSteps != null) {
	                doValidation = true;
	                // TODO(cais): Add useLearningPhase.
	              }
	            case 37:
	              ins = inputs.concat(targets).concat(sampleWeights);
	              this.checkTrainableWeightsConsistency();
	              // TODO(cais): Handle use_learning_phase and learning_phase?
	              // Porting Note: Here we see a key deviation of tfjs-layers from
	              // Keras.
	              //  Due to the imperative nature of tfjs-layers' backend (tfjs-core),
	              //  we do not construct symbolic computation graphs to embody the
	              //  training process. Instead, we define a function that performs the
	              //  training action. In PyKeras, the data (inputs and targets) are fed
	              //  through graph placeholders. In tfjs-layers, the data are fed as
	              //  function arguments. Since the function are defined below in the
	              //  scope, we don't have equivalents of PyKeras's
	              //  `_make_train_funciton`.
	              trainFunction = this.makeTrainFunction();
	              outLabels = this.getDedupedMetricsNames();
	              if (doValidation) {
	                this.makeTestFunction();
	                valFunction = this.testFunction;
	                callbackMetrics = outLabels.slice().concat(outLabels.map(function (n) {
	                  return 'val_' + n;
	                }));
	              } else {
	                valFunction = null;
	                valIns = [];
	                callbackMetrics = outLabels.slice();
	              }
	              callbacks = standardizeCallbacks(args.callbacks, args.yieldEvery);
	              _context3.next = 45;
	              return this.fitLoop(trainFunction, ins, outLabels, batchSize, args.epochs, args.verbose, callbacks, valFunction, valIns, args.shuffle, callbackMetrics, args.initialEpoch, null, null);
	            case 45:
	              out = _context3.sent;
	              return _context3.abrupt("return", out);
	            case 47:
	              _context3.prev = 47;
	              this.isTraining = false;
	              // Memory clean up.
	              disposeNewTensors(inputs, x);
	              disposeNewTensors(targets, y);
	              disposeNewTensors(originalInputs, x);
	              disposeNewTensors(originalTargets, y);
	              disposeNewTensors(valX, inputValX);
	              disposeNewTensors(valY, inputValY);
	              if (sampleWeights != null) {
	                dispose(sampleWeights);
	              }
	              return _context3.finish(47);
	            case 57:
	            case "end":
	              return _context3.stop();
	          }
	        }, _callee3, this, [[4,, 47, 57]]);
	      }));
	      function fit(_x7, _x8) {
	        return _fit.apply(this, arguments);
	      }
	      return fit;
	    }()
	    /**
	     * Abstract fit function for `f(ins)`.
	     * @param f A Function returning a list of tensors. For training, this
	     *   function is expected to perform the updates to the variables.
	     * @param ins List of tensors to be fed to `f`.
	     * @param outLabels List of strings, display names of the outputs of `f`.
	     * @param batchSize Integer batch size or `== null` if unknown. Default : 32.
	     * @param epochs Number of times to iterate over the data. Default : 1.
	     * @param verbose Verbosity mode: 0, 1, or 2. Default: 1.
	     * @param callbacks List of callbacks to be called during training.
	     * @param valF Function to call for validation.
	     * @param valIns List of tensors to be fed to `valF`.
	     * @param shuffle Whether to shuffle the data at the beginning of every
	     * epoch. Default : true.
	     * @param callbackMetrics List of strings, the display names of the metrics
	     *   passed to the callbacks. They should be the concatenation of the
	     *   display names of the outputs of `f` and the list of display names
	     *   of the outputs of `valF`.
	     * @param initialEpoch Epoch at which to start training (useful for
	     *   resuming a previous training run). Default : 0.
	     * @param stepsPerEpoch Total number of steps (batches on samples) before
	     *   declaring one epoch finished and starting the next epoch. Ignored with
	     *   the default value of `undefined` or `null`.
	     * @param validationSteps Number of steps to run validation for (only if
	     *   doing validation from data tensors). Not applicable for tfjs-layers.
	     * @returns A `History` object.
	     */
	  }, {
	    key: "fitLoop",
	    value: function () {
	      var _fitLoop = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4(f, ins, outLabels, batchSize, epochs, verbose, callbacks, valF, valIns, shuffle$1, callbackMetrics, initialEpoch, stepsPerEpoch, validationSteps) {
	        var _this7 = this;
	        var doValidation, numTrainSamples, indexArray, _configureCallbacks, callbackList, history, _loop4, epoch, _ret2;
	        return _regeneratorRuntime().wrap(function _callee4$(_context6) {
	          while (1) switch (_context6.prev = _context6.next) {
	            case 0:
	              if (batchSize == null) {
	                batchSize = 32;
	              }
	              if (epochs == null) {
	                epochs = 1;
	              }
	              if (shuffle$1 == null) {
	                shuffle$1 = true;
	              }
	              if (initialEpoch == null) {
	                initialEpoch = 0;
	              }
	              // TODO(cais): Change const to let below when implementing validation.
	              doValidation = false;
	              if (valF != null && valIns != null) {
	                doValidation = true;
	                // TODO(cais): verbose message.
	              }
	              if (!(validationSteps != null)) {
	                _context6.next = 10;
	                break;
	              }
	              doValidation = true;
	              if (!(stepsPerEpoch == null)) {
	                _context6.next = 10;
	                break;
	              }
	              throw new ValueError('Can only use `validationSteps` when doing step-wise training, ' + 'i.e., `stepsPerEpoch` must be set.');
	            case 10:
	              numTrainSamples = this.checkNumSamples(ins, batchSize, stepsPerEpoch, 'steps_per_epoch');
	              if (numTrainSamples != null) {
	                indexArray = range$2(0, numTrainSamples);
	              }
	              if (verbose == null) {
	                verbose = 1;
	              }
	              _configureCallbacks = configureCallbacks(callbacks, verbose, epochs, initialEpoch, numTrainSamples, stepsPerEpoch, batchSize, doValidation, callbackMetrics), callbackList = _configureCallbacks.callbackList, history = _configureCallbacks.history;
	              callbackList.setModel(this);
	              this.history = history;
	              _context6.next = 18;
	              return callbackList.onTrainBegin();
	            case 18:
	              this.stopTraining_ = false;
	              // TODO(cais): Take care of callbacks.validation_data as in PyKeras.
	              // TODO(cais): Pre-convert feeds for performance as in PyKeras.
	              _loop4 = /*#__PURE__*/_regeneratorRuntime().mark(function _loop4() {
	                var epochLogs, epochIndexArray1D, batches, _loop5, batchIndex, _ret3;
	                return _regeneratorRuntime().wrap(function _loop4$(_context5) {
	                  while (1) switch (_context5.prev = _context5.next) {
	                    case 0:
	                      _context5.next = 2;
	                      return callbackList.onEpochBegin(epoch);
	                    case 2:
	                      epochLogs = {};
	                      if (!(stepsPerEpoch != null)) {
	                        _context5.next = 7;
	                        break;
	                      }
	                      throw new NotImplementedError('stepsPerEpoch mode is not implemented yet.');
	                    case 7:
	                      if (!(shuffle$1 === 'batch')) {
	                        _context5.next = 11;
	                        break;
	                      }
	                      throw new NotImplementedError('batch shuffling is not implemneted' + ' yet');
	                    case 11:
	                      if (shuffle$1) {
	                        shuffle(indexArray);
	                      }
	                    case 12:
	                      // Convert the potentially shuffled indices to Tensor1D, to avoid the
	                      // cost of repeated creation of Array1Ds later on.
	                      epochIndexArray1D = tensor1d(indexArray);
	                      batches = makeBatches(numTrainSamples, batchSize);
	                      _loop5 = /*#__PURE__*/_regeneratorRuntime().mark(function _loop5(batchIndex) {
	                        var batchLogs;
	                        return _regeneratorRuntime().wrap(function _loop5$(_context4) {
	                          while (1) switch (_context4.prev = _context4.next) {
	                            case 0:
	                              batchLogs = {};
	                              _context4.next = 3;
	                              return callbackList.onBatchBegin(batchIndex, batchLogs);
	                            case 3:
	                              tidy(function () {
	                                var batchStart = batches[batchIndex][0];
	                                var batchEnd = batches[batchIndex][1];
	                                var batchIds = sliceAlongFirstAxis(epochIndexArray1D, batchStart, batchEnd - batchStart);
	                                batchLogs['batch'] = batchIndex;
	                                batchLogs['size'] = batchEnd - batchStart;
	                                // TODO(cais): In ins, train flag can be a number, instead of an
	                                //   Tensor? Do we need to handle this in tfjs-layers?
	                                var insBatch = sliceArraysByIndices(ins, batchIds);
	                                var outs = f(insBatch);
	                                for (var i = 0; i < outLabels.length; ++i) {
	                                  var label = outLabels[i];
	                                  var out = outs[i];
	                                  batchLogs[label] = out;
	                                  keep(out);
	                                  // TODO(cais): Use scope() to avoid ownership.
	                                }

	                                if (batchIndex === batches.length - 1) {
	                                  // Last batch.
	                                  if (doValidation) {
	                                    var valOuts = _this7.testLoop(valF, valIns, batchSize);
	                                    // Porting Notes: In tfjs-layers, valOuts is always an Array.
	                                    for (var _i9 = 0; _i9 < outLabels.length; ++_i9) {
	                                      var _label = outLabels[_i9];
	                                      var _out = valOuts[_i9];
	                                      keep(_out);
	                                      // TODO(cais): Use scope() to avoid ownership.
	                                      epochLogs['val_' + _label] = _out;
	                                    }
	                                  }
	                                }
	                              });
	                              _context4.next = 6;
	                              return callbackList.onBatchEnd(batchIndex, batchLogs);
	                            case 6:
	                              disposeTensorsInLogs(batchLogs);
	                              if (!_this7.stopTraining_) {
	                                _context4.next = 9;
	                                break;
	                              }
	                              return _context4.abrupt("return", "break");
	                            case 9:
	                            case "end":
	                              return _context4.stop();
	                          }
	                        }, _loop5);
	                      });
	                      batchIndex = 0;
	                    case 16:
	                      if (!(batchIndex < batches.length)) {
	                        _context5.next = 24;
	                        break;
	                      }
	                      return _context5.delegateYield(_loop5(batchIndex), "t0", 18);
	                    case 18:
	                      _ret3 = _context5.t0;
	                      if (!(_ret3 === "break")) {
	                        _context5.next = 21;
	                        break;
	                      }
	                      return _context5.abrupt("break", 24);
	                    case 21:
	                      ++batchIndex;
	                      _context5.next = 16;
	                      break;
	                    case 24:
	                      epochIndexArray1D.dispose();
	                    case 25:
	                      _context5.next = 27;
	                      return callbackList.onEpochEnd(epoch, epochLogs);
	                    case 27:
	                      if (!_this7.stopTraining_) {
	                        _context5.next = 29;
	                        break;
	                      }
	                      return _context5.abrupt("return", "break");
	                    case 29:
	                    case "end":
	                      return _context5.stop();
	                  }
	                }, _loop4);
	              });
	              epoch = initialEpoch;
	            case 21:
	              if (!(epoch < epochs)) {
	                _context6.next = 29;
	                break;
	              }
	              return _context6.delegateYield(_loop4(), "t0", 23);
	            case 23:
	              _ret2 = _context6.t0;
	              if (!(_ret2 === "break")) {
	                _context6.next = 26;
	                break;
	              }
	              return _context6.abrupt("break", 29);
	            case 26:
	              ++epoch;
	              _context6.next = 21;
	              break;
	            case 29:
	              _context6.next = 31;
	              return callbackList.onTrainEnd();
	            case 31:
	              _context6.next = 33;
	              return this.history.syncData();
	            case 33:
	              return _context6.abrupt("return", this.history);
	            case 34:
	            case "end":
	              return _context6.stop();
	          }
	        }, _callee4, this);
	      }));
	      function fitLoop(_x9, _x10, _x11, _x12, _x13, _x14, _x15, _x16, _x17, _x18, _x19, _x20, _x21, _x22) {
	        return _fitLoop.apply(this, arguments);
	      }
	      return fitLoop;
	    }() // TODO(cais): Add code snippet below when it's possible to instantiate
	    //   actual dataset objects.
	    /**
	     * Trains the model using a dataset object.
	     *
	     * @param dataset A dataset object. Its `iterator()` method is expected
	     *   to generate a dataset iterator object, the `next()` method of which
	     *   is expected to produce data batches for training. The return value
	     *   of the `next()` call ought to contain a boolean `done` field and a
	     *   `value` field. The `value` field is expected to be an array of two
	     *   `tf.Tensor`s or an array of two nested `tf.Tensor` structures. The former
	     *   case is for models with exactly one input and one output (e.g.
	     *   a sequential model). The latter case is for models with multiple
	     *   inputs and/or multiple outputs.
	     *   Of the two items in the array, the first is the input feature(s) and
	     *   the second is the output target(s).
	     * @param args A `ModelFitDatasetArgs`, containing optional fields.
	     *
	     * @return A `History` instance. Its `history` attribute contains all
	     *   information collected during training.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "fitDataset",
	    value: function () {
	      var _fitDataset2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee5(dataset, args) {
	        return _regeneratorRuntime().wrap(function _callee5$(_context7) {
	          while (1) switch (_context7.prev = _context7.next) {
	            case 0:
	              return _context7.abrupt("return", fitDataset(this, dataset, args));
	            case 1:
	            case "end":
	              return _context7.stop();
	          }
	        }, _callee5, this);
	      }));
	      function fitDataset$1(_x23, _x24) {
	        return _fitDataset2.apply(this, arguments);
	      }
	      return fitDataset$1;
	    }()
	    /**
	     * Runs a single gradient update on a single batch of data.
	     *
	     * This method differs from `fit()` and `fitDataset()` in the following
	     * regards:
	     *   - It operates on exactly one batch of data.
	     *   - It returns only the loss and metric values, instead of
	     *     returning the batch-by-batch loss and metric values.
	     *   - It doesn't support fine-grained options such as verbosity and
	     *     callbacks.
	     *
	     * @param x Input data. It could be one of the following:
	     *   - A `tf.Tensor`, or an Array of `tf.Tensor`s (in case the model has
	     *     multiple inputs).
	     *   - An Object mapping input names to corresponding `tf.Tensor` (if the
	     *     model has named inputs).
	     * @param y Target data. It could be either a `tf.Tensor` or multiple
	     *   `tf.Tensor`s. It should be consistent with `x`.
	     * @returns Training loss or losses (in case the model has
	     *   multiple outputs), along with metrics (if any), as numbers.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "trainOnBatch",
	    value: function () {
	      var _trainOnBatch = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee6(x, y) {
	        var standardizeOut, inputs, targets, trainFunction, losses, lossValues, _iterator7, _step7, loss, v;
	        return _regeneratorRuntime().wrap(function _callee6$(_context8) {
	          while (1) switch (_context8.prev = _context8.next) {
	            case 0:
	              _context8.next = 2;
	              return this.standardizeUserData(x, y);
	            case 2:
	              standardizeOut = _context8.sent;
	              inputs = standardizeOut[0];
	              targets = standardizeOut[1];
	              trainFunction = this.makeTrainFunction();
	              losses = trainFunction(inputs.concat(targets));
	              lossValues = [];
	              _iterator7 = _createForOfIteratorHelper(losses);
	              _context8.prev = 9;
	              _iterator7.s();
	            case 11:
	              if ((_step7 = _iterator7.n()).done) {
	                _context8.next = 19;
	                break;
	              }
	              loss = _step7.value;
	              _context8.next = 15;
	              return loss.data();
	            case 15:
	              v = _context8.sent;
	              lossValues.push(v[0]);
	            case 17:
	              _context8.next = 11;
	              break;
	            case 19:
	              _context8.next = 24;
	              break;
	            case 21:
	              _context8.prev = 21;
	              _context8.t0 = _context8["catch"](9);
	              _iterator7.e(_context8.t0);
	            case 24:
	              _context8.prev = 24;
	              _iterator7.f();
	              return _context8.finish(24);
	            case 27:
	              dispose(losses);
	              disposeNewTensors(standardizeOut[0], x);
	              disposeNewTensors(standardizeOut[1], y);
	              return _context8.abrupt("return", singletonOrArray(lossValues));
	            case 31:
	            case "end":
	              return _context8.stop();
	          }
	        }, _callee6, this, [[9, 21, 24, 27]]);
	      }));
	      function trainOnBatch(_x25, _x26) {
	        return _trainOnBatch.apply(this, arguments);
	      }
	      return trainOnBatch;
	    }()
	    /**
	     * Extract weight values of the model.
	     *
	     * @param config: An instance of `io.SaveConfig`, which specifies
	     * model-saving options such as whether only trainable weights are to be
	     * saved.
	     * @returns A `NamedTensorMap` mapping original weight names (i.e.,
	     *   non-uniqueified weight names) to their values.
	     */
	  }, {
	    key: "getNamedWeights",
	    value: function getNamedWeights(config) {
	      var namedWeights = [];
	      var trainableOnly = config != null && config.trainableOnly;
	      var weights = trainableOnly ? this.trainableWeights : this.weights;
	      var weightValues = this.getWeights(trainableOnly);
	      for (var i = 0; i < weights.length; ++i) {
	        if (trainableOnly && !weights[i].trainable) {
	          // Optionally skip non-trainable weights.
	          continue;
	        }
	        namedWeights.push({
	          name: weights[i].originalName,
	          tensor: weightValues[i]
	        });
	      }
	      return namedWeights;
	    }
	    /**
	     * Setter used for force stopping of LayersModel.fit() (i.e., training).
	     *
	     * Example:
	     *
	     * ```js
	     * const input = tf.input({shape: [10]});
	     * const output = tf.layers.dense({units: 1}).apply(input);
	     * const model = tf.model({inputs: [input], outputs: [output]});
	     * model.compile({loss: 'meanSquaredError', optimizer: 'sgd'});
	     * const xs = tf.ones([8, 10]);
	     * const ys = tf.zeros([8, 1]);
	     *
	     * const history = await model.fit(xs, ys, {
	     *   epochs: 10,
	     *   callbacks: {
	     *     onEpochEnd: async (epoch, logs) => {
	     *       if (epoch === 2) {
	     *         model.stopTraining = true;
	     *       }
	     *     }
	     *   }
	     * });
	     *
	     * // There should be only 3 values in the loss array, instead of 10
	     * values,
	     * // due to the stopping after 3 epochs.
	     * console.log(history.history.loss);
	     * ```
	     */
	  }, {
	    key: "stopTraining",
	    get: function get() {
	      return this.stopTraining_;
	    },
	    set: function set(stop) {
	      this.stopTraining_ = stop;
	    }
	  }, {
	    key: "optimizer",
	    get: function get() {
	      return this.optimizer_;
	    },
	    set: function set(optimizer) {
	      if (this.optimizer_ !== optimizer) {
	        this.optimizer_ = optimizer;
	        this.isOptimizerOwned = false;
	      }
	    }
	  }, {
	    key: "dispose",
	    value: function dispose() {
	      var result = _get(_getPrototypeOf(LayersModel.prototype), "dispose", this).call(this);
	      if (result.refCountAfterDispose === 0 && this.optimizer != null && this.isOptimizerOwned) {
	        var numTensorsBeforeOptmizerDisposal = memory().numTensors;
	        this.optimizer_.dispose();
	        result.numDisposedVariables += numTensorsBeforeOptmizerDisposal - memory().numTensors;
	      }
	      return result;
	    }
	  }, {
	    key: "getLossIdentifiers",
	    value: function getLossIdentifiers() {
	      var lossNames;
	      if (typeof this.loss === 'string') {
	        lossNames = toSnakeCase(this.loss);
	      } else if (Array.isArray(this.loss)) {
	        var _iterator8 = _createForOfIteratorHelper(this.loss),
	          _step8;
	        try {
	          for (_iterator8.s(); !(_step8 = _iterator8.n()).done;) {
	            var loss = _step8.value;
	            if (typeof loss !== 'string') {
	              throw new Error('Serialization of non-string loss is not supported.');
	            }
	          }
	        } catch (err) {
	          _iterator8.e(err);
	        } finally {
	          _iterator8.f();
	        }
	        lossNames = this.loss.map(function (name) {
	          return toSnakeCase(name);
	        });
	      } else {
	        var outputNames = Object.keys(this.loss);
	        lossNames = {};
	        var _losses = this.loss;
	        for (var _i10 = 0, _outputNames = outputNames; _i10 < _outputNames.length; _i10++) {
	          var outputName = _outputNames[_i10];
	          if (typeof _losses[outputName] === 'string') {
	            lossNames[outputName] = toSnakeCase(_losses[outputName]);
	          } else {
	            throw new Error('Serialization of non-string loss is not supported.');
	          }
	        }
	      }
	      return lossNames;
	    }
	  }, {
	    key: "getMetricIdentifiers",
	    value: function getMetricIdentifiers() {
	      if (typeof this.metrics === 'string' || typeof this.metrics === 'function') {
	        return [toSnakeCase(getLossOrMetricName(this.metrics))];
	      } else if (Array.isArray(this.metrics)) {
	        return this.metrics.map(function (metric) {
	          return toSnakeCase(getLossOrMetricName(metric));
	        });
	      } else {
	        var metricsIdentifiers = {};
	        for (var key in this.metrics) {
	          metricsIdentifiers[key] = toSnakeCase(getLossOrMetricName(this.metrics[key]));
	        }
	        return metricsIdentifiers;
	      }
	    }
	  }, {
	    key: "getTrainingConfig",
	    value: function getTrainingConfig() {
	      return {
	        loss: this.getLossIdentifiers(),
	        metrics: this.getMetricIdentifiers(),
	        optimizer_config: {
	          class_name: this.optimizer.getClassName(),
	          config: this.optimizer.getConfig()
	        }
	      };
	      // TODO(cais): Add weight_metrics when they are supported.
	      // TODO(cais): Add sample_weight_mode when it's supported.
	      // TODO(cais): Add loss_weights when it's supported.
	    }
	  }, {
	    key: "loadTrainingConfig",
	    value: function loadTrainingConfig(trainingConfig) {
	      if (trainingConfig.weighted_metrics != null) {
	        throw new Error('Loading weight_metrics is not supported yet.');
	      }
	      if (trainingConfig.loss_weights != null) {
	        throw new Error('Loading loss_weights is not supported yet.');
	      }
	      if (trainingConfig.sample_weight_mode != null) {
	        throw new Error('Loading sample_weight_mode is not supported yet.');
	      }
	      var tsConfig = convertPythonicToTs(trainingConfig.optimizer_config);
	      var optimizer = deserialize(tsConfig);
	      var loss;
	      if (typeof trainingConfig.loss === 'string') {
	        loss = toCamelCase(trainingConfig.loss);
	      } else if (Array.isArray(trainingConfig.loss)) {
	        loss = trainingConfig.loss.map(function (lossEntry) {
	          return toCamelCase(lossEntry);
	        });
	      } else if (trainingConfig.loss != null) {
	        loss = {};
	        for (var key in trainingConfig.loss) {
	          loss[key] = toCamelCase(trainingConfig.loss[key]);
	        }
	      }
	      var metrics;
	      if (Array.isArray(trainingConfig.metrics)) {
	        metrics = trainingConfig.metrics.map(function (metric) {
	          return toCamelCase(metric);
	        });
	      } else if (trainingConfig.metrics != null) {
	        metrics = {};
	        for (var _key in trainingConfig.metrics) {
	          metrics[_key] = toCamelCase(trainingConfig.metrics[_key]);
	        }
	      }
	      this.compile({
	        loss: loss,
	        metrics: metrics,
	        optimizer: optimizer
	      });
	    }
	    /**
	     * Save the configuration and/or weights of the LayersModel.
	     *
	     * An `IOHandler` is an object that has a `save` method of the proper
	     * signature defined. The `save` method manages the storing or
	     * transmission of serialized data ("artifacts") that represent the
	     * model's topology and weights onto or via a specific medium, such as
	     * file downloads, local storage, IndexedDB in the web browser and HTTP
	     * requests to a server. TensorFlow.js provides `IOHandler`
	     * implementations for a number of frequently used saving mediums, such as
	     * `tf.io.browserDownloads` and `tf.io.browserLocalStorage`. See `tf.io`
	     * for more details.
	     *
	     * This method also allows you to refer to certain types of `IOHandler`s
	     * as URL-like string shortcuts, such as 'localstorage://' and
	     * 'indexeddb://'.
	     *
	     * Example 1: Save `model`'s topology and weights to browser [local
	     * storage](https://developer.mozilla.org/en-US/docs/Web/API/Window/localStorage);
	     * then load it back.
	     *
	     * ```js
	     * const model = tf.sequential(
	     *     {layers: [tf.layers.dense({units: 1, inputShape: [3]})]});
	     * console.log('Prediction from original model:');
	     * model.predict(tf.ones([1, 3])).print();
	     *
	     * const saveResults = await model.save('localstorage://my-model-1');
	     *
	     * const loadedModel = await tf.loadLayersModel('localstorage://my-model-1');
	     * console.log('Prediction from loaded model:');
	     * loadedModel.predict(tf.ones([1, 3])).print();
	     * ```
	     *
	     * Example 2. Saving `model`'s topology and weights to browser
	     * [IndexedDB](https://developer.mozilla.org/en-US/docs/Web/API/IndexedDB_API);
	     * then load it back.
	     *
	     * ```js
	     * const model = tf.sequential(
	     *     {layers: [tf.layers.dense({units: 1, inputShape: [3]})]});
	     * console.log('Prediction from original model:');
	     * model.predict(tf.ones([1, 3])).print();
	     *
	     * const saveResults = await model.save('indexeddb://my-model-1');
	     *
	     * const loadedModel = await tf.loadLayersModel('indexeddb://my-model-1');
	     * console.log('Prediction from loaded model:');
	     * loadedModel.predict(tf.ones([1, 3])).print();
	     * ```
	     *
	     * Example 3. Saving `model`'s topology and weights as two files
	     * (`my-model-1.json` and `my-model-1.weights.bin`) downloaded from
	     * browser.
	     *
	     * ```js
	     * const model = tf.sequential(
	     *     {layers: [tf.layers.dense({units: 1, inputShape: [3]})]});
	     * const saveResults = await model.save('downloads://my-model-1');
	     * ```
	     *
	     * Example 4. Send  `model`'s topology and weights to an HTTP server.
	     * See the documentation of `tf.io.http` for more details
	     * including specifying request parameters and implementation of the
	     * server.
	     *
	     * ```js
	     * const model = tf.sequential(
	     *     {layers: [tf.layers.dense({units: 1, inputShape: [3]})]});
	     * const saveResults = await model.save('http://my-server/model/upload');
	     * ```
	     *
	     * @param handlerOrURL An instance of `IOHandler` or a URL-like,
	     * scheme-based string shortcut for `IOHandler`.
	     * @param config Options for saving the model.
	     * @returns A `Promise` of `SaveResult`, which summarizes the result of
	     * the saving, such as byte sizes of the saved artifacts for the model's
	     *   topology and weight values.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes', ignoreCI: true}
	     */
	  }, {
	    key: "save",
	    value: function () {
	      var _save = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee7(handlerOrURL, config) {
	        var handlers, weightDataAndSpecs, returnString, unusedArg, modelConfig, modelArtifacts, includeOptimizer, _weightDataAndSpecs$s, weightType, _yield$io$encodeWeigh, optimizerWeightData, optimizerWeightSpecs, checkSize;
	        return _regeneratorRuntime().wrap(function _callee7$(_context9) {
	          while (1) switch (_context9.prev = _context9.next) {
	            case 0:
	              if (!(typeof handlerOrURL === 'string')) {
	                _context9.next = 9;
	                break;
	              }
	              handlers = getSaveHandlers(handlerOrURL);
	              if (!(handlers.length === 0)) {
	                _context9.next = 6;
	                break;
	              }
	              throw new ValueError("Cannot find any save handlers for URL '".concat(handlerOrURL, "'"));
	            case 6:
	              if (!(handlers.length > 1)) {
	                _context9.next = 8;
	                break;
	              }
	              throw new ValueError("Found more than one (".concat(handlers.length, ") save handlers for ") + "URL '".concat(handlerOrURL, "'"));
	            case 8:
	              handlerOrURL = handlers[0];
	            case 9:
	              if (!(handlerOrURL.save == null)) {
	                _context9.next = 11;
	                break;
	              }
	              throw new ValueError('LayersModel.save() cannot proceed because the IOHandler ' + 'provided does not have the `save` attribute defined.');
	            case 11:
	              _context9.next = 13;
	              return encodeWeights(this.getNamedWeights(config));
	            case 13:
	              weightDataAndSpecs = _context9.sent;
	              returnString = false;
	              unusedArg = null;
	              modelConfig = this.toJSON(unusedArg, returnString);
	              modelArtifacts = {
	                modelTopology: modelConfig,
	                format: LAYERS_MODEL_FORMAT_NAME,
	                generatedBy: "TensorFlow.js tfjs-layers v".concat(version$6),
	                convertedBy: null
	              };
	              includeOptimizer = config == null ? false : config.includeOptimizer;
	              if (!(includeOptimizer && this.optimizer != null)) {
	                _context9.next = 34;
	                break;
	              }
	              modelArtifacts.trainingConfig = this.getTrainingConfig();
	              weightType = 'optimizer';
	              _context9.t0 = io;
	              _context9.next = 25;
	              return this.optimizer.getWeights();
	            case 25:
	              _context9.t1 = _context9.sent;
	              _context9.t2 = weightType;
	              _context9.next = 29;
	              return _context9.t0.encodeWeights.call(_context9.t0, _context9.t1, _context9.t2);
	            case 29:
	              _yield$io$encodeWeigh = _context9.sent;
	              optimizerWeightData = _yield$io$encodeWeigh.data;
	              optimizerWeightSpecs = _yield$io$encodeWeigh.specs;
	              (_weightDataAndSpecs$s = weightDataAndSpecs.specs).push.apply(_weightDataAndSpecs$s, _toConsumableArray(optimizerWeightSpecs));
	              weightDataAndSpecs.data = concatenateArrayBuffers([weightDataAndSpecs.data, optimizerWeightData]);
	            case 34:
	              if (this.userDefinedMetadata != null) {
	                // Check serialized size of user-defined metadata.
	                checkSize = true;
	                checkUserDefinedMetadata(this.userDefinedMetadata, this.name, checkSize);
	                modelArtifacts.userDefinedMetadata = this.userDefinedMetadata;
	              }
	              modelArtifacts.weightData = weightDataAndSpecs.data;
	              modelArtifacts.weightSpecs = weightDataAndSpecs.specs;
	              return _context9.abrupt("return", handlerOrURL.save(modelArtifacts));
	            case 38:
	            case "end":
	              return _context9.stop();
	          }
	        }, _callee7, this);
	      }));
	      function save(_x27, _x28) {
	        return _save.apply(this, arguments);
	      }
	      return save;
	    }()
	    /**
	     * Set user-defined metadata.
	     *
	     * The set metadata will be serialized together with the topology
	     * and weights of the model during `save()` calls.
	     *
	     * @param setUserDefinedMetadata
	     */
	  }, {
	    key: "setUserDefinedMetadata",
	    value: function setUserDefinedMetadata(userDefinedMetadata) {
	      checkUserDefinedMetadata(userDefinedMetadata, this.name);
	      this.userDefinedMetadata = userDefinedMetadata;
	    }
	    /**
	     * Get user-defined metadata.
	     *
	     * The metadata is supplied via one of the two routes:
	     *   1. By calling `setUserDefinedMetadata()`.
	     *   2. Loaded during model loading (if the model is constructed
	     *      via `tf.loadLayersModel()`.)
	     *
	     * If no user-defined metadata is available from either of the
	     * two routes, this function will return `undefined`.
	     */
	  }, {
	    key: "getUserDefinedMetadata",
	    value: function getUserDefinedMetadata() {
	      return this.userDefinedMetadata;
	    }
	  }]);
	  return LayersModel;
	}(Container); // The class name is 'Model' rather than 'LayersModel' for backwards
	// compatibility since this class name shows up in the serialization format.
	/** @nocollapse */
	LayersModel.className = 'Model';
	registerClass(LayersModel);
	/**
	 * A `tf.Functional` is an alias to `tf.LayersModel`.
	 *
	 * See also:
	 *   `tf.LayersModel`, `tf.Sequential`, `tf.loadLayersModel`.
	 */
	/** @doc {heading: 'Models', subheading: 'Classes'} */
	var Functional = /*#__PURE__*/function (_LayersModel) {
	  _inherits(Functional, _LayersModel);
	  var _super2 = _createSuper(Functional);
	  function Functional() {
	    _classCallCheck(this, Functional);
	    return _super2.apply(this, arguments);
	  }
	  return _createClass(Functional);
	}(LayersModel);
	Functional.className = 'Functional';
	registerClass(Functional);

	/**
	 * Parses a JSON model configuration file and returns a model instance.
	 *
	 * ```js
	 * // This example shows how to serialize a model using `toJSON()` and
	 * // deserialize it as another model using `tf.models.modelFromJSON()`.
	 * // Note: this example serializes and deserializes only the topology
	 * // of the model; the weights of the loaded model will be different
	 * // from those of the the original model, due to random weight
	 * // initialization.
	 * // To load the topology and weights of a model, use `tf.loadLayersModel()`.
	 * const model1 = tf.sequential();
	 * model1.add(tf.layers.repeatVector({inputShape: [2], n: 4}));
	 * // Serialize `model1` as a JSON object.
	 * const model1JSON = model1.toJSON(null, false);
	 * model1.summary();
	 *
	 * const model2 = await tf.models.modelFromJSON(model1JSON);
	 * model2.summary();
	 * ```
	 *
	 *  @param modelAndWeightsConfig JSON object or string encoding a model and
	 *       weights configuration. It can also be only the topology JSON of the
	 *       model, in which case the weights will not be loaded.
	 *  @param custom_objects Optional dictionary mapping names
	 *       (strings) to custom classes or functions to be
	 *       considered during deserialization.
	 * @returns A TensorFlow.js Layers `tf.LayersModel` instance (uncompiled).
	 */
	function modelFromJSON(_x, _x2) {
	  return _modelFromJSON.apply(this, arguments);
	}
	/**
	 * Load a model composed of Layer objects, including its topology and optionally
	 * weights. See the Tutorial named "How to import a Keras Model" for usage
	 * examples.
	 *
	 * This method is applicable to:
	 *
	 * 1. Models created with the `tf.layers.*`, `tf.sequential`, and
	 * `tf.model` APIs of TensorFlow.js and later saved with the
	 * `tf.LayersModel.save` method.
	 * 2. Models converted from Keras or TensorFlow tf.keras using the
	 * [tensorflowjs_converter](https://github.com/tensorflow/tfjs/tree/master/tfjs-converter).
	 *
	 * This mode is *not* applicable to TensorFlow `SavedModel`s or their converted
	 * forms. For those models, use `tf.loadGraphModel`.
	 *
	 * Example 1. Load a model from an HTTP server.
	 *
	 * ```js
	 * const model = await tf.loadLayersModel(
	 *     'https://storage.googleapis.com/tfjs-models/tfjs/iris_v1/model.json');
	 * model.summary();
	 * ```
	 *
	 * Example 2: Save `model`'s topology and weights to browser [local
	 * storage](https://developer.mozilla.org/en-US/docs/Web/API/Window/localStorage);
	 * then load it back.
	 *
	 * ```js
	 * const model = tf.sequential(
	 *     {layers: [tf.layers.dense({units: 1, inputShape: [3]})]});
	 * console.log('Prediction from original model:');
	 * model.predict(tf.ones([1, 3])).print();
	 *
	 * const saveResults = await model.save('localstorage://my-model-1');
	 *
	 * const loadedModel = await tf.loadLayersModel('localstorage://my-model-1');
	 * console.log('Prediction from loaded model:');
	 * loadedModel.predict(tf.ones([1, 3])).print();
	 * ```
	 *
	 * Example 3. Saving `model`'s topology and weights to browser
	 * [IndexedDB](https://developer.mozilla.org/en-US/docs/Web/API/IndexedDB_API);
	 * then load it back.
	 *
	 * ```js
	 * const model = tf.sequential(
	 *     {layers: [tf.layers.dense({units: 1, inputShape: [3]})]});
	 * console.log('Prediction from original model:');
	 * model.predict(tf.ones([1, 3])).print();
	 *
	 * const saveResults = await model.save('indexeddb://my-model-1');
	 *
	 * const loadedModel = await tf.loadLayersModel('indexeddb://my-model-1');
	 * console.log('Prediction from loaded model:');
	 * loadedModel.predict(tf.ones([1, 3])).print();
	 * ```
	 *
	 * Example 4. Load a model from user-selected files from HTML
	 * [file input
	 * elements](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/input/file).
	 *
	 * ```js
	 * // Note: this code snippet will not work without the HTML elements in the
	 * //   page
	 * const jsonUpload = document.getElementById('json-upload');
	 * const weightsUpload = document.getElementById('weights-upload');
	 *
	 * const model = await tf.loadLayersModel(
	 *     tf.io.browserFiles([jsonUpload.files[0], weightsUpload.files[0]]));
	 * ```
	 *
	 * @param pathOrIOHandler Can be either of the two formats
	 *   1. A string path to the `ModelAndWeightsConfig` JSON describing
	 *      the model in the canonical TensorFlow.js format. For file://
	 *      (tfjs-node-only), http:// and https:// schemas, the path can be
	 *      either absolute or relative. The content of the JSON file is assumed to
	 *      be a JSON object with the following fields and values:
	 *      - 'modelTopology': A JSON object that can be either of:
	 *        1. a model architecture JSON consistent with the format of the return
	 *            value of `keras.Model.to_json()`
	 *        2. a full model JSON in the format of `keras.models.save_model()`.
	 *      - 'weightsManifest': A TensorFlow.js weights manifest.
	 *      See the Python converter function `save_model()` for more details.
	 *      It is also assumed that model weights can be accessed from relative
	 *      paths described by the `paths` fields in weights manifest.
	 *   2. A `tf.io.IOHandler` object that loads model artifacts with its `load`
	 *      method.
	 * @param options Optional configuration arguments for the model loading,
	 *   including:
	 *   - `strict`: Require that the provided weights exactly match those required
	 *     by the layers.  Default true.  Passing false means that both extra
	 *     weights and missing weights will be silently ignored.
	 *   - `onProgress`: A progress callback of the form:
	 *     `(fraction: number) => void`. This callback can be used to monitor the
	 *     model-loading process.
	 * @returns A `Promise` of `tf.LayersModel`, with the topology and weights
	 *     loaded.
	 *
	 * @doc {heading: 'Models', subheading: 'Loading'}
	 */
	function _modelFromJSON() {
	  _modelFromJSON = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee5(modelAndWeightsConfig, customObjects) {
	    var modelTopology, tsConfig, model, weightValues, uniqueWeightValues, _iterator4, _step4, weight;
	    return _regeneratorRuntime().wrap(function _callee5$(_context5) {
	      while (1) switch (_context5.prev = _context5.next) {
	        case 0:
	          if (!('modelTopology' in modelAndWeightsConfig)) {
	            modelAndWeightsConfig = {
	              modelTopology: modelAndWeightsConfig
	            };
	          }
	          modelAndWeightsConfig = modelAndWeightsConfig;
	          modelTopology = modelAndWeightsConfig.modelTopology;
	          if (modelTopology['model_config'] != null) {
	            // If the model-topology JSON contains a 'model_config' field, then it is
	            // a full model JSON (e.g., from `keras.Model.save()`), which contains
	            // not only the model's architecture in its 'model_config' field, but
	            // additional information such as the model's optimizer. We use only the
	            // 'model_config' field currently.
	            modelTopology = modelTopology['model_config'];
	          }
	          tsConfig = convertPythonicToTs(modelTopology);
	          model = deserialize(tsConfig, customObjects);
	          if (!(modelAndWeightsConfig.weightsManifest != null)) {
	            _context5.next = 15;
	            break;
	          }
	          _context5.next = 9;
	          return loadWeights(modelAndWeightsConfig.weightsManifest, modelAndWeightsConfig.pathPrefix, model.weights.map(function (weight) {
	            return weight.originalName;
	          }));
	        case 9:
	          weightValues = _context5.sent;
	          // Map the weights to the unique tensor names generated during model loading
	          uniqueWeightValues = {};
	          _iterator4 = _createForOfIteratorHelper(model.weights);
	          try {
	            for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
	              weight = _step4.value;
	              uniqueWeightValues[weight.originalName] = weightValues[weight.originalName];
	            }
	          } catch (err) {
	            _iterator4.e(err);
	          } finally {
	            _iterator4.f();
	          }
	          model.loadWeights(uniqueWeightValues);
	          // Dispose temporary weight values.
	          dispose(weightValues);
	        case 15:
	          return _context5.abrupt("return", model);
	        case 16:
	        case "end":
	          return _context5.stop();
	      }
	    }, _callee5);
	  }));
	  return _modelFromJSON.apply(this, arguments);
	}
	function loadLayersModel(_x3, _x4) {
	  return _loadLayersModel.apply(this, arguments);
	}
	/**
	 * Load a model and optionally its weights, using an IOHandler object.
	 *
	 * @param handler The instance of `IOHandler` to be used during the model
	 *   loading.
	 * @param customObjects Any optional custom objects to be used during model
	 *   loading.
	 * @param strict Whether the weight loading will be done in strict mode.
	 *   Default: `true`.
	 */
	function _loadLayersModel() {
	  _loadLayersModel = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee6(pathOrIOHandler, options) {
	    var handlers;
	    return _regeneratorRuntime().wrap(function _callee6$(_context6) {
	      while (1) switch (_context6.prev = _context6.next) {
	        case 0:
	          if (options == null) {
	            options = {};
	          }
	          if (!(typeof pathOrIOHandler === 'string')) {
	            _context6.next = 10;
	            break;
	          }
	          handlers = getLoadHandlers(pathOrIOHandler, options);
	          if (!(handlers.length === 0)) {
	            _context6.next = 7;
	            break;
	          }
	          // For backward compatibility: if no load handler can be found,
	          // assume it is a relative http path.
	          // TODO(cais): Reformat the args into a single `LoadOptions` once the core
	          // is refactored.
	          handlers.push(browserHTTPRequest(pathOrIOHandler, options));
	          _context6.next = 9;
	          break;
	        case 7:
	          if (!(handlers.length > 1)) {
	            _context6.next = 9;
	            break;
	          }
	          throw new ValueError("Found more than one (".concat(handlers.length, ") load handlers for ") + "URL '".concat(pathOrIOHandler, "'"));
	        case 9:
	          pathOrIOHandler = handlers[0];
	        case 10:
	          return _context6.abrupt("return", loadLayersModelFromIOHandler(pathOrIOHandler, undefined, options));
	        case 11:
	        case "end":
	          return _context6.stop();
	      }
	    }, _callee6);
	  }));
	  return _loadLayersModel.apply(this, arguments);
	}
	function loadLayersModelFromIOHandler(_x5, _x6, _x7) {
	  return _loadLayersModelFromIOHandler.apply(this, arguments);
	}
	function _loadLayersModelFromIOHandler() {
	  _loadLayersModelFromIOHandler = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee7(handler, customObjects, options) {
	    var artifacts, modelTopology, strict, fastWeightInit, model, trainingConfig, _decodeModelAndOptimi, modelWeights, optimizerWeights;
	    return _regeneratorRuntime().wrap(function _callee7$(_context7) {
	      while (1) switch (_context7.prev = _context7.next) {
	        case 0:
	          if (options == null) {
	            options = {};
	          }
	          if (!(handler.load == null)) {
	            _context7.next = 3;
	            break;
	          }
	          throw new ValueError('Cannot proceed with model loading because the IOHandler provided ' + 'does not have the `load` method implemented.');
	        case 3:
	          _context7.next = 5;
	          return handler.load();
	        case 5:
	          artifacts = _context7.sent;
	          modelTopology = artifacts.modelTopology;
	          if (modelTopology['model_config'] != null) {
	            modelTopology = modelTopology['model_config'];
	          }
	          strict = options.strict == null ? true : options.strict; // If weights are provided and the weight-loading mode is strict, use
	          // fast weight initialization. This skips costly initializers such as
	          // 'orthogonal' and saves unnecessary computation in cases where
	          // the initialized weight values will immediately be overwritten by
	          // loaded weight values.
	          fastWeightInit = artifacts.weightData != null && artifacts.weightSpecs != null && strict;
	          model = deserialize(convertPythonicToTs(modelTopology), customObjects, fastWeightInit);
	          trainingConfig = artifacts.trainingConfig;
	          if (trainingConfig != null) {
	            model.loadTrainingConfig(trainingConfig);
	          }
	          if (artifacts.userDefinedMetadata != null) {
	            model.setUserDefinedMetadata(artifacts.userDefinedMetadata);
	          }
	          // If weightData is present, load the weights into the model.
	          if (!(artifacts.weightData != null)) {
	            _context7.next = 24;
	            break;
	          }
	          if (!(artifacts.weightSpecs == null)) {
	            _context7.next = 17;
	            break;
	          }
	          throw new ValueError('LayersModel artifacts contains weight data, but not weight specs. ' + 'Therefore loading of weights cannot proceed.');
	        case 17:
	          _decodeModelAndOptimi = decodeModelAndOptimizerWeights(artifacts.weightData, artifacts.weightSpecs), modelWeights = _decodeModelAndOptimi.modelWeights, optimizerWeights = _decodeModelAndOptimi.optimizerWeights;
	          model.loadWeights(modelWeights, strict);
	          if (!(model.optimizer != null && optimizerWeights.length > 0)) {
	            _context7.next = 22;
	            break;
	          }
	          _context7.next = 22;
	          return model.optimizer.setWeights(optimizerWeights);
	        case 22:
	          // Dispose temporary weight values.
	          dispose(modelWeights);
	          dispose(optimizerWeights.map(function (w) {
	            return w.tensor;
	          }));
	        case 24:
	          return _context7.abrupt("return", model);
	        case 25:
	        case "end":
	          return _context7.stop();
	      }
	    }, _callee7);
	  }));
	  return _loadLayersModelFromIOHandler.apply(this, arguments);
	}
	function decodeModelAndOptimizerWeights(weightData, specs) {
	  var name2Tensor = decodeWeights(weightData, specs);
	  var modelWeights = {};
	  var optimizerWeights = [];
	  specs.forEach(function (spec) {
	    if (spec.group === 'optimizer') {
	      optimizerWeights.push({
	        name: spec.name,
	        tensor: name2Tensor[spec.name]
	      });
	    } else {
	      modelWeights[spec.name] = name2Tensor[spec.name];
	    }
	  });
	  return {
	    modelWeights: modelWeights,
	    optimizerWeights: optimizerWeights
	  };
	}
	/**
	 * A model with a stack of layers, feeding linearly from one to the next.
	 *
	 * `tf.sequential` is a factory function that creates an instance of
	 * `tf.Sequential`.
	 *
	 * ```js
	 *  // Define a model for linear regression.
	 *  const model = tf.sequential();
	 *  model.add(tf.layers.dense({units: 1, inputShape: [1]}));
	 *
	 *  // Prepare the model for training: Specify the loss and the optimizer.
	 *  model.compile({loss: 'meanSquaredError', optimizer: 'sgd'});
	 *
	 *  // Generate some synthetic data for training.
	 *  const xs = tf.tensor2d([1, 2, 3, 4], [4, 1]);
	 *  const ys = tf.tensor2d([1, 3, 5, 7], [4, 1]);
	 *
	 *  // Train the model using the data then do inference on a data point the
	 *  // model hasn't seen:
	 *  await model.fit(xs, ys);
	 *  model.predict(tf.tensor2d([5], [1, 1])).print();
	 * ```
	 *
	 * @doc {heading: 'Models', subheading: 'Classes'}
	 */
	var Sequential = /*#__PURE__*/function (_LayersModel) {
	  _inherits(Sequential, _LayersModel);
	  var _super = _createSuper(Sequential);
	  function Sequential(args) {
	    var _this;
	    _classCallCheck(this, Sequential);
	    _this = _super.call(this, {
	      inputs: [],
	      outputs: []
	    });
	    args = args || {};
	    _this.trainable = true;
	    _this.built = false;
	    // Set model name.
	    _this.name = args.name != null ? args.name : getUid('sequential_');
	    // Add to the model any layers passed to the constructor.
	    if (args.layers != null) {
	      var _iterator = _createForOfIteratorHelper(args.layers),
	        _step;
	      try {
	        for (_iterator.s(); !(_step = _iterator.n()).done;) {
	          var layer = _step.value;
	          _this.add(layer);
	        }
	      } catch (err) {
	        _iterator.e(err);
	      } finally {
	        _iterator.f();
	      }
	    }
	    return _this;
	  }
	  // Helper function to Sequential.add  Throws if the new output shape will be
	  // invalid.
	  _createClass(Sequential, [{
	    key: "checkShape",
	    value: function checkShape(layer) {
	      var shape = layer.inboundNodes[0].outputTensors[0].shape;
	      if (shape.some(function (x) {
	        return x < 0;
	      })) {
	        throw new ValueError('Negative dimension size caused by adding layer ' + "".concat(layer.name, " with input shape [") + "".concat(layer.inboundNodes[0].inputTensors[0].shape, "]"));
	      }
	    }
	    /**
	     * Adds a layer instance on top of the layer stack.
	     *
	     * ```js
	     *  const model = tf.sequential();
	     *  model.add(tf.layers.dense({units: 8, inputShape: [1]}));
	     *  model.add(tf.layers.dense({units: 4, activation: 'relu6'}));
	     *  model.add(tf.layers.dense({units: 1, activation: 'relu6'}));
	     *  // Note that the untrained model is random at this point.
	     *  model.predict(tf.randomNormal([10, 1])).print();
	     * ```
	     * @param layer Layer instance.
	     *
	     * @exception ValueError In case the `layer` argument does not know its
	     * input shape.
	     * @exception ValueError In case the `layer` argument has multiple output
	     *   tensors, or is already connected somewhere else (forbidden in
	     *   `Sequential` models).
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "add",
	    value: function add(layer) {
	      var isLayerModelInstance = layer instanceof Sequential || layer instanceof LayersModel;
	      var modelLayer;
	      if (isLayerModelInstance) {
	        modelLayer = layer;
	        if (modelLayer.outputs.length !== 1) {
	          throw new ValueError('All layers in a Sequential model ' + 'should have a single output tensor. ' + 'For multi-output layers, ' + 'use the functional API.');
	        }
	        if (modelLayer.inputs.length !== 1) {
	          throw new ValueError('All layers in a Sequential model ' + 'should have a single input tensor. ' + 'For multi-input layers, ' + 'use the functional API.');
	        }
	      }
	      if (this.outputs.length === 0) {
	        // first layer in model: check that it is an input layer
	        if (layer.inboundNodes.length === 0) {
	          // create an input layer
	          if (layer.batchInputShape == null) {
	            throw new ValueError('The first layer in a Sequential model must ' + 'get an `inputShape` or `batchInputShape` argument.');
	          }
	          // Instantiate the input layer.
	          var x = Input({
	            batchShape: layer.batchInputShape,
	            dtype: layer.dtype,
	            name: layer.name + '_input'
	          });
	          // This will build the current layer and create the node connecting
	          // the current layer to the input layer we just created.
	          layer.apply(x);
	        }
	        if (isLayerModelInstance) {
	          this.outputs = modelLayer.outputs;
	          this.inputs = modelLayer.inputs;
	        } else {
	          if (layer.inboundNodes.length !== 1) {
	            throw new ValueError('A layer added to a Sequential model must not already be ' + "connected somewhere else. LayersModel received layer ".concat(layer.name, " ") + "which has ".concat(layer.inboundNodes.length, " pre-existing inbound ") + 'connections.');
	          }
	          if (layer.inboundNodes[0].outputTensors.length !== 1) {
	            throw new ValueError('All layers in a Sequential model ' + 'should have a single output tensor. ' + 'For multi-output layers, ' + 'use the functional API.');
	          }
	          this.checkShape(layer);
	          this.outputs = [layer.inboundNodes[0].outputTensors[0]];
	          this.inputs = getSourceInputs(this.outputs[0]);
	        }
	        this.inboundNodes = [];
	        // We create an input node, which we will keep updated
	        // as we add more layers.
	        // (This call has side effects.)
	        // tslint:disable-next-line:no-unused-expression
	        new Node({
	          outboundLayer: this,
	          inboundLayers: [],
	          nodeIndices: [],
	          tensorIndices: [],
	          inputTensors: this.inputs,
	          outputTensors: this.outputs,
	          // no model-level masking for now
	          inputMasks: pyListRepeat(null, this.inputs.length),
	          outputMasks: [null],
	          inputShapes: this.inputs.map(function (x) {
	            return x.shape;
	          }),
	          outputShapes: this.outputs[0].shape
	        });
	      } else {
	        var outputTensor = layer.apply(this.outputs[0]);
	        if (Array.isArray(outputTensor)) {
	          throw new TypeError('All layers in a Sequential model ' + 'should have a single output tensor. ' + 'For multi-output layers, ' + 'use the functional API.');
	        }
	        this.checkShape(layer);
	        this.outputs = [outputTensor];
	        // update self.inbound_nodes
	        this.inboundNodes[0].outputTensors = this.outputs;
	        this.inboundNodes[0].outputShapes = [this.outputs[0].shape];
	      }
	      this.layers.push(layer);
	      this.built = false;
	    }
	    /**
	     * Removes the last layer in the model.
	     *
	     * @exception TypeError if there are no layers in the model.
	     */
	  }, {
	    key: "pop",
	    value: function pop() {
	      if (this.layers.length === 0) {
	        throw new TypeError('There are no layers in the model.');
	      }
	      this.layers.pop();
	      if (this.layers.length === 0) {
	        this.outputs = [];
	        this.inboundNodes = [];
	        this.outboundNodes = [];
	      } else {
	        var lastLayerIndex = this.layers.length - 1;
	        this.layers[lastLayerIndex].outboundNodes = [];
	        this.outputs = [this.layers[lastLayerIndex].output];
	        // update self.inbound_nodes
	        this.inboundNodes[0].outputTensors = this.outputs;
	        this.inboundNodes[0].outputShapes = [this.outputs[0].shape];
	      }
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      if (this.model == null) {
	        this.build();
	      }
	      return this.model.call(inputs, kwargs);
	    }
	  }, {
	    key: "build",
	    value: function build(inputShape) {
	      // Call `getExactlyOneShape` without using its return value,
	      // to verify that exactly one input shape is provided.
	      getExactlyOneShape(inputShape);
	      if (this.inputs.length === 0 || this.outputs.length === 0) {
	        throw new TypeError('Sequential model cannot be built: model is empty.' + ' Add some layers first.');
	      }
	      // actually create the model
	      this.model = new LayersModel({
	        inputs: this.inputs,
	        outputs: this.outputs[0],
	        name: this.name + '_model'
	      });
	      this.model.trainable = this.trainable;
	      // mirror model attributes
	      this.supportsMasking = this.model.supportsMasking;
	      // TODO(michaelterry): Add caches
	      this.inputLayers = this.model.inputLayers;
	      this.inputLayersNodeIndices = this.model.inputLayersNodeIndices;
	      this.inputLayersTensorIndices = this.model.inputLayersTensorIndices;
	      this.outputLayers = this.model.outputLayers;
	      this.outputLayersNodeIndices = this.model.outputLayersNodeIndices;
	      this.outputLayersTensorIndices = this.model.outputLayersTensorIndices;
	      this.nodesByDepth = this.model.nodesByDepth;
	      this.containerNodes = this.model.containerNodes;
	      this.outputNames = this.model.outputNames;
	      this.inputNames = this.model.inputNames;
	      // TODO(michaelterry): Add feedInputNames, feedInputs, if needed.
	      // TODO(michaelterry): Add callbackModel if needed.
	      this.built = true;
	    }
	  }, {
	    key: "countParams",
	    value: function countParams() {
	      if (!this.built) {
	        this.build();
	      }
	      return _get(_getPrototypeOf(Sequential.prototype), "countParams", this).call(this);
	    }
	    /**
	     * Print a text summary of the Sequential model's layers.
	     *
	     * The summary includes
	     * - Name and type of all layers that comprise the model.
	     * - Output shape(s) of the layers
	     * - Number of weight parameters of each layer
	     * - The total number of trainable and non-trainable parameters of the
	     * model.
	     *
	     * ```js
	     * const model = tf.sequential();
	     * model.add(
	     *     tf.layers.dense({units: 100, inputShape: [10], activation: 'relu'}));
	     * model.add(tf.layers.dense({units: 1, activation: 'sigmoid'}));
	     *
	     * model.summary();
	     * ```
	     *
	     * @param lineLength Custom line length, in number of characters.
	     * @param positions Custom widths of each of the columns, as either
	     *   fractions of `lineLength` (e.g., `[0.5, 0.75, 1]`) or absolute number
	     *   of characters (e.g., `[30, 50, 65]`). Each number corresponds to
	     *   right-most (i.e., ending) position of a column.
	     * @param printFn Custom print function. Can be used to replace the default
	     *   `console.log`. For example, you can use `x => {}` to mute the printed
	     *   messages in the console.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "summary",
	    value: function summary(lineLength, positions) {
	      var printFn = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : console.log;
	      if (!this.built) {
	        this.build();
	      }
	      _get(_getPrototypeOf(Sequential.prototype), "summary", this).call(this, lineLength, positions, printFn);
	    }
	    /**
	     * Sets the weights of the model.
	     *
	     * @param weights Should be a list of Tensors with shapes and types matching
	     *   the output of `model.getWeights()`.
	     */
	  }, {
	    key: "setWeights",
	    value: function setWeights(weights) {
	      if (this.model == null) {
	        this.build();
	      }
	      this.model.setWeights(weights);
	    }
	    /**
	     * Returns the loss value & metrics values for the model in test mode.
	     *
	     * Loss and metrics are specified during `compile()`, which needs to happen
	     * before calls to `evaluate()`.
	     *
	     * Computation is done in batches.
	     *
	     * ```js
	     * const model = tf.sequential({
	     *   layers: [tf.layers.dense({units: 1, inputShape: [10]})]
	     * });
	     * model.compile({optimizer: 'sgd', loss: 'meanSquaredError'});
	     * const result = model.evaluate(tf.ones([8, 10]), tf.ones([8, 1]), {
	     *   batchSize: 4,
	     * });
	     * result.print();
	     * ```
	     *
	     * @param x `tf.Tensor` of test data, or an `Array` of `tf.Tensor`s if the
	     * model has multiple inputs.
	     * @param y `tf.Tensor` of target data, or an `Array` of `tf.Tensor`s if the
	     * model has multiple outputs.
	     * @param args A `ModelEvaluateConfig`, containing optional fields.
	     *
	     * @return `Scalar` test loss (if the model has a single output and no
	     *   metrics) or `Array` of `Scalar`s (if the model has multiple outputs
	     *   and/or metrics). The attribute `model.metricsNames`
	     *   will give you the display labels for the scalar outputs.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "evaluate",
	    value: function evaluate(x, y) {
	      var args = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
	      if (!this.built) {
	        throw new RuntimeError('The model needs to be compiled before being used.');
	      }
	      return this.model.evaluate(x, y, args);
	    }
	    // TODO(cais): Add code snippet below once real dataset objects are
	    //   available.
	    /**
	     * Evaluate model using a dataset object.
	     *
	     * Note: Unlike `evaluate()`, this method is asynchronous (`async`).
	     *
	     * @param dataset A dataset object. Its `iterator()` method is expected
	     *   to generate a dataset iterator object, the `next()` method of which
	     *   is expected to produce data batches for evaluation. The return value
	     *   of the `next()` call ought to contain a boolean `done` field and a
	     *   `value` field. The `value` field is expected to be an array of two
	     *   `tf.Tensor`s or an array of two nested `tf.Tensor` structures. The former
	     *   case is for models with exactly one input and one output (e.g.
	     *   a sequential model). The latter case is for models with multiple
	     *   inputs and/or multiple outputs. Of the two items in the array, the
	     *   first is the input feature(s) and the second is the output target(s).
	     * @param args A configuration object for the dataset-based evaluation.
	     * @returns Loss and metric values as an Array of `Scalar` objects.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "evaluateDataset",
	    value: function () {
	      var _evaluateDataset = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(dataset, args) {
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              if (this.built) {
	                _context.next = 2;
	                break;
	              }
	              throw new RuntimeError('The model needs to be compiled before being used.');
	            case 2:
	              return _context.abrupt("return", this.model.evaluateDataset(dataset, args));
	            case 3:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function evaluateDataset(_x8, _x9) {
	        return _evaluateDataset.apply(this, arguments);
	      }
	      return evaluateDataset;
	    }()
	    /**
	     * Generates output predictions for the input samples.
	     *
	     * Computation is done in batches.
	     *
	     * Note: the "step" mode of predict() is currently not supported.
	     *   This is because the TensorFlow.js core backend is imperative only.
	     *
	     * ```js
	     * const model = tf.sequential({
	     *   layers: [tf.layers.dense({units: 1, inputShape: [10]})]
	     * });
	     * model.predict(tf.ones([2, 10])).print();
	     * ```
	     *
	     * @param x The input data, as a Tensor, or an `Array` of `tf.Tensor`s if
	     *   the model has multiple inputs.
	     * @param conifg A `ModelPredictConfig` object containing optional fields.
	     *
	     * @return `tf.Tensor`(s) of predictions.
	     *
	     * @exception ValueError In case of mismatch between the provided input data
	     *   and the model's expectations, or in case a stateful model receives a
	     *   number of samples that is not a multiple of the batch size.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "predict",
	    value: function predict(x) {
	      var args = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	      if (this.model == null) {
	        this.build();
	      }
	      return this.model.predict(x, args);
	    }
	    /**
	     * Returns predictions for a single batch of samples.
	     *
	     * @param x: Input samples, as a Tensor, or list of Tensors (if the model
	     *   has multiple inputs).
	     * @return Tensor(s) of predictions
	     */
	  }, {
	    key: "predictOnBatch",
	    value: function predictOnBatch(x) {
	      if (this.model == null) {
	        this.build();
	      }
	      return this.model.predictOnBatch(x);
	    }
	    /**
	     * See `LayersModel.compile`.
	     *
	     * @param args
	     */
	  }, {
	    key: "compile",
	    value: function compile(args) {
	      this.build();
	      this.model.compile(args);
	      this.optimizer_ = this.model.optimizer;
	      // tslint:disable-next-line:no-any
	      this.isOptimizerOwned = this.model.isOptimizerOwned;
	      this.loss = this.model.loss;
	      this.metrics = this.model.metrics;
	      // TODO(cais): Add this.lossWeights, this.sampleWeightMode,
	      //   this.weightedMetrics, this.targets.
	      this.metricsTensors = this.model.metricsTensors;
	      this.metricsNames = this.model.metricsNames;
	      // TODO(cais): Add sampleWeights.
	    }
	  }, {
	    key: "optimizer",
	    get: function get() {
	      return this.model == null ? undefined : this.model.optimizer;
	    },
	    set: function set(optimizer) {
	      this.model.optimizer = optimizer;
	    }
	    /**
	     * Trains the model for a fixed number of epochs (iterations on a dataset).
	     *
	     * ```js
	     * const model = tf.sequential({
	     *   layers: [tf.layers.dense({units: 1, inputShape: [10]})]
	     * });
	     * model.compile({optimizer: 'sgd', loss: 'meanSquaredError'});
	     * const history = await model.fit(tf.ones([8, 10]), tf.ones([8, 1]), {
	     *   batchSize: 4,
	     *   epochs: 3
	     * });
	     * console.log(history.history.loss[0]);
	     * ```
	     *
	     * @param x `tf.Tensor` of training data, or an array of `tf.Tensor`s if the
	     * model has multiple inputs. If all inputs in the model are named, you can
	     * also pass a dictionary mapping input names to `tf.Tensor`s.
	     * @param y `tf.Tensor` of target (label) data, or an array of `tf.Tensor`s if
	     * the model has multiple outputs. If all outputs in the model are named, you
	     *  can also pass a dictionary mapping output names to `tf.Tensor`s.
	     * @param args  A `ModelFitConfig`, containing optional fields.
	     *
	     * @return A `History` instance. Its `history` attribute contains all
	     *   information collected during training.
	     *
	     * @exception ValueError In case of mismatch between the provided input data
	     *   and what the model expects.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "fit",
	    value: function () {
	      var _fit = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(x, y) {
	        var args,
	          _args2 = arguments;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              args = _args2.length > 2 && _args2[2] !== undefined ? _args2[2] : {};
	              if (this.built) {
	                _context2.next = 3;
	                break;
	              }
	              throw new RuntimeError('The model needs to be compiled before ' + 'being used.');
	            case 3:
	              return _context2.abrupt("return", this.model.fit(x, y, args));
	            case 4:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function fit(_x10, _x11) {
	        return _fit.apply(this, arguments);
	      }
	      return fit;
	    }()
	    /**
	     * Trains the model using a dataset object.
	     *
	     * ```js
	     * const xArray = [
	     *   [1, 1, 1, 1, 1, 1, 1, 1, 1],
	     *   [1, 1, 1, 1, 1, 1, 1, 1, 1],
	     *   [1, 1, 1, 1, 1, 1, 1, 1, 1],
	     *   [1, 1, 1, 1, 1, 1, 1, 1, 1],
	     * ];
	     * const yArray = [1, 1, 1, 1];
	     * // Create a dataset from the JavaScript array.
	     * const xDataset = tf.data.array(xArray);
	     * const yDataset = tf.data.array(yArray);
	     * // Zip combines the `x` and `y` Datasets into a single Dataset, the
	     * // iterator of which will return an object containing of two tensors,
	     * // corresponding to `x` and `y`.  The call to `batch(4)` will bundle
	     * // four such samples into a single object, with the same keys now pointing
	     * // to tensors that hold 4 examples, organized along the batch dimension.
	     * // The call to `shuffle(4)` causes each iteration through the dataset to
	     * // happen in a different order.  The size of the shuffle window is 4.
	     * const xyDataset = tf.data.zip({xs: xDataset, ys: yDataset})
	     *     .batch(4)
	     *     .shuffle(4);
	     * const model = tf.sequential({
	     *   layers: [tf.layers.dense({units: 1, inputShape: [9]})]
	     * });
	     * model.compile({optimizer: 'sgd', loss: 'meanSquaredError'});
	     * const history = await model.fitDataset(xyDataset, {
	     *   epochs: 4,
	     *   callbacks: {onEpochEnd: (epoch, logs) => console.log(logs.loss)}
	     * });
	     * ```
	     *
	     * @param dataset A dataset object. Its `iterator()` method is expected to
	     *   generate a dataset iterator object, the `next()` method of which is
	     *   expected to produce data batches for evaluation. The return value of the
	     *   `next()` call ought to contain a boolean `done` field and a `value`
	     *   field.
	     *
	     *   The `value` field is expected to be an object of with fields
	     *   `xs` and `ys`, which point to the feature tensor and the target tensor,
	     *   respectively. This case is for models with exactly one input and one
	     *   output (e.g. a sequential model). For example:
	     *   ```js
	     *   {value: {xs: xsTensor, ys: ysTensor}, done: false}
	     *   ```
	     *
	     *   If the model has multiple inputs, the `xs` field of `value` should
	     *   be an object mapping input names to their respective feature tensors.
	     *   For example:
	     *   ```js
	     *   {
	     *     value: {
	     *       xs: {
	     *         input_1: xsTensor1,
	     *         input_2: xsTensor2
	     *       },
	     *       ys: ysTensor
	     *     },
	     *     done: false
	     *   }
	     *   ```
	     *   If the model has multiple outputs, the `ys` field of `value` should
	     *   be an object mapping output names to their respective target tensors.
	     *   For example:
	     *   ```js
	     *   {
	     *     value: {
	     *       xs: xsTensor,
	     *       ys: {
	     *         output_1: ysTensor1,
	     *         output_2: ysTensor2
	     *       },
	     *     },
	     *     done: false
	     *   }
	     *   ```
	     * @param args A `ModelFitDatasetArgs`, containing optional fields.
	     *
	     * @return A `History` instance. Its `history` attribute contains all
	     *   information collected during training.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes', ignoreCI: true}
	     */
	  }, {
	    key: "fitDataset",
	    value: function () {
	      var _fitDataset = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3(dataset, args) {
	        return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	          while (1) switch (_context3.prev = _context3.next) {
	            case 0:
	              if (this.built) {
	                _context3.next = 2;
	                break;
	              }
	              throw new RuntimeError('The model needs to be compiled before ' + 'being used.');
	            case 2:
	              return _context3.abrupt("return", this.model.fitDataset(dataset, args));
	            case 3:
	            case "end":
	              return _context3.stop();
	          }
	        }, _callee3, this);
	      }));
	      function fitDataset(_x12, _x13) {
	        return _fitDataset.apply(this, arguments);
	      }
	      return fitDataset;
	    }()
	    /**
	     * Runs a single gradient update on a single batch of data.
	     *
	     * This method differs from `fit()` and `fitDataset()` in the following
	     * regards:
	     *   - It operates on exactly one batch of data.
	     *   - It returns only the loss and metric values, instead of
	     *     returning the batch-by-batch loss and metric values.
	     *   - It doesn't support fine-grained options such as verbosity and
	     *     callbacks.
	     *
	     * @param x Input data. It could be one of the following:
	     *   - A `tf.Tensor`, or an Array of `tf.Tensor`s (in case the model has
	     *     multiple inputs).
	     *   - An Object mapping input names to corresponding `tf.Tensor` (if the
	     *     model has named inputs).
	     * @param y Target data. It could be either a `tf.Tensor` or multiple
	     *   `tf.Tensor`s. It should be consistent with `x`.
	     * @returns Training loss or losses (in case the model has
	     *   multiple outputs), along with metrics (if any), as numbers.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "trainOnBatch",
	    value: function () {
	      var _trainOnBatch = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4(x, y) {
	        return _regeneratorRuntime().wrap(function _callee4$(_context4) {
	          while (1) switch (_context4.prev = _context4.next) {
	            case 0:
	              return _context4.abrupt("return", this.model.trainOnBatch(x, y));
	            case 1:
	            case "end":
	              return _context4.stop();
	          }
	        }, _callee4, this);
	      }));
	      function trainOnBatch(_x14, _x15) {
	        return _trainOnBatch.apply(this, arguments);
	      }
	      return trainOnBatch;
	    }()
	    /* See parent class for JsDoc */
	    /** @nocollapse */
	  }, {
	    key: "stopTraining",
	    get: function get() {
	      if (this.model == null) {
	        throw new ValueError('Cannot get the stopTraining property of a sequential model before ' + 'it is compiled.');
	      }
	      return this.model.stopTraining;
	    }
	    // TODO(cais): Override get trainableWeights() here
	    // tslint:disable-next-line:no-any
	    ,
	    set:
	    /**
	     * Setter used for force stopping of LayersModel.fit() (i.e., training).
	     *
	     * Example:
	     *
	     * ```js
	     * const model = tf.sequential();
	     * model.add(tf.layers.dense({units: 1, inputShape: [10]}));
	     * model.compile({loss: 'meanSquaredError', optimizer: 'sgd'});
	     * const xs = tf.ones([8, 10]);
	     * const ys = tf.zeros([8, 1]);
	     *
	     * const history = await model.fit(xs, ys, {
	     *   epochs: 10,
	     *   callbacks: {
	     *     onEpochEnd: async (epoch, logs) => {
	     *       if (epoch === 2) {
	     *         model.stopTraining = true;
	     *       }
	     *     }
	     *   }
	     * });
	     *
	     * // There should be only 3 values in the loss array, instead of 10 values,
	     * // due to the stopping after 3 epochs.
	     * console.log(history.history.loss);
	     * ```
	     */
	    function set(stop) {
	      // TODO(cais): When refactoring to remove the composition pattern happens,
	      // remove this method overriding.
	      if (this.model == null) {
	        throw new ValueError('Cannot set the stopTraining property of a sequential model before ' + 'it is compiled.');
	      }
	      this.model.stopTraining = stop;
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      // NOTE(cais): We override the return type of getConfig() to `any` here,
	      //   because the `Sequential` class is a special case among `Container`
	      //   subtypes in that its getConfig() method returns an Array (not a
	      //   dict).
	      var layers = [];
	      var _iterator2 = _createForOfIteratorHelper(this.layers),
	        _step2;
	      try {
	        for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	          var layer = _step2.value;
	          var dict = {};
	          dict['className'] = layer.getClassName();
	          dict['config'] = layer.getConfig();
	          layers.push(dict);
	        }
	      } catch (err) {
	        _iterator2.e(err);
	      } finally {
	        _iterator2.f();
	      }
	      return {
	        name: this.name,
	        layers: layers
	      };
	    }
	  }], [{
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      var customObjects = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
	      var fastWeightInit = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	      var configArray;
	      var extraModelConfig = {};
	      if (config instanceof Array) {
	        if (!(config[0].className != null) || config[0]['className'] === 'Merge') {
	          throw new ValueError('Legacy serialization format not supported yet.');
	        }
	        configArray = config;
	      } else {
	        assert$1(config['layers'] != null, function () {
	          return "When the config data for a Sequential model is not an Array, " + "it must be an Object that contains the 'layers' field.";
	        });
	        configArray = config['layers'];
	        delete config['layers'];
	        extraModelConfig = config;
	      }
	      var model = new cls(extraModelConfig);
	      if (!(model instanceof Sequential)) {
	        throw new NotImplementedError("Sequential.fromConfig called on non-Sequential input: ".concat(model));
	      }
	      var _iterator3 = _createForOfIteratorHelper(configArray),
	        _step3;
	      try {
	        for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
	          var conf = _step3.value;
	          var _customObjects = undefined;
	          var layer = deserialize(conf, _customObjects, fastWeightInit);
	          if (fastWeightInit) {
	            layer.setFastWeightInitDuringBuild(true);
	          }
	          model.add(layer);
	        }
	      } catch (err) {
	        _iterator3.e(err);
	      } finally {
	        _iterator3.f();
	      }
	      return model;
	    }
	  }]);
	  return Sequential;
	}(LayersModel);
	/** @nocollapse */
	Sequential.className = 'Sequential';
	registerClass(Sequential);

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	// TODO(cais): Add doc string to all the public static functions in this
	//   class; include exectuable JavaScript code snippets where applicable
	//   (b/74074458).
	// LayersModel and related factory methods.
	/**
	 * A model is a data structure that consists of `Layers` and defines inputs
	 * and outputs.
	 *
	 * The key difference between `tf.model` and `tf.sequential` is that
	 * `tf.model` is more generic, supporting an arbitrary graph (without
	 * cycles) of layers. `tf.sequential` is less generic and supports only a linear
	 * stack of layers.
	 *
	 * When creating a `tf.LayersModel`, specify its input(s) and output(s). Layers
	 * are used to wire input(s) to output(s).
	 *
	 * For example, the following code snippet defines a model consisting of
	 * two `dense` layers, with 10 and 4 units, respectively.
	 *
	 * ```js
	 * // Define input, which has a size of 5 (not including batch dimension).
	 * const input = tf.input({shape: [5]});
	 *
	 * // First dense layer uses relu activation.
	 * const denseLayer1 = tf.layers.dense({units: 10, activation: 'relu'});
	 * // Second dense layer uses softmax activation.
	 * const denseLayer2 = tf.layers.dense({units: 4, activation: 'softmax'});
	 *
	 * // Obtain the output symbolic tensor by applying the layers on the input.
	 * const output = denseLayer2.apply(denseLayer1.apply(input));
	 *
	 * // Create the model based on the inputs.
	 * const model = tf.model({inputs: input, outputs: output});
	 *
	 * // The model can be used for training, evaluation and prediction.
	 * // For example, the following line runs prediction with the model on
	 * // some fake data.
	 * model.predict(tf.ones([2, 5])).print();
	 * ```
	 * See also:
	 *   `tf.sequential`, `tf.loadLayersModel`.
	 *
	 * @doc {heading: 'Models', subheading: 'Creation'}
	 */
	function model(args) {
	  return new LayersModel(args);
	}
	/**
	 * Creates a `tf.Sequential` model.  A sequential model is any model where the
	 * outputs of one layer are the inputs to the next layer, i.e. the model
	 * topology is a simple 'stack' of layers, with no branching or skipping.
	 *
	 * This means that the first layer passed to a `tf.Sequential` model should have
	 * a defined input shape. What that means is that it should have received an
	 * `inputShape` or `batchInputShape` argument, or for some type of layers
	 * (recurrent, Dense...) an `inputDim` argument.
	 *
	 * The key difference between `tf.model` and `tf.sequential` is that
	 * `tf.sequential` is less generic, supporting only a linear stack of layers.
	 * `tf.model` is more generic and supports an arbitrary graph (without
	 * cycles) of layers.
	 *
	 * Examples:
	 *
	 * ```js
	 * const model = tf.sequential();
	 *
	 * // First layer must have an input shape defined.
	 * model.add(tf.layers.dense({units: 32, inputShape: [50]}));
	 * // Afterwards, TF.js does automatic shape inference.
	 * model.add(tf.layers.dense({units: 4}));
	 *
	 * // Inspect the inferred shape of the model's output, which equals
	 * // `[null, 4]`. The 1st dimension is the undetermined batch dimension; the
	 * // 2nd is the output size of the model's last layer.
	 * console.log(JSON.stringify(model.outputs[0].shape));
	 * ```
	 *
	 * It is also possible to specify a batch size (with potentially undetermined
	 * batch dimension, denoted by "null") for the first layer using the
	 * `batchInputShape` key. The following example is equivalent to the above:
	 *
	 * ```js
	 * const model = tf.sequential();
	 *
	 * // First layer must have a defined input shape
	 * model.add(tf.layers.dense({units: 32, batchInputShape: [null, 50]}));
	 * // Afterwards, TF.js does automatic shape inference.
	 * model.add(tf.layers.dense({units: 4}));
	 *
	 * // Inspect the inferred shape of the model's output.
	 * console.log(JSON.stringify(model.outputs[0].shape));
	 * ```
	 *
	 * You can also use an `Array` of already-constructed `Layer`s to create
	 * a `tf.Sequential` model:
	 *
	 * ```js
	 * const model = tf.sequential({
	 *   layers: [tf.layers.dense({units: 32, inputShape: [50]}),
	 *            tf.layers.dense({units: 4})]
	 * });
	 * console.log(JSON.stringify(model.outputs[0].shape));
	 * ```
	 *
	 * @doc {heading: 'Models', subheading: 'Creation'}
	 */
	function sequential(config) {
	  return new Sequential(config);
	}
	/**
	 * Used to instantiate an input to a model as a `tf.SymbolicTensor`.
	 *
	 * Users should call the `input` factory function for
	 * consistency with other generator functions.
	 *
	 * Example:
	 *
	 * ```js
	 * // Defines a simple logistic regression model with 32 dimensional input
	 * // and 3 dimensional output.
	 * const x = tf.input({shape: [32]});
	 * const y = tf.layers.dense({units: 3, activation: 'softmax'}).apply(x);
	 * const model = tf.model({inputs: x, outputs: y});
	 * model.predict(tf.ones([2, 32])).print();
	 * ```
	 *
	 * Note: `input` is only necessary when using `model`. When using
	 * `sequential`, specify `inputShape` for the first layer or use `inputLayer`
	 * as the first layer.
	 *
	 * @doc {heading: 'Models', subheading: 'Inputs'}
	 */
	function input(config) {
	  return Input(config);
	}
	function registerCallbackConstructor(verbosityLevel, callbackConstructor) {
	  CallbackConstructorRegistry.registerCallbackConstructor(verbosityLevel, callbackConstructor);
	}

	/**
	 * Base class for Activations.
	 *
	 * Special note: due to cross-language compatibility reasons, the
	 * static readonly className field in this family of classes must be set to
	 * the initialLowerCamelCase name of the activation.
	 */
	var Activation$1 = /*#__PURE__*/function (_serialization$Serial) {
	  _inherits(Activation, _serialization$Serial);
	  var _super = _createSuper(Activation);
	  function Activation() {
	    _classCallCheck(this, Activation);
	    return _super.apply(this, arguments);
	  }
	  _createClass(Activation, [{
	    key: "getConfig",
	    value: function getConfig() {
	      return {};
	    }
	  }]);
	  return Activation;
	}(Serializable);
	/**
	 * Exponential linear unit (ELU).
	 * Reference: https://arxiv.org/abs/1511.07289
	 */
	var Elu = /*#__PURE__*/function (_Activation) {
	  _inherits(Elu, _Activation);
	  var _super2 = _createSuper(Elu);
	  function Elu() {
	    _classCallCheck(this, Elu);
	    return _super2.apply(this, arguments);
	  }
	  _createClass(Elu, [{
	    key: "apply",
	    value:
	    /**
	     * Calculate the activation function.
	     *
	     * @param x: Input.
	     * @param alpha: Scaling factor the negative section.
	     * @return Output of the ELU activation.
	     */
	    function apply(x) {
	      var alpha = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
	      return elu$3(x, alpha);
	    }
	  }]);
	  return Elu;
	}(Activation$1);
	/** @nocollapse */
	Elu.className = 'elu';
	registerClass(Elu);
	/**
	 * Scaled Exponential Linear Unit. (Klambauer et al., 2017).
	 * Reference: Self-Normalizing Neural Networks, https://arxiv.org/abs/1706.02515
	 * Notes:
	 *   - To be used together with the initialization "lecunNormal".
	 *   - To be used together with the dropout variant "AlphaDropout".
	 */
	var Selu = /*#__PURE__*/function (_Activation2) {
	  _inherits(Selu, _Activation2);
	  var _super3 = _createSuper(Selu);
	  function Selu() {
	    _classCallCheck(this, Selu);
	    return _super3.apply(this, arguments);
	  }
	  _createClass(Selu, [{
	    key: "apply",
	    value: function apply(x) {
	      return selu$2(x);
	    }
	  }]);
	  return Selu;
	}(Activation$1);
	/** @nocollapse */
	Selu.className = 'selu';
	registerClass(Selu);
	/**
	 *  Rectified linear unit
	 */
	var Relu = /*#__PURE__*/function (_Activation3) {
	  _inherits(Relu, _Activation3);
	  var _super4 = _createSuper(Relu);
	  function Relu() {
	    _classCallCheck(this, Relu);
	    return _super4.apply(this, arguments);
	  }
	  _createClass(Relu, [{
	    key: "apply",
	    value: function apply(x) {
	      return relu$2(x);
	    }
	  }]);
	  return Relu;
	}(Activation$1);
	/** @nocollapse */
	Relu.className = 'relu';
	registerClass(Relu);
	/**
	 * Rectified linear unit activation maxing out at 6.0.
	 */
	var Relu6 = /*#__PURE__*/function (_Activation4) {
	  _inherits(Relu6, _Activation4);
	  var _super5 = _createSuper(Relu6);
	  function Relu6() {
	    _classCallCheck(this, Relu6);
	    return _super5.apply(this, arguments);
	  }
	  _createClass(Relu6, [{
	    key: "apply",
	    value: function apply(x) {
	      return tidy(function () {
	        return minimum$4(6.0, relu$2(x));
	      });
	    }
	  }]);
	  return Relu6;
	}(Activation$1);
	/** @nocollapse */
	Relu6.className = 'relu6';
	registerClass(Relu6);
	//* Linear activation (no-op) */
	var Linear = /*#__PURE__*/function (_Activation5) {
	  _inherits(Linear, _Activation5);
	  var _super6 = _createSuper(Linear);
	  function Linear() {
	    _classCallCheck(this, Linear);
	    return _super6.apply(this, arguments);
	  }
	  _createClass(Linear, [{
	    key: "apply",
	    value: function apply(x) {
	      return x;
	    }
	  }]);
	  return Linear;
	}(Activation$1);
	/** @nocollapse */
	Linear.className = 'linear';
	registerClass(Linear);
	/**
	 * Sigmoid activation function.
	 */
	var Sigmoid = /*#__PURE__*/function (_Activation6) {
	  _inherits(Sigmoid, _Activation6);
	  var _super7 = _createSuper(Sigmoid);
	  function Sigmoid() {
	    _classCallCheck(this, Sigmoid);
	    return _super7.apply(this, arguments);
	  }
	  _createClass(Sigmoid, [{
	    key: "apply",
	    value: function apply(x) {
	      return sigmoid$2(x);
	    }
	  }]);
	  return Sigmoid;
	}(Activation$1);
	/** @nocollapse */
	Sigmoid.className = 'sigmoid';
	registerClass(Sigmoid);
	/**
	 * Segment-wise linear approximation of sigmoid.
	 */
	var HardSigmoid = /*#__PURE__*/function (_Activation7) {
	  _inherits(HardSigmoid, _Activation7);
	  var _super8 = _createSuper(HardSigmoid);
	  function HardSigmoid() {
	    _classCallCheck(this, HardSigmoid);
	    return _super8.apply(this, arguments);
	  }
	  _createClass(HardSigmoid, [{
	    key: "apply",
	    value: function apply(x) {
	      return hardSigmoid(x);
	    }
	  }]);
	  return HardSigmoid;
	}(Activation$1);
	/** @nocollapse */
	HardSigmoid.className = 'hardSigmoid';
	registerClass(HardSigmoid);
	/**
	 * Softplus activation function.
	 */
	var Softplus = /*#__PURE__*/function (_Activation8) {
	  _inherits(Softplus, _Activation8);
	  var _super9 = _createSuper(Softplus);
	  function Softplus() {
	    _classCallCheck(this, Softplus);
	    return _super9.apply(this, arguments);
	  }
	  _createClass(Softplus, [{
	    key: "apply",
	    value: function apply(x) {
	      return softplus$2(x);
	    }
	  }]);
	  return Softplus;
	}(Activation$1);
	/** @nocollapse */
	Softplus.className = 'softplus';
	registerClass(Softplus);
	/**
	 * Softsign activation function.
	 */
	var Softsign = /*#__PURE__*/function (_Activation9) {
	  _inherits(Softsign, _Activation9);
	  var _super10 = _createSuper(Softsign);
	  function Softsign() {
	    _classCallCheck(this, Softsign);
	    return _super10.apply(this, arguments);
	  }
	  _createClass(Softsign, [{
	    key: "apply",
	    value: function apply(x) {
	      return softsign(x);
	    }
	  }]);
	  return Softsign;
	}(Activation$1);
	/** @nocollapse */
	Softsign.className = 'softsign';
	registerClass(Softsign);
	/**
	 * Hyperbolic tangent function.
	 */
	var Tanh = /*#__PURE__*/function (_Activation10) {
	  _inherits(Tanh, _Activation10);
	  var _super11 = _createSuper(Tanh);
	  function Tanh() {
	    _classCallCheck(this, Tanh);
	    return _super11.apply(this, arguments);
	  }
	  _createClass(Tanh, [{
	    key: "apply",
	    value: function apply(x) {
	      return tanh$2(x);
	    }
	  }]);
	  return Tanh;
	}(Activation$1);
	/** @nocollapse */
	Tanh.className = 'tanh';
	registerClass(Tanh);
	/**
	 * Softmax activation function
	 */
	var Softmax$1 = /*#__PURE__*/function (_Activation11) {
	  _inherits(Softmax, _Activation11);
	  var _super12 = _createSuper(Softmax);
	  function Softmax() {
	    _classCallCheck(this, Softmax);
	    return _super12.apply(this, arguments);
	  }
	  _createClass(Softmax, [{
	    key: "apply",
	    value:
	    /**
	     * Calculate the activation function.
	     *
	     * @param x Tensor.
	     * @param axis Integer, axis along which the softmax normalization is applied.
	     * Invalid if < 2, as softmax across 1 (the batch dimension) is assumed to be
	     * an error.
	     *
	     * @returns a Tensor of the same shape as x
	     *
	     * @throws ValueError: In case `dim(x) < 2`.
	     */
	    function apply(x) {
	      var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : -1;
	      return softmax$3(x, axis);
	    }
	  }]);
	  return Softmax;
	}(Activation$1);
	/** @nocollapse */
	Softmax$1.className = 'softmax';
	registerClass(Softmax$1);
	/**
	 * Log softmax activation function
	 */
	var LogSoftmax = /*#__PURE__*/function (_Activation12) {
	  _inherits(LogSoftmax, _Activation12);
	  var _super13 = _createSuper(LogSoftmax);
	  function LogSoftmax() {
	    _classCallCheck(this, LogSoftmax);
	    return _super13.apply(this, arguments);
	  }
	  _createClass(LogSoftmax, [{
	    key: "apply",
	    value:
	    /**
	     * Calculate the activation function of log softmax:
	     * log( exp(x_i) / sum(exp(x)) )
	     *
	     * @param x Tensor.
	     * @param axis Integer, axis along which the softmax normalization is applied.
	     * Invalid if < 2, as softmax across 1 (the batch dimension) is assumed to be
	     * an error.
	     *
	     * @returns a Tensor of the same shape as x
	     *
	     * @throws ValueError: In case `dim(x) < 2`.
	     */
	    function apply(x) {
	      var axis = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : -1;
	      return logSoftmax(x, axis);
	    }
	  }]);
	  return LogSoftmax;
	}(Activation$1);
	/** @nocollapse */
	LogSoftmax.className = 'logSoftmax';
	registerClass(LogSoftmax);
	/**
	 * Gelu activation function
	 */
	var Gelu = /*#__PURE__*/function (_Activation13) {
	  _inherits(Gelu, _Activation13);
	  var _super14 = _createSuper(Gelu);
	  function Gelu() {
	    _classCallCheck(this, Gelu);
	    return _super14.apply(this, arguments);
	  }
	  _createClass(Gelu, [{
	    key: "apply",
	    value:
	    /**
	     * Calculate the activation function.
	     *
	     * @param x Tensor.
	     * @returns a Tensor of the same shape as x
	     */
	    function apply(x) {
	      return tidy(function () {
	        return tidy(function () {
	          var sqrtTwo = Math.sqrt(2);
	          // Compute Φ(x) using the erf function
	          var cdf = mul(0.5, add$3(1, erf$2(div$1(x, sqrtTwo))));
	          // Compute GELU(x) = x * Φ(x)
	          return mul(x, cdf);
	        });
	      });
	    }
	  }]);
	  return Gelu;
	}(Activation$1);
	/** @nocollapse */
	Gelu.className = 'gelu';
	registerClass(Gelu);
	/**
	 * GeluNew activation function
	 */
	var GeluNew = /*#__PURE__*/function (_Activation14) {
	  _inherits(GeluNew, _Activation14);
	  var _super15 = _createSuper(GeluNew);
	  function GeluNew() {
	    _classCallCheck(this, GeluNew);
	    return _super15.apply(this, arguments);
	  }
	  _createClass(GeluNew, [{
	    key: "apply",
	    value:
	    /**
	     * Calculate the activation function.
	     *
	     * @param x Tensor.
	     * @returns a Tensor of the same shape as x
	     */
	    function apply(x) {
	      return tidy(function () {
	        return mul(0.5, mul(x, add$3(1, tanh$2(mul(sqrt$2(div$1(2, Math.PI)), add$3(x, mul(0.044715, pow$3(x, 3))))))));
	      });
	    }
	  }]);
	  return GeluNew;
	}(Activation$1);
	/** @nocollapse */
	GeluNew.className = 'gelu_new';
	registerClass(GeluNew);
	/**
	 * Mish activation function
	 */
	var Mish = /*#__PURE__*/function (_Activation15) {
	  _inherits(Mish, _Activation15);
	  var _super16 = _createSuper(Mish);
	  function Mish() {
	    _classCallCheck(this, Mish);
	    return _super16.apply(this, arguments);
	  }
	  _createClass(Mish, [{
	    key: "apply",
	    value:
	    /**
	     * Calculate the activation function.
	     *
	     * @param x Tensor.
	     * @returns a Tensor of the same shape as x
	     */
	    function apply(x) {
	      return tidy(function () {
	        return mul(x, tanh$2(softplus$2(x)));
	      });
	    }
	  }]);
	  return Mish;
	}(Activation$1);
	/** @nocollapse */
	Mish.className = 'mish';
	registerClass(Mish);
	/**
	 * Swish activation function
	 */
	var Swish = /*#__PURE__*/function (_Activation16) {
	  _inherits(Swish, _Activation16);
	  var _super17 = _createSuper(Swish);
	  function Swish() {
	    _classCallCheck(this, Swish);
	    return _super17.apply(this, arguments);
	  }
	  _createClass(Swish, [{
	    key: "apply",
	    value:
	    /**
	     * Calculate the activation function.
	     *
	     * @param x Tensor.
	     * @param alpha Scaling factor for the sigmoid function.
	     * @returns a Tensor of the same shape as x
	     */
	    function apply(x) {
	      var alpha = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
	      return tidy(function () {
	        return mul(sigmoid$2(mul(x, alpha)), x);
	      });
	    }
	  }]);
	  return Swish;
	}(Activation$1);
	/** @nocollapse */
	Swish.className = 'swish';
	registerClass(Swish);
	function serializeActivation(activation) {
	  return activation.getClassName();
	}
	function deserializeActivation(config) {
	  var customObjects = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	  return deserializeKerasObject(config, SerializationMap.getMap().classNameMap, customObjects, 'activation');
	}
	function getActivation(identifier) {
	  if (identifier == null) {
	    var config = {};
	    config['className'] = 'linear';
	    config['config'] = {};
	    return deserializeActivation(config);
	  }
	  if (typeof identifier === 'string') {
	    var _config = {};
	    _config['className'] = identifier;
	    _config['config'] = {};
	    return deserializeActivation(_config);
	  } else if (identifier instanceof Activation$1) {
	    return identifier;
	  } else {
	    return deserializeActivation(identifier);
	  }
	}

	function assertObjectArgs(args) {
	  if (args != null && _typeof(args) !== 'object') {
	    throw new Error("Argument to L1L2 regularizer's constructor is expected to be an " + "object, but received: ".concat(args));
	  }
	}
	/**
	 * Regularizer base class.
	 */
	var Regularizer = /*#__PURE__*/function (_serialization$Serial) {
	  _inherits(Regularizer, _serialization$Serial);
	  var _super = _createSuper(Regularizer);
	  function Regularizer() {
	    _classCallCheck(this, Regularizer);
	    return _super.apply(this, arguments);
	  }
	  return _createClass(Regularizer);
	}(Serializable);
	var L1L2 = /*#__PURE__*/function (_Regularizer) {
	  _inherits(L1L2, _Regularizer);
	  var _super2 = _createSuper(L1L2);
	  function L1L2(args) {
	    var _this;
	    _classCallCheck(this, L1L2);
	    _this = _super2.call(this);
	    assertObjectArgs(args);
	    _this.l1 = args == null || args.l1 == null ? 0.01 : args.l1;
	    _this.l2 = args == null || args.l2 == null ? 0.01 : args.l2;
	    _this.hasL1 = _this.l1 !== 0;
	    _this.hasL2 = _this.l2 !== 0;
	    return _this;
	  }
	  /**
	   * Porting note: Renamed from __call__.
	   * @param x Variable of which to calculate the regularization score.
	   */
	  _createClass(L1L2, [{
	    key: "apply",
	    value: function apply(x) {
	      var _this2 = this;
	      return tidy(function () {
	        var regularization = zeros$2([1]);
	        if (_this2.hasL1) {
	          regularization = add$3(regularization, sum$3(mul(_this2.l1, abs$2(x))));
	        }
	        if (_this2.hasL2) {
	          regularization = add$3(regularization, sum$3(mul(_this2.l2, square$1(x))));
	        }
	        return reshape$3(regularization, []);
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      return {
	        'l1': this.l1,
	        'l2': this.l2
	      };
	    }
	    /** @nocollapse */
	  }], [{
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      return new cls({
	        l1: config['l1'],
	        l2: config['l2']
	      });
	    }
	  }]);
	  return L1L2;
	}(Regularizer);
	/** @nocollapse */
	L1L2.className = 'L1L2';
	registerClass(L1L2);
	function l1$1(args) {
	  assertObjectArgs(args);
	  return new L1L2({
	    l1: args != null ? args.l1 : null,
	    l2: 0
	  });
	}
	function l2$1(args) {
	  assertObjectArgs(args);
	  return new L1L2({
	    l2: args != null ? args.l2 : null,
	    l1: 0
	  });
	}
	// Maps the JavaScript-like identifier keys to the corresponding keras symbols.
	var REGULARIZER_IDENTIFIER_REGISTRY_SYMBOL_MAP = {
	  'l1l2': 'L1L2'
	};
	function serializeRegularizer(constraint) {
	  return serializeKerasObject(constraint);
	}
	function deserializeRegularizer(config) {
	  var customObjects = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	  return deserializeKerasObject(config, SerializationMap.getMap().classNameMap, customObjects, 'regularizer');
	}
	function getRegularizer(identifier) {
	  if (identifier == null) {
	    return null;
	  }
	  if (typeof identifier === 'string') {
	    var className = identifier in REGULARIZER_IDENTIFIER_REGISTRY_SYMBOL_MAP ? REGULARIZER_IDENTIFIER_REGISTRY_SYMBOL_MAP[identifier] : identifier;
	    var config = {
	      className: className,
	      config: {}
	    };
	    return deserializeRegularizer(config);
	  } else if (identifier instanceof Regularizer) {
	    return identifier;
	  } else {
	    return deserializeRegularizer(identifier);
	  }
	}

	var ReLU = /*#__PURE__*/function (_Layer) {
	  _inherits(ReLU, _Layer);
	  var _super = _createSuper(ReLU);
	  function ReLU(args) {
	    var _this;
	    _classCallCheck(this, ReLU);
	    _this = _super.call(this, args == null ? {} : args);
	    _this.supportsMasking = true;
	    if (args != null) {
	      _this.maxValue = args.maxValue;
	    }
	    return _this;
	  }
	  _createClass(ReLU, [{
	    key: "call",
	    value: function call(inputs, kwargs) {
	      inputs = getExactlyOneTensor(inputs);
	      var output = relu$2(inputs);
	      if (this.maxValue != null) {
	        output = clipByValue$2(output, 0, this.maxValue);
	      }
	      return output;
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      return inputShape;
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        maxValue: this.maxValue
	      };
	      var baseConfig = _get(_getPrototypeOf(ReLU.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return ReLU;
	}(Layer);
	/** @nocollapse */
	ReLU.className = 'ReLU';
	registerClass(ReLU);
	var LeakyReLU = /*#__PURE__*/function (_Layer2) {
	  _inherits(LeakyReLU, _Layer2);
	  var _super2 = _createSuper(LeakyReLU);
	  function LeakyReLU(args) {
	    var _this2;
	    _classCallCheck(this, LeakyReLU);
	    _this2 = _super2.call(this, args == null ? {} : args);
	    _this2.DEFAULT_ALPHA = 0.3;
	    if (args == null) {
	      args = {};
	    }
	    _this2.alpha = args.alpha == null ? _this2.DEFAULT_ALPHA : args.alpha;
	    return _this2;
	  }
	  _createClass(LeakyReLU, [{
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var x = getExactlyOneTensor(inputs);
	      return leakyRelu$2(x, this.alpha);
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      return inputShape;
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        alpha: this.alpha
	      };
	      var baseConfig = _get(_getPrototypeOf(LeakyReLU.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return LeakyReLU;
	}(Layer);
	/** @nocollapse */
	LeakyReLU.className = 'LeakyReLU';
	registerClass(LeakyReLU);
	var PReLU = /*#__PURE__*/function (_Layer3) {
	  _inherits(PReLU, _Layer3);
	  var _super3 = _createSuper(PReLU);
	  function PReLU(args) {
	    var _this3;
	    _classCallCheck(this, PReLU);
	    _this3 = _super3.call(this, args == null ? {} : args);
	    _this3.DEFAULT_ALPHA_INITIALIZER = 'zeros';
	    if (args == null) {
	      args = {};
	    }
	    _this3.supportsMasking = true;
	    _this3.alphaInitializer = getInitializer(args.alphaInitializer || _this3.DEFAULT_ALPHA_INITIALIZER);
	    _this3.alphaRegularizer = getRegularizer(args.alphaRegularizer);
	    _this3.alphaConstraint = getConstraint(args.alphaConstraint);
	    if (args.sharedAxes == null) {
	      _this3.sharedAxes = null;
	    } else if (Array.isArray(args.sharedAxes)) {
	      _this3.sharedAxes = args.sharedAxes;
	    } else if (typeof args.sharedAxes === 'number') {
	      _this3.sharedAxes = [args.sharedAxes];
	    } else {
	      throw new ValueError("Expected sharedAxes to be a number or an array of numbers, " + "but got ".concat(args.sharedAxes));
	    }
	    return _this3;
	  }
	  _createClass(PReLU, [{
	    key: "build",
	    value: function build(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var paramShape = inputShape.slice(1);
	      if (this.sharedAxes != null) {
	        var _iterator = _createForOfIteratorHelper(this.sharedAxes),
	          _step;
	        try {
	          for (_iterator.s(); !(_step = _iterator.n()).done;) {
	            var i = _step.value;
	            paramShape[i - 1] = 1;
	          }
	        } catch (err) {
	          _iterator.e(err);
	        } finally {
	          _iterator.f();
	        }
	      }
	      this.alpha = this.addWeight('alpha', paramShape, 'float32', this.alphaInitializer, this.alphaRegularizer, true, this.alphaConstraint);
	      // Set input spec.
	      var axes = {};
	      if (this.sharedAxes != null) {
	        for (var _i = 1; _i < inputShape.length; ++_i) {
	          axes[_i] = inputShape[_i];
	        }
	      }
	      this.inputSpec = [new InputSpec({
	        ndim: inputShape.length,
	        axes: axes
	      })];
	      this.built = true;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      inputs = getExactlyOneTensor(inputs);
	      return prelu$3(inputs, this.alpha.read());
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        alphaInitializer: serializeInitializer(this.alphaInitializer),
	        alphaRegularizer: serializeRegularizer(this.alphaRegularizer),
	        alphaConstraint: serializeConstraint(this.alphaConstraint),
	        sharedAxes: this.sharedAxes
	      };
	      var baseConfig = _get(_getPrototypeOf(PReLU.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return PReLU;
	}(Layer);
	/** @nocollapse */
	PReLU.className = 'PReLU';
	registerClass(PReLU);
	var ELU$3 = /*#__PURE__*/function (_Layer4) {
	  _inherits(ELU, _Layer4);
	  var _super4 = _createSuper(ELU);
	  function ELU(args) {
	    var _this4;
	    _classCallCheck(this, ELU);
	    _this4 = _super4.call(this, args == null ? {} : args);
	    _this4.DEFAULT_ALPHA = 1.0;
	    if (args == null) {
	      args = {};
	    }
	    if (args.alpha != null && args.alpha !== _this4.DEFAULT_ALPHA) {
	      throw new NotImplementedError("Non-default alpha value (".concat(args.alpha, ") is not supported by the ") + "ELU layer yet.");
	    }
	    _this4.alpha = args.alpha == null ? _this4.DEFAULT_ALPHA : args.alpha;
	    return _this4;
	  }
	  _createClass(ELU, [{
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var x = getExactlyOneTensor(inputs);
	      return elu$4(x);
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      return inputShape;
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        alpha: this.alpha
	      };
	      var baseConfig = _get(_getPrototypeOf(ELU.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return ELU;
	}(Layer);
	/** @nocollapse */
	ELU$3.className = 'ELU';
	registerClass(ELU$3);
	var ThresholdedReLU = /*#__PURE__*/function (_Layer5) {
	  _inherits(ThresholdedReLU, _Layer5);
	  var _super5 = _createSuper(ThresholdedReLU);
	  function ThresholdedReLU(args) {
	    var _this5;
	    _classCallCheck(this, ThresholdedReLU);
	    _this5 = _super5.call(this, args == null ? {} : args);
	    _this5.DEFAULT_THETA = 1.0;
	    if (args == null) {
	      args = {};
	    }
	    _this5.theta = args.theta == null ? _this5.DEFAULT_THETA : args.theta;
	    return _this5;
	  }
	  _createClass(ThresholdedReLU, [{
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var x = getExactlyOneTensor(inputs);
	      return mul(x, cast$3(greater$3(x, this.theta), 'float32'));
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      return inputShape;
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        theta: this.theta
	      };
	      var baseConfig = _get(_getPrototypeOf(ThresholdedReLU.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return ThresholdedReLU;
	}(Layer);
	/** @nocollapse */
	ThresholdedReLU.className = 'ThresholdedReLU';
	registerClass(ThresholdedReLU);
	var Softmax = /*#__PURE__*/function (_Layer6) {
	  _inherits(Softmax, _Layer6);
	  var _super6 = _createSuper(Softmax);
	  function Softmax(args) {
	    var _this6;
	    _classCallCheck(this, Softmax);
	    _this6 = _super6.call(this, args == null ? {} : args);
	    _this6.DEFAULT_AXIS = 1.0;
	    if (args == null) {
	      args = {};
	    }
	    _this6.softmax = new Softmax$1().apply;
	    _this6.axis = args.axis == null ? _this6.DEFAULT_AXIS : args.axis;
	    return _this6;
	  }
	  _createClass(Softmax, [{
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this7 = this;
	      // TODO(pforderique): Add tests for when `this.axis` is a number[].
	      return tidy(function () {
	        var x = getExactlyOneTensor(inputs);
	        var mask = kwargs['mask'];
	        if (mask != null) {
	          // Since mask is 1.0 for positions we want to keep and 0.0 for masked
	          // positions, this operation will create a tensor which is 0.0 for
	          // positions we want to attend and -1e.9 for masked positions.
	          var adder = mul(sub$2(ones$1(x.shape), cast$3(mask, x.dtype)), scalar(-1e9));
	          // Since we are adding it to the raw scores before the softmax, this
	          // is effectively the same as removing these entirely.
	          x = add$3(x, adder);
	        }
	        if (_this7.axis instanceof Array) {
	          if (_this7.axis.length > 1) {
	            return exp$2(sub$2(x, logSumExp(x, _this7.axis, true)));
	          } else {
	            return _this7.softmax(x, _this7.axis[0]);
	          }
	        }
	        return _this7.softmax(x, _this7.axis);
	      });
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      return inputShape;
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        axis: this.axis
	      };
	      var baseConfig = _get(_getPrototypeOf(Softmax.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return Softmax;
	}(Layer);
	/** @nocollapse */
	Softmax.className = 'Softmax';
	registerClass(Softmax);

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	/**
	 * Transforms a single number of array of numbers into an array of numbers.
	 * @param value
	 * @param n: The size of the tuple to be returned.
	 * @param name: Name of the parameter, used for generating error messages.
	 * @returns An array of numbers.
	 */
	function normalizeArray(value, n, name) {
	  if (typeof value === 'number') {
	    return pyListRepeat(value, n);
	  } else {
	    if (value.length !== n) {
	      throw new ValueError("The ".concat(name, " argument must be an integer or tuple of ").concat(n, " integers.") + " Received: ".concat(value.length, " elements."));
	    }
	    for (var i = 0; i < n; ++i) {
	      var singleValue = value[i];
	      if (!isInteger(singleValue)) {
	        throw new ValueError("The ".concat(name, " argument must be an integer or tuple of ").concat(n) + " integers. Received: ".concat(JSON.stringify(value), " including a") + " non-integer number ".concat(singleValue));
	      }
	    }
	    return value;
	  }
	}
	/**
	 * Determines output length of a convolution given input length.
	 * @param inputLength
	 * @param filterSize
	 * @param padding
	 * @param stride
	 * @param dilation: dilation rate.
	 */
	function convOutputLength(inputLength, filterSize, padding, stride) {
	  var dilation = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 1;
	  if (inputLength == null) {
	    return inputLength;
	  }
	  var dilatedFilterSize = filterSize + (filterSize - 1) * (dilation - 1);
	  var outputLength;
	  if (padding === 'same') {
	    outputLength = inputLength;
	  } else {
	    // VALID
	    outputLength = inputLength - dilatedFilterSize + 1;
	  }
	  return Math.floor((outputLength + stride - 1) / stride);
	}
	function deconvLength(dimSize, strideSize, kernelSize, padding) {
	  if (dimSize == null) {
	    return null;
	  }
	  if (padding === 'valid') {
	    dimSize = dimSize * strideSize + max$2([kernelSize - strideSize, 0]);
	  } else if (padding === 'same') {
	    dimSize = dimSize * strideSize;
	  } else {
	    throw new ValueError("Unsupport padding mode: ".concat(padding, "."));
	  }
	  return dimSize;
	}

	/**
	 * Transpose and cast the input before the conv2d.
	 * @param x Input image tensor.
	 * @param dataFormat
	 */
	function preprocessConv2DInput(x, dataFormat) {
	  // TODO(cais): Cast type to float32 if not.
	  return tidy(function () {
	    checkDataFormat(dataFormat);
	    if (dataFormat === 'channelsFirst') {
	      return transpose$2(x, [0, 2, 3, 1]); // NCHW -> NHWC.
	    } else {
	      return x;
	    }
	  });
	}
	/**
	 * Transpose and cast the input before the conv3d.
	 * @param x Input image tensor.
	 * @param dataFormat
	 */
	function preprocessConv3DInput(x, dataFormat) {
	  return tidy(function () {
	    checkDataFormat(dataFormat);
	    if (dataFormat === 'channelsFirst') {
	      return transpose$2(x, [0, 2, 3, 4, 1]); // NCDHW -> NDHWC.
	    } else {
	      return x;
	    }
	  });
	}
	/**
	 * 1D-convolution with bias added.
	 *
	 * Porting Note: This function does not exist in the Python Keras backend.
	 *   It is exactly the same as `conv2d`, except the added `bias`.
	 *
	 * @param x Input tensor, rank-3, of shape `[batchSize, width, inChannels]`.
	 * @param kernel Kernel, rank-3, of shape `[filterWidth, inDepth, outDepth]`.
	 * @param bias Bias, rank-3, of shape `[outDepth]`.
	 * @param strides
	 * @param padding Padding mode.
	 * @param dataFormat Data format.
	 * @param dilationRate
	 * @returns The result of the 1D convolution.
	 * @throws ValueError, if `x`, `kernel` or `bias` is not of the correct rank.
	 */
	function conv1dWithBias(x, kernel, bias) {
	  var strides = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 1;
	  var padding = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 'valid';
	  var dataFormat = arguments.length > 5 ? arguments[5] : undefined;
	  var dilationRate = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : 1;
	  return tidy(function () {
	    if (dataFormat == null) {
	      dataFormat = imageDataFormat();
	    }
	    checkDataFormat(dataFormat);
	    // Check the ranks of x, kernel and bias.
	    if (x.shape.length !== 3) {
	      throw new ValueError("The input of a conv1dWithBias operation should be 3, but is " + "".concat(x.shape.length, " instead."));
	    }
	    if (kernel.shape.length !== 3) {
	      throw new ValueError("The kernel for a conv1dWithBias operation should be 3, but is " + "".concat(kernel.shape.length, " instead"));
	    }
	    if (bias != null && bias.shape.length !== 1) {
	      throw new ValueError("The bias for a conv1dWithBias operation should be 1, but is " + "".concat(bias.shape.length, " instead"));
	    }
	    // TODO(cais): Support CAUSAL padding mode.
	    if (dataFormat === 'channelsFirst') {
	      x = transpose$2(x, [0, 2, 1]); // NCW -> NWC.
	    }

	    if (padding === 'causal') {
	      throw new NotImplementedError('The support for CAUSAL padding mode in conv1dWithBias is not ' + 'implemented yet.');
	    }
	    var y = conv1d$2(x, kernel, strides, padding === 'same' ? 'same' : 'valid', 'NWC', dilationRate);
	    if (bias != null) {
	      y = biasAdd(y, bias);
	    }
	    return y;
	  });
	}
	/**
	 * 1D-convolution.
	 *
	 * @param x Input tensor, rank-3, of shape `[batchSize, width, inChannels]`.
	 * @param kernel Kernel, rank-3, of shape `[filterWidth, inDepth, outDepth]`.s
	 * @param strides
	 * @param padding Padding mode.
	 * @param dataFormat Data format.
	 * @param dilationRate
	 * @returns The result of the 1D convolution.
	 * @throws ValueError, if `x`, `kernel` or `bias` is not of the correct rank.
	 */
	function conv1d$1(x, kernel) {
	  var strides = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;
	  var padding = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'valid';
	  var dataFormat = arguments.length > 4 ? arguments[4] : undefined;
	  var dilationRate = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : 1;
	  return tidy(function () {
	    checkDataFormat(dataFormat);
	    return conv1dWithBias(x, kernel, null, strides, padding, dataFormat, dilationRate);
	  });
	}
	/**
	 * 2D Convolution
	 * @param x
	 * @param kernel kernel of the convolution.
	 * @param strides strides array.
	 * @param padding padding mode. Default to 'valid'.
	 * @param dataFormat data format. Defaults to 'channelsLast'.
	 * @param dilationRate dilation rate array.
	 * @returns Result of the 2D pooling.
	 */
	function conv2d$2(x, kernel) {
	  var strides = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [1, 1];
	  var padding = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'valid';
	  var dataFormat = arguments.length > 4 ? arguments[4] : undefined;
	  var dilationRate = arguments.length > 5 ? arguments[5] : undefined;
	  return tidy(function () {
	    checkDataFormat(dataFormat);
	    return conv2dWithBiasActivation(x, kernel, null, strides, padding, dataFormat, dilationRate);
	  });
	}
	/**
	 * 2D Convolution with an added bias and optional activation.
	 * Note: This function does not exist in the Python Keras Backend. This function
	 * is exactly the same as `conv2d`, except the added `bias`.
	 */
	function conv2dWithBiasActivation(x, kernel, bias) {
	  var strides = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : [1, 1];
	  var padding = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 'valid';
	  var dataFormat = arguments.length > 5 ? arguments[5] : undefined;
	  var dilationRate = arguments.length > 6 ? arguments[6] : undefined;
	  var activation = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : null;
	  return tidy(function () {
	    if (dataFormat == null) {
	      dataFormat = imageDataFormat();
	    }
	    checkDataFormat(dataFormat);
	    if (x.rank !== 3 && x.rank !== 4) {
	      throw new ValueError("conv2dWithBiasActivation expects input to be of rank 3 or 4, " + "but received ".concat(x.rank, "."));
	    }
	    if (kernel.rank !== 3 && kernel.rank !== 4) {
	      throw new ValueError("conv2dWithBiasActivation expects kernel to be of rank 3 or 4, " + "but received ".concat(x.rank, "."));
	    }
	    var y = preprocessConv2DInput(x, dataFormat);
	    if (padding === 'causal') {
	      throw new NotImplementedError('The support for CAUSAL padding mode in conv1dWithBias is not ' + 'implemented yet.');
	    }
	    y = conv2d$3({
	      x: y,
	      filter: kernel,
	      strides: strides,
	      pad: padding === 'same' ? 'same' : 'valid',
	      dilations: dilationRate,
	      dataFormat: 'NHWC',
	      bias: bias,
	      activation: activation
	    });
	    if (dataFormat === 'channelsFirst') {
	      y = transpose$2(y, [0, 3, 1, 2]);
	    }
	    return y;
	  });
	}
	/**
	 * 3D Convolution.
	 * @param x
	 * @param kernel kernel of the convolution.
	 * @param strides strides array.
	 * @param padding padding mode. Default to 'valid'.
	 * @param dataFormat data format. Defaults to 'channelsLast'.
	 * @param dilationRate dilation rate array.
	 * @returns Result of the 3D convolution.
	 */
	function conv3d$1(x, kernel) {
	  var strides = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [1, 1, 1];
	  var padding = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'valid';
	  var dataFormat = arguments.length > 4 ? arguments[4] : undefined;
	  var dilationRate = arguments.length > 5 ? arguments[5] : undefined;
	  return tidy(function () {
	    checkDataFormat(dataFormat);
	    return conv3dWithBias(x, kernel, null, strides, padding, dataFormat, dilationRate);
	  });
	}
	/**
	 * 3D Convolution with an added bias.
	 * Note: This function does not exist in the Python Keras Backend. This function
	 * is exactly the same as `conv3d`, except the added `bias`.
	 */
	function conv3dWithBias(x, kernel, bias) {
	  var strides = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : [1, 1, 1];
	  var padding = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 'valid';
	  var dataFormat = arguments.length > 5 ? arguments[5] : undefined;
	  var dilationRate = arguments.length > 6 ? arguments[6] : undefined;
	  return tidy(function () {
	    if (dataFormat == null) {
	      dataFormat = imageDataFormat();
	    }
	    checkDataFormat(dataFormat);
	    if (x.rank !== 4 && x.rank !== 5) {
	      throw new ValueError("conv3dWithBias expects input to be of rank 4 or 5, but received " + "".concat(x.rank, "."));
	    }
	    if (kernel.rank !== 4 && kernel.rank !== 5) {
	      throw new ValueError("conv3dWithBias expects kernel to be of rank 4 or 5, but received " + "".concat(x.rank, "."));
	    }
	    var y = preprocessConv3DInput(x, dataFormat);
	    if (padding === 'causal') {
	      throw new NotImplementedError('The support for CAUSAL padding mode in conv3dWithBias is not ' + 'implemented yet.');
	    }
	    y = conv3d$2(y, kernel, strides, padding === 'same' ? 'same' : 'valid', 'NDHWC', dilationRate);
	    if (bias != null) {
	      y = biasAdd(y, bias);
	    }
	    if (dataFormat === 'channelsFirst') {
	      y = transpose$2(y, [0, 4, 1, 2, 3]);
	    }
	    return y;
	  });
	}
	/**
	 * Abstract convolution layer.
	 */
	var BaseConv = /*#__PURE__*/function (_Layer) {
	  _inherits(BaseConv, _Layer);
	  var _super = _createSuper(BaseConv);
	  function BaseConv(rank, args) {
	    var _this;
	    _classCallCheck(this, BaseConv);
	    _this = _super.call(this, args);
	    _this.bias = null;
	    _this.DEFAULT_KERNEL_INITIALIZER = 'glorotNormal';
	    _this.DEFAULT_BIAS_INITIALIZER = 'zeros';
	    BaseConv.verifyArgs(args);
	    _this.rank = rank;
	    assertPositiveInteger(_this.rank, 'rank');
	    if (_this.rank !== 1 && _this.rank !== 2 && _this.rank !== 3) {
	      throw new NotImplementedError("Convolution layer for rank other than 1, 2, or 3 (".concat(_this.rank, ") is ") + "not implemented yet.");
	    }
	    _this.kernelSize = normalizeArray(args.kernelSize, rank, 'kernelSize');
	    _this.strides = normalizeArray(args.strides == null ? 1 : args.strides, rank, 'strides');
	    _this.padding = args.padding == null ? 'valid' : args.padding;
	    checkPaddingMode(_this.padding);
	    _this.dataFormat = args.dataFormat == null ? 'channelsLast' : args.dataFormat;
	    checkDataFormat(_this.dataFormat);
	    _this.activation = getActivation(args.activation);
	    _this.useBias = args.useBias == null ? true : args.useBias;
	    _this.biasInitializer = getInitializer(args.biasInitializer || _this.DEFAULT_BIAS_INITIALIZER);
	    _this.biasConstraint = getConstraint(args.biasConstraint);
	    _this.biasRegularizer = getRegularizer(args.biasRegularizer);
	    _this.activityRegularizer = getRegularizer(args.activityRegularizer);
	    _this.dilationRate = normalizeArray(args.dilationRate == null ? 1 : args.dilationRate, rank, 'dilationRate');
	    if (_this.rank === 1 && Array.isArray(_this.dilationRate) && _this.dilationRate.length !== 1) {
	      throw new ValueError("dilationRate must be a number or an array of a single number " + "for 1D convolution, but received " + "".concat(JSON.stringify(_this.dilationRate)));
	    } else if (_this.rank === 2) {
	      if (typeof _this.dilationRate === 'number') {
	        _this.dilationRate = [_this.dilationRate, _this.dilationRate];
	      } else if (_this.dilationRate.length !== 2) {
	        throw new ValueError("dilationRate must be a number or array of two numbers for 2D " + "convolution, but received ".concat(JSON.stringify(_this.dilationRate)));
	      }
	    } else if (_this.rank === 3) {
	      if (typeof _this.dilationRate === 'number') {
	        _this.dilationRate = [_this.dilationRate, _this.dilationRate, _this.dilationRate];
	      } else if (_this.dilationRate.length !== 3) {
	        throw new ValueError("dilationRate must be a number or array of three numbers for 3D " + "convolution, but received ".concat(JSON.stringify(_this.dilationRate)));
	      }
	    }
	    return _this;
	  }
	  _createClass(BaseConv, [{
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        kernelSize: this.kernelSize,
	        strides: this.strides,
	        padding: this.padding,
	        dataFormat: this.dataFormat,
	        dilationRate: this.dilationRate,
	        activation: serializeActivation(this.activation),
	        useBias: this.useBias,
	        biasInitializer: serializeInitializer(this.biasInitializer),
	        biasRegularizer: serializeRegularizer(this.biasRegularizer),
	        activityRegularizer: serializeRegularizer(this.activityRegularizer),
	        biasConstraint: serializeConstraint(this.biasConstraint)
	      };
	      var baseConfig = _get(_getPrototypeOf(BaseConv.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }], [{
	    key: "verifyArgs",
	    value: function verifyArgs(args) {
	      // Check config.kernelSize type and shape.
	      assert('kernelSize' in args, "required key 'kernelSize' not in config");
	      if (typeof args.kernelSize !== 'number' && !checkArrayTypeAndLength(args.kernelSize, 'number', 1, 3)) {
	        throw new ValueError("BaseConv expects config.kernelSize to be number or number[] with " + "length 1, 2, or 3, but received ".concat(JSON.stringify(args.kernelSize), "."));
	      }
	    }
	  }]);
	  return BaseConv;
	}(Layer);
	/**
	 * Abstract nD convolution layer.  Ancestor of convolution layers which reduce
	 * across channels, i.e., Conv1D and Conv2D, but not DepthwiseConv2D.
	 */
	var Conv = /*#__PURE__*/function (_BaseConv) {
	  _inherits(Conv, _BaseConv);
	  var _super2 = _createSuper(Conv);
	  function Conv(rank, args) {
	    var _this2;
	    _classCallCheck(this, Conv);
	    _this2 = _super2.call(this, rank, args);
	    _this2.kernel = null;
	    Conv.verifyArgs(args);
	    _this2.filters = args.filters;
	    assertPositiveInteger(_this2.filters, 'filters');
	    _this2.kernelInitializer = getInitializer(args.kernelInitializer || _this2.DEFAULT_KERNEL_INITIALIZER);
	    _this2.kernelConstraint = getConstraint(args.kernelConstraint);
	    _this2.kernelRegularizer = getRegularizer(args.kernelRegularizer);
	    return _this2;
	  }
	  _createClass(Conv, [{
	    key: "build",
	    value: function build(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var channelAxis = this.dataFormat === 'channelsFirst' ? 1 : inputShape.length - 1;
	      if (inputShape[channelAxis] == null) {
	        throw new ValueError("The channel dimension of the input should be defined. " + "Found ".concat(inputShape[channelAxis]));
	      }
	      var inputDim = inputShape[channelAxis];
	      var kernelShape = this.kernelSize.concat([inputDim, this.filters]);
	      this.kernel = this.addWeight('kernel', kernelShape, null, this.kernelInitializer, this.kernelRegularizer, true, this.kernelConstraint);
	      if (this.useBias) {
	        this.bias = this.addWeight('bias', [this.filters], null, this.biasInitializer, this.biasRegularizer, true, this.biasConstraint);
	      }
	      this.inputSpec = [{
	        ndim: this.rank + 2,
	        axes: _defineProperty({}, channelAxis, inputDim)
	      }];
	      this.built = true;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this3 = this;
	      return tidy(function () {
	        inputs = getExactlyOneTensor(inputs);
	        var outputs;
	        var biasValue = _this3.bias == null ? null : _this3.bias.read();
	        var fusedActivationName = mapActivationToFusedKernel(_this3.activation.getClassName());
	        if (fusedActivationName != null && _this3.rank === 2) {
	          outputs = conv2dWithBiasActivation(inputs, _this3.kernel.read(), biasValue, _this3.strides, _this3.padding, _this3.dataFormat, _this3.dilationRate, fusedActivationName);
	        } else {
	          if (_this3.rank === 1) {
	            outputs = conv1dWithBias(inputs, _this3.kernel.read(), biasValue, _this3.strides[0], _this3.padding, _this3.dataFormat, _this3.dilationRate[0]);
	          } else if (_this3.rank === 2) {
	            // TODO(cais): Move up to constructor.
	            outputs = conv2dWithBiasActivation(inputs, _this3.kernel.read(), biasValue, _this3.strides, _this3.padding, _this3.dataFormat, _this3.dilationRate);
	          } else if (_this3.rank === 3) {
	            outputs = conv3dWithBias(inputs, _this3.kernel.read(), biasValue, _this3.strides, _this3.padding, _this3.dataFormat, _this3.dilationRate);
	          } else {
	            throw new NotImplementedError('convolutions greater than 3D are not implemented yet.');
	          }
	          if (_this3.activation != null) {
	            outputs = _this3.activation.apply(outputs);
	          }
	        }
	        return outputs;
	      });
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var newSpace = [];
	      var space = this.dataFormat === 'channelsLast' ? inputShape.slice(1, inputShape.length - 1) : inputShape.slice(2);
	      for (var i = 0; i < space.length; ++i) {
	        var newDim = convOutputLength(space[i], this.kernelSize[i], this.padding, this.strides[i], typeof this.dilationRate === 'number' ? this.dilationRate : this.dilationRate[i]);
	        newSpace.push(newDim);
	      }
	      var outputShape = [inputShape[0]];
	      if (this.dataFormat === 'channelsLast') {
	        outputShape = outputShape.concat(newSpace);
	        outputShape.push(this.filters);
	      } else {
	        outputShape.push(this.filters);
	        outputShape = outputShape.concat(newSpace);
	      }
	      return outputShape;
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        filters: this.filters,
	        kernelInitializer: serializeInitializer(this.kernelInitializer),
	        kernelRegularizer: serializeRegularizer(this.kernelRegularizer),
	        kernelConstraint: serializeConstraint(this.kernelConstraint)
	      };
	      var baseConfig = _get(_getPrototypeOf(Conv.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }], [{
	    key: "verifyArgs",
	    value: function verifyArgs(args) {
	      // Check config.filters type, shape, and value.
	      if (!('filters' in args) || typeof args.filters !== 'number' || args.filters < 1) {
	        throw new ValueError("Convolution layer expected config.filters to be a 'number' > 0 " + "but got ".concat(JSON.stringify(args.filters)));
	      }
	    }
	  }]);
	  return Conv;
	}(BaseConv);
	var Conv2D = /*#__PURE__*/function (_Conv) {
	  _inherits(Conv2D, _Conv);
	  var _super3 = _createSuper(Conv2D);
	  function Conv2D(args) {
	    var _this4;
	    _classCallCheck(this, Conv2D);
	    _this4 = _super3.call(this, 2, args);
	    Conv2D.verifyArgs(args);
	    return _this4;
	  }
	  _createClass(Conv2D, [{
	    key: "getConfig",
	    value: function getConfig() {
	      var config = _get(_getPrototypeOf(Conv2D.prototype), "getConfig", this).call(this);
	      delete config['rank'];
	      return config;
	    }
	  }], [{
	    key: "verifyArgs",
	    value: function verifyArgs(args) {
	      // config.kernelSize must be a number or array of numbers.
	      if (typeof args.kernelSize !== 'number' && !checkArrayTypeAndLength(args.kernelSize, 'number', 1, 2)) {
	        throw new ValueError("Conv2D expects config.kernelSize to be number or number[] with " + "length 1 or 2, but received ".concat(JSON.stringify(args.kernelSize), "."));
	      }
	    }
	  }]);
	  return Conv2D;
	}(Conv);
	/** @nocollapse */
	Conv2D.className = 'Conv2D';
	registerClass(Conv2D);
	var Conv3D = /*#__PURE__*/function (_Conv2) {
	  _inherits(Conv3D, _Conv2);
	  var _super4 = _createSuper(Conv3D);
	  function Conv3D(args) {
	    var _this5;
	    _classCallCheck(this, Conv3D);
	    _this5 = _super4.call(this, 3, args);
	    Conv3D.verifyArgs(args);
	    return _this5;
	  }
	  _createClass(Conv3D, [{
	    key: "getConfig",
	    value: function getConfig() {
	      var config = _get(_getPrototypeOf(Conv3D.prototype), "getConfig", this).call(this);
	      delete config['rank'];
	      return config;
	    }
	  }], [{
	    key: "verifyArgs",
	    value: function verifyArgs(args) {
	      // config.kernelSize must be a number or array of numbers.
	      if (typeof args.kernelSize !== 'number') {
	        if (!(Array.isArray(args.kernelSize) && (args.kernelSize.length === 1 || args.kernelSize.length === 3))) {
	          throw new ValueError("Conv3D expects config.kernelSize to be number or" + " [number, number, number], but received ".concat(JSON.stringify(args.kernelSize), "."));
	        }
	      }
	    }
	  }]);
	  return Conv3D;
	}(Conv);
	/** @nocollapse */
	Conv3D.className = 'Conv3D';
	registerClass(Conv3D);
	var Conv2DTranspose = /*#__PURE__*/function (_Conv2D) {
	  _inherits(Conv2DTranspose, _Conv2D);
	  var _super5 = _createSuper(Conv2DTranspose);
	  function Conv2DTranspose(args) {
	    var _this6;
	    _classCallCheck(this, Conv2DTranspose);
	    _this6 = _super5.call(this, args);
	    _this6.inputSpec = [new InputSpec({
	      ndim: 4
	    })];
	    if (_this6.padding !== 'same' && _this6.padding !== 'valid') {
	      throw new ValueError("Conv2DTranspose currently supports only padding modes 'same' " + "and 'valid', but received padding mode ".concat(_this6.padding));
	    }
	    return _this6;
	  }
	  _createClass(Conv2DTranspose, [{
	    key: "build",
	    value: function build(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      if (inputShape.length !== 4) {
	        throw new ValueError('Input should have rank 4; Received input shape: ' + JSON.stringify(inputShape));
	      }
	      var channelAxis = this.dataFormat === 'channelsFirst' ? 1 : inputShape.length - 1;
	      if (inputShape[channelAxis] == null) {
	        throw new ValueError('The channel dimension of the inputs should be defined. ' + 'Found `None`.');
	      }
	      var inputDim = inputShape[channelAxis];
	      var kernelShape = this.kernelSize.concat([this.filters, inputDim]);
	      this.kernel = this.addWeight('kernel', kernelShape, 'float32', this.kernelInitializer, this.kernelRegularizer, true, this.kernelConstraint);
	      if (this.useBias) {
	        this.bias = this.addWeight('bias', [this.filters], 'float32', this.biasInitializer, this.biasRegularizer, true, this.biasConstraint);
	      }
	      // Set input spec.
	      this.inputSpec = [new InputSpec({
	        ndim: 4,
	        axes: _defineProperty({}, channelAxis, inputDim)
	      })];
	      this.built = true;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this7 = this;
	      return tidy(function () {
	        var input = getExactlyOneTensor(inputs);
	        if (input.shape.length !== 4) {
	          throw new ValueError("Conv2DTranspose.call() expects input tensor to be rank-4, but " + "received a tensor of rank-".concat(input.shape.length));
	        }
	        var inputShape = input.shape;
	        var batchSize = inputShape[0];
	        var hAxis;
	        var wAxis;
	        if (_this7.dataFormat === 'channelsFirst') {
	          hAxis = 2;
	          wAxis = 3;
	        } else {
	          hAxis = 1;
	          wAxis = 2;
	        }
	        var height = inputShape[hAxis];
	        var width = inputShape[wAxis];
	        var kernelH = _this7.kernelSize[0];
	        var kernelW = _this7.kernelSize[1];
	        var strideH = _this7.strides[0];
	        var strideW = _this7.strides[1];
	        // Infer the dynamic output shape.
	        var outHeight = deconvLength(height, strideH, kernelH, _this7.padding);
	        var outWidth = deconvLength(width, strideW, kernelW, _this7.padding);
	        // Porting Note: We don't branch based on `this.dataFormat` here,
	        // because
	        //   the tjfs-core function `conv2dTranspose` called below always
	        //   assumes channelsLast.
	        var outputShape = [batchSize, outHeight, outWidth, _this7.filters];
	        if (_this7.dataFormat !== 'channelsLast') {
	          input = transpose$2(input, [0, 2, 3, 1]);
	        }
	        var outputs = conv2dTranspose$1(input, _this7.kernel.read(), outputShape, _this7.strides, _this7.padding);
	        if (_this7.dataFormat !== 'channelsLast') {
	          outputs = transpose$2(outputs, [0, 3, 1, 2]);
	        }
	        if (_this7.bias != null) {
	          outputs = biasAdd(outputs, _this7.bias.read(), _this7.dataFormat);
	        }
	        if (_this7.activation != null) {
	          outputs = _this7.activation.apply(outputs);
	        }
	        return outputs;
	      });
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var outputShape = inputShape.slice();
	      var channelAxis;
	      var heightAxis;
	      var widthAxis;
	      if (this.dataFormat === 'channelsFirst') {
	        channelAxis = 1;
	        heightAxis = 2;
	        widthAxis = 3;
	      } else {
	        channelAxis = 3;
	        heightAxis = 1;
	        widthAxis = 2;
	      }
	      var kernelH = this.kernelSize[0];
	      var kernelW = this.kernelSize[1];
	      var strideH = this.strides[0];
	      var strideW = this.strides[1];
	      outputShape[channelAxis] = this.filters;
	      outputShape[heightAxis] = deconvLength(outputShape[heightAxis], strideH, kernelH, this.padding);
	      outputShape[widthAxis] = deconvLength(outputShape[widthAxis], strideW, kernelW, this.padding);
	      return outputShape;
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = _get(_getPrototypeOf(Conv2DTranspose.prototype), "getConfig", this).call(this);
	      delete config['dilationRate'];
	      return config;
	    }
	  }]);
	  return Conv2DTranspose;
	}(Conv2D);
	/** @nocollapse */
	Conv2DTranspose.className = 'Conv2DTranspose';
	registerClass(Conv2DTranspose);
	var Conv3DTranspose = /*#__PURE__*/function (_Conv3D) {
	  _inherits(Conv3DTranspose, _Conv3D);
	  var _super6 = _createSuper(Conv3DTranspose);
	  function Conv3DTranspose(args) {
	    var _this8;
	    _classCallCheck(this, Conv3DTranspose);
	    _this8 = _super6.call(this, args);
	    _this8.inputSpec = [new InputSpec({
	      ndim: 5
	    })];
	    if (_this8.padding !== 'same' && _this8.padding !== 'valid') {
	      throw new ValueError("Conv3DTranspose currently supports only padding modes 'same' " + "and 'valid', but received padding mode ".concat(_this8.padding));
	    }
	    return _this8;
	  }
	  _createClass(Conv3DTranspose, [{
	    key: "build",
	    value: function build(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      if (inputShape.length !== 5) {
	        throw new ValueError('Input should have rank 5; Received input shape: ' + JSON.stringify(inputShape));
	      }
	      var channelAxis = this.dataFormat === 'channelsFirst' ? 1 : inputShape.length - 1;
	      if (inputShape[channelAxis] == null) {
	        throw new ValueError('The channel dimension of the inputs should be defined. ' + 'Found `None`.');
	      }
	      var inputDim = inputShape[channelAxis];
	      var kernelShape = this.kernelSize.concat([this.filters, inputDim]);
	      this.kernel = this.addWeight('kernel', kernelShape, 'float32', this.kernelInitializer, this.kernelRegularizer, true, this.kernelConstraint);
	      if (this.useBias) {
	        this.bias = this.addWeight('bias', [this.filters], 'float32', this.biasInitializer, this.biasRegularizer, true, this.biasConstraint);
	      }
	      // Set input spec.
	      this.inputSpec = [new InputSpec({
	        ndim: 5,
	        axes: _defineProperty({}, channelAxis, inputDim)
	      })];
	      this.built = true;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this9 = this;
	      return tidy(function () {
	        var input = getExactlyOneTensor(inputs);
	        if (input.shape.length !== 5) {
	          throw new ValueError("Conv3DTranspose.call() expects input tensor to be rank-4, but " + "received a tensor of rank-".concat(input.shape.length));
	        }
	        var inputShape = input.shape;
	        var batchSize = inputShape[0];
	        var hAxis;
	        var wAxis;
	        var dAxis;
	        if (_this9.dataFormat === 'channelsFirst') {
	          dAxis = 2;
	          hAxis = 3;
	          wAxis = 4;
	        } else {
	          dAxis = 1;
	          hAxis = 2;
	          wAxis = 3;
	        }
	        var depth = inputShape[dAxis];
	        var height = inputShape[hAxis];
	        var width = inputShape[wAxis];
	        var kernelD = _this9.kernelSize[0];
	        var kernelH = _this9.kernelSize[1];
	        var kernelW = _this9.kernelSize[2];
	        var strideD = _this9.strides[0];
	        var strideH = _this9.strides[1];
	        var strideW = _this9.strides[2];
	        // Infer the dynamic output shape.
	        var outDepth = deconvLength(depth, strideD, kernelD, _this9.padding);
	        var outHeight = deconvLength(height, strideH, kernelH, _this9.padding);
	        var outWidth = deconvLength(width, strideW, kernelW, _this9.padding);
	        // Same as `conv2dTranspose`. We always assumes channelsLast.
	        var outputShape = [batchSize, outDepth, outHeight, outWidth, _this9.filters];
	        if (_this9.dataFormat !== 'channelsLast') {
	          input = transpose$2(input, [0, 2, 3, 4, 1]);
	        }
	        var outputs = conv3dTranspose$1(input, _this9.kernel.read(), outputShape, _this9.strides, _this9.padding);
	        if (_this9.dataFormat !== 'channelsLast') {
	          outputs = transpose$2(outputs, [0, 4, 1, 2, 3]);
	        }
	        if (_this9.bias !== null) {
	          outputs = biasAdd(outputs, _this9.bias.read(), _this9.dataFormat);
	        }
	        if (_this9.activation !== null) {
	          outputs = _this9.activation.apply(outputs);
	        }
	        return outputs;
	      });
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var outputShape = inputShape.slice();
	      var channelAxis;
	      var depthAxis;
	      var heightAxis;
	      var widthAxis;
	      if (this.dataFormat === 'channelsFirst') {
	        channelAxis = 1;
	        depthAxis = 2;
	        heightAxis = 3;
	        widthAxis = 4;
	      } else {
	        channelAxis = 4;
	        depthAxis = 1;
	        heightAxis = 2;
	        widthAxis = 3;
	      }
	      var kernelD = this.kernelSize[0];
	      var kernelH = this.kernelSize[1];
	      var kernelW = this.kernelSize[2];
	      var strideD = this.strides[0];
	      var strideH = this.strides[1];
	      var strideW = this.strides[2];
	      outputShape[channelAxis] = this.filters;
	      outputShape[depthAxis] = deconvLength(outputShape[depthAxis], strideD, kernelD, this.padding);
	      outputShape[heightAxis] = deconvLength(outputShape[heightAxis], strideH, kernelH, this.padding);
	      outputShape[widthAxis] = deconvLength(outputShape[widthAxis], strideW, kernelW, this.padding);
	      return outputShape;
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = _get(_getPrototypeOf(Conv3DTranspose.prototype), "getConfig", this).call(this);
	      delete config['dilationRate'];
	      return config;
	    }
	  }]);
	  return Conv3DTranspose;
	}(Conv3D);
	/** @nocollapse */
	Conv3DTranspose.className = 'Conv3DTranspose';
	registerClass(Conv3DTranspose);
	var SeparableConv = /*#__PURE__*/function (_Conv3) {
	  _inherits(SeparableConv, _Conv3);
	  var _super7 = _createSuper(SeparableConv);
	  function SeparableConv(rank, config) {
	    var _this10;
	    _classCallCheck(this, SeparableConv);
	    _this10 = _super7.call(this, rank, config);
	    _this10.DEFAULT_DEPTHWISE_INITIALIZER = 'glorotUniform';
	    _this10.DEFAULT_POINTWISE_INITIALIZER = 'glorotUniform';
	    _this10.depthwiseKernel = null;
	    _this10.pointwiseKernel = null;
	    if (config.filters == null) {
	      throw new ValueError('The `filters` configuration field is required by SeparableConv, ' + 'but is unspecified.');
	    }
	    if (config.kernelInitializer != null || config.kernelRegularizer != null || config.kernelConstraint != null) {
	      throw new ValueError('Fields kernelInitializer, kernelRegularizer and kernelConstraint ' + 'are invalid for SeparableConv2D. Use depthwiseInitializer, ' + 'depthwiseRegularizer, depthwiseConstraint, pointwiseInitializer, ' + 'pointwiseRegularizer and pointwiseConstraint instead.');
	    }
	    if (config.padding != null && config.padding !== 'same' && config.padding !== 'valid') {
	      throw new ValueError("SeparableConv".concat(_this10.rank, "D supports only padding modes: ") + "'same' and 'valid', but received ".concat(JSON.stringify(config.padding)));
	    }
	    _this10.depthMultiplier = config.depthMultiplier == null ? 1 : config.depthMultiplier;
	    _this10.depthwiseInitializer = getInitializer(config.depthwiseInitializer || _this10.DEFAULT_DEPTHWISE_INITIALIZER);
	    _this10.depthwiseRegularizer = getRegularizer(config.depthwiseRegularizer);
	    _this10.depthwiseConstraint = getConstraint(config.depthwiseConstraint);
	    _this10.pointwiseInitializer = getInitializer(config.depthwiseInitializer || _this10.DEFAULT_POINTWISE_INITIALIZER);
	    _this10.pointwiseRegularizer = getRegularizer(config.pointwiseRegularizer);
	    _this10.pointwiseConstraint = getConstraint(config.pointwiseConstraint);
	    return _this10;
	  }
	  _createClass(SeparableConv, [{
	    key: "build",
	    value: function build(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      if (inputShape.length < this.rank + 2) {
	        throw new ValueError("Inputs to SeparableConv".concat(this.rank, "D should have rank ") + "".concat(this.rank + 2, ", but received input shape: ") + "".concat(JSON.stringify(inputShape)));
	      }
	      var channelAxis = this.dataFormat === 'channelsFirst' ? 1 : inputShape.length - 1;
	      if (inputShape[channelAxis] == null || inputShape[channelAxis] < 0) {
	        throw new ValueError("The channel dimension of the inputs should be defined, " + "but found ".concat(JSON.stringify(inputShape[channelAxis])));
	      }
	      var inputDim = inputShape[channelAxis];
	      var depthwiseKernelShape = this.kernelSize.concat([inputDim, this.depthMultiplier]);
	      var pointwiseKernelShape = [];
	      for (var i = 0; i < this.rank; ++i) {
	        pointwiseKernelShape.push(1);
	      }
	      pointwiseKernelShape.push(inputDim * this.depthMultiplier, this.filters);
	      var trainable = true;
	      this.depthwiseKernel = this.addWeight('depthwise_kernel', depthwiseKernelShape, 'float32', this.depthwiseInitializer, this.depthwiseRegularizer, trainable, this.depthwiseConstraint);
	      this.pointwiseKernel = this.addWeight('pointwise_kernel', pointwiseKernelShape, 'float32', this.pointwiseInitializer, this.pointwiseRegularizer, trainable, this.pointwiseConstraint);
	      if (this.useBias) {
	        this.bias = this.addWeight('bias', [this.filters], 'float32', this.biasInitializer, this.biasRegularizer, trainable, this.biasConstraint);
	      } else {
	        this.bias = null;
	      }
	      this.inputSpec = [new InputSpec({
	        ndim: this.rank + 2,
	        axes: _defineProperty({}, channelAxis, inputDim)
	      })];
	      this.built = true;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this11 = this;
	      return tidy(function () {
	        inputs = getExactlyOneTensor(inputs);
	        var output;
	        if (_this11.rank === 1) {
	          throw new NotImplementedError('1D separable convolution is not implemented yet.');
	        } else if (_this11.rank === 2) {
	          if (_this11.dataFormat === 'channelsFirst') {
	            inputs = transpose$2(inputs, [0, 2, 3, 1]); // NCHW -> NHWC.
	          }

	          output = separableConv2d$1(inputs, _this11.depthwiseKernel.read(), _this11.pointwiseKernel.read(), _this11.strides, _this11.padding, _this11.dilationRate, 'NHWC');
	        }
	        if (_this11.useBias) {
	          output = biasAdd(output, _this11.bias.read(), _this11.dataFormat);
	        }
	        if (_this11.activation != null) {
	          output = _this11.activation.apply(output);
	        }
	        if (_this11.dataFormat === 'channelsFirst') {
	          output = transpose$2(output, [0, 3, 1, 2]); // NHWC -> NCHW.
	        }

	        return output;
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = _get(_getPrototypeOf(SeparableConv.prototype), "getConfig", this).call(this);
	      delete config['rank'];
	      delete config['kernelInitializer'];
	      delete config['kernelRegularizer'];
	      delete config['kernelConstraint'];
	      config['depthwiseInitializer'] = serializeInitializer(this.depthwiseInitializer);
	      config['pointwiseInitializer'] = serializeInitializer(this.pointwiseInitializer);
	      config['depthwiseRegularizer'] = serializeRegularizer(this.depthwiseRegularizer);
	      config['pointwiseRegularizer'] = serializeRegularizer(this.pointwiseRegularizer);
	      config['depthwiseConstraint'] = serializeConstraint(this.depthwiseConstraint);
	      config['pointwiseConstraint'] = serializeConstraint(this.pointwiseConstraint);
	      return config;
	    }
	  }]);
	  return SeparableConv;
	}(Conv);
	/** @nocollapse */
	SeparableConv.className = 'SeparableConv';
	var SeparableConv2D = /*#__PURE__*/function (_SeparableConv) {
	  _inherits(SeparableConv2D, _SeparableConv);
	  var _super8 = _createSuper(SeparableConv2D);
	  function SeparableConv2D(args) {
	    _classCallCheck(this, SeparableConv2D);
	    return _super8.call(this, 2, args);
	  }
	  return _createClass(SeparableConv2D);
	}(SeparableConv);
	/** @nocollapse */
	SeparableConv2D.className = 'SeparableConv2D';
	registerClass(SeparableConv2D);
	var Conv1D = /*#__PURE__*/function (_Conv4) {
	  _inherits(Conv1D, _Conv4);
	  var _super9 = _createSuper(Conv1D);
	  function Conv1D(args) {
	    var _this12;
	    _classCallCheck(this, Conv1D);
	    _this12 = _super9.call(this, 1, args);
	    Conv1D.verifyArgs(args);
	    _this12.inputSpec = [{
	      ndim: 3
	    }];
	    return _this12;
	  }
	  _createClass(Conv1D, [{
	    key: "getConfig",
	    value: function getConfig() {
	      var config = _get(_getPrototypeOf(Conv1D.prototype), "getConfig", this).call(this);
	      delete config['rank'];
	      delete config['dataFormat'];
	      return config;
	    }
	  }], [{
	    key: "verifyArgs",
	    value: function verifyArgs(args) {
	      // config.kernelSize must be a number or array of numbers.
	      if (typeof args.kernelSize !== 'number' && !checkArrayTypeAndLength(args.kernelSize, 'number', 1, 1)) {
	        throw new ValueError("Conv1D expects config.kernelSize to be number or number[] with " + "length 1, but received ".concat(JSON.stringify(args.kernelSize), "."));
	      }
	    }
	  }]);
	  return Conv1D;
	}(Conv);
	/** @nocollapse */
	Conv1D.className = 'Conv1D';
	registerClass(Conv1D);
	var Cropping2D = /*#__PURE__*/function (_Layer2) {
	  _inherits(Cropping2D, _Layer2);
	  var _super10 = _createSuper(Cropping2D);
	  function Cropping2D(args) {
	    var _this13;
	    _classCallCheck(this, Cropping2D);
	    _this13 = _super10.call(this, args);
	    if (typeof args.cropping === 'number') {
	      _this13.cropping = [[args.cropping, args.cropping], [args.cropping, args.cropping]];
	    } else if (typeof args.cropping[0] === 'number') {
	      _this13.cropping = [[args.cropping[0], args.cropping[0]], [args.cropping[1], args.cropping[1]]];
	    } else {
	      _this13.cropping = args.cropping;
	    }
	    _this13.dataFormat = args.dataFormat === undefined ? 'channelsLast' : args.dataFormat;
	    _this13.inputSpec = [{
	      ndim: 4
	    }];
	    return _this13;
	  }
	  _createClass(Cropping2D, [{
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      if (this.dataFormat === 'channelsFirst') {
	        return [inputShape[0], inputShape[1], inputShape[2] - this.cropping[0][0] - this.cropping[0][1], inputShape[3] - this.cropping[1][0] - this.cropping[1][1]];
	      } else {
	        return [inputShape[0], inputShape[1] - this.cropping[0][0] - this.cropping[0][1], inputShape[2] - this.cropping[1][0] - this.cropping[1][1], inputShape[3]];
	      }
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this14 = this;
	      return tidy(function () {
	        inputs = getExactlyOneTensor(inputs);
	        if (_this14.dataFormat === 'channelsLast') {
	          var hSliced = sliceAlongAxis(inputs, _this14.cropping[0][0], inputs.shape[1] - _this14.cropping[0][0] - _this14.cropping[0][1], 2);
	          return sliceAlongAxis(hSliced, _this14.cropping[1][0], inputs.shape[2] - _this14.cropping[1][1] - _this14.cropping[1][0], 3);
	        } else {
	          var _hSliced = sliceAlongAxis(inputs, _this14.cropping[0][0], inputs.shape[2] - _this14.cropping[0][0] - _this14.cropping[0][1], 3);
	          return sliceAlongAxis(_hSliced, _this14.cropping[1][0], inputs.shape[3] - _this14.cropping[1][1] - _this14.cropping[1][0], 4);
	        }
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        cropping: this.cropping,
	        dataFormat: this.dataFormat
	      };
	      var baseConfig = _get(_getPrototypeOf(Cropping2D.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return Cropping2D;
	}(Layer);
	/** @nocollapse */
	Cropping2D.className = 'Cropping2D';
	registerClass(Cropping2D);
	var UpSampling2D = /*#__PURE__*/function (_Layer3) {
	  _inherits(UpSampling2D, _Layer3);
	  var _super11 = _createSuper(UpSampling2D);
	  function UpSampling2D(args) {
	    var _this15;
	    _classCallCheck(this, UpSampling2D);
	    _this15 = _super11.call(this, args);
	    _this15.DEFAULT_SIZE = [2, 2];
	    _this15.inputSpec = [{
	      ndim: 4
	    }];
	    _this15.size = args.size == null ? _this15.DEFAULT_SIZE : args.size;
	    _this15.dataFormat = args.dataFormat == null ? 'channelsLast' : args.dataFormat;
	    checkDataFormat(_this15.dataFormat);
	    _this15.interpolation = args.interpolation == null ? 'nearest' : args.interpolation;
	    checkInterpolationFormat(_this15.interpolation);
	    return _this15;
	  }
	  _createClass(UpSampling2D, [{
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      if (this.dataFormat === 'channelsFirst') {
	        var height = inputShape[2] == null ? null : this.size[0] * inputShape[2];
	        var width = inputShape[3] == null ? null : this.size[1] * inputShape[3];
	        return [inputShape[0], inputShape[1], height, width];
	      } else {
	        var _height = inputShape[1] == null ? null : this.size[0] * inputShape[1];
	        var _width = inputShape[2] == null ? null : this.size[1] * inputShape[2];
	        return [inputShape[0], _height, _width, inputShape[3]];
	      }
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this16 = this;
	      return tidy(function () {
	        var input = getExactlyOneTensor(inputs);
	        var inputShape = input.shape;
	        if (_this16.dataFormat === 'channelsFirst') {
	          input = transpose$2(input, [0, 2, 3, 1]);
	          var height = _this16.size[0] * inputShape[2];
	          var width = _this16.size[1] * inputShape[3];
	          var resized = _this16.interpolation === 'nearest' ? image$1.resizeNearestNeighbor(input, [height, width]) : image$1.resizeBilinear(input, [height, width]);
	          return transpose$2(resized, [0, 3, 1, 2]);
	        } else {
	          var _height2 = _this16.size[0] * inputShape[1];
	          var _width2 = _this16.size[1] * inputShape[2];
	          return _this16.interpolation === 'nearest' ? image$1.resizeNearestNeighbor(input, [_height2, _width2]) : image$1.resizeBilinear(input, [_height2, _width2]);
	        }
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        size: this.size,
	        dataFormat: this.dataFormat,
	        interpolation: this.interpolation
	      };
	      var baseConfig = _get(_getPrototypeOf(UpSampling2D.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return UpSampling2D;
	}(Layer);
	/** @nocollapse */
	UpSampling2D.className = 'UpSampling2D';
	registerClass(UpSampling2D);

	/**
	 * 2D convolution with separable filters.
	 * @param x Input tensor.
	 * @param depthwiseKernel Convolution kernel for depthwise convolution.
	 * @param strides Strides (Array of two integers).
	 * @param padding Padding model.
	 * @param dataFormat Data format.
	 * @param dilationRate Array of two integers, dilation rates for the separable
	 *   convolution.
	 * @returns Output tensor.
	 * @throws ValueError If depthwiseKernel is not a 4D array.
	 */
	function depthwiseConv2d$1(x, depthwiseKernel) {
	  var strides = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [1, 1];
	  var padding = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'valid';
	  var dataFormat = arguments.length > 4 ? arguments[4] : undefined;
	  var dilationRate = arguments.length > 5 ? arguments[5] : undefined;
	  return tidy(function () {
	    if (dataFormat == null) {
	      dataFormat = imageDataFormat();
	    }
	    checkDataFormat(dataFormat);
	    var y = preprocessConv2DInput(x, dataFormat);
	    if (x.rank !== 4) {
	      throw new ValueError("Input for depthwiseConv2d is required to be 4-D, but is instead " + "".concat(x.rank, "-D"));
	    }
	    if (depthwiseKernel.rank !== 4) {
	      throw new ValueError("depthwiseKernel is required to be 4-D, but is instead " + "".concat(depthwiseKernel.rank, "-D"));
	    }
	    y = depthwiseConv2d$3(y, depthwiseKernel, strides, padding === 'same' ? 'same' : 'valid', 'NHWC', dilationRate);
	    if (dataFormat === 'channelsFirst') {
	      y = transpose$2(y, [0, 3, 1, 2]);
	    }
	    return y;
	  });
	}
	var DepthwiseConv2D = /*#__PURE__*/function (_BaseConv) {
	  _inherits(DepthwiseConv2D, _BaseConv);
	  var _super = _createSuper(DepthwiseConv2D);
	  function DepthwiseConv2D(args) {
	    var _this;
	    _classCallCheck(this, DepthwiseConv2D);
	    _this = _super.call(this, 2, args);
	    _this.depthwiseKernel = null;
	    _this.depthMultiplier = args.depthMultiplier == null ? 1 : args.depthMultiplier;
	    _this.depthwiseInitializer = getInitializer(args.depthwiseInitializer || _this.DEFAULT_KERNEL_INITIALIZER);
	    _this.depthwiseConstraint = getConstraint(args.depthwiseConstraint);
	    _this.depthwiseRegularizer = getRegularizer(args.depthwiseRegularizer);
	    return _this;
	  }
	  _createClass(DepthwiseConv2D, [{
	    key: "build",
	    value: function build(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      if (inputShape.length < 4) {
	        throw new ValueError("Inputs to DepthwiseConv2D should have rank 4. " + "Received input shape: ".concat(JSON.stringify(inputShape), "."));
	      }
	      var channelAxis = this.dataFormat === 'channelsFirst' ? 1 : 3;
	      if (inputShape[channelAxis] == null || inputShape[channelAxis] < 0) {
	        throw new ValueError('The channel dimension of the inputs to DepthwiseConv2D should ' + "be defined, but is not (".concat(inputShape[channelAxis], ")."));
	      }
	      var inputDim = inputShape[channelAxis];
	      var depthwiseKernelShape = [this.kernelSize[0], this.kernelSize[1], inputDim, this.depthMultiplier];
	      this.depthwiseKernel = this.addWeight('depthwise_kernel', depthwiseKernelShape, null, this.depthwiseInitializer, this.depthwiseRegularizer, true, this.depthwiseConstraint);
	      if (this.useBias) {
	        this.bias = this.addWeight('bias', [inputDim * this.depthMultiplier], null, this.biasInitializer, this.biasRegularizer, true, this.biasConstraint);
	      } else {
	        this.bias = null;
	      }
	      this.built = true;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this2 = this;
	      return tidy(function () {
	        inputs = getExactlyOneTensor(inputs);
	        var outputs = depthwiseConv2d$1(inputs, _this2.depthwiseKernel.read(), _this2.strides, _this2.padding, _this2.dataFormat, null);
	        // TODO(cais): Add support for dilation.
	        if (_this2.useBias) {
	          outputs = biasAdd(outputs, _this2.bias.read(), _this2.dataFormat);
	        }
	        if (_this2.activation != null) {
	          outputs = _this2.activation.apply(outputs);
	        }
	        return outputs;
	      });
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var rows = this.dataFormat === 'channelsFirst' ? inputShape[2] : inputShape[1];
	      var cols = this.dataFormat === 'channelsFirst' ? inputShape[3] : inputShape[2];
	      var outFilters = this.dataFormat === 'channelsFirst' ? inputShape[1] * this.depthMultiplier : inputShape[3] * this.depthMultiplier;
	      var outRows = convOutputLength(rows, this.kernelSize[0], this.padding, this.strides[0]);
	      var outCols = convOutputLength(cols, this.kernelSize[1], this.padding, this.strides[1]);
	      if (this.dataFormat === 'channelsFirst') {
	        return [inputShape[0], outFilters, outRows, outCols];
	      } else {
	        // In this case, assume 'channelsLast'.
	        return [inputShape[0], outRows, outCols, outFilters];
	      }
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = _get(_getPrototypeOf(DepthwiseConv2D.prototype), "getConfig", this).call(this);
	      config['depthMultiplier'] = this.depthMultiplier;
	      config['depthwiseInitializer'] = serializeInitializer(this.depthwiseInitializer);
	      config['depthwiseRegularizer'] = serializeRegularizer(this.depthwiseRegularizer);
	      config['depthwiseConstraint'] = serializeConstraint(this.depthwiseRegularizer);
	      return config;
	    }
	  }]);
	  return DepthwiseConv2D;
	}(BaseConv);
	/** @nocollapse */
	DepthwiseConv2D.className = 'DepthwiseConv2D';
	registerClass(DepthwiseConv2D);

	/**
	 * Standardize `apply()` args to a single list of tensor inputs.
	 *
	 * When running a model loaded from file, the input tensors `initialState` and
	 * `constants` are passed to `RNN.apply()` as part of `inputs` instead of the
	 * dedicated kwargs fields. `inputs` consists of
	 * `[inputs, initialState0, initialState1, ..., constant0, constant1]` in this
	 * case.
	 * This method makes sure that arguments are
	 * separated and that `initialState` and `constants` are `Array`s of tensors
	 * (or None).
	 *
	 * @param inputs Tensor or `Array` of  tensors.
	 * @param initialState Tensor or `Array` of tensors or `null`/`undefined`.
	 * @param constants Tensor or `Array` of tensors or `null`/`undefined`.
	 * @returns An object consisting of
	 *   inputs: A tensor.
	 *   initialState: `Array` of tensors or `null`.
	 *   constants: `Array` of tensors or `null`.
	 * @throws ValueError, if `inputs` is an `Array` but either `initialState` or
	 *   `constants` is provided.
	 */
	function standardizeArgs(inputs, initialState, constants, numConstants) {
	  if (Array.isArray(inputs)) {
	    if (initialState != null || constants != null) {
	      throw new ValueError('When inputs is an array, neither initialState or constants ' + 'should be provided');
	    }
	    if (numConstants != null) {
	      constants = inputs.slice(inputs.length - numConstants, inputs.length);
	      inputs = inputs.slice(0, inputs.length - numConstants);
	    }
	    if (inputs.length > 1) {
	      initialState = inputs.slice(1, inputs.length);
	    }
	    inputs = inputs[0];
	  }
	  function toListOrNull(x) {
	    if (x == null || Array.isArray(x)) {
	      return x;
	    } else {
	      return [x];
	    }
	  }
	  initialState = toListOrNull(initialState);
	  constants = toListOrNull(constants);
	  return {
	    inputs: inputs,
	    initialState: initialState,
	    constants: constants
	  };
	}
	/**
	 * Iterates over the time dimension of a tensor.
	 *
	 * @param stepFunction RNN step function.
	 *   Parameters:
	 *     inputs: tensor with shape `[samples, ...]` (no time dimension),
	 *       representing input for the batch of samples at a certain time step.
	 *     states: an Array of tensors.
	 *   Returns:
	 *     outputs: tensor with shape `[samples, outputDim]` (no time dimension).
	 *     newStates: list of tensors, same length and shapes as `states`. The first
	 *       state in the list must be the output tensor at the previous timestep.
	 * @param inputs Tensor of temporal data of shape `[samples, time, ...]` (at
	 *   least 3D).
	 * @param initialStates Tensor with shape `[samples, outputDim]` (no time
	 *   dimension), containing the initial values of the states used in the step
	 *   function.
	 * @param goBackwards If `true`, do the iteration over the time dimension in
	 *   reverse order and return the reversed sequence.
	 * @param mask Binary tensor with shape `[sample, time, 1]`, with a zero for
	 *   every element that is masked.
	 * @param constants An Array of constant values passed at each step.
	 * @param unroll Whether to unroll the RNN or to use a symbolic loop. *Not*
	 *   applicable to this imperative deeplearn.js backend. Its value is ignored.
	 * @param needPerStepOutputs Whether the per-step outputs are to be
	 *   concatenated into a single tensor and returned (as the second return
	 *   value). Default: `false`. This arg is included so that the relatively
	 *   expensive concatenation of the stepwise outputs can be omitted unless
	 *   the stepwise outputs need to be kept (e.g., for an LSTM layer of which
	 *   `returnSequence` is `true`.)
	 * @returns An Array: `[lastOutput, outputs, newStates]`.
	 *   lastOutput: the lastest output of the RNN, of shape `[samples, ...]`.
	 *   outputs: tensor with shape `[samples, time, ...]` where each entry
	 *     `output[s, t]` is the output of the step function at time `t` for sample
	 *     `s`. This return value is provided if and only if the
	 *     `needPerStepOutputs` is set as `true`. If it is set as `false`, this
	 *     return value will be `undefined`.
	 *   newStates: Array of tensors, latest states returned by the step function,
	 *      of shape `(samples, ...)`.
	 * @throws ValueError If input dimension is less than 3.
	 *
	 * TODO(nielsene): This needs to be tidy-ed.
	 */
	function rnn$1(stepFunction, inputs, initialStates) {
	  var goBackwards = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var mask = arguments.length > 4 ? arguments[4] : undefined;
	  var constants = arguments.length > 5 ? arguments[5] : undefined;
	  var unroll = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : false;
	  var needPerStepOutputs = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : false;
	  return tidy(function () {
	    var ndim = inputs.shape.length;
	    if (ndim < 3) {
	      throw new ValueError("Input should be at least 3D, but is ".concat(ndim, "D."));
	    }
	    // Transpose to time-major, i.e., from [batch, time, ...] to [time, batch,
	    // ...].
	    var axes = [1, 0].concat(range$2(2, ndim));
	    inputs = transpose$2(inputs, axes);
	    if (constants != null) {
	      throw new NotImplementedError('The rnn() functoin of the deeplearn.js backend does not support ' + 'constants yet.');
	    }
	    // Porting Note: the unroll option is ignored by the imperative backend.
	    if (unroll) {
	      console.warn('Backend rnn(): the unroll = true option is not applicable to the ' + 'imperative deeplearn.js backend.');
	    }
	    if (mask != null) {
	      mask = cast$3(cast$3(mask, 'bool'), 'float32');
	      if (mask.rank === ndim - 1) {
	        mask = expandDims$3(mask, -1);
	      }
	      mask = transpose$2(mask, axes);
	    }
	    if (goBackwards) {
	      inputs = reverse$2(inputs, 0);
	      if (mask != null) {
	        mask = reverse$2(mask, 0);
	      }
	    }
	    // Porting Note: PyKeras with TensorFlow backend uses a symbolic loop
	    //   (tf.while_loop). But for the imperative deeplearn.js backend, we just
	    //   use the usual TypeScript control flow to iterate over the time steps in
	    //   the inputs.
	    // Porting Note: PyKeras patches a "_use_learning_phase" attribute to
	    // outputs.
	    //   This is not idiomatic in TypeScript. The info regarding whether we are
	    //   in a learning (i.e., training) phase for RNN is passed in a different
	    //   way.
	    var perStepOutputs = [];
	    var lastOutput;
	    var states = initialStates;
	    var timeSteps = inputs.shape[0];
	    var perStepInputs = unstack(inputs);
	    var perStepMasks;
	    if (mask != null) {
	      perStepMasks = unstack(mask);
	    }
	    var _loop = function _loop(t) {
	      var currentInput = perStepInputs[t];
	      var stepOutputs = tidy(function () {
	        return stepFunction(currentInput, states);
	      });
	      if (mask == null) {
	        lastOutput = stepOutputs[0];
	        states = stepOutputs[1];
	      } else {
	        var maskedOutputs = tidy(function () {
	          var stepMask = perStepMasks[t];
	          var negStepMask = sub$2(onesLike$3(stepMask), stepMask);
	          // TODO(cais): Would tfc.where() be better for performance?
	          var output = add$3(mul(stepOutputs[0], stepMask), mul(states[0], negStepMask));
	          var newStates = states.map(function (state, i) {
	            return add$3(mul(stepOutputs[1][i], stepMask), mul(state, negStepMask));
	          });
	          return {
	            output: output,
	            newStates: newStates
	          };
	        });
	        lastOutput = maskedOutputs.output;
	        states = maskedOutputs.newStates;
	      }
	      if (needPerStepOutputs) {
	        perStepOutputs.push(lastOutput);
	      }
	    };
	    for (var t = 0; t < timeSteps; ++t) {
	      _loop(t);
	    }
	    var outputs;
	    if (needPerStepOutputs) {
	      var axis = 1;
	      outputs = stack(perStepOutputs, axis);
	    }
	    return [lastOutput, outputs, states];
	  });
	}
	var RNN = /*#__PURE__*/function (_Layer) {
	  _inherits(RNN, _Layer);
	  var _super = _createSuper(RNN);
	  function RNN(args) {
	    var _this;
	    _classCallCheck(this, RNN);
	    _this = _super.call(this, args);
	    var cell;
	    if (args.cell == null) {
	      throw new ValueError('cell property is missing for the constructor of RNN.');
	    } else if (Array.isArray(args.cell)) {
	      cell = new StackedRNNCells({
	        cells: args.cell
	      });
	    } else {
	      cell = args.cell;
	    }
	    if (cell.stateSize == null) {
	      throw new ValueError('The RNN cell should have an attribute `stateSize` (tuple of ' + 'integers, one integer per RNN state).');
	    }
	    _this.cell = cell;
	    _this.returnSequences = args.returnSequences == null ? false : args.returnSequences;
	    _this.returnState = args.returnState == null ? false : args.returnState;
	    _this.goBackwards = args.goBackwards == null ? false : args.goBackwards;
	    _this._stateful = args.stateful == null ? false : args.stateful;
	    _this.unroll = args.unroll == null ? false : args.unroll;
	    _this.supportsMasking = true;
	    _this.inputSpec = [new InputSpec({
	      ndim: 3
	    })];
	    _this.stateSpec = null;
	    _this.states_ = null;
	    // TODO(cais): Add constantsSpec and numConstants.
	    _this.numConstants = null;
	    // TODO(cais): Look into the use of initial_state in the kwargs of the
	    //   constructor.
	    _this.keptStates = [];
	    return _this;
	  }
	  // Porting Note: This is the equivalent of `RNN.states` property getter in
	  //   PyKeras.
	  _createClass(RNN, [{
	    key: "getStates",
	    value: function getStates() {
	      if (this.states_ == null) {
	        var numStates = Array.isArray(this.cell.stateSize) ? this.cell.stateSize.length : 1;
	        return range$2(0, numStates).map(function (x) {
	          return null;
	        });
	      } else {
	        return this.states_;
	      }
	    }
	    // Porting Note: This is the equivalent of the `RNN.states` property setter in
	    //   PyKeras.
	  }, {
	    key: "setStates",
	    value: function setStates(states) {
	      this.states_ = states;
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      if (isArrayOfShapes(inputShape)) {
	        inputShape = inputShape[0];
	      }
	      inputShape = inputShape;
	      // TODO(cais): Remove the casting once stacked RNN cells become supported.
	      var stateSize = this.cell.stateSize;
	      if (!Array.isArray(stateSize)) {
	        stateSize = [stateSize];
	      }
	      var outputDim = stateSize[0];
	      var outputShape;
	      if (this.returnSequences) {
	        outputShape = [inputShape[0], inputShape[1], outputDim];
	      } else {
	        outputShape = [inputShape[0], outputDim];
	      }
	      if (this.returnState) {
	        var stateShape = [];
	        var _iterator = _createForOfIteratorHelper(stateSize),
	          _step;
	        try {
	          for (_iterator.s(); !(_step = _iterator.n()).done;) {
	            var dim = _step.value;
	            stateShape.push([inputShape[0], dim]);
	          }
	        } catch (err) {
	          _iterator.e(err);
	        } finally {
	          _iterator.f();
	        }
	        return [outputShape].concat(stateShape);
	      } else {
	        return outputShape;
	      }
	    }
	  }, {
	    key: "computeMask",
	    value: function computeMask(inputs, mask) {
	      var _this2 = this;
	      return tidy(function () {
	        if (Array.isArray(mask)) {
	          mask = mask[0];
	        }
	        var outputMask = _this2.returnSequences ? mask : null;
	        if (_this2.returnState) {
	          var stateMask = _this2.states.map(function (s) {
	            return null;
	          });
	          return [outputMask].concat(stateMask);
	        } else {
	          return outputMask;
	        }
	      });
	    }
	    /**
	     * Get the current state tensors of the RNN.
	     *
	     * If the state hasn't been set, return an array of `null`s of the correct
	     * length.
	     */
	  }, {
	    key: "states",
	    get: function get() {
	      if (this.states_ == null) {
	        var numStates = Array.isArray(this.cell.stateSize) ? this.cell.stateSize.length : 1;
	        var output = [];
	        for (var i = 0; i < numStates; ++i) {
	          output.push(null);
	        }
	        return output;
	      } else {
	        return this.states_;
	      }
	    },
	    set: function set(s) {
	      this.states_ = s;
	    }
	  }, {
	    key: "build",
	    value: function build(inputShape) {
	      // Note inputShape will be an Array of Shapes of initial states and
	      // constants if these are passed in apply().
	      var constantShape = null;
	      if (this.numConstants != null) {
	        throw new NotImplementedError('Constants support is not implemented in RNN yet.');
	      }
	      if (isArrayOfShapes(inputShape)) {
	        inputShape = inputShape[0];
	      }
	      inputShape = inputShape;
	      var batchSize = this.stateful ? inputShape[0] : null;
	      var inputDim = inputShape.slice(2);
	      this.inputSpec[0] = new InputSpec({
	        shape: [batchSize, null].concat(_toConsumableArray(inputDim))
	      });
	      // Allow cell (if RNNCell Layer) to build before we set or validate
	      // stateSpec.
	      var stepInputShape = [inputShape[0]].concat(inputShape.slice(2));
	      if (constantShape != null) {
	        throw new NotImplementedError('Constants support is not implemented in RNN yet.');
	      } else {
	        this.cell.build(stepInputShape);
	      }
	      // Set or validate stateSpec.
	      var stateSize;
	      if (Array.isArray(this.cell.stateSize)) {
	        stateSize = this.cell.stateSize;
	      } else {
	        stateSize = [this.cell.stateSize];
	      }
	      if (this.stateSpec != null) {
	        if (!arraysEqual(this.stateSpec.map(function (spec) {
	          return spec.shape[spec.shape.length - 1];
	        }), stateSize)) {
	          throw new ValueError("An initialState was passed that is not compatible with " + "cell.stateSize. Received stateSpec=".concat(this.stateSpec, "; ") + "However cell.stateSize is ".concat(this.cell.stateSize));
	        }
	      } else {
	        this.stateSpec = stateSize.map(function (dim) {
	          return new InputSpec({
	            shape: [null, dim]
	          });
	        });
	      }
	      if (this.stateful) {
	        this.resetStates();
	      }
	    }
	    /**
	     * Reset the state tensors of the RNN.
	     *
	     * If the `states` argument is `undefined` or `null`, will set the
	     * state tensor(s) of the RNN to all-zero tensors of the appropriate
	     * shape(s).
	     *
	     * If `states` is provided, will set the state tensors of the RNN to its
	     * value.
	     *
	     * @param states Optional externally-provided initial states.
	     * @param training Whether this call is done during training. For stateful
	     *   RNNs, this affects whether the old states are kept or discarded. In
	     *   particular, if `training` is `true`, the old states will be kept so
	     *   that subsequent backpropgataion through time (BPTT) may work properly.
	     *   Else, the old states will be discarded.
	     */
	  }, {
	    key: "resetStates",
	    value: function resetStates(states) {
	      var _this3 = this;
	      var training = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
	      tidy(function () {
	        if (!_this3.stateful) {
	          throw new AttributeError('Cannot call resetStates() on an RNN Layer that is not stateful.');
	        }
	        var batchSize = _this3.inputSpec[0].shape[0];
	        if (batchSize == null) {
	          throw new ValueError('If an RNN is stateful, it needs to know its batch size. Specify ' + 'the batch size of your input tensors: \n' + '- If using a Sequential model, specify the batch size by ' + 'passing a `batchInputShape` option to your first layer.\n' + '- If using the functional API, specify the batch size by ' + 'passing a `batchShape` option to your Input layer.');
	        }
	        // Initialize state if null.
	        if (_this3.states_ == null) {
	          if (Array.isArray(_this3.cell.stateSize)) {
	            _this3.states_ = _this3.cell.stateSize.map(function (dim) {
	              return zeros$2([batchSize, dim]);
	            });
	          } else {
	            _this3.states_ = [zeros$2([batchSize, _this3.cell.stateSize])];
	          }
	        } else if (states == null) {
	          // Dispose old state tensors.
	          dispose(_this3.states_);
	          // For stateful RNNs, fully dispose kept old states.
	          if (_this3.keptStates != null) {
	            dispose(_this3.keptStates);
	            _this3.keptStates = [];
	          }
	          if (Array.isArray(_this3.cell.stateSize)) {
	            _this3.states_ = _this3.cell.stateSize.map(function (dim) {
	              return zeros$2([batchSize, dim]);
	            });
	          } else {
	            _this3.states_[0] = zeros$2([batchSize, _this3.cell.stateSize]);
	          }
	        } else {
	          if (!Array.isArray(states)) {
	            states = [states];
	          }
	          if (states.length !== _this3.states_.length) {
	            throw new ValueError("Layer ".concat(_this3.name, " expects ").concat(_this3.states_.length, " state(s), ") + "but it received ".concat(states.length, " state value(s). Input ") + "received: ".concat(states));
	          }
	          if (training === true) {
	            // Store old state tensors for complete disposal later, i.e., during
	            // the next no-arg call to this method. We do not dispose the old
	            // states immediately because that BPTT (among other things) require
	            // them.
	            _this3.keptStates.push(_this3.states_.slice());
	          } else {
	            dispose(_this3.states_);
	          }
	          for (var index = 0; index < _this3.states_.length; ++index) {
	            var value = states[index];
	            var dim = Array.isArray(_this3.cell.stateSize) ? _this3.cell.stateSize[index] : _this3.cell.stateSize;
	            var expectedShape = [batchSize, dim];
	            if (!arraysEqual(value.shape, expectedShape)) {
	              throw new ValueError("State ".concat(index, " is incompatible with layer ").concat(_this3.name, ": ") + "expected shape=".concat(expectedShape, ", received shape=").concat(value.shape));
	            }
	            _this3.states_[index] = value;
	          }
	        }
	        _this3.states_ = _this3.states_.map(function (state) {
	          return keep(state.clone());
	        });
	      });
	    }
	  }, {
	    key: "apply",
	    value: function apply(inputs, kwargs) {
	      // TODO(cais): Figure out whether initialState is in kwargs or inputs.
	      var initialState = kwargs == null ? null : kwargs['initialState'];
	      var constants = kwargs == null ? null : kwargs['constants'];
	      if (kwargs == null) {
	        kwargs = {};
	      }
	      var standardized = standardizeArgs(inputs, initialState, constants, this.numConstants);
	      inputs = standardized.inputs;
	      initialState = standardized.initialState;
	      constants = standardized.constants;
	      // If any of `initial_state` or `constants` are specified and are
	      // `tf.SymbolicTensor`s, then add them to the inputs and temporarily modify
	      // the input_spec to include them.
	      var additionalInputs = [];
	      var additionalSpecs = [];
	      if (initialState != null) {
	        kwargs['initialState'] = initialState;
	        additionalInputs = additionalInputs.concat(initialState);
	        this.stateSpec = [];
	        var _iterator2 = _createForOfIteratorHelper(initialState),
	          _step2;
	        try {
	          for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	            var state = _step2.value;
	            this.stateSpec.push(new InputSpec({
	              shape: state.shape
	            }));
	          }
	          // TODO(cais): Use the following instead.
	          // this.stateSpec = initialState.map(state => new InputSpec({shape:
	          // state.shape}));
	        } catch (err) {
	          _iterator2.e(err);
	        } finally {
	          _iterator2.f();
	        }
	        additionalSpecs = additionalSpecs.concat(this.stateSpec);
	      }
	      if (constants != null) {
	        kwargs['constants'] = constants;
	        additionalInputs = additionalInputs.concat(constants);
	        // TODO(cais): Add this.constantsSpec.
	        this.numConstants = constants.length;
	      }
	      var isTensor = additionalInputs[0] instanceof SymbolicTensor;
	      if (isTensor) {
	        // Compute full input spec, including state and constants.
	        var fullInput = [inputs].concat(additionalInputs);
	        var fullInputSpec = this.inputSpec.concat(additionalSpecs);
	        // Perform the call with temporarily replaced inputSpec.
	        var originalInputSpec = this.inputSpec;
	        this.inputSpec = fullInputSpec;
	        var output = _get(_getPrototypeOf(RNN.prototype), "apply", this).call(this, fullInput, kwargs);
	        this.inputSpec = originalInputSpec;
	        return output;
	      } else {
	        return _get(_getPrototypeOf(RNN.prototype), "apply", this).call(this, inputs, kwargs);
	      }
	    }
	    // tslint:disable-next-line:no-any
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this4 = this;
	      // Input shape: `[samples, time (padded with zeros), input_dim]`.
	      // Note that the .build() method of subclasses **must** define
	      // this.inputSpec and this.stateSpec owith complete input shapes.
	      return tidy(function () {
	        var mask = kwargs == null ? null : kwargs['mask'];
	        var training = kwargs == null ? null : kwargs['training'];
	        var initialState = kwargs == null ? null : kwargs['initialState'];
	        inputs = getExactlyOneTensor(inputs);
	        if (initialState == null) {
	          if (_this4.stateful) {
	            initialState = _this4.states_;
	          } else {
	            initialState = _this4.getInitialState(inputs);
	          }
	        }
	        var numStates = Array.isArray(_this4.cell.stateSize) ? _this4.cell.stateSize.length : 1;
	        if (initialState.length !== numStates) {
	          throw new ValueError("RNN Layer has ".concat(numStates, " state(s) but was passed ") + "".concat(initialState.length, " initial state(s)."));
	        }
	        if (_this4.unroll) {
	          console.warn('Ignoring unroll = true for RNN layer, due to imperative backend.');
	        }
	        var cellCallKwargs = {
	          training: training
	        };
	        // TODO(cais): Add support for constants.
	        var step = function step(inputs, states) {
	          // `inputs` and `states` are concatenated to form a single `Array` of
	          // `tf.Tensor`s as the input to `cell.call()`.
	          var outputs = _this4.cell.call([inputs].concat(states), cellCallKwargs);
	          // Marshall the return value into output and new states.
	          return [outputs[0], outputs.slice(1)];
	        };
	        // TODO(cais): Add support for constants.
	        var rnnOutputs = rnn$1(step, inputs, initialState, _this4.goBackwards, mask, null, _this4.unroll, _this4.returnSequences);
	        var lastOutput = rnnOutputs[0];
	        var outputs = rnnOutputs[1];
	        var states = rnnOutputs[2];
	        if (_this4.stateful) {
	          _this4.resetStates(states, training);
	        }
	        var output = _this4.returnSequences ? outputs : lastOutput;
	        // TODO(cais): Property set learning phase flag.
	        if (_this4.returnState) {
	          return [output].concat(states);
	        } else {
	          return output;
	        }
	      });
	    }
	  }, {
	    key: "getInitialState",
	    value: function getInitialState(inputs) {
	      var _this5 = this;
	      return tidy(function () {
	        // Build an all-zero tensor of shape [samples, outputDim].
	        // [Samples, timeSteps, inputDim].
	        var initialState = zeros$2(inputs.shape);
	        // [Samples].
	        initialState = sum$3(initialState, [1, 2]);
	        initialState = expandDims$2(initialState); // [Samples, 1].
	        if (Array.isArray(_this5.cell.stateSize)) {
	          return _this5.cell.stateSize.map(function (dim) {
	            return dim > 1 ? tile$2(initialState, [1, dim]) : initialState;
	          });
	        } else {
	          return _this5.cell.stateSize > 1 ? [tile$2(initialState, [1, _this5.cell.stateSize])] : [initialState];
	        }
	      });
	    }
	  }, {
	    key: "trainableWeights",
	    get: function get() {
	      if (!this.trainable) {
	        return [];
	      }
	      // Porting Note: In TypeScript, `this` is always an instance of `Layer`.
	      return this.cell.trainableWeights;
	    }
	  }, {
	    key: "nonTrainableWeights",
	    get: function get() {
	      // Porting Note: In TypeScript, `this` is always an instance of `Layer`.
	      if (!this.trainable) {
	        return this.cell.weights;
	      }
	      return this.cell.nonTrainableWeights;
	    }
	  }, {
	    key: "setFastWeightInitDuringBuild",
	    value: function setFastWeightInitDuringBuild(value) {
	      _get(_getPrototypeOf(RNN.prototype), "setFastWeightInitDuringBuild", this).call(this, value);
	      if (this.cell != null) {
	        this.cell.setFastWeightInitDuringBuild(value);
	      }
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var baseConfig = _get(_getPrototypeOf(RNN.prototype), "getConfig", this).call(this);
	      var config = {
	        returnSequences: this.returnSequences,
	        returnState: this.returnState,
	        goBackwards: this.goBackwards,
	        stateful: this.stateful,
	        unroll: this.unroll
	      };
	      if (this.numConstants != null) {
	        config['numConstants'] = this.numConstants;
	      }
	      var cellConfig = this.cell.getConfig();
	      if (this.getClassName() === RNN.className) {
	        config['cell'] = {
	          'className': this.cell.getClassName(),
	          'config': cellConfig
	        };
	      }
	      // this order is necessary, to prevent cell name from replacing layer name
	      return Object.assign(Object.assign(Object.assign({}, cellConfig), baseConfig), config);
	    }
	    /** @nocollapse */
	  }], [{
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      var customObjects = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
	      var cellConfig = config['cell'];
	      var cell = deserialize(cellConfig, customObjects);
	      return new cls(Object.assign(config, {
	        cell: cell
	      }));
	    }
	  }]);
	  return RNN;
	}(Layer);
	/** @nocollapse */
	RNN.className = 'RNN';
	registerClass(RNN);
	// Porting Note: This is a common parent class for RNN cells. There is no
	// equivalent of this in PyKeras. Having a common parent class forgoes the
	//  need for `has_attr(cell, ...)` checks or its TypeScript equivalent.
	/**
	 * An RNNCell layer.
	 *
	 * @doc {heading: 'Layers', subheading: 'Classes'}
	 */
	var RNNCell = /*#__PURE__*/function (_Layer2) {
	  _inherits(RNNCell, _Layer2);
	  var _super2 = _createSuper(RNNCell);
	  function RNNCell() {
	    _classCallCheck(this, RNNCell);
	    return _super2.apply(this, arguments);
	  }
	  return _createClass(RNNCell);
	}(Layer);
	var SimpleRNNCell = /*#__PURE__*/function (_RNNCell) {
	  _inherits(SimpleRNNCell, _RNNCell);
	  var _super3 = _createSuper(SimpleRNNCell);
	  function SimpleRNNCell(args) {
	    var _this6;
	    _classCallCheck(this, SimpleRNNCell);
	    _this6 = _super3.call(this, args);
	    _this6.DEFAULT_ACTIVATION = 'tanh';
	    _this6.DEFAULT_KERNEL_INITIALIZER = 'glorotNormal';
	    _this6.DEFAULT_RECURRENT_INITIALIZER = 'orthogonal';
	    _this6.DEFAULT_BIAS_INITIALIZER = 'zeros';
	    _this6.units = args.units;
	    assertPositiveInteger(_this6.units, "units");
	    _this6.activation = getActivation(args.activation == null ? _this6.DEFAULT_ACTIVATION : args.activation);
	    _this6.useBias = args.useBias == null ? true : args.useBias;
	    _this6.kernelInitializer = getInitializer(args.kernelInitializer || _this6.DEFAULT_KERNEL_INITIALIZER);
	    _this6.recurrentInitializer = getInitializer(args.recurrentInitializer || _this6.DEFAULT_RECURRENT_INITIALIZER);
	    _this6.biasInitializer = getInitializer(args.biasInitializer || _this6.DEFAULT_BIAS_INITIALIZER);
	    _this6.kernelRegularizer = getRegularizer(args.kernelRegularizer);
	    _this6.recurrentRegularizer = getRegularizer(args.recurrentRegularizer);
	    _this6.biasRegularizer = getRegularizer(args.biasRegularizer);
	    _this6.kernelConstraint = getConstraint(args.kernelConstraint);
	    _this6.recurrentConstraint = getConstraint(args.recurrentConstraint);
	    _this6.biasConstraint = getConstraint(args.biasConstraint);
	    _this6.dropout = min$2([1, max$2([0, args.dropout == null ? 0 : args.dropout])]);
	    _this6.recurrentDropout = min$2([1, max$2([0, args.recurrentDropout == null ? 0 : args.recurrentDropout])]);
	    _this6.dropoutFunc = args.dropoutFunc;
	    _this6.stateSize = _this6.units;
	    _this6.dropoutMask = null;
	    _this6.recurrentDropoutMask = null;
	    return _this6;
	  }
	  _createClass(SimpleRNNCell, [{
	    key: "build",
	    value: function build(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      // TODO(cais): Use regularizer.
	      this.kernel = this.addWeight('kernel', [inputShape[inputShape.length - 1], this.units], null, this.kernelInitializer, this.kernelRegularizer, true, this.kernelConstraint);
	      this.recurrentKernel = this.addWeight('recurrent_kernel', [this.units, this.units], null, this.recurrentInitializer, this.recurrentRegularizer, true, this.recurrentConstraint);
	      if (this.useBias) {
	        this.bias = this.addWeight('bias', [this.units], null, this.biasInitializer, this.biasRegularizer, true, this.biasConstraint);
	      } else {
	        this.bias = null;
	      }
	      this.built = true;
	    }
	    // Porting Note: PyKeras' equivalent of this method takes two tensor inputs:
	    //   `inputs` and `states`. Here, the two tensors are combined into an
	    //   `Tensor[]` Array as the first input argument.
	    //   Similarly, PyKeras' equivalent of this method returns two values:
	    //    `output` and `[output]`. Here the two are combined into one length-2
	    //    `Tensor[]`, consisting of `output` repeated.
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this7 = this;
	      return tidy(function () {
	        inputs = inputs;
	        if (inputs.length !== 2) {
	          throw new ValueError("SimpleRNNCell expects 2 input Tensors, got ".concat(inputs.length, "."));
	        }
	        var prevOutput = inputs[1];
	        inputs = inputs[0];
	        var training = kwargs['training'] == null ? false : kwargs['training'];
	        if (0 < _this7.dropout && _this7.dropout < 1 && _this7.dropoutMask == null) {
	          _this7.dropoutMask = generateDropoutMask({
	            ones: function ones() {
	              return onesLike$3(inputs);
	            },
	            rate: _this7.dropout,
	            training: training,
	            dropoutFunc: _this7.dropoutFunc
	          });
	        }
	        if (0 < _this7.recurrentDropout && _this7.recurrentDropout < 1 && _this7.recurrentDropoutMask == null) {
	          _this7.recurrentDropoutMask = generateDropoutMask({
	            ones: function ones() {
	              return onesLike$3(prevOutput);
	            },
	            rate: _this7.recurrentDropout,
	            training: training,
	            dropoutFunc: _this7.dropoutFunc
	          });
	        }
	        var h;
	        var dpMask = _this7.dropoutMask;
	        var recDpMask = _this7.recurrentDropoutMask;
	        if (dpMask != null) {
	          h = dot$1(mul(inputs, dpMask), _this7.kernel.read());
	        } else {
	          h = dot$1(inputs, _this7.kernel.read());
	        }
	        if (_this7.bias != null) {
	          h = biasAdd(h, _this7.bias.read());
	        }
	        if (recDpMask != null) {
	          prevOutput = mul(prevOutput, recDpMask);
	        }
	        var output = add$3(h, dot$1(prevOutput, _this7.recurrentKernel.read()));
	        if (_this7.activation != null) {
	          output = _this7.activation.apply(output);
	        }
	        // TODO(cais): Properly set learning phase on output tensor?
	        return [output, output];
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var baseConfig = _get(_getPrototypeOf(SimpleRNNCell.prototype), "getConfig", this).call(this);
	      var config = {
	        units: this.units,
	        activation: serializeActivation(this.activation),
	        useBias: this.useBias,
	        kernelInitializer: serializeInitializer(this.kernelInitializer),
	        recurrentInitializer: serializeInitializer(this.recurrentInitializer),
	        biasInitializer: serializeInitializer(this.biasInitializer),
	        kernelRegularizer: serializeRegularizer(this.kernelRegularizer),
	        recurrentRegularizer: serializeRegularizer(this.recurrentRegularizer),
	        biasRegularizer: serializeRegularizer(this.biasRegularizer),
	        activityRegularizer: serializeRegularizer(this.activityRegularizer),
	        kernelConstraint: serializeConstraint(this.kernelConstraint),
	        recurrentConstraint: serializeConstraint(this.recurrentConstraint),
	        biasConstraint: serializeConstraint(this.biasConstraint),
	        dropout: this.dropout,
	        recurrentDropout: this.recurrentDropout
	      };
	      return Object.assign(Object.assign({}, baseConfig), config);
	    }
	  }]);
	  return SimpleRNNCell;
	}(RNNCell);
	/** @nocollapse */
	SimpleRNNCell.className = 'SimpleRNNCell';
	registerClass(SimpleRNNCell);
	var SimpleRNN = /*#__PURE__*/function (_RNN) {
	  _inherits(SimpleRNN, _RNN);
	  var _super4 = _createSuper(SimpleRNN);
	  function SimpleRNN(args) {
	    _classCallCheck(this, SimpleRNN);
	    args.cell = new SimpleRNNCell(args);
	    return _super4.call(this, args); // TODO(cais): Add activityRegularizer.
	  }
	  _createClass(SimpleRNN, [{
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this8 = this;
	      return tidy(function () {
	        if (_this8.cell.dropoutMask != null) {
	          dispose(_this8.cell.dropoutMask);
	          _this8.cell.dropoutMask = null;
	        }
	        if (_this8.cell.recurrentDropoutMask != null) {
	          dispose(_this8.cell.recurrentDropoutMask);
	          _this8.cell.recurrentDropoutMask = null;
	        }
	        var mask = kwargs == null ? null : kwargs['mask'];
	        var training = kwargs == null ? null : kwargs['training'];
	        var initialState = kwargs == null ? null : kwargs['initialState'];
	        return _get(_getPrototypeOf(SimpleRNN.prototype), "call", _this8).call(_this8, inputs, {
	          mask: mask,
	          training: training,
	          initialState: initialState
	        });
	      });
	    }
	    /** @nocollapse */
	  }], [{
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      return new cls(config);
	    }
	  }]);
	  return SimpleRNN;
	}(RNN);
	/** @nocollapse */
	SimpleRNN.className = 'SimpleRNN';
	registerClass(SimpleRNN);
	var GRUCell = /*#__PURE__*/function (_RNNCell2) {
	  _inherits(GRUCell, _RNNCell2);
	  var _super5 = _createSuper(GRUCell);
	  function GRUCell(args) {
	    var _this9;
	    _classCallCheck(this, GRUCell);
	    _this9 = _super5.call(this, args);
	    _this9.DEFAULT_ACTIVATION = 'tanh';
	    _this9.DEFAULT_RECURRENT_ACTIVATION = 'hardSigmoid';
	    _this9.DEFAULT_KERNEL_INITIALIZER = 'glorotNormal';
	    _this9.DEFAULT_RECURRENT_INITIALIZER = 'orthogonal';
	    _this9.DEFAULT_BIAS_INITIALIZER = 'zeros';
	    if (args.resetAfter) {
	      throw new ValueError("GRUCell does not support reset_after parameter set to true.");
	    }
	    _this9.units = args.units;
	    assertPositiveInteger(_this9.units, 'units');
	    _this9.activation = getActivation(args.activation === undefined ? _this9.DEFAULT_ACTIVATION : args.activation);
	    _this9.recurrentActivation = getActivation(args.recurrentActivation === undefined ? _this9.DEFAULT_RECURRENT_ACTIVATION : args.recurrentActivation);
	    _this9.useBias = args.useBias == null ? true : args.useBias;
	    _this9.kernelInitializer = getInitializer(args.kernelInitializer || _this9.DEFAULT_KERNEL_INITIALIZER);
	    _this9.recurrentInitializer = getInitializer(args.recurrentInitializer || _this9.DEFAULT_RECURRENT_INITIALIZER);
	    _this9.biasInitializer = getInitializer(args.biasInitializer || _this9.DEFAULT_BIAS_INITIALIZER);
	    _this9.kernelRegularizer = getRegularizer(args.kernelRegularizer);
	    _this9.recurrentRegularizer = getRegularizer(args.recurrentRegularizer);
	    _this9.biasRegularizer = getRegularizer(args.biasRegularizer);
	    _this9.kernelConstraint = getConstraint(args.kernelConstraint);
	    _this9.recurrentConstraint = getConstraint(args.recurrentConstraint);
	    _this9.biasConstraint = getConstraint(args.biasConstraint);
	    _this9.dropout = min$2([1, max$2([0, args.dropout == null ? 0 : args.dropout])]);
	    _this9.recurrentDropout = min$2([1, max$2([0, args.recurrentDropout == null ? 0 : args.recurrentDropout])]);
	    _this9.dropoutFunc = args.dropoutFunc;
	    _this9.implementation = args.implementation;
	    _this9.stateSize = _this9.units;
	    _this9.dropoutMask = null;
	    _this9.recurrentDropoutMask = null;
	    return _this9;
	  }
	  _createClass(GRUCell, [{
	    key: "build",
	    value: function build(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var inputDim = inputShape[inputShape.length - 1];
	      this.kernel = this.addWeight('kernel', [inputDim, this.units * 3], null, this.kernelInitializer, this.kernelRegularizer, true, this.kernelConstraint);
	      this.recurrentKernel = this.addWeight('recurrent_kernel', [this.units, this.units * 3], null, this.recurrentInitializer, this.recurrentRegularizer, true, this.recurrentConstraint);
	      if (this.useBias) {
	        this.bias = this.addWeight('bias', [this.units * 3], null, this.biasInitializer, this.biasRegularizer, true, this.biasConstraint);
	      } else {
	        this.bias = null;
	      }
	      // Porting Notes: Unlike the PyKeras implementation, we perform slicing
	      //   of the weights and bias in the call() method, at execution time.
	      this.built = true;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this10 = this;
	      return tidy(function () {
	        inputs = inputs;
	        if (inputs.length !== 2) {
	          throw new ValueError("GRUCell expects 2 input Tensors (inputs, h, c), got " + "".concat(inputs.length, "."));
	        }
	        var training = kwargs['training'] == null ? false : kwargs['training'];
	        var hTMinus1 = inputs[1]; // Previous memory state.
	        inputs = inputs[0];
	        // Note: For superior performance, TensorFlow.js always uses
	        // implementation 2, regardless of the actual value of
	        // config.implementation.
	        if (0 < _this10.dropout && _this10.dropout < 1 && _this10.dropoutMask == null) {
	          _this10.dropoutMask = generateDropoutMask({
	            ones: function ones() {
	              return onesLike$3(inputs);
	            },
	            rate: _this10.dropout,
	            training: training,
	            count: 3,
	            dropoutFunc: _this10.dropoutFunc
	          });
	        }
	        if (0 < _this10.recurrentDropout && _this10.recurrentDropout < 1 && _this10.recurrentDropoutMask == null) {
	          _this10.recurrentDropoutMask = generateDropoutMask({
	            ones: function ones() {
	              return onesLike$3(hTMinus1);
	            },
	            rate: _this10.recurrentDropout,
	            training: training,
	            count: 3,
	            dropoutFunc: _this10.dropoutFunc
	          });
	        }
	        var dpMask = _this10.dropoutMask;
	        var recDpMask = _this10.recurrentDropoutMask;
	        var z;
	        var r;
	        var hh;
	        if (0 < _this10.dropout && _this10.dropout < 1) {
	          inputs = mul(inputs, dpMask[0]);
	        }
	        var matrixX = dot$1(inputs, _this10.kernel.read());
	        if (_this10.useBias) {
	          matrixX = biasAdd(matrixX, _this10.bias.read());
	        }
	        if (0 < _this10.recurrentDropout && _this10.recurrentDropout < 1) {
	          hTMinus1 = mul(hTMinus1, recDpMask[0]);
	        }
	        var recurrentKernelValue = _this10.recurrentKernel.read();
	        var _tfc$split = split$3(recurrentKernelValue, [2 * _this10.units, _this10.units], recurrentKernelValue.rank - 1),
	          _tfc$split2 = _slicedToArray(_tfc$split, 2),
	          rk1 = _tfc$split2[0],
	          rk2 = _tfc$split2[1];
	        var matrixInner = dot$1(hTMinus1, rk1);
	        var _tfc$split3 = split$3(matrixX, 3, matrixX.rank - 1),
	          _tfc$split4 = _slicedToArray(_tfc$split3, 3),
	          xZ = _tfc$split4[0],
	          xR = _tfc$split4[1],
	          xH = _tfc$split4[2];
	        var _tfc$split5 = split$3(matrixInner, 2, matrixInner.rank - 1),
	          _tfc$split6 = _slicedToArray(_tfc$split5, 2),
	          recurrentZ = _tfc$split6[0],
	          recurrentR = _tfc$split6[1];
	        z = _this10.recurrentActivation.apply(add$3(xZ, recurrentZ));
	        r = _this10.recurrentActivation.apply(add$3(xR, recurrentR));
	        var recurrentH = dot$1(mul(r, hTMinus1), rk2);
	        hh = _this10.activation.apply(add$3(xH, recurrentH));
	        var h = add$3(mul(z, hTMinus1), mul(add$3(1, neg$2(z)), hh));
	        // TODO(cais): Add use_learning_phase flag properly.
	        return [h, h];
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var baseConfig = _get(_getPrototypeOf(GRUCell.prototype), "getConfig", this).call(this);
	      var config = {
	        units: this.units,
	        activation: serializeActivation(this.activation),
	        recurrentActivation: serializeActivation(this.recurrentActivation),
	        useBias: this.useBias,
	        kernelInitializer: serializeInitializer(this.kernelInitializer),
	        recurrentInitializer: serializeInitializer(this.recurrentInitializer),
	        biasInitializer: serializeInitializer(this.biasInitializer),
	        kernelRegularizer: serializeRegularizer(this.kernelRegularizer),
	        recurrentRegularizer: serializeRegularizer(this.recurrentRegularizer),
	        biasRegularizer: serializeRegularizer(this.biasRegularizer),
	        activityRegularizer: serializeRegularizer(this.activityRegularizer),
	        kernelConstraint: serializeConstraint(this.kernelConstraint),
	        recurrentConstraint: serializeConstraint(this.recurrentConstraint),
	        biasConstraint: serializeConstraint(this.biasConstraint),
	        dropout: this.dropout,
	        recurrentDropout: this.recurrentDropout,
	        implementation: this.implementation,
	        resetAfter: false
	      };
	      return Object.assign(Object.assign({}, baseConfig), config);
	    }
	  }]);
	  return GRUCell;
	}(RNNCell);
	/** @nocollapse */
	GRUCell.className = 'GRUCell';
	registerClass(GRUCell);
	var GRU = /*#__PURE__*/function (_RNN2) {
	  _inherits(GRU, _RNN2);
	  var _super6 = _createSuper(GRU);
	  function GRU(args) {
	    _classCallCheck(this, GRU);
	    if (args.implementation === 0) {
	      console.warn('`implementation=0` has been deprecated, and now defaults to ' + '`implementation=1`. Please update your layer call.');
	    }
	    args.cell = new GRUCell(args);
	    return _super6.call(this, args); // TODO(cais): Add activityRegularizer.
	  }
	  _createClass(GRU, [{
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this11 = this;
	      return tidy(function () {
	        if (_this11.cell.dropoutMask != null) {
	          dispose(_this11.cell.dropoutMask);
	          _this11.cell.dropoutMask = null;
	        }
	        if (_this11.cell.recurrentDropoutMask != null) {
	          dispose(_this11.cell.recurrentDropoutMask);
	          _this11.cell.recurrentDropoutMask = null;
	        }
	        var mask = kwargs == null ? null : kwargs['mask'];
	        var training = kwargs == null ? null : kwargs['training'];
	        var initialState = kwargs == null ? null : kwargs['initialState'];
	        return _get(_getPrototypeOf(GRU.prototype), "call", _this11).call(_this11, inputs, {
	          mask: mask,
	          training: training,
	          initialState: initialState
	        });
	      });
	    }
	    /** @nocollapse */
	  }], [{
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      if (config['implmentation'] === 0) {
	        config['implementation'] = 1;
	      }
	      return new cls(config);
	    }
	  }]);
	  return GRU;
	}(RNN);
	/** @nocollapse */
	GRU.className = 'GRU';
	registerClass(GRU);
	var LSTMCell = /*#__PURE__*/function (_RNNCell3) {
	  _inherits(LSTMCell, _RNNCell3);
	  var _super7 = _createSuper(LSTMCell);
	  function LSTMCell(args) {
	    var _this12;
	    _classCallCheck(this, LSTMCell);
	    _this12 = _super7.call(this, args);
	    _this12.DEFAULT_ACTIVATION = 'tanh';
	    _this12.DEFAULT_RECURRENT_ACTIVATION = 'hardSigmoid';
	    _this12.DEFAULT_KERNEL_INITIALIZER = 'glorotNormal';
	    _this12.DEFAULT_RECURRENT_INITIALIZER = 'orthogonal';
	    _this12.DEFAULT_BIAS_INITIALIZER = 'zeros';
	    _this12.units = args.units;
	    assertPositiveInteger(_this12.units, 'units');
	    _this12.activation = getActivation(args.activation === undefined ? _this12.DEFAULT_ACTIVATION : args.activation);
	    _this12.recurrentActivation = getActivation(args.recurrentActivation === undefined ? _this12.DEFAULT_RECURRENT_ACTIVATION : args.recurrentActivation);
	    _this12.useBias = args.useBias == null ? true : args.useBias;
	    _this12.kernelInitializer = getInitializer(args.kernelInitializer || _this12.DEFAULT_KERNEL_INITIALIZER);
	    _this12.recurrentInitializer = getInitializer(args.recurrentInitializer || _this12.DEFAULT_RECURRENT_INITIALIZER);
	    _this12.biasInitializer = getInitializer(args.biasInitializer || _this12.DEFAULT_BIAS_INITIALIZER);
	    _this12.unitForgetBias = args.unitForgetBias;
	    _this12.kernelRegularizer = getRegularizer(args.kernelRegularizer);
	    _this12.recurrentRegularizer = getRegularizer(args.recurrentRegularizer);
	    _this12.biasRegularizer = getRegularizer(args.biasRegularizer);
	    _this12.kernelConstraint = getConstraint(args.kernelConstraint);
	    _this12.recurrentConstraint = getConstraint(args.recurrentConstraint);
	    _this12.biasConstraint = getConstraint(args.biasConstraint);
	    _this12.dropout = min$2([1, max$2([0, args.dropout == null ? 0 : args.dropout])]);
	    _this12.recurrentDropout = min$2([1, max$2([0, args.recurrentDropout == null ? 0 : args.recurrentDropout])]);
	    _this12.dropoutFunc = args.dropoutFunc;
	    _this12.implementation = args.implementation;
	    _this12.stateSize = [_this12.units, _this12.units];
	    _this12.dropoutMask = null;
	    _this12.recurrentDropoutMask = null;
	    return _this12;
	  }
	  _createClass(LSTMCell, [{
	    key: "build",
	    value: function build(inputShape) {
	      var _a;
	      inputShape = getExactlyOneShape(inputShape);
	      var inputDim = inputShape[inputShape.length - 1];
	      this.kernel = this.addWeight('kernel', [inputDim, this.units * 4], null, this.kernelInitializer, this.kernelRegularizer, true, this.kernelConstraint);
	      this.recurrentKernel = this.addWeight('recurrent_kernel', [this.units, this.units * 4], null, this.recurrentInitializer, this.recurrentRegularizer, true, this.recurrentConstraint);
	      var biasInitializer;
	      if (this.useBias) {
	        if (this.unitForgetBias) {
	          var capturedBiasInit = this.biasInitializer;
	          var capturedUnits = this.units;
	          biasInitializer = new (_a = /*#__PURE__*/function (_Initializer) {
	            _inherits(CustomInit, _Initializer);
	            var _super8 = _createSuper(CustomInit);
	            function CustomInit() {
	              _classCallCheck(this, CustomInit);
	              return _super8.apply(this, arguments);
	            }
	            _createClass(CustomInit, [{
	              key: "apply",
	              value: function apply(shape, dtype) {
	                // TODO(cais): More informative variable names?
	                var bI = capturedBiasInit.apply([capturedUnits]);
	                var bF = new Ones().apply([capturedUnits]);
	                var bCAndH = capturedBiasInit.apply([capturedUnits * 2]);
	                return concatAlongFirstAxis(concatAlongFirstAxis(bI, bF), bCAndH);
	              }
	            }]);
	            return CustomInit;
	          }(Initializer), /** @nocollapse */
	          _a.className = 'CustomInit', _a)();
	        } else {
	          biasInitializer = this.biasInitializer;
	        }
	        this.bias = this.addWeight('bias', [this.units * 4], null, biasInitializer, this.biasRegularizer, true, this.biasConstraint);
	      } else {
	        this.bias = null;
	      }
	      // Porting Notes: Unlike the PyKeras implementation, we perform slicing
	      //   of the weights and bias in the call() method, at execution time.
	      this.built = true;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this13 = this;
	      return tidy(function () {
	        var training = kwargs['training'] == null ? false : kwargs['training'];
	        inputs = inputs;
	        if (inputs.length !== 3) {
	          throw new ValueError("LSTMCell expects 3 input Tensors (inputs, h, c), got " + "".concat(inputs.length, "."));
	        }
	        var hTMinus1 = inputs[1]; // Previous memory state.
	        var cTMinus1 = inputs[2]; // Previous carry state.
	        inputs = inputs[0];
	        if (0 < _this13.dropout && _this13.dropout < 1 && _this13.dropoutMask == null) {
	          _this13.dropoutMask = generateDropoutMask({
	            ones: function ones() {
	              return onesLike$3(inputs);
	            },
	            rate: _this13.dropout,
	            training: training,
	            count: 4,
	            dropoutFunc: _this13.dropoutFunc
	          });
	        }
	        if (0 < _this13.recurrentDropout && _this13.recurrentDropout < 1 && _this13.recurrentDropoutMask == null) {
	          _this13.recurrentDropoutMask = generateDropoutMask({
	            ones: function ones() {
	              return onesLike$3(hTMinus1);
	            },
	            rate: _this13.recurrentDropout,
	            training: training,
	            count: 4,
	            dropoutFunc: _this13.dropoutFunc
	          });
	        }
	        var dpMask = _this13.dropoutMask;
	        var recDpMask = _this13.recurrentDropoutMask;
	        // Note: For superior performance, TensorFlow.js always uses
	        // implementation 2 regardless of the actual value of
	        // config.implementation.
	        var i;
	        var f;
	        var c;
	        var o;
	        if (0 < _this13.dropout && _this13.dropout < 1) {
	          inputs = mul(inputs, dpMask[0]);
	        }
	        var z = dot$1(inputs, _this13.kernel.read());
	        if (0 < _this13.recurrentDropout && _this13.recurrentDropout < 1) {
	          hTMinus1 = mul(hTMinus1, recDpMask[0]);
	        }
	        z = add$3(z, dot$1(hTMinus1, _this13.recurrentKernel.read()));
	        if (_this13.useBias) {
	          z = biasAdd(z, _this13.bias.read());
	        }
	        var _tfc$split7 = split$3(z, 4, z.rank - 1),
	          _tfc$split8 = _slicedToArray(_tfc$split7, 4),
	          z0 = _tfc$split8[0],
	          z1 = _tfc$split8[1],
	          z2 = _tfc$split8[2],
	          z3 = _tfc$split8[3];
	        i = _this13.recurrentActivation.apply(z0);
	        f = _this13.recurrentActivation.apply(z1);
	        c = add$3(mul(f, cTMinus1), mul(i, _this13.activation.apply(z2)));
	        o = _this13.recurrentActivation.apply(z3);
	        var h = mul(o, _this13.activation.apply(c));
	        // TODO(cais): Add use_learning_phase flag properly.
	        return [h, h, c];
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var baseConfig = _get(_getPrototypeOf(LSTMCell.prototype), "getConfig", this).call(this);
	      var config = {
	        units: this.units,
	        activation: serializeActivation(this.activation),
	        recurrentActivation: serializeActivation(this.recurrentActivation),
	        useBias: this.useBias,
	        kernelInitializer: serializeInitializer(this.kernelInitializer),
	        recurrentInitializer: serializeInitializer(this.recurrentInitializer),
	        biasInitializer: serializeInitializer(this.biasInitializer),
	        unitForgetBias: this.unitForgetBias,
	        kernelRegularizer: serializeRegularizer(this.kernelRegularizer),
	        recurrentRegularizer: serializeRegularizer(this.recurrentRegularizer),
	        biasRegularizer: serializeRegularizer(this.biasRegularizer),
	        activityRegularizer: serializeRegularizer(this.activityRegularizer),
	        kernelConstraint: serializeConstraint(this.kernelConstraint),
	        recurrentConstraint: serializeConstraint(this.recurrentConstraint),
	        biasConstraint: serializeConstraint(this.biasConstraint),
	        dropout: this.dropout,
	        recurrentDropout: this.recurrentDropout,
	        implementation: this.implementation
	      };
	      return Object.assign(Object.assign({}, baseConfig), config);
	    }
	  }]);
	  return LSTMCell;
	}(RNNCell);
	/** @nocollapse */
	LSTMCell.className = 'LSTMCell';
	registerClass(LSTMCell);
	var LSTM = /*#__PURE__*/function (_RNN3) {
	  _inherits(LSTM, _RNN3);
	  var _super9 = _createSuper(LSTM);
	  function LSTM(args) {
	    _classCallCheck(this, LSTM);
	    if (args.implementation === 0) {
	      console.warn('`implementation=0` has been deprecated, and now defaults to ' + '`implementation=1`. Please update your layer call.');
	    }
	    args.cell = new LSTMCell(args);
	    return _super9.call(this, args); // TODO(cais): Add activityRegularizer.
	  }
	  _createClass(LSTM, [{
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this14 = this;
	      return tidy(function () {
	        if (_this14.cell.dropoutMask != null) {
	          dispose(_this14.cell.dropoutMask);
	          _this14.cell.dropoutMask = null;
	        }
	        if (_this14.cell.recurrentDropoutMask != null) {
	          dispose(_this14.cell.recurrentDropoutMask);
	          _this14.cell.recurrentDropoutMask = null;
	        }
	        var mask = kwargs == null ? null : kwargs['mask'];
	        var training = kwargs == null ? null : kwargs['training'];
	        var initialState = kwargs == null ? null : kwargs['initialState'];
	        return _get(_getPrototypeOf(LSTM.prototype), "call", _this14).call(_this14, inputs, {
	          mask: mask,
	          training: training,
	          initialState: initialState
	        });
	      });
	    }
	    /** @nocollapse */
	  }], [{
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      if (config['implmentation'] === 0) {
	        config['implementation'] = 1;
	      }
	      return new cls(config);
	    }
	  }]);
	  return LSTM;
	}(RNN);
	/** @nocollapse */
	LSTM.className = 'LSTM';
	registerClass(LSTM);
	var StackedRNNCells = /*#__PURE__*/function (_RNNCell4) {
	  _inherits(StackedRNNCells, _RNNCell4);
	  var _super10 = _createSuper(StackedRNNCells);
	  function StackedRNNCells(args) {
	    var _this15;
	    _classCallCheck(this, StackedRNNCells);
	    _this15 = _super10.call(this, args);
	    _this15.cells = args.cells;
	    return _this15;
	  }
	  _createClass(StackedRNNCells, [{
	    key: "stateSize",
	    get: function get() {
	      // States are a flat list in reverse order of the cell stack.
	      // This allows preserving the requirement `stack.statesize[0] ===
	      // outputDim`. E.g., states of a 2-layer LSTM would be `[h2, c2, h1, c1]`,
	      // assuming one LSTM has states `[h, c]`.
	      var stateSize = [];
	      var _iterator3 = _createForOfIteratorHelper(this.cells.slice().reverse()),
	        _step3;
	      try {
	        for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
	          var cell = _step3.value;
	          if (Array.isArray(cell.stateSize)) {
	            stateSize.push.apply(stateSize, _toConsumableArray(cell.stateSize));
	          } else {
	            stateSize.push(cell.stateSize);
	          }
	        }
	      } catch (err) {
	        _iterator3.e(err);
	      } finally {
	        _iterator3.f();
	      }
	      return stateSize;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this16 = this;
	      return tidy(function () {
	        inputs = inputs;
	        var states = inputs.slice(1);
	        // Recover per-cell states.
	        var nestedStates = [];
	        var _iterator4 = _createForOfIteratorHelper(_this16.cells.slice().reverse()),
	          _step4;
	        try {
	          for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
	            var _cell = _step4.value;
	            if (Array.isArray(_cell.stateSize)) {
	              nestedStates.push(states.splice(0, _cell.stateSize.length));
	            } else {
	              nestedStates.push(states.splice(0, 1));
	            }
	          }
	        } catch (err) {
	          _iterator4.e(err);
	        } finally {
	          _iterator4.f();
	        }
	        nestedStates.reverse();
	        // Call the cells in order and store the returned states.
	        var newNestedStates = [];
	        var callInputs;
	        for (var i = 0; i < _this16.cells.length; ++i) {
	          var cell = _this16.cells[i];
	          states = nestedStates[i];
	          // TODO(cais): Take care of constants.
	          if (i === 0) {
	            callInputs = [inputs[0]].concat(states);
	          } else {
	            callInputs = [callInputs[0]].concat(states);
	          }
	          callInputs = cell.call(callInputs, kwargs);
	          newNestedStates.push(callInputs.slice(1));
	        }
	        // Format the new states as a flat list in reverse cell order.
	        states = [];
	        var _iterator5 = _createForOfIteratorHelper(newNestedStates.slice().reverse()),
	          _step5;
	        try {
	          for (_iterator5.s(); !(_step5 = _iterator5.n()).done;) {
	            var _states;
	            var cellStates = _step5.value;
	            (_states = states).push.apply(_states, _toConsumableArray(cellStates));
	          }
	        } catch (err) {
	          _iterator5.e(err);
	        } finally {
	          _iterator5.f();
	        }
	        return [callInputs[0]].concat(states);
	      });
	    }
	  }, {
	    key: "build",
	    value: function build(inputShape) {
	      if (isArrayOfShapes(inputShape)) {
	        // TODO(cais): Take care of input constants.
	        // const constantShape = inputShape.slice(1);
	        inputShape = inputShape[0];
	      }
	      inputShape = inputShape;
	      var outputDim;
	      this.cells.forEach(function (cell, i) {
	        nameScope("RNNCell_".concat(i), function () {
	          // TODO(cais): Take care of input constants.
	          cell.build(inputShape);
	          if (Array.isArray(cell.stateSize)) {
	            outputDim = cell.stateSize[0];
	          } else {
	            outputDim = cell.stateSize;
	          }
	          inputShape = [inputShape[0], outputDim];
	        });
	      });
	      this.built = true;
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var baseConfig = _get(_getPrototypeOf(StackedRNNCells.prototype), "getConfig", this).call(this);
	      var getCellConfig = function getCellConfig(cell) {
	        return {
	          'className': cell.getClassName(),
	          'config': cell.getConfig()
	        };
	      };
	      var cellConfigs = this.cells.map(getCellConfig);
	      var config = {
	        'cells': cellConfigs
	      };
	      return Object.assign(Object.assign({}, baseConfig), config);
	    }
	    /** @nocollapse */
	  }, {
	    key: "trainableWeights",
	    get: function get() {
	      if (!this.trainable) {
	        return [];
	      }
	      var weights = [];
	      var _iterator6 = _createForOfIteratorHelper(this.cells),
	        _step6;
	      try {
	        for (_iterator6.s(); !(_step6 = _iterator6.n()).done;) {
	          var cell = _step6.value;
	          weights.push.apply(weights, _toConsumableArray(cell.trainableWeights));
	        }
	      } catch (err) {
	        _iterator6.e(err);
	      } finally {
	        _iterator6.f();
	      }
	      return weights;
	    }
	  }, {
	    key: "nonTrainableWeights",
	    get: function get() {
	      var weights = [];
	      var _iterator7 = _createForOfIteratorHelper(this.cells),
	        _step7;
	      try {
	        for (_iterator7.s(); !(_step7 = _iterator7.n()).done;) {
	          var _cell2 = _step7.value;
	          weights.push.apply(weights, _toConsumableArray(_cell2.nonTrainableWeights));
	        }
	      } catch (err) {
	        _iterator7.e(err);
	      } finally {
	        _iterator7.f();
	      }
	      if (!this.trainable) {
	        var trainableWeights = [];
	        var _iterator8 = _createForOfIteratorHelper(this.cells),
	          _step8;
	        try {
	          for (_iterator8.s(); !(_step8 = _iterator8.n()).done;) {
	            var cell = _step8.value;
	            trainableWeights.push.apply(trainableWeights, _toConsumableArray(cell.trainableWeights));
	          }
	        } catch (err) {
	          _iterator8.e(err);
	        } finally {
	          _iterator8.f();
	        }
	        return trainableWeights.concat(weights);
	      }
	      return weights;
	    }
	    /**
	     * Retrieve the weights of a the model.
	     *
	     * @returns A flat `Array` of `tf.Tensor`s.
	     */
	  }, {
	    key: "getWeights",
	    value: function getWeights() {
	      var weights = [];
	      var _iterator9 = _createForOfIteratorHelper(this.cells),
	        _step9;
	      try {
	        for (_iterator9.s(); !(_step9 = _iterator9.n()).done;) {
	          var cell = _step9.value;
	          weights.push.apply(weights, _toConsumableArray(cell.weights));
	        }
	      } catch (err) {
	        _iterator9.e(err);
	      } finally {
	        _iterator9.f();
	      }
	      return batchGetValue(weights);
	    }
	    /**
	     * Set the weights of the model.
	     *
	     * @param weights An `Array` of `tf.Tensor`s with shapes and types matching
	     *     the output of `getWeights()`.
	     */
	  }, {
	    key: "setWeights",
	    value: function setWeights(weights) {
	      var tuples = [];
	      var _iterator10 = _createForOfIteratorHelper(this.cells),
	        _step10;
	      try {
	        for (_iterator10.s(); !(_step10 = _iterator10.n()).done;) {
	          var cell = _step10.value;
	          var numParams = cell.weights.length;
	          var inputWeights = weights.splice(numParams);
	          for (var i = 0; i < cell.weights.length; ++i) {
	            tuples.push([cell.weights[i], inputWeights[i]]);
	          }
	        }
	      } catch (err) {
	        _iterator10.e(err);
	      } finally {
	        _iterator10.f();
	      }
	      batchSetValue(tuples);
	    }
	  }], [{
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      var customObjects = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
	      var cells = [];
	      var _iterator11 = _createForOfIteratorHelper(config['cells']),
	        _step11;
	      try {
	        for (_iterator11.s(); !(_step11 = _iterator11.n()).done;) {
	          var cellConfig = _step11.value;
	          cells.push(deserialize(cellConfig, customObjects));
	        }
	      } catch (err) {
	        _iterator11.e(err);
	      } finally {
	        _iterator11.f();
	      }
	      return new cls({
	        cells: cells
	      });
	    }
	  }]);
	  return StackedRNNCells;
	}(RNNCell);
	/** @nocollapse */
	StackedRNNCells.className = 'StackedRNNCells';
	registerClass(StackedRNNCells);
	function generateDropoutMask(args) {
	  var ones = args.ones,
	    rate = args.rate,
	    _args$training = args.training,
	    training = _args$training === void 0 ? false : _args$training,
	    _args$count = args.count,
	    count = _args$count === void 0 ? 1 : _args$count,
	    dropoutFunc = args.dropoutFunc;
	  var droppedInputs = function droppedInputs() {
	    return dropoutFunc != null ? dropoutFunc(ones(), rate) : dropout$1(ones(), rate);
	  };
	  var createMask = function createMask() {
	    return inTrainPhase(droppedInputs, ones, training);
	  };
	  // just in case count is provided with null or undefined
	  if (!count || count <= 1) {
	    return keep(createMask().clone());
	  }
	  var masks = Array(count).fill(undefined).map(createMask);
	  return masks.map(function (m) {
	    return keep(m.clone());
	  });
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	var __rest = undefined && undefined.__rest || function (s, e) {
	  var t = {};
	  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
	  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
	    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
	  }
	  return t;
	};
	var ConvRNN2DCell = /*#__PURE__*/function (_RNNCell) {
	  _inherits(ConvRNN2DCell, _RNNCell);
	  var _super = _createSuper(ConvRNN2DCell);
	  function ConvRNN2DCell() {
	    _classCallCheck(this, ConvRNN2DCell);
	    return _super.apply(this, arguments);
	  }
	  return _createClass(ConvRNN2DCell);
	}(RNNCell);
	/**
	 * Base class for convolutional-recurrent layers.
	 */
	var ConvRNN2D = /*#__PURE__*/function (_RNN) {
	  _inherits(ConvRNN2D, _RNN);
	  var _super2 = _createSuper(ConvRNN2D);
	  function ConvRNN2D(args) {
	    var _this;
	    _classCallCheck(this, ConvRNN2D);
	    if (args.unroll) {
	      throw new NotImplementedError('Unrolling is not possible with convolutional RNNs.');
	    }
	    if (Array.isArray(args.cell)) {
	      throw new NotImplementedError('It is not possible at the moment to stack convolutional cells.');
	    }
	    _this = _super2.call(this, args);
	    _this.inputSpec = [new InputSpec({
	      ndim: 5
	    })];
	    return _this;
	  }
	  _createClass(ConvRNN2D, [{
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this2 = this;
	      return tidy(function () {
	        if (_this2.cell.dropoutMask != null) {
	          dispose(_this2.cell.dropoutMask);
	          _this2.cell.dropoutMask = null;
	        }
	        if (_this2.cell.recurrentDropoutMask != null) {
	          dispose(_this2.cell.recurrentDropoutMask);
	          _this2.cell.recurrentDropoutMask = null;
	        }
	        if (kwargs && kwargs['constants']) {
	          throw new ValueError('ConvRNN2D cell does not support constants');
	        }
	        var mask = kwargs == null ? null : kwargs['mask'];
	        var training = kwargs == null ? null : kwargs['training'];
	        var initialState = kwargs == null ? null : kwargs['initialState'];
	        return _get(_getPrototypeOf(ConvRNN2D.prototype), "call", _this2).call(_this2, inputs, {
	          mask: mask,
	          training: training,
	          initialState: initialState
	        });
	      });
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      var outShape = this.computeSingleOutputShape(inputShape);
	      if (!this.returnSequences) {
	        outShape = [outShape[0]].concat(_toConsumableArray(outShape.slice(2)));
	      }
	      if (this.returnState) {
	        outShape = [outShape].concat(_toConsumableArray(Array(2).fill([inputShape[0]].concat(_toConsumableArray(outShape.slice(-3))))));
	      }
	      return outShape;
	    }
	  }, {
	    key: "getInitialState",
	    value: function getInitialState(inputs) {
	      var _this3 = this;
	      return tidy(function () {
	        var stateSize = _this3.cell.stateSize;
	        var inputShape = inputs.shape;
	        var outputShape = _this3.computeSingleOutputShape(inputShape);
	        var stateShape = [outputShape[0]].concat(_toConsumableArray(outputShape.slice(2)));
	        var initialState = zeros$2(stateShape);
	        if (Array.isArray(stateSize)) {
	          return Array(stateSize.length).fill(initialState);
	        }
	        return [initialState];
	      });
	    }
	  }, {
	    key: "resetStates",
	    value: function resetStates(states) {
	      var _this4 = this;
	      var training = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
	      tidy(function () {
	        if (!_this4.stateful) {
	          throw new AttributeError('Cannot call resetStates() on an RNN Layer that is not stateful.');
	        }
	        var inputShape = _this4.inputSpec[0].shape;
	        var outputShape = _this4.computeSingleOutputShape(inputShape);
	        var stateShape = [outputShape[0]].concat(_toConsumableArray(outputShape.slice(2)));
	        var batchSize = inputShape[0];
	        if (batchSize == null) {
	          throw new ValueError('If an RNN is stateful, it needs to know its batch size. Specify ' + 'the batch size of your input tensors: \n' + '- If using a Sequential model, specify the batch size by ' + 'passing a `batchInputShape` option to your first layer.\n' + '- If using the functional API, specify the batch size by ' + 'passing a `batchShape` option to your Input layer.');
	        }
	        // Initialize state if null.
	        if (_this4.getStates() == null) {
	          if (Array.isArray(_this4.cell.stateSize)) {
	            _this4.states_ = _this4.cell.stateSize.map(function () {
	              return zeros$2(stateShape);
	            });
	          } else {
	            _this4.states_ = [zeros$2(stateShape)];
	          }
	        } else if (states == null) {
	          // Dispose old state tensors.
	          dispose(_this4.states_);
	          // For stateful RNNs, fully dispose kept old states.
	          if (_this4.keptStates != null) {
	            dispose(_this4.keptStates);
	            _this4.keptStates = [];
	          }
	          if (Array.isArray(_this4.cell.stateSize)) {
	            _this4.states_ = _this4.cell.stateSize.map(function () {
	              return zeros$2(stateShape);
	            });
	          } else {
	            _this4.states_[0] = zeros$2(stateShape);
	          }
	        } else {
	          if (!Array.isArray(states)) {
	            states = [states];
	          }
	          if (states.length !== _this4.states_.length) {
	            throw new ValueError("Layer ".concat(_this4.name, " expects ").concat(_this4.states_.length, " state(s), ") + "but it received ".concat(states.length, " state value(s). Input ") + "received: ".concat(states));
	          }
	          if (training) {
	            // Store old state tensors for complete disposal later, i.e., during
	            // the next no-arg call to this method. We do not dispose the old
	            // states immediately because that BPTT (among other things) require
	            // them.
	            _this4.keptStates.push(_this4.states_.slice());
	          } else {
	            dispose(_this4.states_);
	          }
	          for (var index = 0; index < _this4.states_.length; ++index) {
	            var value = states[index];
	            var expectedShape = stateShape;
	            if (!arraysEqual(value.shape, expectedShape)) {
	              throw new ValueError("State ".concat(index, " is incompatible with layer ").concat(_this4.name, ": ") + "expected shape=".concat(expectedShape, ", received shape=").concat(value.shape));
	            }
	            _this4.states_[index] = value;
	          }
	        }
	        _this4.states_ = _this4.states_.map(function (state) {
	          return keep(state.clone());
	        });
	      });
	    }
	  }, {
	    key: "computeSingleOutputShape",
	    value: function computeSingleOutputShape(inputShape) {
	      var _this$cell = this.cell,
	        dataFormat = _this$cell.dataFormat,
	        filters = _this$cell.filters,
	        kernelSize = _this$cell.kernelSize,
	        padding = _this$cell.padding,
	        strides = _this$cell.strides,
	        dilationRate = _this$cell.dilationRate;
	      var isChannelsFirst = dataFormat === 'channelsFirst';
	      var h = inputShape[isChannelsFirst ? 3 : 2];
	      var w = inputShape[isChannelsFirst ? 4 : 3];
	      var hOut = convOutputLength(h, kernelSize[0], padding, strides[0], dilationRate[0]);
	      var wOut = convOutputLength(w, kernelSize[1], padding, strides[1], dilationRate[1]);
	      var outShape = [].concat(_toConsumableArray(inputShape.slice(0, 2)), _toConsumableArray(isChannelsFirst ? [filters, hOut, wOut] : [hOut, wOut, filters]));
	      return outShape;
	    }
	  }]);
	  return ConvRNN2D;
	}(RNN);
	/** @nocollapse */
	ConvRNN2D.className = 'ConvRNN2D';
	var ConvLSTM2DCell = /*#__PURE__*/function (_LSTMCell) {
	  _inherits(ConvLSTM2DCell, _LSTMCell);
	  var _super3 = _createSuper(ConvLSTM2DCell);
	  function ConvLSTM2DCell(args) {
	    var _this5;
	    _classCallCheck(this, ConvLSTM2DCell);
	    var filters = args.filters,
	      kernelSize = args.kernelSize,
	      strides = args.strides,
	      padding = args.padding,
	      dataFormat = args.dataFormat,
	      dilationRate = args.dilationRate;
	    _this5 = _super3.call(this, Object.assign(Object.assign({}, args), {
	      units: filters
	    }));
	    _this5.filters = filters;
	    assertPositiveInteger(_this5.filters, 'filters');
	    _this5.kernelSize = normalizeArray(kernelSize, 2, 'kernelSize');
	    _this5.kernelSize.forEach(function (size) {
	      return assertPositiveInteger(size, 'kernelSize');
	    });
	    _this5.strides = normalizeArray(strides || 1, 2, 'strides');
	    _this5.strides.forEach(function (stride) {
	      return assertPositiveInteger(stride, 'strides');
	    });
	    _this5.padding = padding || 'valid';
	    checkPaddingMode(_this5.padding);
	    _this5.dataFormat = dataFormat || 'channelsLast';
	    checkDataFormat(_this5.dataFormat);
	    _this5.dilationRate = normalizeArray(dilationRate || 1, 2, 'dilationRate');
	    _this5.dilationRate.forEach(function (rate) {
	      return assertPositiveInteger(rate, 'dilationRate');
	    });
	    return _this5;
	  }
	  _createClass(ConvLSTM2DCell, [{
	    key: "build",
	    value: function build(inputShape) {
	      var _a;
	      inputShape = getExactlyOneShape(inputShape);
	      var channelAxis = this.dataFormat === 'channelsFirst' ? 1 : inputShape.length - 1;
	      if (inputShape[channelAxis] == null) {
	        throw new ValueError("The channel dimension of the input should be defined. " + "Found ".concat(inputShape[channelAxis]));
	      }
	      var inputDim = inputShape[channelAxis];
	      var numOfKernels = 4;
	      var kernelShape = this.kernelSize.concat([inputDim, this.filters * numOfKernels]);
	      this.kernel = this.addWeight('kernel', kernelShape, null, this.kernelInitializer, this.kernelRegularizer, true, this.kernelConstraint);
	      var recurrentKernelShape = this.kernelSize.concat([this.filters, this.filters * numOfKernels]);
	      this.recurrentKernel = this.addWeight('recurrent_kernel', recurrentKernelShape, null, this.recurrentInitializer, this.recurrentRegularizer, true, this.recurrentConstraint);
	      if (this.useBias) {
	        var biasInitializer;
	        if (this.unitForgetBias) {
	          var init = this.biasInitializer;
	          var filters = this.filters;
	          biasInitializer = new (_a = /*#__PURE__*/function (_Initializer) {
	            _inherits(CustomInit, _Initializer);
	            var _super4 = _createSuper(CustomInit);
	            function CustomInit() {
	              _classCallCheck(this, CustomInit);
	              return _super4.apply(this, arguments);
	            }
	            _createClass(CustomInit, [{
	              key: "apply",
	              value: function apply(shape, dtype) {
	                var biasI = init.apply([filters]);
	                var biasF = ones$1([filters]);
	                var biasCAndO = init.apply([filters * 2]);
	                return concatenate$2([biasI, biasF, biasCAndO]);
	              }
	            }]);
	            return CustomInit;
	          }(Initializer), /** @nocollapse */
	          _a.className = 'CustomInit', _a)();
	        } else {
	          biasInitializer = this.biasInitializer;
	        }
	        this.bias = this.addWeight('bias', [this.filters * numOfKernels], null, biasInitializer, this.biasRegularizer, true, this.biasConstraint);
	      }
	      this.built = true;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this6 = this;
	      return tidy(function () {
	        if (inputs.length !== 3) {
	          throw new ValueError("ConvLSTM2DCell expects 3 input Tensors (inputs, h, c), got " + "".concat(inputs.length, "."));
	        }
	        var training = kwargs['training'] || false;
	        var x = inputs[0]; // Current input
	        var hTMinus1 = inputs[1]; // Previous memory state.
	        var cTMinus1 = inputs[2]; // Previous carry state.
	        var numOfKernels = 4;
	        if (0 < _this6.dropout && _this6.dropout < 1 && _this6.dropoutMask == null) {
	          _this6.dropoutMask = generateDropoutMask({
	            ones: function ones() {
	              return onesLike$3(x);
	            },
	            rate: _this6.dropout,
	            training: training,
	            count: numOfKernels,
	            dropoutFunc: _this6.dropoutFunc
	          });
	        }
	        var dropoutMask = _this6.dropoutMask;
	        var applyDropout = function applyDropout(x, mask, index) {
	          if (!mask || !mask[index]) {
	            return x;
	          }
	          return mul(mask[index], x);
	        };
	        var xI = applyDropout(x, dropoutMask, 0);
	        var xF = applyDropout(x, dropoutMask, 1);
	        var xC = applyDropout(x, dropoutMask, 2);
	        var xO = applyDropout(x, dropoutMask, 3);
	        if (0 < _this6.recurrentDropout && _this6.recurrentDropout < 1 && _this6.recurrentDropoutMask == null) {
	          _this6.recurrentDropoutMask = generateDropoutMask({
	            ones: function ones() {
	              return onesLike$3(hTMinus1);
	            },
	            rate: _this6.recurrentDropout,
	            training: training,
	            count: numOfKernels,
	            dropoutFunc: _this6.dropoutFunc
	          });
	        }
	        var recDropoutMask = _this6.recurrentDropoutMask;
	        var hI = applyDropout(hTMinus1, recDropoutMask, 0);
	        var hF = applyDropout(hTMinus1, recDropoutMask, 1);
	        var hC = applyDropout(hTMinus1, recDropoutMask, 2);
	        var hO = applyDropout(hTMinus1, recDropoutMask, 3);
	        var kernelChannelAxis = 3;
	        var _tfc$split = split$3(_this6.kernel.read(), numOfKernels, kernelChannelAxis),
	          _tfc$split2 = _slicedToArray(_tfc$split, 4),
	          kernelI = _tfc$split2[0],
	          kernelF = _tfc$split2[1],
	          kernelC = _tfc$split2[2],
	          kernelO = _tfc$split2[3];
	        var _ref = _this6.useBias ? split$3(_this6.bias.read(), numOfKernels) : [null, null, null, null],
	          _ref2 = _slicedToArray(_ref, 4),
	          biasI = _ref2[0],
	          biasF = _ref2[1],
	          biasC = _ref2[2],
	          biasO = _ref2[3];
	        xI = _this6.inputConv(xI, kernelI, biasI, _this6.padding);
	        xF = _this6.inputConv(xF, kernelF, biasF, _this6.padding);
	        xC = _this6.inputConv(xC, kernelC, biasC, _this6.padding);
	        xO = _this6.inputConv(xO, kernelO, biasO, _this6.padding);
	        var _tfc$split3 = split$3(_this6.recurrentKernel.read(), numOfKernels, kernelChannelAxis),
	          _tfc$split4 = _slicedToArray(_tfc$split3, 4),
	          recKernelI = _tfc$split4[0],
	          recKernelF = _tfc$split4[1],
	          recKernelC = _tfc$split4[2],
	          recKernelO = _tfc$split4[3];
	        hI = _this6.recurrentConv(hI, recKernelI);
	        hF = _this6.recurrentConv(hF, recKernelF);
	        hC = _this6.recurrentConv(hC, recKernelC);
	        hO = _this6.recurrentConv(hO, recKernelO);
	        var i = _this6.recurrentActivation.apply(add$3(xI, hI));
	        var f = _this6.recurrentActivation.apply(add$3(xF, hF));
	        var c = add$3(mul(f, cTMinus1), mul(i, _this6.activation.apply(add$3(xC, hC))));
	        var h = mul(_this6.recurrentActivation.apply(add$3(xO, hO)), _this6.activation.apply(c));
	        return [h, h, c];
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var _a = _get(_getPrototypeOf(ConvLSTM2DCell.prototype), "getConfig", this).call(this),
	        _ = _a['units'],
	        baseConfig = __rest(_a, ['units']);
	      var config = {
	        filters: this.filters,
	        kernelSize: this.kernelSize,
	        padding: this.padding,
	        dataFormat: this.dataFormat,
	        dilationRate: this.dilationRate,
	        strides: this.strides
	      };
	      return Object.assign(Object.assign({}, baseConfig), config);
	    }
	  }, {
	    key: "inputConv",
	    value: function inputConv(x, w, b, padding) {
	      var out = conv2d$4(x, w, this.strides, padding || 'valid', this.dataFormat === 'channelsFirst' ? 'NCHW' : 'NHWC', this.dilationRate);
	      if (b) {
	        return biasAdd(out, b, this.dataFormat);
	      }
	      return out;
	    }
	  }, {
	    key: "recurrentConv",
	    value: function recurrentConv(x, w) {
	      var strides = 1;
	      return conv2d$4(x, w, strides, 'same', this.dataFormat === 'channelsFirst' ? 'NCHW' : 'NHWC');
	    }
	  }]);
	  return ConvLSTM2DCell;
	}(LSTMCell);
	/** @nocollapse */
	ConvLSTM2DCell.className = 'ConvLSTM2DCell';
	registerClass(ConvLSTM2DCell);
	var ConvLSTM2D = /*#__PURE__*/function (_ConvRNN2D) {
	  _inherits(ConvLSTM2D, _ConvRNN2D);
	  var _super5 = _createSuper(ConvLSTM2D);
	  function ConvLSTM2D(args) {
	    _classCallCheck(this, ConvLSTM2D);
	    var cell = new ConvLSTM2DCell(args);
	    return _super5.call(this, Object.assign(Object.assign({}, args), {
	      cell: cell
	    }));
	  }
	  /** @nocollapse */
	  _createClass(ConvLSTM2D, null, [{
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      return new cls(config);
	    }
	  }]);
	  return ConvLSTM2D;
	}(ConvRNN2D);
	/** @nocollapse */
	ConvLSTM2D.className = 'ConvLSTM2D';
	registerClass(ConvLSTM2D);

	var Dropout = /*#__PURE__*/function (_Layer) {
	  _inherits(Dropout, _Layer);
	  var _super = _createSuper(Dropout);
	  function Dropout(args) {
	    var _this;
	    _classCallCheck(this, Dropout);
	    _this = _super.call(this, args);
	    _this.rate = Math.max(Math.min(args.rate, 1), 0);
	    // So that the scalar doesn't get tidied up between executions.
	    _this.noiseShape = args.noiseShape;
	    _this.seed = args.seed;
	    _this.supportsMasking = true;
	    return _this;
	  }
	  _createClass(Dropout, [{
	    key: "getNoiseShape",
	    value: function getNoiseShape(input) {
	      if (this.noiseShape == null) {
	        return this.noiseShape;
	      }
	      var inputShape = input.shape;
	      var noiseShape = [];
	      for (var i = 0; i < this.noiseShape.length; ++i) {
	        noiseShape.push(this.noiseShape[i] == null ? inputShape[i] : this.noiseShape[i]);
	      }
	      return noiseShape;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this2 = this;
	      return tidy(function () {
	        _this2.invokeCallHook(inputs, kwargs);
	        var input = getExactlyOneTensor(inputs);
	        if (0 < _this2.rate && _this2.rate < 1) {
	          var training = kwargs['training'] == null ? false : kwargs['training'];
	          var noiseShape = _this2.getNoiseShape(input);
	          var output = inTrainPhase(function () {
	            return dropout$1(input, _this2.rate, noiseShape, _this2.seed);
	          }, function () {
	            return input;
	          }, training);
	          return output;
	        }
	        return inputs;
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        rate: this.rate,
	        noiseShape: this.noiseShape,
	        seed: this.seed
	      };
	      var baseConfig = _get(_getPrototypeOf(Dropout.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }, {
	    key: "dispose",
	    value: function dispose() {
	      return _get(_getPrototypeOf(Dropout.prototype), "dispose", this).call(this);
	    }
	  }]);
	  return Dropout;
	}(Layer);
	/** @nocollapse */
	Dropout.className = 'Dropout';
	registerClass(Dropout);
	var SpatialDropout1D = /*#__PURE__*/function (_Dropout) {
	  _inherits(SpatialDropout1D, _Dropout);
	  var _super2 = _createSuper(SpatialDropout1D);
	  function SpatialDropout1D(args) {
	    var _this3;
	    _classCallCheck(this, SpatialDropout1D);
	    _this3 = _super2.call(this, args);
	    _this3.inputSpec = [{
	      ndim: 3
	    }];
	    return _this3;
	  }
	  _createClass(SpatialDropout1D, [{
	    key: "getNoiseShape",
	    value: function getNoiseShape(input) {
	      var inputShape = input.shape;
	      return [inputShape[0], 1, inputShape[2]];
	    }
	  }]);
	  return SpatialDropout1D;
	}(Dropout);
	/** @nocollapse */
	SpatialDropout1D.className = 'SpatialDropout1D';
	registerClass(SpatialDropout1D);
	var Dense = /*#__PURE__*/function (_Layer2) {
	  _inherits(Dense, _Layer2);
	  var _super3 = _createSuper(Dense);
	  function Dense(args) {
	    var _this4;
	    _classCallCheck(this, Dense);
	    _this4 = _super3.call(this, args);
	    // Default activation: Linear (none).
	    _this4.activation = null;
	    _this4.useBias = true;
	    _this4.kernel = null;
	    _this4.bias = null;
	    _this4.DEFAULT_KERNEL_INITIALIZER = 'glorotNormal';
	    _this4.DEFAULT_BIAS_INITIALIZER = 'zeros';
	    if (args.batchInputShape == null && args.inputShape == null && args.inputDim != null) {
	      // This logic is copied from Layer's constructor, since we can't
	      // do exactly what the Python constructor does for Dense().
	      var batchSize = null;
	      if (args.batchSize != null) {
	        batchSize = args.batchSize;
	      }
	      _this4.batchInputShape = [batchSize, args.inputDim];
	    }
	    _this4.units = args.units;
	    assertPositiveInteger(_this4.units, 'units');
	    _this4.activation = getActivation(args.activation);
	    if (args.useBias != null) {
	      _this4.useBias = args.useBias;
	    }
	    _this4.kernelInitializer = getInitializer(args.kernelInitializer || _this4.DEFAULT_KERNEL_INITIALIZER);
	    _this4.biasInitializer = getInitializer(args.biasInitializer || _this4.DEFAULT_BIAS_INITIALIZER);
	    _this4.kernelConstraint = getConstraint(args.kernelConstraint);
	    _this4.biasConstraint = getConstraint(args.biasConstraint);
	    _this4.kernelRegularizer = getRegularizer(args.kernelRegularizer);
	    _this4.biasRegularizer = getRegularizer(args.biasRegularizer);
	    _this4.activityRegularizer = getRegularizer(args.activityRegularizer);
	    _this4.supportsMasking = true;
	    _this4.inputSpec = [{
	      minNDim: 2
	    }];
	    return _this4;
	  }
	  _createClass(Dense, [{
	    key: "build",
	    value: function build(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var inputLastDim = inputShape[inputShape.length - 1];
	      if (this.kernel == null) {
	        this.kernel = this.addWeight('kernel', [inputLastDim, this.units], null, this.kernelInitializer, this.kernelRegularizer, true, this.kernelConstraint);
	        if (this.useBias) {
	          this.bias = this.addWeight('bias', [this.units], null, this.biasInitializer, this.biasRegularizer, true, this.biasConstraint);
	        }
	      }
	      this.inputSpec = [{
	        minNDim: 2,
	        axes: _defineProperty({}, -1, inputLastDim)
	      }];
	      this.built = true;
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var outputShape = inputShape.slice();
	      outputShape[outputShape.length - 1] = this.units;
	      return outputShape;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this5 = this;
	      return tidy(function () {
	        _this5.invokeCallHook(inputs, kwargs);
	        // Dense layer accepts only a single input.
	        var input = getExactlyOneTensor(inputs);
	        var fusedActivationName = mapActivationToFusedKernel(_this5.activation.getClassName());
	        var output;
	        if (fusedActivationName != null) {
	          output = dot$1(input, _this5.kernel.read(), fusedActivationName, _this5.bias ? _this5.bias.read() : null);
	        } else {
	          output = dot$1(input, _this5.kernel.read());
	          if (_this5.bias != null) {
	            output = biasAdd(output, _this5.bias.read());
	          }
	          if (_this5.activation != null) {
	            output = _this5.activation.apply(output);
	          }
	        }
	        return output;
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        units: this.units,
	        activation: serializeActivation(this.activation),
	        useBias: this.useBias,
	        kernelInitializer: serializeInitializer(this.kernelInitializer),
	        biasInitializer: serializeInitializer(this.biasInitializer),
	        kernelRegularizer: serializeRegularizer(this.kernelRegularizer),
	        biasRegularizer: serializeRegularizer(this.biasRegularizer),
	        activityRegularizer: serializeRegularizer(this.activityRegularizer),
	        kernelConstraint: serializeConstraint(this.kernelConstraint),
	        biasConstraint: serializeConstraint(this.biasConstraint)
	      };
	      var baseConfig = _get(_getPrototypeOf(Dense.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return Dense;
	}(Layer);
	/** @nocollapse */
	Dense.className = 'Dense';
	registerClass(Dense);
	var Flatten = /*#__PURE__*/function (_Layer3) {
	  _inherits(Flatten, _Layer3);
	  var _super4 = _createSuper(Flatten);
	  function Flatten(args) {
	    var _this6;
	    _classCallCheck(this, Flatten);
	    args = args || {};
	    _this6 = _super4.call(this, args);
	    _this6.inputSpec = [{
	      minNDim: 3
	    }];
	    _this6.dataFormat = args.dataFormat;
	    return _this6;
	  }
	  _createClass(Flatten, [{
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var _iterator = _createForOfIteratorHelper(inputShape.slice(1)),
	        _step;
	      try {
	        for (_iterator.s(); !(_step = _iterator.n()).done;) {
	          var dim = _step.value;
	          if (dim == null) {
	            throw new ValueError("The shape of the input to \"Flatten\" is not fully defined " + "(got ".concat(inputShape.slice(1), "). Make sure to pass a complete ") + "\"input_shape\" or \"batch_input_shape\" argument to the first " + "layer in your model.");
	          }
	        }
	      } catch (err) {
	        _iterator.e(err);
	      } finally {
	        _iterator.f();
	      }
	      return [inputShape[0], arrayProd(inputShape, 1)];
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this7 = this;
	      return tidy(function () {
	        _this7.invokeCallHook(inputs, kwargs);
	        var input = getExactlyOneTensor(inputs);
	        if (_this7.dataFormat === 'channelsFirst' && input.rank > 1) {
	          var permutation = [0];
	          for (var i = 2; i < input.rank; ++i) {
	            permutation.push(i);
	          }
	          permutation.push(1);
	          input = transpose$2(input, permutation);
	        }
	        return batchFlatten(input);
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {};
	      if (this.dataFormat != null) {
	        config['dataFormat'] = this.dataFormat;
	      }
	      var baseConfig = _get(_getPrototypeOf(Flatten.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return Flatten;
	}(Layer);
	/** @nocollapse */
	Flatten.className = 'Flatten';
	registerClass(Flatten);
	var Activation = /*#__PURE__*/function (_Layer4) {
	  _inherits(Activation, _Layer4);
	  var _super5 = _createSuper(Activation);
	  function Activation(args) {
	    var _this8;
	    _classCallCheck(this, Activation);
	    _this8 = _super5.call(this, args);
	    _this8.supportsMasking = true;
	    _this8.activation = getActivation(args.activation);
	    return _this8;
	  }
	  _createClass(Activation, [{
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this9 = this;
	      return tidy(function () {
	        _this9.invokeCallHook(inputs, kwargs);
	        var input = getExactlyOneTensor(inputs);
	        return _this9.activation.apply(input);
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        activation: serializeActivation(this.activation)
	      };
	      var baseConfig = _get(_getPrototypeOf(Activation.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return Activation;
	}(Layer);
	/** @nocollapse */
	Activation.className = 'Activation';
	registerClass(Activation);
	var RepeatVector = /*#__PURE__*/function (_Layer5) {
	  _inherits(RepeatVector, _Layer5);
	  var _super6 = _createSuper(RepeatVector);
	  function RepeatVector(args) {
	    var _this10;
	    _classCallCheck(this, RepeatVector);
	    _this10 = _super6.call(this, args);
	    _this10.n = args.n;
	    _this10.inputSpec = [{
	      ndim: 2
	    }];
	    return _this10;
	  }
	  _createClass(RepeatVector, [{
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      return [inputShape[0], this.n, inputShape[1]];
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this11 = this;
	      return tidy(function () {
	        inputs = getExactlyOneTensor(inputs);
	        return repeat(inputs, _this11.n);
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        n: this.n
	      };
	      var baseConfig = _get(_getPrototypeOf(RepeatVector.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return RepeatVector;
	}(Layer);
	/** @nocollapse */
	RepeatVector.className = 'RepeatVector';
	registerClass(RepeatVector);
	var Reshape = /*#__PURE__*/function (_Layer6) {
	  _inherits(Reshape, _Layer6);
	  var _super7 = _createSuper(Reshape);
	  function Reshape(args) {
	    var _this12;
	    _classCallCheck(this, Reshape);
	    _this12 = _super7.call(this, args);
	    _this12.targetShape = args.targetShape;
	    // Make sure that all unknown dimensions are represented as `null`.
	    for (var i = 0; i < _this12.targetShape.length; ++i) {
	      if (_this12.isUnknown(_this12.targetShape[i])) {
	        _this12.targetShape[i] = null;
	      }
	    }
	    return _this12;
	  }
	  _createClass(Reshape, [{
	    key: "isUnknown",
	    value: function isUnknown(dim) {
	      return dim < 0 || dim == null;
	    }
	    /**
	     * Finds and replaces a missing dimension in output shape.
	     *
	     * This is a near direct port of the internal Numpy function
	     * `_fix_unknown_dimension` in `numpy/core/src/multiarray/shape.c`.
	     *
	     * @param inputShape: Original shape of array begin reshape.
	     * @param outputShape: Target shape of the array, with at most a single
	     * `null` or negative number, which indicates an underdetermined dimension
	     * that should be derived from `inputShape` and the known dimensions of
	     *   `outputShape`.
	     * @returns: The output shape with `null` replaced with its computed value.
	     * @throws: ValueError: If `inputShape` and `outputShape` do not match.
	     */
	  }, {
	    key: "fixUnknownDimension",
	    value: function fixUnknownDimension(inputShape, outputShape) {
	      var errorMsg = 'Total size of new array must be unchanged.';
	      var finalShape = outputShape.slice();
	      var known = 1;
	      var unknown = null;
	      for (var i = 0; i < finalShape.length; ++i) {
	        var dim = finalShape[i];
	        if (this.isUnknown(dim)) {
	          if (unknown === null) {
	            unknown = i;
	          } else {
	            throw new ValueError('Can only specifiy one unknown dimension.');
	          }
	        } else {
	          known *= dim;
	        }
	      }
	      var originalSize = arrayProd(inputShape);
	      if (unknown !== null) {
	        if (known === 0 || originalSize % known !== 0) {
	          throw new ValueError(errorMsg);
	        }
	        finalShape[unknown] = originalSize / known;
	      } else if (originalSize !== known) {
	        throw new ValueError(errorMsg);
	      }
	      return finalShape;
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      var anyUnknownDims = false;
	      for (var i = 0; i < inputShape.length; ++i) {
	        if (this.isUnknown(inputShape[i])) {
	          anyUnknownDims = true;
	          break;
	        }
	      }
	      if (anyUnknownDims) {
	        return inputShape.slice(0, 1).concat(this.targetShape);
	      } else {
	        return inputShape.slice(0, 1).concat(this.fixUnknownDimension(inputShape.slice(1), this.targetShape));
	      }
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this13 = this;
	      return tidy(function () {
	        _this13.invokeCallHook(inputs, kwargs);
	        var input = getExactlyOneTensor(inputs);
	        var inputShape = input.shape;
	        var outputShape = inputShape.slice(0, 1).concat(_this13.fixUnknownDimension(inputShape.slice(1), _this13.targetShape));
	        return reshape$3(input, outputShape);
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        targetShape: this.targetShape
	      };
	      var baseConfig = _get(_getPrototypeOf(Reshape.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return Reshape;
	}(Layer);
	/** @nocollapse */
	Reshape.className = 'Reshape';
	registerClass(Reshape);
	var Permute = /*#__PURE__*/function (_Layer7) {
	  _inherits(Permute, _Layer7);
	  var _super8 = _createSuper(Permute);
	  function Permute(args) {
	    var _this14;
	    _classCallCheck(this, Permute);
	    _this14 = _super8.call(this, args);
	    if (args.dims == null) {
	      throw new Error('Required configuration field `dims` is missing during Permute ' + 'constructor call.');
	    }
	    if (!Array.isArray(args.dims)) {
	      throw new Error('Permute constructor requires `dims` to be an Array, but received ' + "".concat(args.dims, " instead."));
	    }
	    // Check the validity of the permutation indices.
	    var expectedSortedIndices = range$2(1, args.dims.length + 1);
	    if (!arraysEqual(args.dims.slice().sort(), expectedSortedIndices)) {
	      throw new Error('Invalid permutation `dims`: ' + JSON.stringify(args.dims) + ' `dims` must contain consecutive integers starting from 1.');
	    }
	    _this14.dims = args.dims;
	    _this14.dimsIncludingBatch = [0].concat(_this14.dims);
	    _this14.inputSpec = [new InputSpec({
	      ndim: _this14.dims.length + 1
	    })];
	    return _this14;
	  }
	  _createClass(Permute, [{
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var outputShape = inputShape.slice();
	      this.dims.forEach(function (dim, i) {
	        outputShape[i + 1] = inputShape[dim];
	      });
	      return outputShape;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      return transpose$2(getExactlyOneTensor(inputs), this.dimsIncludingBatch);
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        dims: this.dims
	      };
	      var baseConfig = _get(_getPrototypeOf(Permute.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return Permute;
	}(Layer);
	/** @nocollapse */
	Permute.className = 'Permute';
	registerClass(Permute);
	var Masking = /*#__PURE__*/function (_Layer8) {
	  _inherits(Masking, _Layer8);
	  var _super9 = _createSuper(Masking);
	  function Masking(args) {
	    var _this15;
	    _classCallCheck(this, Masking);
	    _this15 = _super9.call(this, args == null ? {} : args);
	    _this15.supportsMasking = true;
	    if (args != null) {
	      _this15.maskValue = args.maskValue == null ? 0 : args.maskValue;
	    } else {
	      _this15.maskValue = 0;
	    }
	    return _this15;
	  }
	  _createClass(Masking, [{
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      return inputShape;
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var baseConfig = _get(_getPrototypeOf(Masking.prototype), "getConfig", this).call(this);
	      var config = {
	        maskValue: this.maskValue
	      };
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }, {
	    key: "computeMask",
	    value: function computeMask(inputs, mask) {
	      var input = getExactlyOneTensor(inputs);
	      var axis = -1;
	      return any$2(notEqual$2(input, this.maskValue), axis);
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this16 = this;
	      return tidy(function () {
	        _this16.invokeCallHook(inputs, kwargs);
	        var input = getExactlyOneTensor(inputs);
	        var axis = -1;
	        var keepDims = true;
	        var booleanMask = any$2(notEqual$2(input, _this16.maskValue), axis, keepDims);
	        var output = mul(input, cast$3(booleanMask, input.dtype));
	        return output;
	      });
	    }
	  }]);
	  return Masking;
	}(Layer);
	/** @nocollapse */
	Masking.className = 'Masking';
	registerClass(Masking);

	var Embedding = /*#__PURE__*/function (_Layer) {
	  _inherits(Embedding, _Layer);
	  var _super = _createSuper(Embedding);
	  function Embedding(args) {
	    var _this;
	    _classCallCheck(this, Embedding);
	    _this = _super.call(this, args);
	    _this.embeddings = null;
	    _this.DEFAULT_EMBEDDINGS_INITIALIZER = 'randomUniform';
	    if (args.batchInputShape == null && args.inputShape == null) {
	      // Porting Note: This logic is copied from Layer's constructor, since we
	      // can't do exactly what the Python constructor does for Embedding().
	      // Specifically, the super constructor can not be called after the
	      // mutation of the `config` argument.
	      var batchSize = null;
	      if (args.batchSize != null) {
	        batchSize = args.batchSize;
	      }
	      if (args.inputLength == null) {
	        // Fix super-constructor to what it would have done if
	        // 'config.inputShape' were (None, )
	        _this.batchInputShape = [batchSize, null];
	      } else {
	        // Fix super-constructor to what it would have done if
	        // 'config.inputShape' were (config.inputLength, )
	        _this.batchInputShape = [batchSize].concat(toList(args.inputLength));
	      }
	    }
	    _this.inputDim = args.inputDim;
	    assertPositiveInteger(_this.inputDim, 'inputDim');
	    _this.outputDim = args.outputDim;
	    assertPositiveInteger(_this.outputDim, 'outputDim');
	    _this.embeddingsInitializer = getInitializer(args.embeddingsInitializer || _this.DEFAULT_EMBEDDINGS_INITIALIZER);
	    _this.embeddingsRegularizer = getRegularizer(args.embeddingsRegularizer);
	    _this.activityRegularizer = getRegularizer(args.activityRegularizer);
	    _this.embeddingsConstraint = getConstraint(args.embeddingsConstraint);
	    _this.maskZero = args.maskZero;
	    _this.supportsMasking = args.maskZero;
	    _this.inputLength = args.inputLength;
	    return _this;
	  }
	  _createClass(Embedding, [{
	    key: "build",
	    value: function build(inputShape) {
	      this.embeddings = this.addWeight('embeddings', [this.inputDim, this.outputDim], this.dtype, this.embeddingsInitializer, this.embeddingsRegularizer, true, this.embeddingsConstraint);
	      this.built = true;
	    }
	    // Override warnOnIncompatibleInputShape because an embedding layer allows
	    // the input to have varying ranks.
	  }, {
	    key: "warnOnIncompatibleInputShape",
	    value: function warnOnIncompatibleInputShape(inputShape) {}
	  }, {
	    key: "computeMask",
	    value: function computeMask(inputs, mask) {
	      var _this2 = this;
	      return tidy(function () {
	        if (!_this2.maskZero) {
	          return null;
	        } else {
	          inputs = getExactlyOneTensor(inputs);
	          return notEqual$2(inputs, zerosLike$3(inputs));
	        }
	      });
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      if (this.inputLength == null) {
	        return [].concat(_toConsumableArray(inputShape), [this.outputDim]);
	      }
	      // inputLength can be an array if input is 3D or higher.
	      var inLens = toList(this.inputLength);
	      if (inLens.length !== inputShape.length - 1) {
	        throw new ValueError("\"inputLength\" is ".concat(this.inputLength, ", but received ") + "input shape has shape ".concat(inputShape));
	      } else {
	        var i = 0;
	        for (var k = 0; k < inLens.length; ++k) {
	          var s1 = inLens[k];
	          var s2 = inputShape[k + 1];
	          if (s1 != null && s2 != null && s1 !== s2) {
	            throw new ValueError("\"inputLength\" is ".concat(this.inputLength, ", but received ") + "input shape has shape ".concat(inputShape));
	          } else if (s1 == null) {
	            inLens[i] = s2;
	          }
	          i++;
	        }
	      }
	      return [inputShape[0]].concat(_toConsumableArray(inLens), [this.outputDim]);
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this3 = this;
	      return tidy(function () {
	        _this3.invokeCallHook(inputs, kwargs);
	        // Embedding layer accepts only a single input.
	        var input = getExactlyOneTensor(inputs);
	        if (input.dtype !== 'int32') {
	          input = cast$2(input, 'int32');
	        }
	        var output = gather(_this3.embeddings.read(), reshape$3(input, [input.size]));
	        return reshape$3(output, getExactlyOneShape(_this3.computeOutputShape(input.shape)));
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        inputDim: this.inputDim,
	        outputDim: this.outputDim,
	        embeddingsInitializer: serializeInitializer(this.embeddingsInitializer),
	        embeddingsRegularizer: serializeRegularizer(this.embeddingsRegularizer),
	        activityRegularizer: serializeRegularizer(this.activityRegularizer),
	        embeddingsConstraint: serializeConstraint(this.embeddingsConstraint),
	        maskZero: this.maskZero,
	        inputLength: this.inputLength
	      };
	      var baseConfig = _get(_getPrototypeOf(Embedding.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return Embedding;
	}(Layer);
	/** @nocollapse */
	Embedding.className = 'Embedding';
	registerClass(Embedding);

	/**
	 * Generic Merge layer for element-wise merge functions.
	 *
	 * Used to implement `Sum`, `Average`, `Concatenate`, etc.
	 */
	var Merge = /*#__PURE__*/function (_Layer) {
	  _inherits(Merge, _Layer);
	  var _super = _createSuper(Merge);
	  function Merge(args) {
	    var _this;
	    _classCallCheck(this, Merge);
	    _this = _super.call(this, args || {});
	    _this.supportsMasking = true;
	    return _this;
	  }
	  /**
	   * Logic for merging multiple tensors, to be overridden by subclasses.
	   * @param inputs
	   */
	  _createClass(Merge, [{
	    key: "mergeFunction",
	    value: function mergeFunction(inputs) {
	      throw new NotImplementedError();
	    }
	    /**
	     * Computes the shape of the result of an elementwise operation.
	     *
	     * @param shape1: Shape of the first tensor.
	     * @param shape2: Shape of the second tensor.
	     * @returns Expected output shape when an elementwise operation is carried
	     *   out on 2 tensors with shapes `shape1` and `shape2`.
	     * @throws ValueError: If `shape1` and `shape2` are not compatible for
	     *   element-wise operations.
	     */
	  }, {
	    key: "computeElementwiseOpOutputShape",
	    value: function computeElementwiseOpOutputShape(shape1, shape2) {
	      if (shape1 == null || shape2 == null) {
	        return null;
	      } else if (shape1.length < shape2.length) {
	        return this.computeElementwiseOpOutputShape(shape2, shape1);
	      } else if (shape2.length === 0) {
	        return shape1;
	      }
	      var outputShape = shape1.slice(0, shape1.length - shape2.length);
	      for (var k = 0; k < shape2.length; ++k) {
	        var i = shape1[shape1.length - shape2.length + k];
	        var j = shape2[k];
	        if (i == null || j == null || i < 0 || j < 0) {
	          outputShape.push(null);
	        } else if (i === 1) {
	          outputShape.push(j);
	        } else if (j === 1) {
	          outputShape.push(i);
	        } else {
	          if (i !== j) {
	            throw new ValueError('Operands could not be broadcast together with shapes ' + JSON.stringify(shape1) + ' ' + JSON.stringify(shape2));
	          }
	          outputShape.push(i);
	        }
	      }
	      return outputShape;
	    }
	  }, {
	    key: "build",
	    value: function build(inputShape) {
	      // Used purely for shape validation.
	      if (Array.isArray(inputShape) && !Array.isArray(inputShape[0])) {
	        // Make sure that inputShape is an Array of shape.
	        inputShape = [getExactlyOneShape(inputShape)];
	      }
	      inputShape = inputShape;
	      if (inputShape.length < 2) {
	        throw new ValueError('A merge layer should be called on an Array of at least 2 inputs.' + " Got ".concat(inputShape.length, " input(s)."));
	      }
	      // Make sure that there is at most one unique batch size among the input
	      // shapes.
	      var batchSizes = [];
	      var _iterator = _createForOfIteratorHelper(inputShape),
	        _step;
	      try {
	        for (_iterator.s(); !(_step = _iterator.n()).done;) {
	          var _shape = _step.value;
	          if (_shape != null && _shape[0] !== null) {
	            batchSizes.push(_shape[0]);
	          }
	        }
	      } catch (err) {
	        _iterator.e(err);
	      } finally {
	        _iterator.f();
	      }
	      batchSizes = unique$2(batchSizes);
	      if (batchSizes.length > 1) {
	        throw new ValueError("Can not merge tensors with different batch sizes. " + "Got tensors with shapes: ".concat(JSON.stringify(inputShape), "."));
	      }
	      var outputShape = inputShape[0] == null ? null : inputShape[0].slice(1);
	      for (var i = 1; i < inputShape.length; ++i) {
	        var shape = inputShape[i] == null ? null : inputShape[i].slice(1);
	        outputShape = this.computeElementwiseOpOutputShape(outputShape, shape);
	      }
	      // If the inputs have different ranks, we have to reshape them to make them
	      // broadcastable.
	      var allRanks = inputShape.map(function (shape) {
	        return shape.length;
	      });
	      if (inputShape.indexOf(null) === -1 && unique$2(allRanks).length === 1) {
	        this.reshapeRequired = false;
	      } else {
	        this.reshapeRequired = true;
	      }
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this2 = this;
	      return tidy(function () {
	        inputs = inputs;
	        if (_this2.reshapeRequired) {
	          var reshapedInputs = [];
	          var inputDims = inputs.map(function (input) {
	            return input.rank;
	          });
	          if (inputDims.indexOf(null) === -1) {
	            // If ranks of all inputs are available, we simply expand each of them
	            // at axis=1 until all of them have the same rank.
	            var maxNDim = max$2(inputDims);
	            var _iterator2 = _createForOfIteratorHelper(inputs),
	              _step2;
	            try {
	              for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	                var x = _step2.value;
	                var xNDim = x.rank;
	                for (var k = 0; k < maxNDim - xNDim; ++k) {
	                  x = expandDims$2(x, 1);
	                }
	                reshapedInputs.push(x);
	              }
	            } catch (err) {
	              _iterator2.e(err);
	            } finally {
	              _iterator2.f();
	            }
	            return _this2.mergeFunction(reshapedInputs);
	          } else {
	            // Transpose all inputs so that batch size is the last dimension.
	            // [batchSize, dim1, dim2, ...] -> [dim1, dim2, ..., batchSize]
	            var transposed = false;
	            var _iterator3 = _createForOfIteratorHelper(inputs),
	              _step3;
	            try {
	              for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
	                var _x = _step3.value;
	                var _xNDim = _x.rank;
	                if (_xNDim == null) {
	                  var xShape = _x.shape;
	                  var _batchSize = xShape[0];
	                  var _newShape = xShape.slice(1).concat([_batchSize]);
	                  var xTransposed = reshape$3(_x, [_batchSize].concat(arrayProd(xShape.slice(1))));
	                  xTransposed = transpose$2(xTransposed, [1, 0]);
	                  xTransposed = reshape$3(xTransposed, _newShape);
	                  reshapedInputs.push(xTransposed);
	                  transposed = true;
	                } else if (_xNDim > 1) {
	                  var _dims = range$2(1, _xNDim).concat([0]);
	                  reshapedInputs.push(transpose$2(_x, _dims));
	                  transposed = true;
	                } else {
	                  // We don't transpose inputs if they are 1D vectors or scalars.
	                  reshapedInputs.push(_x);
	                }
	              }
	            } catch (err) {
	              _iterator3.e(err);
	            } finally {
	              _iterator3.f();
	            }
	            var y = _this2.mergeFunction(reshapedInputs);
	            var yNDim = y.rank;
	            if (transposed) {
	              // If inputs have been transposed, we have to transpose the output
	              // too.
	              if (yNDim == null) {
	                var yShape = y.shape;
	                var _yNDim = yShape.length;
	                var batchSize = yShape[_yNDim - 1];
	                var newShape = [batchSize].concat(yShape.slice(0, yShape.length - 1));
	                y = reshape$3(transpose$2(reshape$3(y, [-1, batchSize]), [1, 0]), newShape);
	              } else if (yNDim > 1) {
	                var dims = [yNDim - 1].concat(range$2(0, yNDim - 1));
	                y = transpose$2(y, dims);
	              }
	            }
	            return y;
	          }
	        } else {
	          return _this2.mergeFunction(inputs);
	        }
	      });
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = inputShape;
	      var outputShape;
	      if (inputShape[0] == null) {
	        outputShape = null;
	      } else {
	        outputShape = inputShape[0].slice(1);
	      }
	      for (var i = 1; i < inputShape.length; ++i) {
	        var shape = inputShape[i] == null ? null : inputShape[i].slice(1);
	        outputShape = this.computeElementwiseOpOutputShape(outputShape, shape);
	      }
	      var batchSizes = [];
	      var _iterator4 = _createForOfIteratorHelper(inputShape),
	        _step4;
	      try {
	        for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
	          var _shape2 = _step4.value;
	          if (_shape2 != null && _shape2[0] !== null) {
	            batchSizes.push(_shape2[0]);
	          }
	        }
	      } catch (err) {
	        _iterator4.e(err);
	      } finally {
	        _iterator4.f();
	      }
	      batchSizes = unique$2(batchSizes);
	      if (batchSizes.length === 1) {
	        outputShape = batchSizes.concat(outputShape);
	      } else {
	        outputShape = [null].concat(outputShape);
	      }
	      return outputShape;
	    }
	  }, {
	    key: "computeMask",
	    value: function computeMask(inputs, mask) {
	      return tidy(function () {
	        if (mask == null) {
	          return null;
	        }
	        if (!Array.isArray(mask)) {
	          throw new ValueError('`mask` should be an Array');
	        }
	        if (!Array.isArray(inputs)) {
	          throw new ValueError('`inputs` should be an Array');
	        }
	        if (mask.length !== inputs.length) {
	          throw new ValueError("The Array 'inputs' and 'mask' are expected to have the same " + "length, but have different lengths " + "(".concat(inputs.length, " vs ").concat(mask.length, ")"));
	        }
	        if (mask.every(function (m) {
	          return m == null;
	        })) {
	          return null;
	        }
	        mask = mask.map(function (m) {
	          return m == null ? m : expandDims$3(m, 0);
	        });
	        var output = mask[0];
	        for (var i = 1; i < mask.length - 1; ++i) {
	          output = logicalAnd$2(output, mask[i]);
	        }
	        return output;
	      });
	    }
	  }]);
	  return Merge;
	}(Layer);
	var Add = /*#__PURE__*/function (_Merge) {
	  _inherits(Add, _Merge);
	  var _super2 = _createSuper(Add);
	  function Add(args) {
	    _classCallCheck(this, Add);
	    return _super2.call(this, args);
	  }
	  _createClass(Add, [{
	    key: "mergeFunction",
	    value: function mergeFunction(inputs) {
	      return tidy(function () {
	        var output = inputs[0].clone();
	        for (var i = 1; i < inputs.length; ++i) {
	          output = add$3(output, inputs[i]);
	        }
	        return output;
	      });
	    }
	  }]);
	  return Add;
	}(Merge);
	/** @nocollapse */
	Add.className = 'Add';
	registerClass(Add);
	/**
	 * Calculate the element-wise sum of inputs, which all have the same shape.
	 *
	 * This function can be invoked in three ways.
	 *
	 * 1. Construct an instance of `Add` layer, by using no input argument
	 *    or a single configuration argument. The resultant `Add` layer can then
	 *    be used on `tf.SymbolicTensor`s or `tf.Tensor`s. For example:
	 *
	 * ```js
	 * const addLayer = tf.layers.add();
	 *
	 * // The layer can be applied to inputs.
	 * const input1 = tf.input({shape: [2, 2]});
	 * const input2 = tf.input({shape: [2, 2]});
	 * const output = addLayer.apply([input1, input2]);
	 * console.log(output.shape);
	 * // You get [null, 2, 2], with the first dimension as the undetermined batch
	 * // dimension.
	 * ```
	 *
	 * 2. Invoke directly on an `Array` of `tf.SymbolicTensor`s. This constructs
	 *    an `Layer` object internally and calls its `apply` method on the inputs,
	 *    generating a new `tf.SymbolicTensor`. For example:
	 *
	 * ```js
	 * const input1 = tf.input({shape: [2, 2]});
	 * const input2 = tf.input({shape: [2, 2]});
	 * const output = tf.layers.add([input1, input2]);
	 * console.log(output.shape);
	 * // You get [null, 2, 2], with the first dimension as the undetermined batch
	 * // dimension.
	 * ```
	 *
	 * 3. Invoke directly on `tf.Tensor`s, i.e., concrete values. This constructs
	 *    an `Layer` object internally and calls its `apply` method on the inputs,
	 *    generating a new `tf.Tensor` as the result of the computation. For
	 * example:
	 *
	 * ```js
	 * const input1 = tf.tensor2d([1, 2, 3, 4], [2, 2]);
	 * const input2 = tf.tensor2d([10, 20, 30, 40], [2, 2]);
	 * tf.layers.add([input1, input2]).print();
	 * // Gives [[11, 22], [33, 44]].
	 *
	 */
	function add$2(config) {
	  if (Array.isArray(config)) {
	    var layer = new Add({});
	    return layer.apply(config);
	  } else {
	    return new Add(config);
	  }
	}
	var Multiply = /*#__PURE__*/function (_Merge2) {
	  _inherits(Multiply, _Merge2);
	  var _super3 = _createSuper(Multiply);
	  function Multiply(args) {
	    _classCallCheck(this, Multiply);
	    return _super3.call(this, args);
	  }
	  _createClass(Multiply, [{
	    key: "mergeFunction",
	    value: function mergeFunction(inputs) {
	      return tidy(function () {
	        var output = inputs[0].clone();
	        for (var i = 1; i < inputs.length; ++i) {
	          output = mul(output, inputs[i]);
	        }
	        return output;
	      });
	    }
	  }]);
	  return Multiply;
	}(Merge);
	/** @nocollapse */
	Multiply.className = 'Multiply';
	registerClass(Multiply);
	/**
	 * Calculate the element-wise product of inputs, which all have the same shape.
	 *
	 * This function can be invoked in three ways.
	 *
	 * 1. Construct an instance of `Multiply` layer, by using no input argument
	 *    or a single configuration argument. The resultant `Multiply` layer can
	 *    then be used on `tf.SymbolicTensor`s or `tf.Tensor`s. For example:
	 *
	 * ```js
	 * const multiplyLayer = tf.layers.multiply();
	 *
	 * // The layer can be applied to inputs.
	 * const input1 = tf.input({shape: [2, 2]});
	 * const input2 = tf.input({shape: [2, 2]});
	 * const output = multiplyLayer.apply([input1, input2]);
	 * console.log(output.shape);
	 * // You get [null, 2, 2], with the first dimension as the undetermined batch
	 * // dimension.
	 * ```
	 *
	 * 2. Invoke directly on an `Array` of `tf.SymbolicTensor`s. This constructs
	 *    an `Layer` object internally and calls its `apply` method on the inputs,
	 *    generating a new `tf.SymbolicTensor`. For example:
	 *
	 * ```js
	 * const input1 = tf.input({shape: [2, 2]});
	 * const input2 = tf.input({shape: [2, 2]});
	 * const output = tf.layers.multiply([input1, input2]);
	 * console.log(output.shape);
	 * // You get [null, 2, 2], with the first dimension as the undetermined batch
	 * // dimension.
	 * ```
	 *
	 * 3. Invoke directly on `tf.Tensor`s, i.e., concrete values. This constructs
	 *    an `Layer` object internally and calls its `apply` method on the inputs,
	 *    generating a new `tf.Tensor` as the result of the computation. For
	 * example:
	 *
	 * ```js
	 * const input1 = tf.tensor2d([1, 2, 3, 4], [2, 2]);
	 * const input2 = tf.tensor2d([10, 20, 30, 40], [2, 2]);
	 * tf.layers.multiply([input1, input2]).print();
	 * // Gives [[10, 40], [90, 160]].
	 *
	 */
	function multiply$3(config) {
	  if (Array.isArray(config)) {
	    var layer = new Multiply({});
	    return layer.apply(config);
	  } else {
	    return new Multiply(config);
	  }
	}
	var Average = /*#__PURE__*/function (_Merge3) {
	  _inherits(Average, _Merge3);
	  var _super4 = _createSuper(Average);
	  function Average(args) {
	    _classCallCheck(this, Average);
	    return _super4.call(this, args);
	  }
	  _createClass(Average, [{
	    key: "mergeFunction",
	    value: function mergeFunction(inputs) {
	      return tidy(function () {
	        var output = inputs[0].clone();
	        for (var i = 1; i < inputs.length; ++i) {
	          output = add$3(output, inputs[i]);
	        }
	        return mul(1 / inputs.length, output);
	      });
	    }
	  }]);
	  return Average;
	}(Merge);
	/** @nocollapse */
	Average.className = 'Average';
	registerClass(Average);
	/**
	 * Calculate the element-wise arithmetic mean of inputs, which all have the same
	 * shape.
	 *
	 * This function can be invoked in three ways.
	 *
	 * 1. Construct an instance of `Average` layer, by using no input argument
	 *    or a single configuration argument. The resultant `Average` layer can then
	 *    be used on `tf.SymbolicTensor`s or `tf.Tensor`s. For example:
	 *
	 * ```js
	 * const averageLayer = tf.layers.average();
	 *
	 * // The layer can be applied to inputs.
	 * const input1 = tf.input({shape: [2, 2]});
	 * const input2 = tf.input({shape: [2, 2]});
	 * const output = averageLayer.apply([input1, input2]);
	 * console.log(output.shape);
	 * // You get [null, 2, 2], with the first dimension as the undetermined batch
	 * // dimension.
	 * ```
	 *
	 * 2. Invoke directly on an `Array` of `tf.SymbolicTensor`s. This constructs
	 *    an `Layer` object internally and calls its `apply` method on the inputs,
	 *    generating a new `tf.SymbolicTensor`. For example:
	 *
	 * ```js
	 * const input1 = tf.input({shape: [2, 2]});
	 * const input2 = tf.input({shape: [2, 2]});
	 * const output = tf.layers.average([input1, input2]);
	 * console.log(output.shape);
	 * // You get [null, 2, 2], with the first dimension as the undetermined batch
	 * // dimension.
	 * ```
	 *
	 * 3. Invoke directly on `tf.Tensor`s, i.e., concrete values. This constructs
	 *    an `Layer` object internally and calls its `apply` method on the inputs,
	 *    generating a new `tf.Tensor` as the result of the computation. For
	 * example:
	 *
	 * ```js
	 * const input1 = tf.tensor2d([1, 2, 3, 4], [2, 2]);
	 * const input2 = tf.tensor2d([10, 20, 30, 40], [2, 2]);
	 * tf.layers.average([input1, input2]).print();
	 * // Gives [[5.5, 11], [16.5, 22]].
	 *
	 */
	function average$1(config) {
	  if (Array.isArray(config)) {
	    var layer = new Average({});
	    return layer.apply(config);
	  } else {
	    return new Average(config);
	  }
	}
	var Maximum = /*#__PURE__*/function (_Merge4) {
	  _inherits(Maximum, _Merge4);
	  var _super5 = _createSuper(Maximum);
	  function Maximum(args) {
	    _classCallCheck(this, Maximum);
	    return _super5.call(this, args);
	  }
	  _createClass(Maximum, [{
	    key: "mergeFunction",
	    value: function mergeFunction(inputs) {
	      return tidy(function () {
	        var output = inputs[0];
	        for (var i = 1; i < inputs.length; ++i) {
	          output = maximum$4(output, inputs[i]);
	        }
	        return output;
	      });
	    }
	  }]);
	  return Maximum;
	}(Merge);
	/** @nocollapse */
	Maximum.className = 'Maximum';
	registerClass(Maximum);
	/**
	 * Calculate the element-wise maximum of inputs, which all have the same shape.
	 *
	 * This function can be invoked in three ways.
	 *
	 * 1. Construct an instance of `Maximum` layer, by using no input argument
	 *    or a single configuration argument. The resultant `Maximum` layer can then
	 *    be used on `tf.SymbolicTensor`s or `tf.Tensor`s. For example:
	 *
	 * ```js
	 * const maximumLayer = tf.layers.maximum();
	 *
	 * // The layer can be applied to inputs.
	 * const input1 = tf.input({shape: [2, 2]});
	 * const input2 = tf.input({shape: [2, 2]});
	 * const output = maximumLayer.apply([input1, input2]);
	 * console.log(output.shape);
	 * // You get [null, 2, 2], with the first dimension as the undetermined batch
	 * // dimension.
	 * ```
	 *
	 * 2. Invoke directly on an `Array` of `tf.SymbolicTensor`s. This constructs
	 *    an `Layer` object internally and calls its `apply` method on the inputs,
	 *    generating a new `tf.SymbolicTensor`. For example:
	 *
	 * ```js
	 * const input1 = tf.input({shape: [2, 2]});
	 * const input2 = tf.input({shape: [2, 2]});
	 * const output = tf.layers.maximum([input1, input2]);
	 * console.log(output.shape);
	 * // You get [null, 2, 2], with the first dimension as the undetermined batch
	 * // dimension.
	 * ```
	 *
	 * 3. Invoke directly on `tf.Tensor`s, i.e., concrete values. This constructs
	 *    an `Layer` object internally and calls its `apply` method on the inputs,
	 *    generating a new `tf.Tensor` as the result of the computation. For
	 * example:
	 *
	 * ```js
	 * const input1 = tf.tensor2d([1, 20, 3, 40], [2, 2]);
	 * const input2 = tf.tensor2d([10, 2, 30, 4], [2, 2]);
	 * tf.layers.maximum([input1, input2]).print();
	 * // Gives [[10, 20], [30, 40]].
	 *
	 */
	function maximum$3(config) {
	  if (Array.isArray(config)) {
	    var layer = new Maximum({});
	    return layer.apply(config);
	  } else {
	    return new Maximum(config);
	  }
	}
	var Minimum = /*#__PURE__*/function (_Merge5) {
	  _inherits(Minimum, _Merge5);
	  var _super6 = _createSuper(Minimum);
	  function Minimum(args) {
	    _classCallCheck(this, Minimum);
	    return _super6.call(this, args);
	  }
	  _createClass(Minimum, [{
	    key: "mergeFunction",
	    value: function mergeFunction(inputs) {
	      return tidy(function () {
	        var output = inputs[0];
	        for (var i = 1; i < inputs.length; ++i) {
	          output = minimum$4(output, inputs[i]);
	        }
	        return output;
	      });
	    }
	  }]);
	  return Minimum;
	}(Merge);
	/** @nocollapse */
	Minimum.className = 'Minimum';
	registerClass(Minimum);
	/**
	 * Calculate the element-wise minimum of inputs, which all have the same shape.
	 *
	 * This function can be invoked in three ways.
	 *
	 * 1. Construct an instance of `Minimum` layer, by using no input argument
	 *    or a single configuration argument. The resultant `Minimum` layer can then
	 *    be used on `tf.SymbolicTensor`s or `tf.Tensor`s. For example:
	 *
	 * ```js
	 * const minimumLayer = tf.layers.minimum();
	 *
	 * // The layer can be applied to inputs.
	 * const input1 = tf.input({shape: [2, 2]});
	 * const input2 = tf.input({shape: [2, 2]});
	 * const output = minimumLayer.apply([input1, input2]);
	 * console.log(output.shape);
	 * // You get [null, 2, 2], with the first dimension as the undetermined batch
	 * // dimension.
	 * ```
	 *
	 * 2. Invoke directly on an `Array` of `tf.SymbolicTensor`s. This constructs
	 *    an `Layer` object internally and calls its `apply` method on the inputs,
	 *    generating a new `tf.SymbolicTensor`. For example:
	 *
	 * ```js
	 * const input1 = tf.input({shape: [2, 2]});
	 * const input2 = tf.input({shape: [2, 2]});
	 * const output = tf.layers.minimum([input1, input2]);
	 * console.log(output.shape);
	 * // You get [null, 2, 2], with the first dimension as the undetermined batch
	 * // dimension.
	 * ```
	 *
	 * 3. Invoke directly on `tf.Tensor`s, i.e., concrete values. This constructs
	 *    an `Layer` object internally and calls its `apply` method on the inputs,
	 *    generating a new `tf.Tensor` as the result of the computation. For
	 * example:
	 *
	 * ```js
	 * const input1 = tf.tensor2d([1, 20, 3, 40], [2, 2]);
	 * const input2 = tf.tensor2d([10, 2, 30, 4], [2, 2]);
	 * tf.layers.minimum([input1, input2]).print();
	 * // Gives [[1, 2], [3, 4]].
	 *
	 */
	function minimum$3(config) {
	  if (Array.isArray(config)) {
	    var layer = new Minimum({});
	    return layer.apply(config);
	  } else {
	    return new Minimum(config);
	  }
	}
	var Concatenate = /*#__PURE__*/function (_Merge6) {
	  _inherits(Concatenate, _Merge6);
	  var _super7 = _createSuper(Concatenate);
	  function Concatenate(args) {
	    var _this3;
	    _classCallCheck(this, Concatenate);
	    _this3 = _super7.call(this, args);
	    _this3.DEFAULT_AXIS = -1;
	    if (args == null) {
	      args = {};
	    }
	    _this3.axis = args.axis == null ? _this3.DEFAULT_AXIS : args.axis;
	    _this3.supportsMasking = true;
	    _this3.reshapeRequired = false;
	    return _this3;
	  }
	  _createClass(Concatenate, [{
	    key: "build",
	    value: function build(inputShape) {
	      // Used purely for shape validation.]
	      if (!(Array.isArray(inputShape) && Array.isArray(inputShape[0])) || inputShape.length === 1) {
	        throw new ValueError('A `Concatenate` layer should be called on a list of at least 2 ' + 'inputs');
	      }
	      inputShape = inputShape;
	      var allNoneShape = true;
	      var _iterator5 = _createForOfIteratorHelper(inputShape),
	        _step5;
	      try {
	        for (_iterator5.s(); !(_step5 = _iterator5.n()).done;) {
	          var _shape3 = _step5.value;
	          if (_shape3 != null) {
	            allNoneShape = false;
	            break;
	          }
	        }
	      } catch (err) {
	        _iterator5.e(err);
	      } finally {
	        _iterator5.f();
	      }
	      if (allNoneShape) {
	        return;
	      }
	      var shapeSet = [];
	      for (var i = 0; i < inputShape.length; ++i) {
	        var shapeWithoutConcatAxis = inputShape[i].slice();
	        shapeWithoutConcatAxis.splice(this.axis, 1);
	        var exists = false;
	        var _iterator6 = _createForOfIteratorHelper(shapeSet),
	          _step6;
	        try {
	          for (_iterator6.s(); !(_step6 = _iterator6.n()).done;) {
	            var shape = _step6.value;
	            if (arraysEqual(shape, shapeWithoutConcatAxis)) {
	              exists = true;
	              break;
	            }
	          }
	        } catch (err) {
	          _iterator6.e(err);
	        } finally {
	          _iterator6.f();
	        }
	        if (!exists) {
	          shapeSet.push(shapeWithoutConcatAxis);
	        }
	      }
	      if (shapeSet.length > 1) {
	        throw new ValueError('A `Concatenate` layer requires inputs with matching shapes ' + 'except for the concat axis. Got input shapes: ' + JSON.stringify(inputShape));
	      }
	    }
	  }, {
	    key: "mergeFunction",
	    value: function mergeFunction(inputs) {
	      var _this4 = this;
	      return tidy(function () {
	        return concatenate$2(inputs, _this4.axis);
	      });
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      if (!(Array.isArray(inputShape) && Array.isArray(inputShape[0]))) {
	        throw new ValueError('A `Concatenate` layer should be called on a list of inputs.');
	      }
	      var inputShapes = inputShape;
	      var outputShape = inputShapes[0].slice();
	      var axis = this.axis < 0 ? outputShape.length + this.axis : this.axis;
	      // Porting Note: the line above is because TypeScript doesn't support
	      //   negative indices.
	      var _iterator7 = _createForOfIteratorHelper(inputShapes.slice(1)),
	        _step7;
	      try {
	        for (_iterator7.s(); !(_step7 = _iterator7.n()).done;) {
	          var shape = _step7.value;
	          if (outputShape[axis] == null || shape[axis] == null) {
	            outputShape[axis] = null;
	            break;
	          }
	          outputShape[axis] += shape[axis];
	        }
	      } catch (err) {
	        _iterator7.e(err);
	      } finally {
	        _iterator7.f();
	      }
	      return outputShape;
	    }
	  }, {
	    key: "computeMask",
	    value: function computeMask(inputs, mask) {
	      var _this5 = this;
	      if (mask == null) {
	        return null;
	      }
	      if (!Array.isArray(mask)) {
	        throw new ValueError('`mask` should be an array for Concatenate');
	      }
	      if (!Array.isArray(inputs)) {
	        throw new ValueError('`inputs` should be an array for Concatenate');
	      }
	      if (mask.length !== inputs.length) {
	        throw new ValueError("Mismatch in the length of mask (".concat(mask.length, ") ") + "and the legnth of inputs (".concat(inputs.length, ")"));
	      }
	      return tidy(function () {
	        var allNullMasks = true;
	        mask.forEach(function (m) {
	          if (m != null) {
	            allNullMasks = false;
	            return;
	          }
	        });
	        if (allNullMasks) {
	          return null;
	        }
	        var outputMasks = [];
	        for (var i = 0; i < inputs.length; ++i) {
	          if (mask[i] == null) {
	            // Input is unmasked. Append all 1's to masks.
	            outputMasks.push(cast$3(onesLike$3(inputs[i]), 'bool'));
	          } else if (mask[i].rank < inputs[i].rank) {
	            // Mask is smaller than the input, expand it.
	            outputMasks.push(expandDims$3(mask[i], -1));
	          } else {
	            outputMasks.push(mask[i]);
	          }
	        }
	        var concatenatedMasks = concat$2(outputMasks, _this5.axis);
	        return all$2(concatenatedMasks, -1, false);
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        'axis': this.axis
	      };
	      var baseConfig = _get(_getPrototypeOf(Concatenate.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return Concatenate;
	}(Merge);
	/** @nocollapse */
	Concatenate.className = 'Concatenate';
	registerClass(Concatenate);
	/**
	 * Concatenate an `Array` of inputs.
	 *
	 * This function can be invoked in three ways.
	 *
	 * 1. Construct an instance of `Concatenate` layer, by using no input argument
	 *    or a single configuration argument. The resultant `Concatenate` layer can
	 *    then be used on `tf.SymbolicTensor`s or `tf.Tensor`s. For example:
	 *
	 * ```js
	 * const concatLayer = tf.layers.concatenate();
	 *
	 * // The layer can be applied to inputs.
	 * const input1 = tf.input({shape: [2, 3]});
	 * const input2 = tf.input({shape: [2, 4]});
	 * const output = concatLayer.apply([input1, input2]);
	 * console.log(output.shape);
	 * // You get [null, 2, 7], with the first dimension as the undetermined batch
	 * // dimension and the last dimension as the result of concatenating the
	 * // last dimensions of the two inputs.
	 * ```
	 *
	 * 2. Invoke directly on an `Array` of `tf.SymbolicTensor`s. This constructs
	 *    an `Layer` object internally and calls its `apply` method on the inputs,
	 *    generating a new `tf.SymbolicTensor`. For example:
	 *
	 * ```js
	 * const input1 = tf.input({shape: [2, 3]});
	 * const input2 = tf.input({shape: [2, 4]});
	 * const output = tf.layers.concatenate([input1, input2]);
	 * console.log(output.shape);
	 * // You get [null, 2, 2], with the first dimension as the undetermined batch
	 * // dimension and the last dimension as the result of concatenating the
	 * // last dimensions of the two inputs.
	 * ```
	 *
	 * 3. Invoke directly on `tf.Tensor`s, i.e., concrete values. This constructs
	 *    an `Layer` object internally and calls its `apply` method on the inputs,
	 *    generating a new `tf.Tensor` as the result of the computation. For
	 * example:
	 *
	 * ```js
	 * const input1 = tf.tensor2d([[1, 2], [3, 4]], [2, 2]);
	 * const input2 = tf.tensor2d([[10, 20], [30, 40]], [2, 2]);
	 * tf.layers.concatenate([input1, input2]).print();
	 * // Gives [[1, 2, 10, 20], [3, 4, 30, 40]].
	 *
	 */
	function concatenate$1(config) {
	  if (Array.isArray(config)) {
	    var layer = new Concatenate({});
	    return layer.apply(config);
	  } else {
	    return new Concatenate(config);
	  }
	}
	/**
	 * Interpretable potentially negative axis index.
	 *
	 * For example, given axis = -1, and dim = 3, this function will return 2.
	 *
	 * @param axis The axis index, may be a positive, zero or negative integer.
	 * @param dim Total number of dimensions, a positive integer.
	 * @returns A non-negative axis index equivalent to the input `axis`.
	 */
	function interpretAxis(axis, dim) {
	  while (axis < 0) {
	    axis += dim;
	  }
	  return axis;
	}
	function batchDot(x, y, axes) {
	  if (x.shape.length > 3 || y.shape.length > 3) {
	    throw new NotImplementedError('batchDot is not implemented for tensors of 4D or higher rank yet');
	  }
	  assert$1(x.shape.length >= 2, function () {
	    return "batchDot requires the rank of x to be >= 2, " + "but got ".concat(x.shape.length);
	  });
	  assert$1(x.shape.length >= 2, function () {
	    return "batchDot requires the rank of y to be >= 2, " + "but got ".concat(y.shape.length);
	  });
	  if (typeof axes === 'number') {
	    axes = [axes, axes];
	  }
	  if (x.dtype === 'complex64' || y.dtype === 'complex64') {
	    throw new NotImplementedError('batchDot is not implemented for complex64-type Tensors yet.');
	  }
	  var xNDim = x.shape.length;
	  var yNDim = y.shape.length;
	  if (axes == null) {
	    // Behave like batchMatmul by default.
	    axes = [xNDim - 1, yNDim - 2];
	  }
	  var axesArray = axes;
	  return tidy(function () {
	    var diff;
	    if (xNDim > yNDim) {
	      diff = xNDim - yNDim;
	      var diffShape = [];
	      for (var i = 0; i < diff; ++i) {
	        diffShape.push(1);
	      }
	      y = reshape$3(y, y.shape.concat(diffShape));
	    } else if (yNDim > xNDim) {
	      diff = yNDim - xNDim;
	      var _diffShape = [];
	      for (var _i = 0; _i < diff; ++_i) {
	        _diffShape.push(1);
	      }
	      x = reshape$3(x, x.shape.concat(_diffShape));
	    } else {
	      diff = 0;
	    }
	    var out;
	    if (x.shape.length === 2 && y.shape.length === 2) {
	      if (axesArray[0] === axesArray[1]) {
	        out = sum$3(mul(x, y), axesArray[0]);
	      } else {
	        out = sum$3(mul(transpose$2(x, [1, 0]), y), axesArray[1]);
	      }
	    } else {
	      var adjX = axesArray[0] !== x.shape.length - 1;
	      var adjY = axesArray[1] === y.shape.length - 1;
	      out = matMul$1(x, y, adjX, adjY);
	    }
	    if (diff > 0) {
	      var idx;
	      if (xNDim > yNDim) {
	        idx = xNDim + yNDim - 3;
	      } else {
	        idx = xNDim - 1;
	      }
	      var squeezeAxes = [];
	      for (var _i2 = idx; _i2 < idx + diff; ++_i2) {
	        squeezeAxes.push(_i2);
	      }
	      out = squeeze(out, squeezeAxes);
	    }
	    if (out.shape.length === 1) {
	      out = expandDims$3(out, 1);
	    }
	    return out;
	  });
	}
	var Dot = /*#__PURE__*/function (_Merge7) {
	  _inherits(Dot, _Merge7);
	  var _super8 = _createSuper(Dot);
	  function Dot(args) {
	    var _this6;
	    _classCallCheck(this, Dot);
	    _this6 = _super8.call(this, args);
	    _this6.axes = args.axes;
	    _this6.normalize = args.normalize == null ? false : args.normalize;
	    _this6.supportsMasking = true;
	    _this6.reshapeRequired = false;
	    return _this6;
	  }
	  _createClass(Dot, [{
	    key: "build",
	    value: function build(inputShape) {
	      assert$1(Array.isArray(inputShape) && inputShape.length === 2 && Array.isArray(inputShape[0]) && Array.isArray(inputShape[1]), function () {
	        return 'A `Dot` layer should be called on a list of exactly 2 inputs.';
	      });
	      var shape1 = inputShape[0];
	      var shape2 = inputShape[1];
	      if (shape1.length > 3 || shape2.length > 3) {
	        throw new NotImplementedError('Dot layer does not support tensors of 4D or higher rank yet.');
	      }
	      var axes = this.interpretAxes(shape1, shape2);
	      if (shape1[axes[0]] !== shape2[axes[1]]) {
	        throw new ValueError("Dimension incompatibility: " + "".concat(shape1[axes[0]], " !== ").concat(shape2[axes[1]]));
	      }
	    }
	  }, {
	    key: "mergeFunction",
	    value: function mergeFunction(inputs) {
	      if (inputs.length !== 2) {
	        throw new ValueError('A `Dot` layer must be called on exactly 2 inputs, ' + "but received ".concat(inputs.length, " input(s)."));
	      }
	      var x1 = inputs[0];
	      var x2 = inputs[1];
	      var axes;
	      if (!Array.isArray(this.axes)) {
	        axes = [interpretAxis(this.axes, x1.shape.length), interpretAxis(this.axes, x2.shape.length)];
	      } else {
	        axes = this.axes.map(function (axis, i) {
	          return interpretAxis(axis, inputs[i].shape.length);
	        });
	      }
	      if (this.normalize) {
	        x1 = l2Normalize(x1, axes[0]);
	        x2 = l2Normalize(x2, axes[1]);
	      }
	      return batchDot(x1, x2, axes);
	    }
	  }, {
	    key: "interpretAxes",
	    value: function interpretAxes(shape1, shape2) {
	      var axes;
	      if (!Array.isArray(this.axes)) {
	        // `this.axes` is a single integer.
	        axes = [interpretAxis(this.axes, shape1.length), interpretAxis(this.axes, shape2.length)];
	      } else {
	        // `this.axes` is an Array of integers.
	        axes = this.axes;
	      }
	      return axes;
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      assert$1(Array.isArray(inputShape) && inputShape.length === 2 && Array.isArray(inputShape[0]) && Array.isArray(inputShape[1]), function () {
	        return 'A `Dot` layer should be called on a list of exactly 2 inputs.';
	      });
	      var shape1 = inputShape[0].slice();
	      var shape2 = inputShape[1].slice();
	      if (shape1.length > 3 || shape2.length > 3) {
	        throw new NotImplementedError('Dot layer does not support tensors of 4D or higher rank yet.');
	      }
	      var axes = this.interpretAxes(shape1, shape2);
	      shape1.splice(axes[0], 1);
	      shape2.splice(axes[1], 1);
	      shape2.splice(0, 1);
	      var outputShape = shape1.concat(shape2);
	      if (outputShape.length === 1) {
	        outputShape.push(1);
	      }
	      return outputShape;
	    }
	  }, {
	    key: "computeMask",
	    value: function computeMask(inputs, mask) {
	      return null;
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        'axes': this.axes,
	        'normalize': this.normalize
	      };
	      var baseConfig = _get(_getPrototypeOf(Dot.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return Dot;
	}(Merge);
	/** @nocollapse */
	Dot.className = 'Dot';
	registerClass(Dot);
	// TODO(cais): Add functional interfaces for the merge layers.

	var GaussianNoise = /*#__PURE__*/function (_Layer) {
	  _inherits(GaussianNoise, _Layer);
	  var _super = _createSuper(GaussianNoise);
	  function GaussianNoise(args) {
	    var _this;
	    _classCallCheck(this, GaussianNoise);
	    _this = _super.call(this, args);
	    _this.supportsMasking = true;
	    _this.stddev = args.stddev;
	    return _this;
	  }
	  _createClass(GaussianNoise, [{
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      return inputShape;
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var baseConfig = _get(_getPrototypeOf(GaussianNoise.prototype), "getConfig", this).call(this);
	      var config = {
	        stddev: this.stddev
	      };
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this2 = this;
	      return tidy(function () {
	        _this2.invokeCallHook(inputs, kwargs);
	        var input = getExactlyOneTensor(inputs);
	        var noised = function noised() {
	          return add$3(randomNormal$1(input.shape, 0, _this2.stddev), input);
	        };
	        var output = inTrainPhase(noised, function () {
	          return input;
	        }, kwargs['training'] || false);
	        return output;
	      });
	    }
	  }]);
	  return GaussianNoise;
	}(Layer);
	/** @nocollapse */
	GaussianNoise.className = 'GaussianNoise';
	registerClass(GaussianNoise);
	var GaussianDropout = /*#__PURE__*/function (_Layer2) {
	  _inherits(GaussianDropout, _Layer2);
	  var _super2 = _createSuper(GaussianDropout);
	  function GaussianDropout(args) {
	    var _this3;
	    _classCallCheck(this, GaussianDropout);
	    _this3 = _super2.call(this, args);
	    _this3.supportsMasking = true;
	    _this3.rate = args.rate;
	    return _this3;
	  }
	  _createClass(GaussianDropout, [{
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      return inputShape;
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var baseConfig = _get(_getPrototypeOf(GaussianDropout.prototype), "getConfig", this).call(this);
	      var config = {
	        rate: this.rate
	      };
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this4 = this;
	      return tidy(function () {
	        _this4.invokeCallHook(inputs, kwargs);
	        var input = getExactlyOneTensor(inputs);
	        if (_this4.rate > 0 && _this4.rate < 1) {
	          var noised = function noised() {
	            var stddev = Math.sqrt(_this4.rate / (1 - _this4.rate));
	            return mul(input, randomNormal$1(input.shape, 1, stddev));
	          };
	          return inTrainPhase(noised, function () {
	            return input;
	          }, kwargs['training'] || false);
	        }
	        return input;
	      });
	    }
	  }]);
	  return GaussianDropout;
	}(Layer);
	/** @nocollapse */
	GaussianDropout.className = 'GaussianDropout';
	registerClass(GaussianDropout);
	/**
	 * Applies Alpha Dropout to the input.
	 *
	 * As it is a regularization layer, it is only active at training time.
	 *
	 * Alpha Dropout is a `Dropout` that keeps mean and variance of inputs
	 * to their original values, in order to ensure the self-normalizing property
	 * even after this dropout.
	 * Alpha Dropout fits well to Scaled Exponential Linear Units
	 * by randomly setting activations to the negative saturation value.
	 *
	 * Arguments:
	 *   - `rate`: float, drop probability (as with `Dropout`).
	 *     The multiplicative noise will have
	 *     standard deviation `sqrt(rate / (1 - rate))`.
	 *   - `noise_shape`: A 1-D `Tensor` of type `int32`, representing the
	 *     shape for randomly generated keep/drop flags.
	 *
	 * Input shape:
	 *   Arbitrary. Use the keyword argument `inputShape`
	 *   (tuple of integers, does not include the samples axis)
	 *   when using this layer as the first layer in a model.
	 *
	 * Output shape:
	 *   Same shape as input.
	 *
	 * References:
	 *   - [Self-Normalizing Neural Networks](https://arxiv.org/abs/1706.02515)
	 */
	var AlphaDropout = /*#__PURE__*/function (_Layer3) {
	  _inherits(AlphaDropout, _Layer3);
	  var _super3 = _createSuper(AlphaDropout);
	  function AlphaDropout(args) {
	    var _this5;
	    _classCallCheck(this, AlphaDropout);
	    _this5 = _super3.call(this, args);
	    _this5.supportsMasking = true;
	    _this5.rate = args.rate;
	    _this5.noiseShape = args.noiseShape;
	    return _this5;
	  }
	  _createClass(AlphaDropout, [{
	    key: "_getNoiseShape",
	    value: function _getNoiseShape(inputs) {
	      return this.noiseShape || getExactlyOneTensor(inputs).shape;
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      return inputShape;
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var baseConfig = _get(_getPrototypeOf(AlphaDropout.prototype), "getConfig", this).call(this);
	      var config = {
	        rate: this.rate
	      };
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this6 = this;
	      return tidy(function () {
	        if (_this6.rate < 1 && _this6.rate > 0) {
	          var noiseShape = _this6._getNoiseShape(inputs);
	          var droppedInputs = function droppedInputs() {
	            var input = getExactlyOneTensor(inputs);
	            var alpha = 1.6732632423543772848170429916717;
	            var scale = 1.0507009873554804934193349852946;
	            var alphaP = -alpha * scale;
	            var keptIdx = greaterEqual$2(randomUniform$1(noiseShape), _this6.rate);
	            keptIdx = cast$2(keptIdx, 'float32'); // get default dtype.
	            // Get affine transformation params.
	            var a = Math.pow((1 - _this6.rate) * (1 + _this6.rate * Math.pow(alphaP, 2)), -0.5);
	            var b = -a * alphaP * _this6.rate;
	            // Apply mask.
	            var x = add$3(mul(input, keptIdx), mul(add$3(keptIdx, -1), alphaP));
	            return add$3(mul(x, a), b);
	          };
	          return inTrainPhase(droppedInputs, function () {
	            return getExactlyOneTensor(inputs);
	          }, kwargs['training'] || false);
	        }
	        return inputs;
	      });
	    }
	  }]);
	  return AlphaDropout;
	}(Layer);
	/** @nocollapse */
	AlphaDropout.className = 'AlphaDropout';
	registerClass(AlphaDropout);

	/**
	 * Applies batch normalization on x given mean, var, beta and gamma.
	 *
	 * I.e. returns:
	 *   `output = (x - mean) / (sqrt(var) + epsilon) * gamma + beta`
	 *
	 * @param x Input tensor.
	 * @param mean Mean of batch.
	 * @param variance Variance of batch.
	 * @param beta Tensor with which to center the input.
	 * @param gamma Tensor by which to scale the input.
	 * @param epsilon Fuzz factor.
	 * @returns The result of the batch normalization.
	 */
	function batchNormalization$1(x, mean, variance, beta, gamma) {
	  var epsilon = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : 1e-3;
	  var out;
	  if (x.rank === 2) {
	    out = batchNorm2d(x, mean, variance, beta, gamma, epsilon);
	  } else if (x.rank === 3) {
	    // TODO(cais): Check rank; give proper error message.
	    out = batchNorm3d(x, mean, variance, beta, gamma, epsilon);
	  } else if (x.rank === 4) {
	    out = batchNorm4d(x, mean, variance, beta, gamma, epsilon);
	  } else {
	    throw new NotImplementedError("batchNormalization is not implemented for array of rank ".concat(x.rank, " ") + "yet");
	  }
	  return out;
	}
	/**
	 * Non-broadcasting batch normalization for use in training (not inference).
	 *
	 * The input is normalized to zero mean and unit variance along the
	 * `reductionAxes`, followed by scaling with `gamma` and shifted by `beta`.
	 * The result of that is returned as the first element
	 * of the returned `Array`. The other two elements are the mean and variance,
	 * respectively.
	 *
	 * @param x Input tensor to be normalized.
	 * @param gamma Tensor by which to scale the input.
	 * @param beta Tensor by which to center the input.
	 * @param reductionAxes Axes over which to normalize.
	 * @param epsilon Fuzz factor.
	 * @returns An `Array` of three `Tensors`:
	 *   [normalized tensor, mean of input, variance of input].
	 */
	function regularNormalizeBatchInTraining(x, gamma, beta, reductionAxes) {
	  var epsilon = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 1e-3;
	  return tidy(function () {
	    var meanAndVariance = moments(x, reductionAxes);
	    var mean = meanAndVariance.mean;
	    var variance = meanAndVariance.variance;
	    var normed = batchNormalization$1(x, mean, variance, beta, gamma, epsilon);
	    return [normed, mean, variance];
	  });
	}
	/**
	 * Broadcasting batch normalization for use in training (not inference).
	 *
	 * The input is normalized to zero mean and unit variance along the
	 * `reductionAxes`, followed by scaling with `gamma` and shifted by `beta`.
	 * The result of that is returned as the first element
	 * of the returned `Array`. The other two elements are the mean and variance,
	 * respectively.
	 *
	 * @param x Input tensor to be normalized.
	 * @param gamma Tensor by which to scale the input.
	 * @param beta Tensor by which to center the input.
	 * @param reductionAxes Axes over which to normalize.
	 * @param epsilon Fuzz factor.
	 * @returns An `Array` of three `Tensors`:
	 *   [normalized tensor, mean of input, variance of input].
	 */
	function broadcastNormalizeBatchInTraining(x, gamma, beta, reductionAxes) {
	  var epsilon = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 1e-3;
	  return tidy(function () {
	    var meanAndVariance = moments(x, reductionAxes);
	    var mean = meanAndVariance.mean;
	    var variance = meanAndVariance.variance;
	    var targetShape = [];
	    var _iterator = _createForOfIteratorHelper(range$2(0, x.rank)),
	      _step;
	    try {
	      for (_iterator.s(); !(_step = _iterator.n()).done;) {
	        var axis = _step.value;
	        if (reductionAxes.indexOf(axis) !== -1) {
	          targetShape.push(1);
	        } else {
	          targetShape.push(x.shape[axis]);
	        }
	      }
	    } catch (err) {
	      _iterator.e(err);
	    } finally {
	      _iterator.f();
	    }
	    var broadcastMean = reshape$3(mean, targetShape);
	    var broadcastVariance = reshape$3(variance, targetShape);
	    var broadcastGamma = gamma == null ? null : reshape$3(gamma, targetShape);
	    var broadcastBeta = beta == null ? null : reshape$3(beta, targetShape);
	    var normed = batchNormalization$1(x, broadcastMean, broadcastVariance, broadcastBeta, broadcastGamma, epsilon);
	    return [normed, mean, variance];
	  });
	}
	/**
	 * Batch normalization for use in training (not inference).
	 *
	 * @param x Input tensor to be normalized.
	 * @param gamma Tensor by which to scale the input.
	 * @param beta Tensor by which to center the input.
	 * @param reductionAxes Axes over which to normalize.
	 * @param epsilon Fuzz factor.
	 * @returns An `Array` of three `Tensors`:
	 *   [normalized tensor, mean of input, variance of input].
	 */
	function normalizeBatchInTraining(x, gamma, beta, reductionAxes) {
	  var epsilon = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 1e-3;
	  if (arraysEqual(reductionAxes.slice().sort(), range$2(0, x.rank - 1))) {
	    return regularNormalizeBatchInTraining(x, gamma, beta, reductionAxes, epsilon);
	  } else {
	    return broadcastNormalizeBatchInTraining(x, gamma, beta, reductionAxes, epsilon);
	  }
	}
	var BatchNormalization = /*#__PURE__*/function (_Layer) {
	  _inherits(BatchNormalization, _Layer);
	  var _super = _createSuper(BatchNormalization);
	  function BatchNormalization(args) {
	    var _this;
	    _classCallCheck(this, BatchNormalization);
	    if (args == null) {
	      args = {};
	    }
	    _this = _super.call(this, args);
	    _this.supportsMasking = true;
	    _this.axis = args.axis == null ? -1 : args.axis;
	    _this.momentum = args.momentum == null ? 0.99 : args.momentum;
	    _this.epsilon = args.epsilon == null ? 1e-3 : args.epsilon;
	    _this.center = args.center == null ? true : args.center;
	    _this.scale = args.scale == null ? true : args.scale;
	    _this.betaInitializer = getInitializer(args.betaInitializer || 'zeros');
	    _this.gammaInitializer = getInitializer(args.gammaInitializer || 'ones');
	    _this.movingMeanInitializer = getInitializer(args.movingMeanInitializer || 'zeros');
	    _this.movingVarianceInitializer = getInitializer(args.movingVarianceInitializer || 'ones');
	    _this.betaConstraint = getConstraint(args.betaConstraint);
	    _this.gammaConstraint = getConstraint(args.gammaConstraint);
	    _this.betaRegularizer = getRegularizer(args.betaRegularizer);
	    _this.gammaRegularizer = getRegularizer(args.gammaRegularizer);
	    return _this;
	  }
	  _createClass(BatchNormalization, [{
	    key: "build",
	    value: function build(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var axis = this.axis >= 0 ? this.axis : this.axis + inputShape.length;
	      var dim = inputShape[axis];
	      if (dim == null) {
	        throw new ValueError("Axis ".concat(axis, " of input tensor should have a defined dimension but ") + "the layer received an input with shape " + "".concat(JSON.stringify(inputShape), "."));
	      }
	      this.inputSpec = [new InputSpec({
	        ndim: inputShape.length,
	        axes: _defineProperty({}, axis, dim)
	      })];
	      var shape = [dim];
	      if (this.scale) {
	        this.gamma = this.addWeight('gamma', shape, null, this.gammaInitializer, this.gammaRegularizer, true, this.gammaConstraint);
	      }
	      if (this.center) {
	        this.beta = this.addWeight('beta', shape, null, this.betaInitializer, this.betaRegularizer, true, this.betaConstraint);
	      }
	      this.movingMean = this.addWeight('moving_mean', shape, null, this.movingMeanInitializer, null, false);
	      this.movingVariance = this.addWeight('moving_variance', shape, null, this.movingVarianceInitializer, null, false);
	      this.built = true;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this2 = this;
	      return tidy(function () {
	        var training = kwargs['training'] == null ? false : kwargs['training'];
	        var input = getExactlyOneTensor(inputs);
	        var inputShape = input.shape;
	        var ndim = inputShape.length;
	        var reductionAxes = range$2(0, ndim);
	        var axis = _this2.axis >= 0 ? _this2.axis : _this2.axis + ndim;
	        reductionAxes.splice(axis, 1);
	        var broadcastShape = pyListRepeat(1, ndim);
	        broadcastShape[axis] = inputShape[axis];
	        var sortedReductionAxes = reductionAxes.slice();
	        sortedReductionAxes.sort();
	        var needsBroadcasting = !arraysEqual(sortedReductionAxes, range$2(0, ndim).slice(0, ndim - 1));
	        var normalizeInference = function normalizeInference() {
	          if (needsBroadcasting) {
	            var broadcastMovingMean = reshape$3(_this2.movingMean.read(), broadcastShape);
	            var broadcastMovingVariance = reshape$3(_this2.movingVariance.read(), broadcastShape);
	            var broadcastBeta = _this2.center ? reshape$3(_this2.beta.read(), broadcastShape) : null;
	            var broadcastGamma = _this2.scale ? reshape$3(_this2.gamma.read(), broadcastShape) : null;
	            return batchNormalization$1(input, broadcastMovingMean, broadcastMovingVariance, broadcastBeta, broadcastGamma, _this2.epsilon);
	          } else {
	            return batchNormalization$1(input, _this2.movingMean.read(), _this2.movingVariance.read(), _this2.beta == null ? null : _this2.beta.read(), _this2.gamma == null ? null : _this2.gamma.read(), _this2.epsilon);
	          }
	        };
	        if (!training) {
	          return normalizeInference();
	        }
	        var _normalizeBatchInTrai = normalizeBatchInTraining(input, _this2.gamma.read(), _this2.beta.read(), reductionAxes, _this2.epsilon),
	          _normalizeBatchInTrai2 = _slicedToArray(_normalizeBatchInTrai, 3),
	          normedTraining = _normalizeBatchInTrai2[0],
	          mean = _normalizeBatchInTrai2[1],
	          variance = _normalizeBatchInTrai2[2];
	        var doMovingAverage = function doMovingAverage(variable, value, momentum) {
	          tidy(function () {
	            var decay = 1 - momentum;
	            var origValue = variable.read();
	            var updateDelta = mul(sub$2(origValue, value), decay);
	            variable.write(sub$2(origValue, updateDelta));
	          });
	        };
	        // Perform updates to moving mean and moving variance for training.
	        // Porting Note: In PyKeras, these updates to `movingMean` and
	        //   `movingAverage` are done as a deferred Graph, added to the `Layer`'s
	        //   `update`s using the `add_update()` method. Here we do it imperatively
	        //   and encapsulate the updates in a function that is invoked
	        //   immediately.
	        var updateMovingMeanAndVariance = function updateMovingMeanAndVariance() {
	          doMovingAverage(_this2.movingMean, mean, _this2.momentum);
	          doMovingAverage(_this2.movingVariance, variance, _this2.momentum);
	        };
	        updateMovingMeanAndVariance();
	        return normedTraining;
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        axis: this.axis,
	        momentum: this.momentum,
	        epsilon: this.epsilon,
	        center: this.center,
	        scale: this.scale,
	        betaInitializer: serializeInitializer(this.betaInitializer),
	        gammaInitializer: serializeInitializer(this.gammaInitializer),
	        movingMeanInitializer: serializeInitializer(this.movingMeanInitializer),
	        movingVarianceInitializer: serializeInitializer(this.movingVarianceInitializer),
	        betaRegularizer: serializeRegularizer(this.betaRegularizer),
	        gammaRegularizer: serializeRegularizer(this.gammaRegularizer),
	        betaConstraint: serializeConstraint(this.betaConstraint),
	        gammaConstraint: serializeConstraint(this.gammaConstraint)
	      };
	      var baseConfig = _get(_getPrototypeOf(BatchNormalization.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return BatchNormalization;
	}(Layer);
	/** @nocollapse */
	BatchNormalization.className = 'BatchNormalization';
	registerClass(BatchNormalization);
	var LayerNormalization = /*#__PURE__*/function (_Layer2) {
	  _inherits(LayerNormalization, _Layer2);
	  var _super2 = _createSuper(LayerNormalization);
	  function LayerNormalization(args) {
	    var _this3;
	    _classCallCheck(this, LayerNormalization);
	    if (args == null) {
	      args = {};
	    }
	    _this3 = _super2.call(this, args);
	    _this3.axis = args.axis == null ? -1 : args.axis;
	    if (typeof _this3.axis === 'number') {
	      if (!Number.isInteger(_this3.axis)) {
	        throw new Error("Expected axis to be an integer, but received ".concat(_this3.axis));
	      }
	    } else if (Array.isArray(_this3.axis)) {
	      var _iterator2 = _createForOfIteratorHelper(_this3.axis),
	        _step2;
	      try {
	        for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	          var axis = _step2.value;
	          if (!Number.isInteger(axis)) {
	            throw new Error("Expected axis to be an array of integers, " + "but received ".concat(JSON.stringify(_this3.axis)));
	          }
	        }
	      } catch (err) {
	        _iterator2.e(err);
	      } finally {
	        _iterator2.f();
	      }
	    } else {
	      throw new Error("Expected axis to be an integer or an array of integers, " + "but received ".concat(JSON.stringify(_this3.axis)));
	    }
	    _this3.epsilon = args.epsilon == null ? 1e-3 : args.epsilon;
	    _this3.center = args.center == null ? true : args.center;
	    _this3.scale = args.scale == null ? true : args.scale;
	    _this3.betaInitializer = getInitializer(args.betaInitializer || 'zeros');
	    _this3.gammaInitializer = getInitializer(args.gammaInitializer || 'ones');
	    _this3.betaRegularizer = getRegularizer(args.betaRegularizer);
	    _this3.gammaRegularizer = getRegularizer(args.gammaRegularizer);
	    _this3.supportsMasking = true;
	    return _this3;
	  }
	  _createClass(LayerNormalization, [{
	    key: "build",
	    value: function build(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var nDims = inputShape.length;
	      // Convert axis to array and resolve negatives.
	      if (typeof this.axis === 'number') {
	        this.axis = [this.axis];
	      }
	      for (var i = 0; i < this.axis.length; ++i) {
	        if (this.axis[i] < 0) {
	          this.axis[i] += nDims;
	        }
	      }
	      // Further validate axes.
	      var _iterator3 = _createForOfIteratorHelper(this.axis),
	        _step3;
	      try {
	        for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
	          var axis = _step3.value;
	          if (axis < 0 || axis >= nDims) {
	            throw new Error("Invalid axis: ".concat(axis));
	          }
	        }
	      } catch (err) {
	        _iterator3.e(err);
	      } finally {
	        _iterator3.f();
	      }
	      if (this.axis.length !== unique$2(this.axis).length) {
	        throw new Error("Found duplicate axes in: ".concat(this.axis));
	      }
	      var paramShape = this.axis.map(function (axis) {
	        return inputShape[axis];
	      });
	      var trainable = true;
	      if (this.scale) {
	        this.gamma = this.addWeight('gamma', paramShape, 'float32', this.gammaInitializer, this.gammaRegularizer, trainable);
	      } else {
	        this.gamma = null;
	      }
	      if (this.center) {
	        this.beta = this.addWeight('beta', paramShape, 'float32', this.betaInitializer, this.betaRegularizer, trainable);
	      } else {
	        this.beta = null;
	      }
	      this.built = true;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this4 = this;
	      var input = getExactlyOneTensor(inputs);
	      var inputShape = input.shape;
	      var nDims = inputShape.length;
	      return tidy(function () {
	        var keepDims = true;
	        var _moments = moments(input, _this4.axis, keepDims),
	          mean = _moments.mean,
	          variance = _moments.variance;
	        var broadcastShape = pyListRepeat(1, nDims);
	        var _iterator4 = _createForOfIteratorHelper(_this4.axis),
	          _step4;
	        try {
	          for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
	            var dim = _step4.value;
	            broadcastShape[dim] = inputShape[dim];
	          }
	        } catch (err) {
	          _iterator4.e(err);
	        } finally {
	          _iterator4.f();
	        }
	        var broadcast = function broadcast(v) {
	          if (v != null && v.shape.length !== nDims) {
	            return reshape$3(v, broadcastShape);
	          } else {
	            return v;
	          }
	        };
	        var scale = _this4.scale ? broadcast(_this4.gamma.read()) : null;
	        var offset = _this4.center ? broadcast(_this4.beta.read()) : null;
	        // TODO(https://github.com/tensorflow/tfjs/issues/2120): The tiling below
	        // is a workaround for the limitation of core's batchNormalization?d don't
	        // support broadcasting in their gradients. In addition, the tiling is
	        // necessary to ensure correctness on the browser CPU backend regardless
	        // of forward or backward computation. Remove this workaround once the
	        // limitation is addressed. See .
	        var momentsTiling = [];
	        var scaleOffsetTiling = [];
	        for (var i = 0; i < nDims; ++i) {
	          if (_this4.axis.indexOf(i) !== -1) {
	            momentsTiling.push(inputShape[i]);
	            scaleOffsetTiling.push(1);
	          } else {
	            momentsTiling.push(1);
	            scaleOffsetTiling.push(inputShape[i]);
	          }
	        }
	        mean = tile$3(mean, momentsTiling);
	        variance = tile$3(variance, momentsTiling);
	        if (scale != null) {
	          scale = tile$3(scale, scaleOffsetTiling);
	        }
	        if (offset != null) {
	          offset = tile$3(offset, scaleOffsetTiling);
	        }
	        return batchNormalization$1(input, mean, variance, offset, scale, _this4.epsilon);
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        axis: this.axis,
	        epsilon: this.epsilon,
	        center: this.center,
	        scale: this.scale,
	        betaInitializer: serializeInitializer(this.betaInitializer),
	        gammaInitializer: serializeInitializer(this.gammaInitializer),
	        betaRegularizer: serializeRegularizer(this.betaRegularizer),
	        gammaRegularizer: serializeRegularizer(this.gammaRegularizer)
	      };
	      var baseConfig = _get(_getPrototypeOf(LayerNormalization.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return LayerNormalization;
	}(Layer);
	/** @nocollapse */
	LayerNormalization.className = 'LayerNormalization';
	registerClass(LayerNormalization);

	/**
	 * Pads the middle dimension of a 3D tensor.
	 *
	 * @param x Input `tf.Tensor` to be padded.
	 * @param padding `Array` of 2 integers, how many zeros to add at the start and
	 *   end of the middle dimension (i.e., dimension 1).
	 * @return A padded 3D `tf.Tensor`.
	 */
	function temporalPadding(x, padding) {
	  return tidy(function () {
	    if (x.rank !== 3) {
	      throw new ValueError("temporalPadding expects input tensor to be 3-D, but received a " + "".concat(x.rank, "-D tensor."));
	    }
	    if (padding == null) {
	      padding = [1, 1];
	    }
	    if (padding.length !== 2) {
	      throw new ValueError("temporalPadding expects input padding pattern to be a length-2 " + "array, but received a length-".concat(padding.length, " array."));
	    }
	    var pattern = [[0, 0], padding, [0, 0]];
	    return pad(x, pattern);
	  });
	}
	/**
	 * Pads the 2nd and 3rd dimensions of a 4D tensor.
	 *
	 * @param x Input `tf.Tensor` to be padded.
	 * @param padding `Array` of two `Array`s, each of which is an `Array` of two
	 *   integers. The amount of padding at the beginning and end of the 2nd and 3rd
	 *   dimensions, respectively.
	 * @param dataFormat 'channelsLast' (default) or 'channelsFirst'.
	 * @return Padded 4D `tf.Tensor`.
	 */
	function spatial2dPadding(x, padding, dataFormat) {
	  return tidy(function () {
	    if (x.rank !== 4) {
	      throw new ValueError("temporalPadding expects input tensor to be 4-D, but received a " + "".concat(x.rank, "-D tensor."));
	    }
	    if (padding == null) {
	      padding = [[1, 1], [1, 1]];
	    }
	    if (padding.length !== 2 || padding[0].length !== 2 || padding[1].length !== 2) {
	      throw new ValueError('spatial2dPadding expects `padding` to be an Array of two Arrays, ' + 'each of which is an Array of two integers.');
	    }
	    if (dataFormat == null) {
	      dataFormat = imageDataFormat();
	    }
	    if (dataFormat !== 'channelsLast' && dataFormat !== 'channelsFirst') {
	      throw new ValueError("Unknown data format: ".concat(dataFormat, ". ") + "Supported data formats are 'channelsLast' and 'channelsFirst.");
	    }
	    var pattern;
	    if (dataFormat === 'channelsFirst') {
	      pattern = [[0, 0], [0, 0], padding[0], padding[1]];
	    } else {
	      pattern = [[0, 0], padding[0], padding[1], [0, 0]];
	    }
	    return pad(x, pattern);
	  });
	}
	var ZeroPadding2D = /*#__PURE__*/function (_Layer) {
	  _inherits(ZeroPadding2D, _Layer);
	  var _super = _createSuper(ZeroPadding2D);
	  function ZeroPadding2D(args) {
	    var _this;
	    _classCallCheck(this, ZeroPadding2D);
	    if (args == null) {
	      args = {};
	    }
	    _this = _super.call(this, args);
	    _this.dataFormat = args.dataFormat == null ? imageDataFormat() : args.dataFormat;
	    // TODO(cais): Maybe refactor the following logic surrounding `padding`
	    //   into a helper method.
	    if (args.padding == null) {
	      _this.padding = [[1, 1], [1, 1]];
	    } else if (typeof args.padding === 'number') {
	      _this.padding = [[args.padding, args.padding], [args.padding, args.padding]];
	    } else {
	      args.padding = args.padding;
	      if (args.padding.length !== 2) {
	        throw new ValueError("ZeroPadding2D expects padding to be a length-2 array, but " + "received a length-".concat(args.padding.length, " array."));
	      }
	      var heightPadding;
	      var widthPadding;
	      if (typeof args.padding[0] === 'number') {
	        heightPadding = [args.padding[0], args.padding[0]];
	        widthPadding = [args.padding[1], args.padding[1]];
	      } else {
	        args.padding = args.padding;
	        if (args.padding[0].length !== 2) {
	          throw new ValueError("ZeroPadding2D expects height padding to be a length-2 array, " + "but received a length-".concat(args.padding[0].length, " array."));
	        }
	        heightPadding = args.padding[0];
	        if (args.padding[1].length !== 2) {
	          throw new ValueError("ZeroPadding2D expects width padding to be a length-2 array, " + "but received a length-".concat(args.padding[1].length, " array."));
	        }
	        widthPadding = args.padding[1];
	      }
	      _this.padding = [heightPadding, widthPadding];
	    }
	    _this.inputSpec = [new InputSpec({
	      ndim: 4
	    })];
	    return _this;
	  }
	  _createClass(ZeroPadding2D, [{
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var rows;
	      var cols;
	      if (this.dataFormat === 'channelsFirst') {
	        if (inputShape[2] != null && inputShape[2] >= 0) {
	          rows = inputShape[2] + this.padding[0][0] + this.padding[0][1];
	        } else {
	          rows = null;
	        }
	        if (inputShape[3] != null && inputShape[3] >= 0) {
	          cols = inputShape[3] + this.padding[1][0] + this.padding[1][1];
	        } else {
	          cols = null;
	        }
	        return [inputShape[0], inputShape[1], rows, cols];
	      } else {
	        if (inputShape[1] != null && inputShape[1] >= 0) {
	          rows = inputShape[1] + this.padding[0][0] + this.padding[0][1];
	        } else {
	          rows = null;
	        }
	        if (inputShape[2] != null && inputShape[2] >= 0) {
	          cols = inputShape[2] + this.padding[1][0] + this.padding[1][1];
	        } else {
	          cols = null;
	        }
	        return [inputShape[0], rows, cols, inputShape[3]];
	      }
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this2 = this;
	      return tidy(function () {
	        return spatial2dPadding(getExactlyOneTensor(inputs), _this2.padding, _this2.dataFormat);
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        padding: this.padding,
	        dataFormat: this.dataFormat
	      };
	      var baseConfig = _get(_getPrototypeOf(ZeroPadding2D.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return ZeroPadding2D;
	}(Layer);
	/** @nocollapse */
	ZeroPadding2D.className = 'ZeroPadding2D';
	registerClass(ZeroPadding2D);

	/**
	 * 2D pooling.
	 * @param x
	 * @param poolSize
	 * @param strides strides. Defaults to [1, 1].
	 * @param padding padding. Defaults to 'valid'.
	 * @param dataFormat data format. Defaults to 'channelsLast'.
	 * @param poolMode Mode of pooling. Defaults to 'max'.
	 * @returns Result of the 2D pooling.
	 */
	function pool2d(x, poolSize, strides, padding, dataFormat, poolMode) {
	  return tidy(function () {
	    checkDataFormat(dataFormat);
	    checkPoolMode(poolMode);
	    checkPaddingMode(padding);
	    if (strides == null) {
	      strides = [1, 1];
	    }
	    if (padding == null) {
	      padding = 'valid';
	    }
	    if (dataFormat == null) {
	      dataFormat = imageDataFormat();
	    }
	    if (poolMode == null) {
	      poolMode = 'max';
	    }
	    // TODO(cais): Remove the preprocessing step once deeplearn.js supports
	    // dataFormat as an input argument.
	    x = preprocessConv2DInput(x, dataFormat); // x is NHWC after preprocessing.
	    var y;
	    var paddingString = padding === 'same' ? 'same' : 'valid';
	    if (poolMode === 'max') {
	      // TODO(cais): Rank check?
	      y = maxPool$2(x, poolSize, strides, paddingString);
	    } else {
	      // 'avg'
	      // TODO(cais): Check the dtype and rank of x and give clear error message
	      //   if those are incorrect.
	      y = avgPool$2(
	      // TODO(cais): Rank check?
	      x, poolSize, strides, paddingString);
	    }
	    if (dataFormat === 'channelsFirst') {
	      y = transpose$2(y, [0, 3, 1, 2]); // NHWC -> NCHW.
	    }

	    return y;
	  });
	}
	/**
	 * 3D pooling.
	 * @param x
	 * @param poolSize. Default to [1, 1, 1].
	 * @param strides strides. Defaults to [1, 1, 1].
	 * @param padding padding. Defaults to 'valid'.
	 * @param dataFormat data format. Defaults to 'channelsLast'.
	 * @param poolMode Mode of pooling. Defaults to 'max'.
	 * @returns Result of the 3D pooling.
	 */
	function pool3d$1(x, poolSize, strides, padding, dataFormat, poolMode) {
	  return tidy(function () {
	    checkDataFormat(dataFormat);
	    checkPoolMode(poolMode);
	    checkPaddingMode(padding);
	    if (strides == null) {
	      strides = [1, 1, 1];
	    }
	    if (padding == null) {
	      padding = 'valid';
	    }
	    if (dataFormat == null) {
	      dataFormat = imageDataFormat();
	    }
	    if (poolMode == null) {
	      poolMode = 'max';
	    }
	    // x is NDHWC after preprocessing.
	    x = preprocessConv3DInput(x, dataFormat);
	    var y;
	    var paddingString = padding === 'same' ? 'same' : 'valid';
	    if (poolMode === 'max') {
	      y = maxPool3d$1(x, poolSize, strides, paddingString);
	    } else {
	      // 'avg'
	      y = avgPool3d$1(x, poolSize, strides, paddingString);
	    }
	    if (dataFormat === 'channelsFirst') {
	      y = transpose$2(y, [0, 4, 1, 2, 3]); // NDHWC -> NCDHW.
	    }

	    return y;
	  });
	}
	/**
	 * Abstract class for different pooling 1D layers.
	 */
	var Pooling1D = /*#__PURE__*/function (_Layer) {
	  _inherits(Pooling1D, _Layer);
	  var _super = _createSuper(Pooling1D);
	  /**
	   *
	   * @param args Parameters for the Pooling layer.
	   *
	   * config.poolSize defaults to 2.
	   */
	  function Pooling1D(args) {
	    var _this;
	    _classCallCheck(this, Pooling1D);
	    if (args.poolSize == null) {
	      args.poolSize = 2;
	    }
	    _this = _super.call(this, args);
	    if (typeof args.poolSize === 'number') {
	      _this.poolSize = [args.poolSize];
	    } else if (Array.isArray(args.poolSize) && args.poolSize.length === 1 && typeof args.poolSize[0] === 'number') {
	      _this.poolSize = args.poolSize;
	    } else {
	      throw new ValueError("poolSize for 1D convolutional layer must be a number or an " + "Array of a single number, but received " + "".concat(JSON.stringify(args.poolSize)));
	    }
	    assertPositiveInteger(_this.poolSize, 'poolSize');
	    if (args.strides == null) {
	      _this.strides = _this.poolSize;
	    } else {
	      if (typeof args.strides === 'number') {
	        _this.strides = [args.strides];
	      } else if (Array.isArray(args.strides) && args.strides.length === 1 && typeof args.strides[0] === 'number') {
	        _this.strides = args.strides;
	      } else {
	        throw new ValueError("strides for 1D convolutional layer must be a number or an " + "Array of a single number, but received " + "".concat(JSON.stringify(args.strides)));
	      }
	    }
	    assertPositiveInteger(_this.strides, 'strides');
	    _this.padding = args.padding == null ? 'valid' : args.padding;
	    checkPaddingMode(_this.padding);
	    _this.inputSpec = [new InputSpec({
	      ndim: 3
	    })];
	    return _this;
	  }
	  _createClass(Pooling1D, [{
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var length = convOutputLength(inputShape[1], this.poolSize[0], this.padding, this.strides[0]);
	      return [inputShape[0], length, inputShape[2]];
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this2 = this;
	      return tidy(function () {
	        _this2.invokeCallHook(inputs, kwargs);
	        // Add dummy last dimension.
	        inputs = expandDims$2(getExactlyOneTensor(inputs), 2);
	        var output = _this2.poolingFunction(getExactlyOneTensor(inputs), [_this2.poolSize[0], 1], [_this2.strides[0], 1], _this2.padding, 'channelsLast');
	        // Remove dummy last dimension.
	        return squeeze(output, [2]);
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        poolSize: this.poolSize,
	        padding: this.padding,
	        strides: this.strides
	      };
	      var baseConfig = _get(_getPrototypeOf(Pooling1D.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return Pooling1D;
	}(Layer);
	var MaxPooling1D = /*#__PURE__*/function (_Pooling1D) {
	  _inherits(MaxPooling1D, _Pooling1D);
	  var _super2 = _createSuper(MaxPooling1D);
	  function MaxPooling1D(args) {
	    _classCallCheck(this, MaxPooling1D);
	    return _super2.call(this, args);
	  }
	  _createClass(MaxPooling1D, [{
	    key: "poolingFunction",
	    value: function poolingFunction(inputs, poolSize, strides, padding, dataFormat) {
	      checkDataFormat(dataFormat);
	      checkPaddingMode(padding);
	      return pool2d(inputs, poolSize, strides, padding, dataFormat, 'max');
	    }
	  }]);
	  return MaxPooling1D;
	}(Pooling1D);
	/** @nocollapse */
	MaxPooling1D.className = 'MaxPooling1D';
	registerClass(MaxPooling1D);
	var AveragePooling1D = /*#__PURE__*/function (_Pooling1D2) {
	  _inherits(AveragePooling1D, _Pooling1D2);
	  var _super3 = _createSuper(AveragePooling1D);
	  function AveragePooling1D(args) {
	    _classCallCheck(this, AveragePooling1D);
	    return _super3.call(this, args);
	  }
	  _createClass(AveragePooling1D, [{
	    key: "poolingFunction",
	    value: function poolingFunction(inputs, poolSize, strides, padding, dataFormat) {
	      checkDataFormat(dataFormat);
	      checkPaddingMode(padding);
	      return pool2d(inputs, poolSize, strides, padding, dataFormat, 'avg');
	    }
	  }]);
	  return AveragePooling1D;
	}(Pooling1D);
	/** @nocollapse */
	AveragePooling1D.className = 'AveragePooling1D';
	registerClass(AveragePooling1D);
	/**
	 * Abstract class for different pooling 2D layers.
	 */
	var Pooling2D = /*#__PURE__*/function (_Layer2) {
	  _inherits(Pooling2D, _Layer2);
	  var _super4 = _createSuper(Pooling2D);
	  function Pooling2D(args) {
	    var _this3;
	    _classCallCheck(this, Pooling2D);
	    if (args.poolSize == null) {
	      args.poolSize = [2, 2];
	    }
	    _this3 = _super4.call(this, args);
	    _this3.poolSize = Array.isArray(args.poolSize) ? args.poolSize : [args.poolSize, args.poolSize];
	    if (args.strides == null) {
	      _this3.strides = _this3.poolSize;
	    } else if (Array.isArray(args.strides)) {
	      if (args.strides.length !== 2) {
	        throw new ValueError("If the strides property of a 2D pooling layer is an Array, " + "it is expected to have a length of 2, but received length " + "".concat(args.strides.length, "."));
	      }
	      _this3.strides = args.strides;
	    } else {
	      // `config.strides` is a number.
	      _this3.strides = [args.strides, args.strides];
	    }
	    assertPositiveInteger(_this3.poolSize, 'poolSize');
	    assertPositiveInteger(_this3.strides, 'strides');
	    _this3.padding = args.padding == null ? 'valid' : args.padding;
	    _this3.dataFormat = args.dataFormat == null ? 'channelsLast' : args.dataFormat;
	    checkDataFormat(_this3.dataFormat);
	    checkPaddingMode(_this3.padding);
	    _this3.inputSpec = [new InputSpec({
	      ndim: 4
	    })];
	    return _this3;
	  }
	  _createClass(Pooling2D, [{
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var rows = this.dataFormat === 'channelsFirst' ? inputShape[2] : inputShape[1];
	      var cols = this.dataFormat === 'channelsFirst' ? inputShape[3] : inputShape[2];
	      rows = convOutputLength(rows, this.poolSize[0], this.padding, this.strides[0]);
	      cols = convOutputLength(cols, this.poolSize[1], this.padding, this.strides[1]);
	      if (this.dataFormat === 'channelsFirst') {
	        return [inputShape[0], inputShape[1], rows, cols];
	      } else {
	        return [inputShape[0], rows, cols, inputShape[3]];
	      }
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this4 = this;
	      return tidy(function () {
	        _this4.invokeCallHook(inputs, kwargs);
	        return _this4.poolingFunction(getExactlyOneTensor(inputs), _this4.poolSize, _this4.strides, _this4.padding, _this4.dataFormat);
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        poolSize: this.poolSize,
	        padding: this.padding,
	        strides: this.strides,
	        dataFormat: this.dataFormat
	      };
	      var baseConfig = _get(_getPrototypeOf(Pooling2D.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return Pooling2D;
	}(Layer);
	var MaxPooling2D = /*#__PURE__*/function (_Pooling2D) {
	  _inherits(MaxPooling2D, _Pooling2D);
	  var _super5 = _createSuper(MaxPooling2D);
	  function MaxPooling2D(args) {
	    _classCallCheck(this, MaxPooling2D);
	    return _super5.call(this, args);
	  }
	  _createClass(MaxPooling2D, [{
	    key: "poolingFunction",
	    value: function poolingFunction(inputs, poolSize, strides, padding, dataFormat) {
	      checkDataFormat(dataFormat);
	      checkPaddingMode(padding);
	      return pool2d(inputs, poolSize, strides, padding, dataFormat, 'max');
	    }
	  }]);
	  return MaxPooling2D;
	}(Pooling2D);
	/** @nocollapse */
	MaxPooling2D.className = 'MaxPooling2D';
	registerClass(MaxPooling2D);
	var AveragePooling2D = /*#__PURE__*/function (_Pooling2D2) {
	  _inherits(AveragePooling2D, _Pooling2D2);
	  var _super6 = _createSuper(AveragePooling2D);
	  function AveragePooling2D(args) {
	    _classCallCheck(this, AveragePooling2D);
	    return _super6.call(this, args);
	  }
	  _createClass(AveragePooling2D, [{
	    key: "poolingFunction",
	    value: function poolingFunction(inputs, poolSize, strides, padding, dataFormat) {
	      checkDataFormat(dataFormat);
	      checkPaddingMode(padding);
	      return pool2d(inputs, poolSize, strides, padding, dataFormat, 'avg');
	    }
	  }]);
	  return AveragePooling2D;
	}(Pooling2D);
	/** @nocollapse */
	AveragePooling2D.className = 'AveragePooling2D';
	registerClass(AveragePooling2D);
	/**
	 * Abstract class for different pooling 3D layers.
	 */
	var Pooling3D = /*#__PURE__*/function (_Layer3) {
	  _inherits(Pooling3D, _Layer3);
	  var _super7 = _createSuper(Pooling3D);
	  function Pooling3D(args) {
	    var _this5;
	    _classCallCheck(this, Pooling3D);
	    if (args.poolSize == null) {
	      args.poolSize = [2, 2, 2];
	    }
	    _this5 = _super7.call(this, args);
	    _this5.poolSize = Array.isArray(args.poolSize) ? args.poolSize : [args.poolSize, args.poolSize, args.poolSize];
	    if (args.strides == null) {
	      _this5.strides = _this5.poolSize;
	    } else if (Array.isArray(args.strides)) {
	      if (args.strides.length !== 3) {
	        throw new ValueError("If the strides property of a 3D pooling layer is an Array, " + "it is expected to have a length of 3, but received length " + "".concat(args.strides.length, "."));
	      }
	      _this5.strides = args.strides;
	    } else {
	      // `config.strides` is a number.
	      _this5.strides = [args.strides, args.strides, args.strides];
	    }
	    assertPositiveInteger(_this5.poolSize, 'poolSize');
	    assertPositiveInteger(_this5.strides, 'strides');
	    _this5.padding = args.padding == null ? 'valid' : args.padding;
	    _this5.dataFormat = args.dataFormat == null ? 'channelsLast' : args.dataFormat;
	    checkDataFormat(_this5.dataFormat);
	    checkPaddingMode(_this5.padding);
	    _this5.inputSpec = [new InputSpec({
	      ndim: 5
	    })];
	    return _this5;
	  }
	  _createClass(Pooling3D, [{
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var depths = this.dataFormat === 'channelsFirst' ? inputShape[2] : inputShape[1];
	      var rows = this.dataFormat === 'channelsFirst' ? inputShape[3] : inputShape[2];
	      var cols = this.dataFormat === 'channelsFirst' ? inputShape[4] : inputShape[3];
	      depths = convOutputLength(depths, this.poolSize[0], this.padding, this.strides[0]);
	      rows = convOutputLength(rows, this.poolSize[1], this.padding, this.strides[1]);
	      cols = convOutputLength(cols, this.poolSize[2], this.padding, this.strides[2]);
	      if (this.dataFormat === 'channelsFirst') {
	        return [inputShape[0], inputShape[1], depths, rows, cols];
	      } else {
	        return [inputShape[0], depths, rows, cols, inputShape[4]];
	      }
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this6 = this;
	      return tidy(function () {
	        _this6.invokeCallHook(inputs, kwargs);
	        return _this6.poolingFunction(getExactlyOneTensor(inputs), _this6.poolSize, _this6.strides, _this6.padding, _this6.dataFormat);
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        poolSize: this.poolSize,
	        padding: this.padding,
	        strides: this.strides,
	        dataFormat: this.dataFormat
	      };
	      var baseConfig = _get(_getPrototypeOf(Pooling3D.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return Pooling3D;
	}(Layer);
	var MaxPooling3D = /*#__PURE__*/function (_Pooling3D) {
	  _inherits(MaxPooling3D, _Pooling3D);
	  var _super8 = _createSuper(MaxPooling3D);
	  function MaxPooling3D(args) {
	    _classCallCheck(this, MaxPooling3D);
	    return _super8.call(this, args);
	  }
	  _createClass(MaxPooling3D, [{
	    key: "poolingFunction",
	    value: function poolingFunction(inputs, poolSize, strides, padding, dataFormat) {
	      checkDataFormat(dataFormat);
	      checkPaddingMode(padding);
	      return pool3d$1(inputs, poolSize, strides, padding, dataFormat, 'max');
	    }
	  }]);
	  return MaxPooling3D;
	}(Pooling3D);
	/** @nocollapse */
	MaxPooling3D.className = 'MaxPooling3D';
	registerClass(MaxPooling3D);
	var AveragePooling3D = /*#__PURE__*/function (_Pooling3D2) {
	  _inherits(AveragePooling3D, _Pooling3D2);
	  var _super9 = _createSuper(AveragePooling3D);
	  function AveragePooling3D(args) {
	    _classCallCheck(this, AveragePooling3D);
	    return _super9.call(this, args);
	  }
	  _createClass(AveragePooling3D, [{
	    key: "poolingFunction",
	    value: function poolingFunction(inputs, poolSize, strides, padding, dataFormat) {
	      checkDataFormat(dataFormat);
	      checkPaddingMode(padding);
	      return pool3d$1(inputs, poolSize, strides, padding, dataFormat, 'avg');
	    }
	  }]);
	  return AveragePooling3D;
	}(Pooling3D);
	/** @nocollapse */
	AveragePooling3D.className = 'AveragePooling3D';
	registerClass(AveragePooling3D);
	/**
	 * Abstract class for different global pooling 1D layers.
	 */
	var GlobalPooling1D = /*#__PURE__*/function (_Layer4) {
	  _inherits(GlobalPooling1D, _Layer4);
	  var _super10 = _createSuper(GlobalPooling1D);
	  function GlobalPooling1D(args) {
	    var _this7;
	    _classCallCheck(this, GlobalPooling1D);
	    _this7 = _super10.call(this, args);
	    _this7.inputSpec = [new InputSpec({
	      ndim: 3
	    })];
	    return _this7;
	  }
	  _createClass(GlobalPooling1D, [{
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      return [inputShape[0], inputShape[2]];
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      throw new NotImplementedError();
	    }
	  }]);
	  return GlobalPooling1D;
	}(Layer);
	var GlobalAveragePooling1D = /*#__PURE__*/function (_GlobalPooling1D) {
	  _inherits(GlobalAveragePooling1D, _GlobalPooling1D);
	  var _super11 = _createSuper(GlobalAveragePooling1D);
	  function GlobalAveragePooling1D(args) {
	    _classCallCheck(this, GlobalAveragePooling1D);
	    return _super11.call(this, args || {});
	  }
	  _createClass(GlobalAveragePooling1D, [{
	    key: "call",
	    value: function call(inputs, kwargs) {
	      return tidy(function () {
	        var input = getExactlyOneTensor(inputs);
	        return mean$3(input, 1);
	      });
	    }
	  }]);
	  return GlobalAveragePooling1D;
	}(GlobalPooling1D);
	/** @nocollapse */
	GlobalAveragePooling1D.className = 'GlobalAveragePooling1D';
	registerClass(GlobalAveragePooling1D);
	var GlobalMaxPooling1D = /*#__PURE__*/function (_GlobalPooling1D2) {
	  _inherits(GlobalMaxPooling1D, _GlobalPooling1D2);
	  var _super12 = _createSuper(GlobalMaxPooling1D);
	  function GlobalMaxPooling1D(args) {
	    _classCallCheck(this, GlobalMaxPooling1D);
	    return _super12.call(this, args || {});
	  }
	  _createClass(GlobalMaxPooling1D, [{
	    key: "call",
	    value: function call(inputs, kwargs) {
	      return tidy(function () {
	        var input = getExactlyOneTensor(inputs);
	        return max$3(input, 1);
	      });
	    }
	  }]);
	  return GlobalMaxPooling1D;
	}(GlobalPooling1D);
	/** @nocollapse */
	GlobalMaxPooling1D.className = 'GlobalMaxPooling1D';
	registerClass(GlobalMaxPooling1D);
	/**
	 * Abstract class for different global pooling 2D layers.
	 */
	var GlobalPooling2D = /*#__PURE__*/function (_Layer5) {
	  _inherits(GlobalPooling2D, _Layer5);
	  var _super13 = _createSuper(GlobalPooling2D);
	  function GlobalPooling2D(args) {
	    var _this8;
	    _classCallCheck(this, GlobalPooling2D);
	    _this8 = _super13.call(this, args);
	    _this8.dataFormat = args.dataFormat == null ? 'channelsLast' : args.dataFormat;
	    checkDataFormat(_this8.dataFormat);
	    _this8.inputSpec = [new InputSpec({
	      ndim: 4
	    })];
	    return _this8;
	  }
	  _createClass(GlobalPooling2D, [{
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = inputShape;
	      if (this.dataFormat === 'channelsLast') {
	        return [inputShape[0], inputShape[3]];
	      } else {
	        return [inputShape[0], inputShape[1]];
	      }
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      throw new NotImplementedError();
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        dataFormat: this.dataFormat
	      };
	      var baseConfig = _get(_getPrototypeOf(GlobalPooling2D.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return GlobalPooling2D;
	}(Layer);
	var GlobalAveragePooling2D = /*#__PURE__*/function (_GlobalPooling2D) {
	  _inherits(GlobalAveragePooling2D, _GlobalPooling2D);
	  var _super14 = _createSuper(GlobalAveragePooling2D);
	  function GlobalAveragePooling2D() {
	    _classCallCheck(this, GlobalAveragePooling2D);
	    return _super14.apply(this, arguments);
	  }
	  _createClass(GlobalAveragePooling2D, [{
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this9 = this;
	      return tidy(function () {
	        var input = getExactlyOneTensor(inputs);
	        if (_this9.dataFormat === 'channelsLast') {
	          return mean$3(input, [1, 2]);
	        } else {
	          return mean$3(input, [2, 3]);
	        }
	      });
	    }
	  }]);
	  return GlobalAveragePooling2D;
	}(GlobalPooling2D);
	/** @nocollapse */
	GlobalAveragePooling2D.className = 'GlobalAveragePooling2D';
	registerClass(GlobalAveragePooling2D);
	var GlobalMaxPooling2D = /*#__PURE__*/function (_GlobalPooling2D2) {
	  _inherits(GlobalMaxPooling2D, _GlobalPooling2D2);
	  var _super15 = _createSuper(GlobalMaxPooling2D);
	  function GlobalMaxPooling2D() {
	    _classCallCheck(this, GlobalMaxPooling2D);
	    return _super15.apply(this, arguments);
	  }
	  _createClass(GlobalMaxPooling2D, [{
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this10 = this;
	      return tidy(function () {
	        var input = getExactlyOneTensor(inputs);
	        if (_this10.dataFormat === 'channelsLast') {
	          return max$3(input, [1, 2]);
	        } else {
	          return max$3(input, [2, 3]);
	        }
	      });
	    }
	  }]);
	  return GlobalMaxPooling2D;
	}(GlobalPooling2D);
	/** @nocollapse */
	GlobalMaxPooling2D.className = 'GlobalMaxPooling2D';
	registerClass(GlobalMaxPooling2D);

	/**
	 * Abstract wrapper base class.
	 *
	 * Wrappers take another layer and augment it in various ways.
	 * Do not use this class as a layer, it is only an abstract base class.
	 * Two usable wrappers are the `TimeDistributed` and `Bidirectional` wrappers.
	 */
	var Wrapper = /*#__PURE__*/function (_Layer) {
	  _inherits(Wrapper, _Layer);
	  var _super = _createSuper(Wrapper);
	  function Wrapper(args) {
	    var _this;
	    _classCallCheck(this, Wrapper);
	    // Porting Note: In PyKeras, `self.layer` is set prior to the calling
	    //   `super()`. But we can't do that here due to TypeScript's restriction.
	    //   See: https://github.com/Microsoft/TypeScript/issues/8277
	    //   As a result, we have to add checks in `get trainable()` and
	    //   `set trainable()` below in order to prevent using `this.layer` when
	    //   its value is `undefined`. The super constructor does use the getter
	    //   and the setter of `this.layer`.
	    _this = _super.call(this, args);
	    _this.layer = args.layer;
	    return _this;
	  }
	  _createClass(Wrapper, [{
	    key: "build",
	    value: function build(inputShape) {
	      this.built = true;
	    }
	    // TODO(cais): Implement activityRegularizer getter.
	  }, {
	    key: "trainable",
	    get: function get() {
	      // Porting Note: the check of `this.layer` here is necessary due to the
	      //   way the `constructor` of this class is written (see Porting Note
	      //   above).
	      if (this.layer != null) {
	        return this.layer.trainable;
	      } else {
	        return false;
	      }
	    },
	    set: function set(value) {
	      // Porting Note: the check of `this.layer` here is necessary due to the
	      //   way the `constructor` of this class is written (see Porting Note
	      //   above).
	      if (this.layer != null) {
	        this.layer.trainable = value;
	      }
	    }
	  }, {
	    key: "trainableWeights",
	    get: function get() {
	      return this.layer.trainableWeights;
	    }
	    // TODO(cais): Implement setter for trainableWeights.
	  }, {
	    key: "nonTrainableWeights",
	    get: function get() {
	      return this.layer.nonTrainableWeights;
	    }
	    // TODO(cais): Implement setter for nonTrainableWeights.
	  }, {
	    key: "updates",
	    get: function get() {
	      // tslint:disable-next-line:no-any
	      return this.layer._updates;
	    }
	    // TODO(cais): Implement getUpdatesFor().
	  }, {
	    key: "losses",
	    get: function get() {
	      return this.layer.losses;
	    }
	    // TODO(cais): Implement getLossesFor().
	  }, {
	    key: "getWeights",
	    value: function getWeights() {
	      return this.layer.getWeights();
	    }
	  }, {
	    key: "setWeights",
	    value: function setWeights(weights) {
	      this.layer.setWeights(weights);
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        'layer': {
	          'className': this.layer.getClassName(),
	          'config': this.layer.getConfig()
	        }
	      };
	      var baseConfig = _get(_getPrototypeOf(Wrapper.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }, {
	    key: "setFastWeightInitDuringBuild",
	    value: function setFastWeightInitDuringBuild(value) {
	      _get(_getPrototypeOf(Wrapper.prototype), "setFastWeightInitDuringBuild", this).call(this, value);
	      if (this.layer != null) {
	        this.layer.setFastWeightInitDuringBuild(value);
	      }
	    }
	    /** @nocollapse */
	  }], [{
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      var customObjects = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
	      var layerConfig = config['layer'];
	      var layer = deserialize(layerConfig, customObjects);
	      delete config['layer'];
	      var newConfig = {
	        layer: layer
	      };
	      Object.assign(newConfig, config);
	      return new cls(newConfig);
	    }
	  }]);
	  return Wrapper;
	}(Layer);
	var TimeDistributed = /*#__PURE__*/function (_Wrapper) {
	  _inherits(TimeDistributed, _Wrapper);
	  var _super2 = _createSuper(TimeDistributed);
	  function TimeDistributed(args) {
	    var _this2;
	    _classCallCheck(this, TimeDistributed);
	    _this2 = _super2.call(this, args);
	    _this2.supportsMasking = true;
	    return _this2;
	  }
	  _createClass(TimeDistributed, [{
	    key: "build",
	    value: function build(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      if (inputShape.length < 3) {
	        throw new ValueError("TimeDistributed layer expects an input shape >= 3D, but received " + "input shape ".concat(JSON.stringify(inputShape)));
	      }
	      this.inputSpec = [{
	        shape: inputShape
	      }];
	      var childInputShape = [inputShape[0]].concat(inputShape.slice(2));
	      if (!this.layer.built) {
	        this.layer.build(childInputShape);
	        this.layer.built = true;
	      }
	      _get(_getPrototypeOf(TimeDistributed.prototype), "build", this).call(this, inputShape);
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var childInputShape = [inputShape[0]].concat(inputShape.slice(2));
	      var childOutputShape = this.layer.computeOutputShape(childInputShape);
	      var timesteps = inputShape[1];
	      return [childOutputShape[0], timesteps].concat(childOutputShape.slice(1));
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this3 = this;
	      return tidy(function () {
	        // TODO(cais): Add 'training' and 'useLearningPhase' to kwargs.
	        inputs = getExactlyOneTensor(inputs);
	        // Porting Note: In tfjs-layers, `inputs` are always concrete tensor
	        // values. Hence the inputs can't have an undetermined first (batch)
	        // dimension, which is why we always use the K.rnn approach here.
	        var step = function step(inputs, states) {
	          // TODO(cais): Add useLearningPhase.
	          // NOTE(cais): `layer.call` may return a length-1 array of Tensor in
	          //   some cases (e.g., `layer` is a `Sequential` instance), which is
	          //   why `getExactlyOneTensor` is used below.
	          var output = getExactlyOneTensor(_this3.layer.call(inputs, kwargs));
	          return [output, []];
	        };
	        var rnnOutputs = rnn$1(step, inputs, [], false /* goBackwards */, null /* mask */, null /* constants */, false /* unroll */, true /* needPerStepOutputs */);
	        var y = rnnOutputs[1];
	        // TODO(cais): Add activity regularization.
	        // TODO(cais): Add useLearningPhase.
	        return y;
	      });
	    }
	  }]);
	  return TimeDistributed;
	}(Wrapper);
	/** @nocollapse */
	TimeDistributed.className = 'TimeDistributed';
	registerClass(TimeDistributed);
	function checkBidirectionalMergeMode(value) {
	  checkStringTypeUnionValue(VALID_BIDIRECTIONAL_MERGE_MODES, 'BidirectionalMergeMode', value);
	}
	var DEFAULT_BIDIRECTIONAL_MERGE_MODE = 'concat';
	var Bidirectional = /*#__PURE__*/function (_Wrapper2) {
	  _inherits(Bidirectional, _Wrapper2);
	  var _super3 = _createSuper(Bidirectional);
	  function Bidirectional(args) {
	    var _this4;
	    _classCallCheck(this, Bidirectional);
	    _this4 = _super3.call(this, args);
	    // Note: When creating `this.forwardLayer`, the original Layer object
	    //   (`config.layer`) ought to be cloned. This is why we call
	    //   `getConfig()` followed by `deserialize()`. Without this cloning,
	    //   the layer names saved during serialization will incorrectly contain
	    //   the 'forward_' prefix. In Python Keras, this is done using
	    //   `copy.copy` (shallow copy), which does not have a simple equivalent
	    //   in JavaScript. JavaScript's `Object.assign()` does not copy
	    //   methods.
	    var layerConfig = args.layer.getConfig();
	    var forwDict = {};
	    forwDict['className'] = args.layer.getClassName();
	    forwDict['config'] = layerConfig;
	    _this4.forwardLayer = deserialize(forwDict);
	    layerConfig['goBackwards'] = layerConfig['goBackwards'] === true ? false : true;
	    var backDict = {};
	    backDict['className'] = args.layer.getClassName();
	    backDict['config'] = layerConfig;
	    _this4.backwardLayer = deserialize(backDict);
	    _this4.forwardLayer.name = 'forward_' + _this4.forwardLayer.name;
	    _this4.backwardLayer.name = 'backward_' + _this4.backwardLayer.name;
	    _this4.mergeMode = args.mergeMode === undefined ? DEFAULT_BIDIRECTIONAL_MERGE_MODE : args.mergeMode;
	    checkBidirectionalMergeMode(_this4.mergeMode);
	    if (args.weights) {
	      throw new NotImplementedError('weights support is not implemented for Bidirectional layer yet.');
	    }
	    _this4._stateful = args.layer.stateful;
	    _this4.returnSequences = args.layer.returnSequences;
	    _this4.returnState = args.layer.returnState;
	    _this4.supportsMasking = true;
	    _this4._trainable = true;
	    _this4.inputSpec = args.layer.inputSpec;
	    _this4.numConstants = null;
	    return _this4;
	  }
	  _createClass(Bidirectional, [{
	    key: "trainable",
	    get: function get() {
	      return this._trainable;
	    },
	    set: function set(value) {
	      // Porting Note: the check of `this.layer` here is necessary due to the
	      //   way the `constructor` of this class is written (see Porting Note
	      //   above).
	      this._trainable = value;
	      if (this.forwardLayer != null) {
	        this.forwardLayer.trainable = value;
	      }
	      if (this.backwardLayer != null) {
	        this.backwardLayer.trainable = value;
	      }
	    }
	  }, {
	    key: "getWeights",
	    value: function getWeights() {
	      return this.forwardLayer.getWeights().concat(this.backwardLayer.getWeights());
	    }
	  }, {
	    key: "setWeights",
	    value: function setWeights(weights) {
	      var numWeights = weights.length;
	      var numeightsOver2 = Math.floor(numWeights / 2);
	      this.forwardLayer.setWeights(weights.slice(0, numeightsOver2));
	      this.backwardLayer.setWeights(weights.slice(numeightsOver2));
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      var layerShapes = this.forwardLayer.computeOutputShape(inputShape);
	      if (!(Array.isArray(layerShapes) && Array.isArray(layerShapes[0]))) {
	        layerShapes = [layerShapes];
	      }
	      layerShapes = layerShapes;
	      var outputShape;
	      var outputShapes;
	      var stateShape;
	      if (this.returnState) {
	        stateShape = layerShapes.slice(1);
	        outputShape = layerShapes[0];
	      } else {
	        outputShape = layerShapes[0];
	      }
	      outputShape = outputShape;
	      if (this.mergeMode === 'concat') {
	        outputShape[outputShape.length - 1] *= 2;
	        outputShapes = [outputShape];
	      } else if (this.mergeMode == null) {
	        outputShapes = [outputShape, outputShape.slice()];
	      } else {
	        outputShapes = [outputShape];
	      }
	      if (this.returnState) {
	        if (this.mergeMode == null) {
	          return outputShapes.concat(stateShape).concat(stateShape.slice());
	        }
	        return [outputShape].concat(stateShape).concat(stateShape.slice());
	      }
	      return singletonOrArray(outputShapes);
	    }
	  }, {
	    key: "apply",
	    value: function apply(inputs, kwargs) {
	      var initialState = kwargs == null ? null : kwargs['initialState'];
	      var constants = kwargs == null ? null : kwargs['constants'];
	      if (kwargs == null) {
	        kwargs = {};
	      }
	      var standardized = standardizeArgs(inputs, initialState, constants, this.numConstants);
	      inputs = standardized.inputs;
	      initialState = standardized.initialState;
	      constants = standardized.constants;
	      if (Array.isArray(inputs)) {
	        initialState = inputs.slice(1);
	        inputs = inputs[0];
	      }
	      if ((initialState == null || initialState.length === 0) && constants == null) {
	        return _get(_getPrototypeOf(Bidirectional.prototype), "apply", this).call(this, inputs, kwargs);
	      }
	      var additionalInputs = [];
	      var additionalSpecs = [];
	      if (initialState != null) {
	        var numStates = initialState.length;
	        if (numStates % 2 > 0) {
	          throw new ValueError('When passing `initialState` to a Bidrectional RNN, ' + 'the state should be an Array containing the states of ' + 'the underlying RNNs.');
	        }
	        kwargs['initialState'] = initialState;
	        additionalInputs.push.apply(additionalInputs, _toConsumableArray(initialState));
	        var stateSpecs = initialState.map(function (state) {
	          return new InputSpec({
	            shape: state.shape
	          });
	        });
	        this.forwardLayer.stateSpec = stateSpecs.slice(0, numStates / 2);
	        this.backwardLayer.stateSpec = stateSpecs.slice(numStates / 2);
	        additionalSpecs.push.apply(additionalSpecs, _toConsumableArray(stateSpecs));
	      }
	      if (constants != null) {
	        throw new NotImplementedError('Support for constants in Bidirectional layers is not ' + 'implemented yet.');
	      }
	      var isSymbolicTensor = additionalInputs[0] instanceof SymbolicTensor;
	      for (var _i = 0, _additionalInputs = additionalInputs; _i < _additionalInputs.length; _i++) {
	        var tensor = _additionalInputs[_i];
	        if (tensor instanceof SymbolicTensor !== isSymbolicTensor) {
	          throw new ValueError('The initial state of a Bidirectional layer cannot be ' + 'specified as a mix of symbolic and non-symbolic tensors');
	        }
	      }
	      if (isSymbolicTensor) {
	        // Compute the full input and specs, including the states.
	        var fullInput = [inputs].concat(additionalInputs);
	        var fullInputSpec = this.inputSpec.concat(additionalSpecs);
	        // Perform the call temporarily and replace inputSpec.
	        // Note: with initial states symbolic calls and non-symbolic calls to
	        // this method differ in how the initial states are passed. For
	        // symbolic calls, the initial states are passed in the first arg, as
	        // an Array of SymbolicTensors; for non-symbolic calls, they are
	        // passed in the second arg as a part of the kwargs. Hence the need to
	        // temporarily modify inputSpec here.
	        // TODO(cais): Make refactoring so that this hacky code below is no
	        // longer needed.
	        var originalInputSpec = this.inputSpec;
	        this.inputSpec = fullInputSpec;
	        var output = _get(_getPrototypeOf(Bidirectional.prototype), "apply", this).call(this, fullInput, kwargs);
	        this.inputSpec = originalInputSpec;
	        return output;
	      } else {
	        return _get(_getPrototypeOf(Bidirectional.prototype), "apply", this).call(this, inputs, kwargs);
	      }
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this5 = this;
	      return tidy(function () {
	        var initialState = kwargs['initialState'];
	        var y;
	        var yRev;
	        if (initialState == null) {
	          y = _this5.forwardLayer.call(inputs, kwargs);
	          yRev = _this5.backwardLayer.call(inputs, kwargs);
	        } else {
	          var forwardState = initialState.slice(0, initialState.length / 2);
	          var backwardState = initialState.slice(initialState.length / 2);
	          y = _this5.forwardLayer.call(inputs, Object.assign(kwargs, {
	            initialState: forwardState
	          }));
	          yRev = _this5.backwardLayer.call(inputs, Object.assign(kwargs, {
	            initialState: backwardState
	          }));
	        }
	        var states;
	        if (_this5.returnState) {
	          if (Array.isArray(y)) {
	            states = y.slice(1).concat(yRev.slice(1));
	          } else {}
	          y = y[0];
	          yRev = yRev[0];
	        }
	        if (_this5.returnSequences) {
	          yRev = reverse$2(yRev, 1);
	        }
	        var output;
	        if (_this5.mergeMode === 'concat') {
	          output = concatenate$2([y, yRev]);
	        } else if (_this5.mergeMode === 'sum') {
	          output = add$3(y, yRev);
	        } else if (_this5.mergeMode === 'ave') {
	          output = mul(.5, add$3(y, yRev));
	        } else if (_this5.mergeMode === 'mul') {
	          output = mul(y, yRev);
	        } else if (_this5.mergeMode == null) {
	          output = [y, yRev];
	        }
	        // TODO(cais): Properly set learning phase.
	        if (_this5.returnState) {
	          if (_this5.mergeMode == null) {
	            return output.concat(states);
	          }
	          return [output].concat(states);
	        }
	        return output;
	      });
	    }
	  }, {
	    key: "resetStates",
	    value: function resetStates(states) {
	      this.forwardLayer.resetStates();
	      this.backwardLayer.resetStates();
	    }
	  }, {
	    key: "build",
	    value: function build(inputShape) {
	      var _this6 = this;
	      nameScope(this.forwardLayer.name, function () {
	        _this6.forwardLayer.build(inputShape);
	      });
	      nameScope(this.backwardLayer.name, function () {
	        _this6.backwardLayer.build(inputShape);
	      });
	      this.built = true;
	    }
	  }, {
	    key: "computeMask",
	    value: function computeMask(inputs, mask) {
	      if (Array.isArray(mask)) {
	        mask = mask[0];
	      }
	      var outputMask;
	      if (this.returnSequences) {
	        if (this.mergeMode == null) {
	          outputMask = [mask, mask];
	        } else {
	          outputMask = mask;
	        }
	      } else {
	        if (this.mergeMode == null) {
	          outputMask = [null, null];
	        } else {
	          outputMask = null;
	        }
	      }
	      if (this.returnState) {
	        var states = this.forwardLayer.states;
	        var stateMask = states.map(function (state) {
	          return null;
	        });
	        if (Array.isArray(outputMask)) {
	          return outputMask.concat(stateMask).concat(stateMask);
	        } else {
	          return [outputMask].concat(stateMask).concat(stateMask);
	        }
	      } else {
	        return outputMask;
	      }
	    }
	  }, {
	    key: "trainableWeights",
	    get: function get() {
	      return this.forwardLayer.trainableWeights.concat(this.backwardLayer.trainableWeights);
	    }
	  }, {
	    key: "nonTrainableWeights",
	    get: function get() {
	      return this.forwardLayer.nonTrainableWeights.concat(this.backwardLayer.nonTrainableWeights);
	    }
	    // TODO(cais): Implement constraints().
	  }, {
	    key: "setFastWeightInitDuringBuild",
	    value: function setFastWeightInitDuringBuild(value) {
	      _get(_getPrototypeOf(Bidirectional.prototype), "setFastWeightInitDuringBuild", this).call(this, value);
	      if (this.forwardLayer != null) {
	        this.forwardLayer.setFastWeightInitDuringBuild(value);
	      }
	      if (this.backwardLayer != null) {
	        this.backwardLayer.setFastWeightInitDuringBuild(value);
	      }
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        'mergeMode': this.mergeMode
	      };
	      // TODO(cais): Add logic for `numConstants` once the property is added.
	      var baseConfig = _get(_getPrototypeOf(Bidirectional.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	    /** @nocollapse */
	  }], [{
	    key: "fromConfig",
	    value: function fromConfig(cls, config) {
	      var rnnLayer = deserialize(config['layer']);
	      delete config['layer'];
	      // TODO(cais): Add logic for `numConstants` once the property is added.
	      if (config['numConstants'] != null) {
	        throw new NotImplementedError("Deserialization of a Bidirectional layer with numConstants " + "present is not supported yet.");
	      }
	      // tslint:disable-next-line:no-any
	      var newConfig = config;
	      newConfig['layer'] = rnnLayer;
	      return new cls(newConfig);
	    }
	  }]);
	  return Bidirectional;
	}(Wrapper);
	/** @nocollapse */
	Bidirectional.className = 'Bidirectional';
	registerClass(Bidirectional);

	/**
	 * Preprocessing Rescaling Layer
	 *
	 * This rescales images by a scaling and offset factor
	 */
	var Rescaling = /*#__PURE__*/function (_Layer) {
	  _inherits(Rescaling, _Layer);
	  var _super = _createSuper(Rescaling);
	  function Rescaling(args) {
	    var _this;
	    _classCallCheck(this, Rescaling);
	    _this = _super.call(this, args);
	    _this.scale = args.scale;
	    if (args.offset) {
	      _this.offset = args.offset;
	    } else {
	      _this.offset = 0;
	    }
	    return _this;
	  }
	  _createClass(Rescaling, [{
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        'scale': this.scale,
	        'offset': this.offset
	      };
	      var baseConfig = _get(_getPrototypeOf(Rescaling.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this2 = this;
	      return tidy(function () {
	        inputs = getExactlyOneTensor(inputs);
	        if (inputs.dtype !== 'float32') {
	          inputs = cast$2(inputs, 'float32');
	        }
	        return add$3(mul(inputs, _this2.scale), _this2.offset);
	      });
	    }
	  }]);
	  return Rescaling;
	}(Layer);
	/** @nocollapse */
	Rescaling.className = 'Rescaling';
	registerClass(Rescaling);

	var resizeBilinear$2 = image$1.resizeBilinear,
	  cropAndResize$2 = image$1.cropAndResize;
	var CenterCrop = /*#__PURE__*/function (_Layer) {
	  _inherits(CenterCrop, _Layer);
	  var _super = _createSuper(CenterCrop);
	  function CenterCrop(args) {
	    var _this;
	    _classCallCheck(this, CenterCrop);
	    _this = _super.call(this, args);
	    _this.height = args.height;
	    _this.width = args.width;
	    return _this;
	  }
	  _createClass(CenterCrop, [{
	    key: "centerCrop",
	    value: function centerCrop(inputs, hBuffer, wBuffer, height, width, inputHeight, inputWidth, dtype) {
	      return tidy(function () {
	        var input;
	        var isRank3 = false;
	        var top = hBuffer / inputHeight;
	        var left = wBuffer / inputWidth;
	        var bottom = (height + hBuffer) / inputHeight;
	        var right = (width + wBuffer) / inputWidth;
	        var bound = [top, left, bottom, right];
	        var boxesArr = [];
	        if (inputs.rank === 3) {
	          isRank3 = true;
	          input = stack([inputs]);
	        } else {
	          input = inputs;
	        }
	        for (var i = 0; i < input.shape[0]; i++) {
	          boxesArr.push(bound);
	        }
	        var boxes = tensor(boxesArr, [boxesArr.length, 4]);
	        var boxInd = range$3(0, boxesArr.length, 1, 'int32');
	        var cropSize = [height, width];
	        var cropped = cropAndResize$2(input, boxes, boxInd, cropSize, 'nearest');
	        if (isRank3) {
	          return cast$2(getExactlyOneTensor(unstack(cropped)), dtype);
	        }
	        return cast$2(cropped, dtype);
	      });
	    }
	  }, {
	    key: "upsize",
	    value: function upsize(inputs, height, width, dtype) {
	      return tidy(function () {
	        var outputs = resizeBilinear$2(inputs, [height, width]);
	        return cast$2(outputs, dtype);
	      });
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this2 = this;
	      return tidy(function () {
	        var rankedInputs = getExactlyOneTensor(inputs);
	        var dtype = rankedInputs.dtype;
	        var inputShape = rankedInputs.shape;
	        var inputHeight = inputShape[inputShape.length - 3];
	        var inputWidth = inputShape[inputShape.length - 2];
	        var hBuffer = 0;
	        if (inputHeight !== _this2.height) {
	          hBuffer = Math.floor((inputHeight - _this2.height) / 2);
	        }
	        var wBuffer = 0;
	        if (inputWidth !== _this2.width) {
	          wBuffer = Math.floor((inputWidth - _this2.width) / 2);
	          if (wBuffer === 0) {
	            wBuffer = 1;
	          }
	        }
	        if (hBuffer >= 0 && wBuffer >= 0) {
	          return _this2.centerCrop(rankedInputs, hBuffer, wBuffer, _this2.height, _this2.width, inputHeight, inputWidth, dtype);
	        } else {
	          return _this2.upsize(inputs, _this2.height, _this2.width, dtype);
	        }
	      });
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        'height': this.height,
	        'width': this.width
	      };
	      var baseConfig = _get(_getPrototypeOf(CenterCrop.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var hAxis = inputShape.length - 3;
	      var wAxis = inputShape.length - 2;
	      inputShape[hAxis] = this.height;
	      inputShape[wAxis] = this.width;
	      return inputShape;
	    }
	  }]);
	  return CenterCrop;
	}(Layer);
	/** @nocollapse */
	CenterCrop.className = 'CenterCrop';
	registerClass(CenterCrop);

	/**
	 * @license
	 * Copyright 2022 CodeSmith LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	function encodeCategoricalInputs(inputs, outputMode, depth, weights) {
	  var input = getExactlyOneTensor(inputs);
	  if (input.dtype !== 'int32') {
	    input = cast$2(input, 'int32');
	  }
	  if (outputMode === 'int') {
	    return input;
	  }
	  var originalShape = input.shape;
	  if (input.rank === 0) {
	    input = expandDims$3(input, -1);
	  }
	  if (outputMode === 'oneHot') {
	    if (input.shape[input.shape.length - 1] !== 1) {
	      input = expandDims$3(input, -1);
	    }
	  }
	  if (input.rank > 2) {
	    throw new ValueError("When outputMode is not int, maximum output rank is 2" + " Received outputMode ".concat(outputMode, " and input shape ").concat(originalShape) + " which would result in output rank ".concat(input.rank, "."));
	  }
	  var binaryOutput = ['multiHot', 'oneHot'].includes(outputMode);
	  var denseBincountInput = input;
	  var binCounts;
	  if (typeof weights !== 'undefined' && outputMode === 'count') {
	    binCounts = denseBincount$2(denseBincountInput, weights, depth, binaryOutput);
	  } else {
	    binCounts = denseBincount$2(denseBincountInput, [], depth, binaryOutput);
	  }
	  if (outputMode !== 'tfIdf') {
	    return binCounts;
	  }
	  if (weights) {
	    return mul(binCounts, weights);
	  } else {
	    throw new ValueError("When outputMode is 'tfIdf', weights must be provided.");
	  }
	}

	var CategoryEncoding = /*#__PURE__*/function (_Layer) {
	  _inherits(CategoryEncoding, _Layer);
	  var _super = _createSuper(CategoryEncoding);
	  function CategoryEncoding(args) {
	    var _this;
	    _classCallCheck(this, CategoryEncoding);
	    _this = _super.call(this, args);
	    _this.numTokens = args.numTokens;
	    if (args.outputMode) {
	      _this.outputMode = args.outputMode;
	    } else {
	      _this.outputMode = 'multiHot';
	    }
	    return _this;
	  }
	  _createClass(CategoryEncoding, [{
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        'numTokens': this.numTokens,
	        'outputMode': this.outputMode
	      };
	      var baseConfig = _get(_getPrototypeOf(CategoryEncoding.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      if (inputShape == null) {
	        return [this.numTokens];
	      }
	      if (this.outputMode === 'oneHot' && inputShape[inputShape.length - 1] !== 1) {
	        inputShape.push(this.numTokens);
	        return inputShape;
	      }
	      inputShape[inputShape.length - 1] = this.numTokens;
	      return inputShape;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this2 = this;
	      return tidy(function () {
	        inputs = getExactlyOneTensor(inputs);
	        if (inputs.dtype !== 'int32') {
	          inputs = cast$2(inputs, 'int32');
	        }
	        var countWeights;
	        if (typeof kwargs['countWeights'] !== 'undefined') {
	          if (_this2.outputMode !== 'count') {
	            throw new ValueError("countWeights is not used when outputMode !== count.\n              Received countWeights=".concat(kwargs['countWeights']));
	          }
	          countWeights = getExactlyOneTensor(kwargs['countWeights']);
	        }
	        var maxValue = max$3(inputs);
	        var minValue = min$3(inputs);
	        var greaterEqualMax = greater$3(_this2.numTokens, maxValue).bufferSync().get(0);
	        var greaterMin = greaterEqual$2(minValue, 0).bufferSync().get(0);
	        if (!(greaterEqualMax && greaterMin)) {
	          throw new ValueError('Input values must be between 0 < values <=' + " numTokens with numTokens=".concat(_this2.numTokens));
	        }
	        return encodeCategoricalInputs(inputs, _this2.outputMode, _this2.numTokens, countWeights);
	      });
	    }
	  }]);
	  return CategoryEncoding;
	}(Layer);
	/** @nocollapse */
	CategoryEncoding.className = 'CategoryEncoding';
	registerClass(CategoryEncoding);

	// tf methods unimplemented in tfjs: 'bicubic', 'area', 'lanczos3', 'lanczos5',
	//                                   'gaussian', 'mitchellcubic'
	var INTERPOLATION_KEYS$1 = ['bilinear', 'nearest'];
	var INTERPOLATION_METHODS$1 = new Set(INTERPOLATION_KEYS$1);
	/**
	 * Preprocessing Resizing Layer
	 *
	 * This resizes images by a scaling and offset factor
	 */
	var Resizing = /*#__PURE__*/function (_Layer) {
	  _inherits(Resizing, _Layer);
	  var _super = _createSuper(Resizing);
	  function Resizing(args) {
	    var _this;
	    _classCallCheck(this, Resizing);
	    _this = _super.call(this, args);
	    _this.height = args.height;
	    _this.width = args.width;
	    if (args.interpolation) {
	      if (INTERPOLATION_METHODS$1.has(args.interpolation)) {
	        _this.interpolation = args.interpolation;
	      } else {
	        throw new ValueError("Invalid interpolation parameter: ".concat(args.interpolation, " is not implemented"));
	      }
	    } else {
	      _this.interpolation = 'bilinear';
	    }
	    _this.cropToAspectRatio = Boolean(args.cropToAspectRatio);
	    return _this;
	  }
	  _createClass(Resizing, [{
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var numChannels = inputShape[2];
	      return [this.height, this.width, numChannels];
	    }
	  }, {
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        'height': this.height,
	        'width': this.width,
	        'interpolation': this.interpolation,
	        'cropToAspectRatio': this.cropToAspectRatio
	      };
	      var baseConfig = _get(_getPrototypeOf(Resizing.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this2 = this;
	      return tidy(function () {
	        var size = [_this2.height, _this2.width];
	        if (_this2.interpolation === 'bilinear') {
	          return image$1.resizeBilinear(inputs, size, !_this2.cropToAspectRatio);
	        } else if (_this2.interpolation === 'nearest') {
	          return image$1.resizeNearestNeighbor(inputs, size, !_this2.cropToAspectRatio);
	        } else {
	          throw new Error("Interpolation is ".concat(_this2.interpolation, " but only ").concat(_toConsumableArray(INTERPOLATION_METHODS$1), " are supported"));
	        }
	      });
	    }
	  }]);
	  return Resizing;
	}(Layer);
	/** @nocollapse */
	Resizing.className = 'Resizing';
	registerClass(Resizing);

	/**
	 * @license
	 * Copyright 2023 CodeSmith LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	/**
	 * Keeps track of seed and handles pseudorandomness
	 * Instance created in BaseRandomLayer class
	 * Utilized for random preprocessing layers
	 */
	var RandomSeed = /*#__PURE__*/function () {
	  function RandomSeed(seed) {
	    _classCallCheck(this, RandomSeed);
	    this.seed = seed;
	  }
	  _createClass(RandomSeed, [{
	    key: "next",
	    value: function next() {
	      if (this.seed === undefined) {
	        return undefined;
	      }
	      return this.seed++;
	    }
	  }]);
	  return RandomSeed;
	}();
	RandomSeed.className = 'RandomSeed';

	var BaseRandomLayer = /*#__PURE__*/function (_Layer) {
	  _inherits(BaseRandomLayer, _Layer);
	  var _super = _createSuper(BaseRandomLayer);
	  function BaseRandomLayer(args) {
	    var _this;
	    _classCallCheck(this, BaseRandomLayer);
	    _this = _super.call(this, args);
	    _this.randomGenerator = new RandomSeed(args.seed);
	    return _this;
	  }
	  _createClass(BaseRandomLayer, [{
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        'seed': this.randomGenerator.seed
	      };
	      var baseConfig = _get(_getPrototypeOf(BaseRandomLayer.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }]);
	  return BaseRandomLayer;
	}(Layer); // A layer handle the random number creation and savemodel behavior.
	/** @nocollapse */
	BaseRandomLayer.className = 'BaseRandomLayer';

	var INTERPOLATION_KEYS = ['bilinear', 'nearest'];
	var INTERPOLATION_METHODS = new Set(INTERPOLATION_KEYS);
	/**
	 * Preprocessing Layer with randomly varies image during training
	 *
	 * This layer randomly adjusts the width of a batch of images of a
	 * batch of images by a random factor.
	 *
	 * The input should be a 3D (unbatched) or
	 * 4D (batched) tensor in the `"channels_last"` image data format. Input pixel
	 * values can be of any range (e.g. `[0., 1.)` or `[0, 255]`) and of integer
	 * or floating point dtype. By default, the layer will output floats.
	 *
	 * tf methods implemented in tfjs: 'bilinear', 'nearest',
	 * tf methods unimplemented in tfjs: 'bicubic', 'area', 'lanczos3', 'lanczos5',
	 *                                   'gaussian', 'mitchellcubic'
	 *
	 */
	var RandomWidth = /*#__PURE__*/function (_BaseRandomLayer) {
	  _inherits(RandomWidth, _BaseRandomLayer);
	  var _super = _createSuper(RandomWidth);
	  function RandomWidth(args) {
	    var _this;
	    _classCallCheck(this, RandomWidth);
	    _this = _super.call(this, args);
	    var factor = args.factor,
	      _args$interpolation = args.interpolation,
	      interpolation = _args$interpolation === void 0 ? 'bilinear' : _args$interpolation;
	    _this.factor = factor;
	    if (Array.isArray(_this.factor) && _this.factor.length === 2) {
	      _this.widthLower = _this.factor[0];
	      _this.widthUpper = _this.factor[1];
	    } else if (!Array.isArray(_this.factor) && _this.factor > 0) {
	      _this.widthLower = -_this.factor;
	      _this.widthUpper = _this.factor;
	    } else {
	      throw new ValueError("Invalid factor: ".concat(_this.factor, ". Must be positive number or tuple of 2 numbers"));
	    }
	    if (_this.widthLower < -1.0 || _this.widthUpper < -1.0) {
	      throw new ValueError("factor must have values larger than -1. Got: ".concat(_this.factor));
	    }
	    if (_this.widthUpper < _this.widthLower) {
	      throw new ValueError("factor cannot have upper bound less than lower bound.\n        Got upper bound: ".concat(_this.widthUpper, ".\n        Got lower bound: ").concat(_this.widthLower, "\n      "));
	    }
	    if (interpolation) {
	      if (INTERPOLATION_METHODS.has(interpolation)) {
	        _this.interpolation = interpolation;
	      } else {
	        throw new ValueError("Invalid interpolation parameter: ".concat(interpolation, " is not implemented"));
	      }
	    }
	    return _this;
	  }
	  _createClass(RandomWidth, [{
	    key: "getConfig",
	    value: function getConfig() {
	      var config = {
	        'factor': this.factor,
	        'interpolation': this.interpolation
	      };
	      var baseConfig = _get(_getPrototypeOf(RandomWidth.prototype), "getConfig", this).call(this);
	      Object.assign(config, baseConfig);
	      return config;
	    }
	  }, {
	    key: "computeOutputShape",
	    value: function computeOutputShape(inputShape) {
	      inputShape = getExactlyOneShape(inputShape);
	      var numChannels = inputShape[2];
	      return [this.imgHeight, -1, numChannels];
	    }
	  }, {
	    key: "call",
	    value: function call(inputs, kwargs) {
	      var _this2 = this;
	      return tidy(function () {
	        var input = getExactlyOneTensor(inputs);
	        _this2.imgHeight = input.shape[input.shape.length - 3];
	        var imgWidth = input.shape[input.shape.length - 2];
	        _this2.widthFactor = randomUniform$1([1], 1.0 + _this2.widthLower, 1.0 + _this2.widthUpper, 'float32', _this2.randomGenerator.next());
	        var adjustedWidth = _this2.widthFactor.dataSync()[0] * imgWidth;
	        adjustedWidth = Math.round(adjustedWidth);
	        var size = [_this2.imgHeight, adjustedWidth];
	        switch (_this2.interpolation) {
	          case 'bilinear':
	            return image$1.resizeBilinear(inputs, size);
	          case 'nearest':
	            return image$1.resizeNearestNeighbor(inputs, size);
	          default:
	            throw new Error("Interpolation is ".concat(_this2.interpolation, "\n          but only ").concat(_toConsumableArray(INTERPOLATION_METHODS), " are supported"));
	        }
	      });
	    }
	  }]);
	  return RandomWidth;
	}(BaseRandomLayer);
	/** @nocollapse */
	RandomWidth.className = 'RandomWidth';
	registerClass(RandomWidth);

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	// TODO(cais): Add doc string to all the public static functions in this
	//   class; include exectuable JavaScript code snippets where applicable
	//   (b/74074458).
	// Input Layer.
	/**
	 * An input layer is an entry point into a `tf.LayersModel`.
	 *
	 * `InputLayer` is generated automatically for `tf.Sequential` models by
	 * specifying the `inputshape` or `batchInputShape` for the first layer.  It
	 * should not be specified explicitly. However, it can be useful sometimes,
	 * e.g., when constructing a sequential model from a subset of another
	 * sequential model's layers. Like the code snippet below shows.
	 *
	 * ```js
	 * // Define a model which simply adds two inputs.
	 * const model1 = tf.sequential();
	 * model1.add(tf.layers.dense({inputShape: [4], units: 3, activation: 'relu'}));
	 * model1.add(tf.layers.dense({units: 1, activation: 'sigmoid'}));
	 * model1.summary();
	 * model1.predict(tf.zeros([1, 4])).print();
	 *
	 * // Construct another model, reusing the second layer of `model1` while
	 * // not using the first layer of `model1`. Note that you cannot add the second
	 * // layer of `model` directly as the first layer of the new sequential model,
	 * // because doing so will lead to an error related to the fact that the layer
	 * // is not an input layer. Instead, you need to create an `inputLayer` and add
	 * // it to the new sequential model before adding the reused layer.
	 * const model2 = tf.sequential();
	 * // Use an inputShape that matches the input shape of `model1`'s second
	 * // layer.
	 * model2.add(tf.layers.inputLayer({inputShape: [3]}));
	 * model2.add(model1.layers[1]);
	 * model2.summary();
	 * model2.predict(tf.zeros([1, 3])).print();
	 * ```
	 *
	 * @doc {heading: 'Layers', subheading: 'Inputs', namespace: 'layers'}
	 */
	function inputLayer(args) {
	  return new InputLayer(args);
	}
	// Advanced Activation Layers.
	/**
	 * Exponential Linear Unit (ELU).
	 *
	 * It follows:
	 * `f(x) =  alpha * (exp(x) - 1.) for x < 0`,
	 * `f(x) = x for x >= 0`.
	 *
	 * Input shape:
	 *   Arbitrary. Use the configuration `inputShape` when using this layer as the
	 *   first layer in a model.
	 *
	 * Output shape:
	 *   Same shape as the input.
	 *
	 * References:
	 *   - [Fast and Accurate Deep Network Learning by Exponential Linear Units
	 * (ELUs)](https://arxiv.org/abs/1511.07289v1)
	 *
	 * @doc {
	 *   heading: 'Layers',
	 *   subheading: 'Advanced Activation',
	 *   namespace: 'layers'
	 * }
	 */
	function elu$2(args) {
	  return new ELU$3(args);
	}
	/**
	 * Rectified Linear Unit activation function.
	 *
	 * Input shape:
	 *   Arbitrary. Use the config field `inputShape` (Array of integers, does
	 *   not include the sample axis) when using this layer as the first layer
	 *   in a model.
	 *
	 * Output shape:
	 *   Same shape as the input.
	 *
	 * @doc {
	 *   heading: 'Layers',
	 *   subheading: 'Advanced Activation',
	 *   namespace: 'layers'
	 * }
	 */
	function reLU(args) {
	  return new ReLU(args);
	}
	/**
	 * Leaky version of a rectified linear unit.
	 *
	 * It allows a small gradient when the unit is not active:
	 * `f(x) = alpha * x for x < 0.`
	 * `f(x) = x for x >= 0.`
	 *
	 * Input shape:
	 *   Arbitrary. Use the configuration `inputShape` when using this layer as the
	 *   first layer in a model.
	 *
	 * Output shape:
	 *   Same shape as the input.
	 *
	 * @doc {
	 *   heading: 'Layers',
	 *   subheading: 'Advanced Activation',
	 *   namespace: 'layers'
	 * }
	 */
	function leakyReLU(args) {
	  return new LeakyReLU(args);
	}
	/**
	 * Parameterized version of a leaky rectified linear unit.
	 *
	 * It follows
	 * `f(x) = alpha * x for x < 0.`
	 * `f(x) = x for x >= 0.`
	 * wherein `alpha` is a trainable weight.
	 *
	 * Input shape:
	 *   Arbitrary. Use the configuration `inputShape` when using this layer as the
	 *   first layer in a model.
	 *
	 * Output shape:
	 *   Same shape as the input.
	 *
	 * @doc {
	 *   heading: 'Layers',
	 *   subheading: 'Advanced Activation',
	 *   namespace: 'layers'
	 * }
	 */
	function prelu$2(args) {
	  return new PReLU(args);
	}
	/**
	 * Softmax activation layer.
	 *
	 * Input shape:
	 *   Arbitrary. Use the configuration `inputShape` when using this layer as the
	 *   first layer in a model.
	 *
	 * Output shape:
	 *   Same shape as the input.
	 *
	 * @doc {
	 *   heading: 'Layers',
	 *   subheading: 'Advanced Activation',
	 *   namespace: 'layers'
	 * }
	 */
	function softmax$2(args) {
	  return new Softmax(args);
	}
	/**
	 * Thresholded Rectified Linear Unit.
	 *
	 * It follows:
	 * `f(x) = x for x > theta`,
	 * `f(x) = 0 otherwise`.
	 *
	 * Input shape:
	 *   Arbitrary. Use the configuration `inputShape` when using this layer as the
	 *   first layer in a model.
	 *
	 * Output shape:
	 *   Same shape as the input.
	 *
	 * References:
	 *   - [Zero-Bias Autoencoders and the Benefits of Co-Adapting
	 * Features](http://arxiv.org/abs/1402.3337)
	 *
	 * @doc {
	 *   heading: 'Layers',
	 *   subheading: 'Advanced Activation',
	 *   namespace: 'layers'
	 * }
	 */
	function thresholdedReLU(args) {
	  return new ThresholdedReLU(args);
	}
	// Convolutional Layers.
	/**
	 * 1D convolution layer (e.g., temporal convolution).
	 *
	 * This layer creates a convolution kernel that is convolved
	 * with the layer input over a single spatial (or temporal) dimension
	 * to produce a tensor of outputs.
	 *
	 * If `use_bias` is True, a bias vector is created and added to the outputs.
	 *
	 * If `activation` is not `null`, it is applied to the outputs as well.
	 *
	 * When using this layer as the first layer in a model, provide an
	 * `inputShape` argument `Array` or `null`.
	 *
	 * For example, `inputShape` would be:
	 * - `[10, 128]` for sequences of 10 vectors of 128-dimensional vectors
	 * - `[null, 128]` for variable-length sequences of 128-dimensional vectors.
	 *
	 * @doc {heading: 'Layers', subheading: 'Convolutional',  namespace: 'layers'}
	 */
	function conv1d(args) {
	  return new Conv1D(args);
	}
	/**
	 * 2D convolution layer (e.g. spatial convolution over images).
	 *
	 * This layer creates a convolution kernel that is convolved
	 * with the layer input to produce a tensor of outputs.
	 *
	 * If `useBias` is True, a bias vector is created and added to the outputs.
	 *
	 * If `activation` is not `null`, it is applied to the outputs as well.
	 *
	 * When using this layer as the first layer in a model,
	 * provide the keyword argument `inputShape`
	 * (Array of integers, does not include the sample axis),
	 * e.g. `inputShape=[128, 128, 3]` for 128x128 RGB pictures
	 * in `dataFormat='channelsLast'`.
	 *
	 * @doc {heading: 'Layers', subheading: 'Convolutional', namespace: 'layers'}
	 */
	function conv2d$1(args) {
	  return new Conv2D(args);
	}
	/**
	 * Transposed convolutional layer (sometimes called Deconvolution).
	 *
	 * The need for transposed convolutions generally arises
	 * from the desire to use a transformation going in the opposite direction of
	 * a normal convolution, i.e., from something that has the shape of the output
	 * of some convolution to something that has the shape of its input while
	 * maintaining a connectivity pattern that is compatible with said
	 * convolution.
	 *
	 * When using this layer as the first layer in a model, provide the
	 * configuration `inputShape` (`Array` of integers, does not include the
	 * sample axis), e.g., `inputShape: [128, 128, 3]` for 128x128 RGB pictures in
	 * `dataFormat: 'channelsLast'`.
	 *
	 * Input shape:
	 *   4D tensor with shape:
	 *   `[batch, channels, rows, cols]` if `dataFormat` is `'channelsFirst'`.
	 *   or 4D tensor with shape
	 *   `[batch, rows, cols, channels]` if `dataFormat` is `'channelsLast'`.
	 *
	 * Output shape:
	 *   4D tensor with shape:
	 *   `[batch, filters, newRows, newCols]` if `dataFormat` is
	 * `'channelsFirst'`. or 4D tensor with shape:
	 *   `[batch, newRows, newCols, filters]` if `dataFormat` is `'channelsLast'`.
	 *
	 * References:
	 *   - [A guide to convolution arithmetic for deep
	 * learning](https://arxiv.org/abs/1603.07285v1)
	 *   - [Deconvolutional
	 * Networks](http://www.matthewzeiler.com/pubs/cvpr2010/cvpr2010.pdf)
	 *
	 * @doc {heading: 'Layers', subheading: 'Convolutional', namespace: 'layers'}
	 */
	function conv2dTranspose(args) {
	  return new Conv2DTranspose(args);
	}
	/**
	 * 3D convolution layer (e.g. spatial convolution over volumes).
	 *
	 * This layer creates a convolution kernel that is convolved
	 * with the layer input to produce a tensor of outputs.
	 *
	 * If `useBias` is True, a bias vector is created and added to the outputs.
	 *
	 * If `activation` is not `null`, it is applied to the outputs as well.
	 *
	 * When using this layer as the first layer in a model,
	 * provide the keyword argument `inputShape`
	 * (Array of integers, does not include the sample axis),
	 * e.g. `inputShape=[128, 128, 128, 1]` for 128x128x128 grayscale volumes
	 * in `dataFormat='channelsLast'`.
	 *
	 * @doc {heading: 'Layers', subheading: 'Convolutional', namespace: 'layers'}
	 */
	function conv3d(args) {
	  return new Conv3D(args);
	}
	function conv3dTranspose(args) {
	  return new Conv3DTranspose(args);
	}
	/**
	 * Depthwise separable 2D convolution.
	 *
	 * Separable convolution consists of first performing
	 * a depthwise spatial convolution
	 * (which acts on each input channel separately)
	 * followed by a pointwise convolution which mixes together the resulting
	 * output channels. The `depthMultiplier` argument controls how many
	 * output channels are generated per input channel in the depthwise step.
	 *
	 * Intuitively, separable convolutions can be understood as
	 * a way to factorize a convolution kernel into two smaller kernels,
	 * or as an extreme version of an Inception block.
	 *
	 * Input shape:
	 *   4D tensor with shape:
	 *     `[batch, channels, rows, cols]` if data_format='channelsFirst'
	 *   or 4D tensor with shape:
	 *     `[batch, rows, cols, channels]` if data_format='channelsLast'.
	 *
	 * Output shape:
	 *   4D tensor with shape:
	 *     `[batch, filters, newRows, newCols]` if data_format='channelsFirst'
	 *   or 4D tensor with shape:
	 *     `[batch, newRows, newCols, filters]` if data_format='channelsLast'.
	 *     `rows` and `cols` values might have changed due to padding.
	 *
	 * @doc {heading: 'Layers', subheading: 'Convolutional', namespace: 'layers'}
	 */
	function separableConv2d(args) {
	  return new SeparableConv2D(args);
	}
	/**
	 * Cropping layer for 2D input (e.g., image).
	 *
	 * This layer can crop an input
	 * at the top, bottom, left and right side of an image tensor.
	 *
	 * Input shape:
	 *   4D tensor with shape:
	 *   - If `dataFormat` is `"channelsLast"`:
	 *     `[batch, rows, cols, channels]`
	 *   - If `data_format` is `"channels_first"`:
	 *     `[batch, channels, rows, cols]`.
	 *
	 * Output shape:
	 *   4D with shape:
	 *   - If `dataFormat` is `"channelsLast"`:
	 *     `[batch, croppedRows, croppedCols, channels]`
	 *    - If `dataFormat` is `"channelsFirst"`:
	 *     `[batch, channels, croppedRows, croppedCols]`.
	 *
	 * Examples
	 * ```js
	 *
	 * const model = tf.sequential();
	 * model.add(tf.layers.cropping2D({cropping:[[2, 2], [2, 2]],
	 *                                inputShape: [128, 128, 3]}));
	 * //now output shape is [batch, 124, 124, 3]
	 * ```
	 *
	 * @doc {heading: 'Layers', subheading: 'Convolutional', namespace: 'layers'}
	 */
	function cropping2D(args) {
	  return new Cropping2D(args);
	}
	/**
	 * Upsampling layer for 2D inputs.
	 *
	 * Repeats the rows and columns of the data
	 * by size[0] and size[1] respectively.
	 *
	 *
	 * Input shape:
	 *    4D tensor with shape:
	 *     - If `dataFormat` is `"channelsLast"`:
	 *         `[batch, rows, cols, channels]`
	 *     - If `dataFormat` is `"channelsFirst"`:
	 *        `[batch, channels, rows, cols]`
	 *
	 * Output shape:
	 *     4D tensor with shape:
	 *     - If `dataFormat` is `"channelsLast"`:
	 *        `[batch, upsampledRows, upsampledCols, channels]`
	 *     - If `dataFormat` is `"channelsFirst"`:
	 *         `[batch, channels, upsampledRows, upsampledCols]`
	 *
	 *
	 * @doc {heading: 'Layers', subheading: 'Convolutional', namespace: 'layers'}
	 */
	function upSampling2d(args) {
	  return new UpSampling2D(args);
	}
	// Convolutional(depthwise) Layers.
	/**
	 * Depthwise separable 2D convolution.
	 *
	 * Depthwise Separable convolutions consists in performing just the first step
	 * in a depthwise spatial convolution (which acts on each input channel
	 * separately). The `depthMultiplier` argument controls how many output channels
	 * are generated per input channel in the depthwise step.
	 *
	 * @doc {heading: 'Layers', subheading: 'Convolutional', namespace: 'layers'}
	 */
	function depthwiseConv2d(args) {
	  return new DepthwiseConv2D(args);
	}
	// Basic Layers.
	/**
	 * Applies an activation function to an output.
	 *
	 * This layer applies element-wise activation function.  Other layers, notably
	 * `dense` can also apply activation functions.  Use this isolated activation
	 * function to extract the values before and after the
	 * activation. For instance:
	 *
	 * ```js
	 * const input = tf.input({shape: [5]});
	 * const denseLayer = tf.layers.dense({units: 1});
	 * const activationLayer = tf.layers.activation({activation: 'relu6'});
	 *
	 * // Obtain the output symbolic tensors by applying the layers in order.
	 * const denseOutput = denseLayer.apply(input);
	 * const activationOutput = activationLayer.apply(denseOutput);
	 *
	 * // Create the model based on the inputs.
	 * const model = tf.model({
	 *     inputs: input,
	 *     outputs: [denseOutput, activationOutput]
	 * });
	 *
	 * // Collect both outputs and print separately.
	 * const [denseOut, activationOut] = model.predict(tf.randomNormal([6, 5]));
	 * denseOut.print();
	 * activationOut.print();
	 * ```
	 *
	 * @doc {heading: 'Layers', subheading: 'Basic', namespace: 'layers'}
	 */
	function activation(args) {
	  return new Activation(args);
	}
	/**
	 * Creates a dense (fully connected) layer.
	 *
	 * This layer implements the operation:
	 *   `output = activation(dot(input, kernel) + bias)`
	 *
	 * `activation` is the element-wise activation function
	 *   passed as the `activation` argument.
	 *
	 * `kernel` is a weights matrix created by the layer.
	 *
	 * `bias` is a bias vector created by the layer (only applicable if `useBias`
	 * is `true`).
	 *
	 * **Input shape:**
	 *
	 *   nD `tf.Tensor` with shape: `(batchSize, ..., inputDim)`.
	 *
	 *   The most common situation would be
	 *   a 2D input with shape `(batchSize, inputDim)`.
	 *
	 * **Output shape:**
	 *
	 *   nD tensor with shape: `(batchSize, ..., units)`.
	 *
	 *   For instance, for a 2D input with shape `(batchSize, inputDim)`,
	 *   the output would have shape `(batchSize, units)`.
	 *
	 * Note: if the input to the layer has a rank greater than 2, then it is
	 * flattened prior to the initial dot product with the kernel.
	 *
	 * @doc {heading: 'Layers', subheading: 'Basic', namespace: 'layers'}
	 */
	function dense(args) {
	  return new Dense(args);
	}
	/**
	 * Applies
	 * [dropout](http://www.cs.toronto.edu/~rsalakhu/papers/srivastava14a.pdf) to
	 * the input.
	 *
	 * Dropout consists in randomly setting a fraction `rate` of input units to 0 at
	 * each update during training time, which helps prevent overfitting.
	 *
	 * @doc {heading: 'Layers', subheading: 'Basic', namespace: 'layers'}
	 */
	function dropout(args) {
	  return new Dropout(args);
	}
	/**
	 * Spatial 1D version of Dropout.
	 *
	 * This Layer type performs the same function as the Dropout layer, but it drops
	 * entire 1D feature maps instead of individual elements. For example, if an
	 * input example consists of 3 timesteps and the feature map for each timestep
	 * has a size of 4, a `spatialDropout1d` layer may zero out the feature maps
	 * of the 1st timesteps and 2nd timesteps completely while sparing all feature
	 * elements of the 3rd timestep.
	 *
	 * If adjacent frames (timesteps) are strongly correlated (as is normally the
	 * case in early convolution layers), regular dropout will not regularize the
	 * activation and will otherwise just result in merely an effective learning
	 * rate decrease. In this case, `spatialDropout1d` will help promote
	 * independence among feature maps and should be used instead.
	 *
	 * **Arguments:**
	 *   rate: A floating-point number >=0 and <=1. Fraction of the input elements
	 *     to drop.
	 *
	 * **Input shape:**
	 *   3D tensor with shape `(samples, timesteps, channels)`.
	 *
	 * **Output shape:**
	 *   Same as the input shape.
	 *
	 * References:
	 *   - [Efficient Object Localization Using Convolutional
	 *      Networks](https://arxiv.org/abs/1411.4280)
	 *
	 * @doc {heading: 'Layers', subheading: 'Basic', namespace: 'layers'}
	 */
	function spatialDropout1d(args) {
	  return new SpatialDropout1D(args);
	}
	/**
	 * Flattens the input. Does not affect the batch size.
	 *
	 * A `Flatten` layer flattens each batch in its inputs to 1D (making the output
	 * 2D).
	 *
	 * For example:
	 *
	 * ```js
	 * const input = tf.input({shape: [4, 3]});
	 * const flattenLayer = tf.layers.flatten();
	 * // Inspect the inferred output shape of the flatten layer, which
	 * // equals `[null, 12]`. The 2nd dimension is 4 * 3, i.e., the result of the
	 * // flattening. (The 1st dimension is the undermined batch size.)
	 * console.log(JSON.stringify(flattenLayer.apply(input).shape));
	 * ```
	 *
	 * @doc {heading: 'Layers', subheading: 'Basic', namespace: 'layers'}
	 */
	function flatten(args) {
	  return new Flatten(args);
	}
	/**
	 * Repeats the input n times in a new dimension.
	 *
	 * ```js
	 *  const model = tf.sequential();
	 *  model.add(tf.layers.repeatVector({n: 4, inputShape: [2]}));
	 *  const x = tf.tensor2d([[10, 20]]);
	 *  // Use the model to do inference on a data point the model hasn't seen
	 *  model.predict(x).print();
	 *  // output shape is now [batch, 2, 4]
	 * ```
	 *
	 * @doc {heading: 'Layers', subheading: 'Basic', namespace: 'layers'}
	 */
	function repeatVector(args) {
	  return new RepeatVector(args);
	}
	/**
	 * Reshapes an input to a certain shape.
	 *
	 * ```js
	 * const input = tf.input({shape: [4, 3]});
	 * const reshapeLayer = tf.layers.reshape({targetShape: [2, 6]});
	 * // Inspect the inferred output shape of the Reshape layer, which
	 * // equals `[null, 2, 6]`. (The 1st dimension is the undermined batch size.)
	 * console.log(JSON.stringify(reshapeLayer.apply(input).shape));
	 * ```
	 *
	 * Input shape:
	 *   Arbitrary, although all dimensions in the input shape must be fixed.
	 *   Use the configuration `inputShape` when using this layer as the
	 *   first layer in a model.
	 *
	 *
	 * Output shape:
	 *   [batchSize, targetShape[0], targetShape[1], ...,
	 *    targetShape[targetShape.length - 1]].
	 *
	 * @doc {heading: 'Layers', subheading: 'Basic', namespace: 'layers'}
	 */
	function reshape$2(args) {
	  return new Reshape(args);
	}
	/**
	 * Permutes the dimensions of the input according to a given pattern.
	 *
	 * Useful for, e.g., connecting RNNs and convnets together.
	 *
	 * Example:
	 *
	 * ```js
	 * const model = tf.sequential();
	 * model.add(tf.layers.permute({
	 *   dims: [2, 1],
	 *   inputShape: [10, 64]
	 * }));
	 * console.log(model.outputShape);
	 * // Now model's output shape is [null, 64, 10], where null is the
	 * // unpermuted sample (batch) dimension.
	 * ```
	 *
	 * Input shape:
	 *   Arbitrary. Use the configuration field `inputShape` when using this
	 *   layer as the first layer in a model.
	 *
	 * Output shape:
	 *   Same rank as the input shape, but with the dimensions re-ordered (i.e.,
	 *   permuted) according to the `dims` configuration of this layer.
	 *
	 * @doc {heading: 'Layers', subheading: 'Basic', namespace: 'layers'}
	 */
	function permute(args) {
	  return new Permute(args);
	}
	/**
	 * Maps positive integers (indices) into dense vectors of fixed size.
	 * E.g. [[4], [20]] -> [[0.25, 0.1], [0.6, -0.2]]
	 *
	 * **Input shape:** 2D tensor with shape: `[batchSize, sequenceLength]`.
	 *
	 * **Output shape:** 3D tensor with shape: `[batchSize, sequenceLength,
	 * outputDim]`.
	 *
	 * @doc {heading: 'Layers', subheading: 'Basic', namespace: 'layers'}
	 */
	function embedding(args) {
	  return new Embedding(args);
	}
	// Merge Layers.
	/**
	 * Layer that performs element-wise addition on an `Array` of inputs.
	 *
	 * It takes as input a list of tensors, all of the same shape, and returns a
	 * single tensor (also of the same shape). The inputs are specified as an
	 * `Array` when the `apply` method of the `Add` layer instance is called. For
	 * example:
	 *
	 * ```js
	 * const input1 = tf.input({shape: [2, 2]});
	 * const input2 = tf.input({shape: [2, 2]});
	 * const addLayer = tf.layers.add();
	 * const sum = addLayer.apply([input1, input2]);
	 * console.log(JSON.stringify(sum.shape));
	 * // You get [null, 2, 2], with the first dimension as the undetermined batch
	 * // dimension.
	 * ```
	 *
	 * @doc {heading: 'Layers', subheading: 'Merge', namespace: 'layers'}
	 */
	function add$1(args) {
	  return new Add(args);
	}
	/**
	 * Layer that performs element-wise averaging on an `Array` of inputs.
	 *
	 * It takes as input a list of tensors, all of the same shape, and returns a
	 * single tensor (also of the same shape). For example:
	 *
	 * ```js
	 * const input1 = tf.input({shape: [2, 2]});
	 * const input2 = tf.input({shape: [2, 2]});
	 * const averageLayer = tf.layers.average();
	 * const average = averageLayer.apply([input1, input2]);
	 * console.log(JSON.stringify(average.shape));
	 * // You get [null, 2, 2], with the first dimension as the undetermined batch
	 * // dimension.
	 * ```
	 *
	 * @doc {heading: 'Layers', subheading: 'Merge', namespace: 'layers'}
	 */
	function average(args) {
	  return new Average(args);
	}
	/**
	 * Layer that concatenates an `Array` of inputs.
	 *
	 * It takes a list of tensors, all of the same shape except for the
	 * concatenation axis, and returns a single tensor, the concatenation
	 * of all inputs. For example:
	 *
	 * ```js
	 * const input1 = tf.input({shape: [2, 2]});
	 * const input2 = tf.input({shape: [2, 3]});
	 * const concatLayer = tf.layers.concatenate();
	 * const output = concatLayer.apply([input1, input2]);
	 * console.log(JSON.stringify(output.shape));
	 * // You get [null, 2, 5], with the first dimension as the undetermined batch
	 * // dimension. The last dimension (5) is the result of concatenating the
	 * // last dimensions of the inputs (2 and 3).
	 * ```
	 *
	 * @doc {heading: 'Layers', subheading: 'Merge', namespace: 'layers'}
	 */
	function concatenate(args) {
	  return new Concatenate(args);
	}
	/**
	 * Layer that computes the element-wise maximum of an `Array` of inputs.
	 *
	 * It takes as input a list of tensors, all of the same shape, and returns a
	 * single tensor (also of the same shape). For example:
	 *
	 * ```js
	 * const input1 = tf.input({shape: [2, 2]});
	 * const input2 = tf.input({shape: [2, 2]});
	 * const maxLayer = tf.layers.maximum();
	 * const max = maxLayer.apply([input1, input2]);
	 * console.log(JSON.stringify(max.shape));
	 * // You get [null, 2, 2], with the first dimension as the undetermined batch
	 * // dimension.
	 * ```
	 *
	 * @doc {heading: 'Layers', subheading: 'Merge', namespace: 'layers'}
	 */
	function maximum$2(args) {
	  return new Maximum(args);
	}
	/**
	 * Layer that computes the element-wise minimum of an `Array` of inputs.
	 *
	 * It takes as input a list of tensors, all of the same shape, and returns a
	 * single tensor (also of the same shape). For example:
	 *
	 * ```js
	 * const input1 = tf.input({shape: [2, 2]});
	 * const input2 = tf.input({shape: [2, 2]});
	 * const minLayer = tf.layers.minimum();
	 * const min = minLayer.apply([input1, input2]);
	 * console.log(JSON.stringify(min.shape));
	 * // You get [null, 2, 2], with the first dimension as the undetermined batch
	 * // dimension.
	 * ```
	 *
	 * @doc {heading: 'Layers', subheading: 'Merge', namespace: 'layers'}
	 */
	function minimum$2(args) {
	  return new Minimum(args);
	}
	/**
	 * Layer that multiplies (element-wise) an `Array` of inputs.
	 *
	 * It takes as input an Array of tensors, all of the same
	 * shape, and returns a single tensor (also of the same shape).
	 * For example:
	 *
	 * ```js
	 * const input1 = tf.input({shape: [2, 2]});
	 * const input2 = tf.input({shape: [2, 2]});
	 * const input3 = tf.input({shape: [2, 2]});
	 * const multiplyLayer = tf.layers.multiply();
	 * const product = multiplyLayer.apply([input1, input2, input3]);
	 * console.log(product.shape);
	 * // You get [null, 2, 2], with the first dimension as the undetermined batch
	 * // dimension.
	 *
	 * @doc {heading: 'Layers', subheading: 'Merge', namespace: 'layers'}
	 */
	function multiply$2(args) {
	  return new Multiply(args);
	}
	/**
	 * Layer that computes a dot product between samples in two tensors.
	 *
	 * E.g., if applied to a list of two tensors `a` and `b` both of shape
	 * `[batchSize, n]`, the output will be a tensor of shape `[batchSize, 1]`,
	 * where each entry at index `[i, 0]` will be the dot product between
	 * `a[i, :]` and `b[i, :]`.
	 *
	 * Example:
	 *
	 * ```js
	 * const dotLayer = tf.layers.dot({axes: -1});
	 * const x1 = tf.tensor2d([[10, 20], [30, 40]]);
	 * const x2 = tf.tensor2d([[-1, -2], [-3, -4]]);
	 *
	 * // Invoke the layer's apply() method in eager (imperative) mode.
	 * const y = dotLayer.apply([x1, x2]);
	 * y.print();
	 * ```
	 *
	 * @doc {heading: 'Layers', subheading: 'Merge', namespace: 'layers'}
	 */
	function dot(args) {
	  return new Dot(args);
	}
	// Normalization Layers.
	/**
	 * Batch normalization layer (Ioffe and Szegedy, 2014).
	 *
	 * Normalize the activations of the previous layer at each batch,
	 * i.e. applies a transformation that maintains the mean activation
	 * close to 0 and the activation standard deviation close to 1.
	 *
	 * Input shape:
	 *   Arbitrary. Use the keyword argument `inputShape` (Array of integers, does
	 *   not include the sample axis) when calling the constructor of this class,
	 *   if this layer is used as a first layer in a model.
	 *
	 * Output shape:
	 *   Same shape as input.
	 *
	 * References:
	 *   - [Batch Normalization: Accelerating Deep Network Training by Reducing
	 * Internal Covariate Shift](https://arxiv.org/abs/1502.03167)
	 *
	 * @doc {heading: 'Layers', subheading: 'Normalization', namespace: 'layers'}
	 */
	function batchNormalization(args) {
	  return new BatchNormalization(args);
	}
	/**
	 * Layer-normalization layer (Ba et al., 2016).
	 *
	 * Normalizes the activations of the previous layer for each given example in a
	 * batch independently, instead of across a batch like in `batchNormalization`.
	 * In other words, this layer applies a transformation that maintains the mean
	 * activation within each example close to 0 and activation variance close to 1.
	 *
	 * Input shape:
	 *   Arbitrary. Use the argument `inputShape` when using this layer as the first
	 *   layer in a model.
	 *
	 * Output shape:
	 *   Same as input.
	 *
	 * References:
	 *   - [Layer Normalization](https://arxiv.org/abs/1607.06450)
	 *
	 * @doc {heading: 'Layers', subheading: 'Normalization', namespace: 'layers'}
	 */
	function layerNormalization(args) {
	  return new LayerNormalization(args);
	}
	// Padding Layers.
	/**
	 * Zero-padding layer for 2D input (e.g., image).
	 *
	 * This layer can add rows and columns of zeros
	 * at the top, bottom, left and right side of an image tensor.
	 *
	 * Input shape:
	 *   4D tensor with shape:
	 *   - If `dataFormat` is `"channelsLast"`:
	 *     `[batch, rows, cols, channels]`
	 *   - If `data_format` is `"channels_first"`:
	 *     `[batch, channels, rows, cols]`.
	 *
	 * Output shape:
	 *   4D with shape:
	 *   - If `dataFormat` is `"channelsLast"`:
	 *     `[batch, paddedRows, paddedCols, channels]`
	 *    - If `dataFormat` is `"channelsFirst"`:
	 *     `[batch, channels, paddedRows, paddedCols]`.
	 *
	 * @doc {heading: 'Layers', subheading: 'Padding', namespace: 'layers'}
	 */
	function zeroPadding2d(args) {
	  return new ZeroPadding2D(args);
	}
	// Pooling Layers.
	/**
	 * Average pooling operation for spatial data.
	 *
	 * Input shape: `[batchSize, inLength, channels]`
	 *
	 * Output shape: `[batchSize, pooledLength, channels]`
	 *
	 * `tf.avgPool1d` is an alias.
	 *
	 * @doc {heading: 'Layers', subheading: 'Pooling', namespace: 'layers'}
	 */
	function averagePooling1d(args) {
	  return new AveragePooling1D(args);
	}
	function avgPool1d(args) {
	  return averagePooling1d(args);
	}
	// For backwards compatibility.
	// See https://github.com/tensorflow/tfjs/issues/152
	function avgPooling1d(args) {
	  return averagePooling1d(args);
	}
	/**
	 * Average pooling operation for spatial data.
	 *
	 * Input shape:
	 *  - If `dataFormat === CHANNEL_LAST`:
	 *      4D tensor with shape:
	 *      `[batchSize, rows, cols, channels]`
	 *  - If `dataFormat === CHANNEL_FIRST`:
	 *      4D tensor with shape:
	 *      `[batchSize, channels, rows, cols]`
	 *
	 * Output shape
	 *  - If `dataFormat === CHANNEL_LAST`:
	 *      4D tensor with shape:
	 *      `[batchSize, pooledRows, pooledCols, channels]`
	 *  - If `dataFormat === CHANNEL_FIRST`:
	 *      4D tensor with shape:
	 *      `[batchSize, channels, pooledRows, pooledCols]`
	 *
	 * `tf.avgPool2d` is an alias.
	 *
	 * @doc {heading: 'Layers', subheading: 'Pooling', namespace: 'layers'}
	 */
	function averagePooling2d(args) {
	  return new AveragePooling2D(args);
	}
	function avgPool2d(args) {
	  return averagePooling2d(args);
	}
	// For backwards compatibility.
	// See https://github.com/tensorflow/tfjs/issues/152
	function avgPooling2d(args) {
	  return averagePooling2d(args);
	}
	/**
	 * Average pooling operation for 3D data.
	 *
	 * Input shape
	 *   - If `dataFormat === channelsLast`:
	 *       5D tensor with shape:
	 *       `[batchSize, depths, rows, cols, channels]`
	 *   - If `dataFormat === channelsFirst`:
	 *      4D tensor with shape:
	 *       `[batchSize, channels, depths, rows, cols]`
	 *
	 * Output shape
	 *   - If `dataFormat=channelsLast`:
	 *       5D tensor with shape:
	 *       `[batchSize, pooledDepths, pooledRows, pooledCols, channels]`
	 *   - If `dataFormat=channelsFirst`:
	 *       5D tensor with shape:
	 *       `[batchSize, channels, pooledDepths, pooledRows, pooledCols]`
	 *
	 * @doc {heading: 'Layers', subheading: 'Pooling', namespace: 'layers'}
	 */
	function averagePooling3d(args) {
	  return new AveragePooling3D(args);
	}
	function avgPool3d(args) {
	  return averagePooling3d(args);
	}
	// For backwards compatibility.
	// See https://github.com/tensorflow/tfjs/issues/152
	function avgPooling3d(args) {
	  return averagePooling3d(args);
	}
	/**
	 * Global average pooling operation for temporal data.
	 *
	 * Input Shape: 3D tensor with shape: `[batchSize, steps, features]`.
	 *
	 * Output Shape: 2D tensor with shape: `[batchSize, features]`.
	 *
	 * @doc {heading: 'Layers', subheading: 'Pooling', namespace: 'layers'}
	 */
	function globalAveragePooling1d(args) {
	  return new GlobalAveragePooling1D(args);
	}
	/**
	 * Global average pooling operation for spatial data.
	 *
	 * Input shape:
	 *   - If `dataFormat` is `CHANNEL_LAST`:
	 *       4D tensor with shape: `[batchSize, rows, cols, channels]`.
	 *   - If `dataFormat` is `CHANNEL_FIRST`:
	 *       4D tensor with shape: `[batchSize, channels, rows, cols]`.
	 *
	 * Output shape:
	 *   2D tensor with shape: `[batchSize, channels]`.
	 *
	 * @doc {heading: 'Layers', subheading: 'Pooling', namespace: 'layers'}
	 */
	function globalAveragePooling2d(args) {
	  return new GlobalAveragePooling2D(args);
	}
	/**
	 * Global max pooling operation for temporal data.
	 *
	 * Input Shape: 3D tensor with shape: `[batchSize, steps, features]`.
	 *
	 * Output Shape: 2D tensor with shape: `[batchSize, features]`.
	 *
	 * @doc {heading: 'Layers', subheading: 'Pooling', namespace: 'layers'}
	 */
	function globalMaxPooling1d(args) {
	  return new GlobalMaxPooling1D(args);
	}
	/**
	 * Global max pooling operation for spatial data.
	 *
	 * Input shape:
	 *   - If `dataFormat` is `CHANNEL_LAST`:
	 *       4D tensor with shape: `[batchSize, rows, cols, channels]`.
	 *   - If `dataFormat` is `CHANNEL_FIRST`:
	 *       4D tensor with shape: `[batchSize, channels, rows, cols]`.
	 *
	 * Output shape:
	 *   2D tensor with shape: `[batchSize, channels]`.
	 *
	 * @doc {heading: 'Layers', subheading: 'Pooling', namespace: 'layers'}
	 */
	function globalMaxPooling2d(args) {
	  return new GlobalMaxPooling2D(args);
	}
	/**
	 * Max pooling operation for temporal data.
	 *
	 * Input shape:  `[batchSize, inLength, channels]`
	 *
	 * Output shape: `[batchSize, pooledLength, channels]`
	 *
	 * @doc {heading: 'Layers', subheading: 'Pooling', namespace: 'layers'}
	 */
	function maxPooling1d(args) {
	  return new MaxPooling1D(args);
	}
	/**
	 * Max pooling operation for spatial data.
	 *
	 * Input shape
	 *   - If `dataFormat === CHANNEL_LAST`:
	 *       4D tensor with shape:
	 *       `[batchSize, rows, cols, channels]`
	 *   - If `dataFormat === CHANNEL_FIRST`:
	 *      4D tensor with shape:
	 *       `[batchSize, channels, rows, cols]`
	 *
	 * Output shape
	 *   - If `dataFormat=CHANNEL_LAST`:
	 *       4D tensor with shape:
	 *       `[batchSize, pooledRows, pooledCols, channels]`
	 *   - If `dataFormat=CHANNEL_FIRST`:
	 *       4D tensor with shape:
	 *       `[batchSize, channels, pooledRows, pooledCols]`
	 *
	 * @doc {heading: 'Layers', subheading: 'Pooling', namespace: 'layers'}
	 */
	function maxPooling2d(args) {
	  return new MaxPooling2D(args);
	}
	/**
	 * Max pooling operation for 3D data.
	 *
	 * Input shape
	 *   - If `dataFormat === channelsLast`:
	 *       5D tensor with shape:
	 *       `[batchSize, depths, rows, cols, channels]`
	 *   - If `dataFormat === channelsFirst`:
	 *      5D tensor with shape:
	 *       `[batchSize, channels, depths, rows, cols]`
	 *
	 * Output shape
	 *   - If `dataFormat=channelsLast`:
	 *       5D tensor with shape:
	 *       `[batchSize, pooledDepths, pooledRows, pooledCols, channels]`
	 *   - If `dataFormat=channelsFirst`:
	 *       5D tensor with shape:
	 *       `[batchSize, channels, pooledDepths, pooledRows, pooledCols]`
	 *
	 * @doc {heading: 'Layers', subheading: 'Pooling', namespace: 'layers'}
	 */
	function maxPooling3d(args) {
	  return new MaxPooling3D(args);
	}
	// Recurrent Layers.
	/**
	 * Gated Recurrent Unit - Cho et al. 2014.
	 *
	 * This is an `RNN` layer consisting of one `GRUCell`. However, unlike
	 * the underlying `GRUCell`, the `apply` method of `SimpleRNN` operates
	 * on a sequence of inputs. The shape of the input (not including the first,
	 * batch dimension) needs to be at least 2-D, with the first dimension being
	 * time steps. For example:
	 *
	 * ```js
	 * const rnn = tf.layers.gru({units: 8, returnSequences: true});
	 *
	 * // Create an input with 10 time steps.
	 * const input = tf.input({shape: [10, 20]});
	 * const output = rnn.apply(input);
	 *
	 * console.log(JSON.stringify(output.shape));
	 * // [null, 10, 8]: 1st dimension is unknown batch size; 2nd dimension is the
	 * // same as the sequence length of `input`, due to `returnSequences`: `true`;
	 * // 3rd dimension is the `GRUCell`'s number of units.
	 *
	 * @doc {heading: 'Layers', subheading: 'Recurrent', namespace: 'layers'}
	 */
	function gru(args) {
	  return new GRU(args);
	}
	/**
	 * Cell class for `GRU`.
	 *
	 * `GRUCell` is distinct from the `RNN` subclass `GRU` in that its
	 * `apply` method takes the input data of only a single time step and returns
	 * the cell's output at the time step, while `GRU` takes the input data
	 * over a number of time steps. For example:
	 *
	 * ```js
	 * const cell = tf.layers.gruCell({units: 2});
	 * const input = tf.input({shape: [10]});
	 * const output = cell.apply(input);
	 *
	 * console.log(JSON.stringify(output.shape));
	 * // [null, 10]: This is the cell's output at a single time step. The 1st
	 * // dimension is the unknown batch size.
	 * ```
	 *
	 * Instance(s) of `GRUCell` can be used to construct `RNN` layers. The
	 * most typical use of this workflow is to combine a number of cells into a
	 * stacked RNN cell (i.e., `StackedRNNCell` internally) and use it to create an
	 * RNN. For example:
	 *
	 * ```js
	 * const cells = [
	 *   tf.layers.gruCell({units: 4}),
	 *   tf.layers.gruCell({units: 8}),
	 * ];
	 * const rnn = tf.layers.rnn({cell: cells, returnSequences: true});
	 *
	 * // Create an input with 10 time steps and a length-20 vector at each step.
	 * const input = tf.input({shape: [10, 20]});
	 * const output = rnn.apply(input);
	 *
	 * console.log(JSON.stringify(output.shape));
	 * // [null, 10, 8]: 1st dimension is unknown batch size; 2nd dimension is the
	 * // same as the sequence length of `input`, due to `returnSequences`: `true`;
	 * // 3rd dimension is the last `gruCell`'s number of units.
	 * ```
	 *
	 * To create an `RNN` consisting of only *one* `GRUCell`, use the
	 * `tf.layers.gru`.
	 *
	 * @doc {heading: 'Layers', subheading: 'Recurrent', namespace: 'layers'}
	 */
	function gruCell(args) {
	  return new GRUCell(args);
	}
	/**
	 * Long-Short Term Memory layer - Hochreiter 1997.
	 *
	 * This is an `RNN` layer consisting of one `LSTMCell`. However, unlike
	 * the underlying `LSTMCell`, the `apply` method of `LSTM` operates
	 * on a sequence of inputs. The shape of the input (not including the first,
	 * batch dimension) needs to be at least 2-D, with the first dimension being
	 * time steps. For example:
	 *
	 * ```js
	 * const lstm = tf.layers.lstm({units: 8, returnSequences: true});
	 *
	 * // Create an input with 10 time steps.
	 * const input = tf.input({shape: [10, 20]});
	 * const output = lstm.apply(input);
	 *
	 * console.log(JSON.stringify(output.shape));
	 * // [null, 10, 8]: 1st dimension is unknown batch size; 2nd dimension is the
	 * // same as the sequence length of `input`, due to `returnSequences`: `true`;
	 * // 3rd dimension is the `LSTMCell`'s number of units.
	 *
	 * @doc {heading: 'Layers', subheading: 'Recurrent', namespace: 'layers'}
	 */
	function lstm(args) {
	  return new LSTM(args);
	}
	/**
	 * Cell class for `LSTM`.
	 *
	 * `LSTMCell` is distinct from the `RNN` subclass `LSTM` in that its
	 * `apply` method takes the input data of only a single time step and returns
	 * the cell's output at the time step, while `LSTM` takes the input data
	 * over a number of time steps. For example:
	 *
	 * ```js
	 * const cell = tf.layers.lstmCell({units: 2});
	 * const input = tf.input({shape: [10]});
	 * const output = cell.apply(input);
	 *
	 * console.log(JSON.stringify(output.shape));
	 * // [null, 10]: This is the cell's output at a single time step. The 1st
	 * // dimension is the unknown batch size.
	 * ```
	 *
	 * Instance(s) of `LSTMCell` can be used to construct `RNN` layers. The
	 * most typical use of this workflow is to combine a number of cells into a
	 * stacked RNN cell (i.e., `StackedRNNCell` internally) and use it to create an
	 * RNN. For example:
	 *
	 * ```js
	 * const cells = [
	 *   tf.layers.lstmCell({units: 4}),
	 *   tf.layers.lstmCell({units: 8}),
	 * ];
	 * const rnn = tf.layers.rnn({cell: cells, returnSequences: true});
	 *
	 * // Create an input with 10 time steps and a length-20 vector at each step.
	 * const input = tf.input({shape: [10, 20]});
	 * const output = rnn.apply(input);
	 *
	 * console.log(JSON.stringify(output.shape));
	 * // [null, 10, 8]: 1st dimension is unknown batch size; 2nd dimension is the
	 * // same as the sequence length of `input`, due to `returnSequences`: `true`;
	 * // 3rd dimension is the last `lstmCell`'s number of units.
	 * ```
	 *
	 * To create an `RNN` consisting of only *one* `LSTMCell`, use the
	 * `tf.layers.lstm`.
	 *
	 * @doc {heading: 'Layers', subheading: 'Recurrent', namespace: 'layers'}
	 */
	function lstmCell(args) {
	  return new LSTMCell(args);
	}
	/**
	 * Fully-connected RNN where the output is to be fed back to input.
	 *
	 * This is an `RNN` layer consisting of one `SimpleRNNCell`. However, unlike
	 * the underlying `SimpleRNNCell`, the `apply` method of `SimpleRNN` operates
	 * on a sequence of inputs. The shape of the input (not including the first,
	 * batch dimension) needs to be at least 2-D, with the first dimension being
	 * time steps. For example:
	 *
	 * ```js
	 * const rnn = tf.layers.simpleRNN({units: 8, returnSequences: true});
	 *
	 * // Create an input with 10 time steps.
	 * const input = tf.input({shape: [10, 20]});
	 * const output = rnn.apply(input);
	 *
	 * console.log(JSON.stringify(output.shape));
	 * // [null, 10, 8]: 1st dimension is unknown batch size; 2nd dimension is the
	 * // same as the sequence length of `input`, due to `returnSequences`: `true`;
	 * // 3rd dimension is the `SimpleRNNCell`'s number of units.
	 * ```
	 *
	 * @doc {heading: 'Layers', subheading: 'Recurrent', namespace: 'layers'}
	 */
	function simpleRNN(args) {
	  return new SimpleRNN(args);
	}
	/**
	 * Cell class for `SimpleRNN`.
	 *
	 * `SimpleRNNCell` is distinct from the `RNN` subclass `SimpleRNN` in that its
	 * `apply` method takes the input data of only a single time step and returns
	 * the cell's output at the time step, while `SimpleRNN` takes the input data
	 * over a number of time steps. For example:
	 *
	 * ```js
	 * const cell = tf.layers.simpleRNNCell({units: 2});
	 * const input = tf.input({shape: [10]});
	 * const output = cell.apply(input);
	 *
	 * console.log(JSON.stringify(output.shape));
	 * // [null, 10]: This is the cell's output at a single time step. The 1st
	 * // dimension is the unknown batch size.
	 * ```
	 *
	 * Instance(s) of `SimpleRNNCell` can be used to construct `RNN` layers. The
	 * most typical use of this workflow is to combine a number of cells into a
	 * stacked RNN cell (i.e., `StackedRNNCell` internally) and use it to create an
	 * RNN. For example:
	 *
	 * ```js
	 * const cells = [
	 *   tf.layers.simpleRNNCell({units: 4}),
	 *   tf.layers.simpleRNNCell({units: 8}),
	 * ];
	 * const rnn = tf.layers.rnn({cell: cells, returnSequences: true});
	 *
	 * // Create an input with 10 time steps and a length-20 vector at each step.
	 * const input = tf.input({shape: [10, 20]});
	 * const output = rnn.apply(input);
	 *
	 * console.log(JSON.stringify(output.shape));
	 * // [null, 10, 8]: 1st dimension is unknown batch size; 2nd dimension is the
	 * // same as the sequence length of `input`, due to `returnSequences`: `true`;
	 * // 3rd dimension is the last `SimpleRNNCell`'s number of units.
	 * ```
	 *
	 * To create an `RNN` consisting of only *one* `SimpleRNNCell`, use the
	 * `tf.layers.simpleRNN`.
	 *
	 * @doc {heading: 'Layers', subheading: 'Recurrent', namespace: 'layers'}
	 */
	function simpleRNNCell(args) {
	  return new SimpleRNNCell(args);
	}
	/**
	 * Convolutional LSTM layer - Xingjian Shi 2015.
	 *
	 * This is a `ConvRNN2D` layer consisting of one `ConvLSTM2DCell`. However,
	 * unlike the underlying `ConvLSTM2DCell`, the `apply` method of `ConvLSTM2D`
	 * operates on a sequence of inputs. The shape of the input (not including the
	 * first, batch dimension) needs to be 4-D, with the first dimension being time
	 * steps. For example:
	 *
	 * ```js
	 * const filters = 3;
	 * const kernelSize = 3;
	 *
	 * const batchSize = 4;
	 * const sequenceLength = 2;
	 * const size = 5;
	 * const channels = 3;
	 *
	 * const inputShape = [batchSize, sequenceLength, size, size, channels];
	 * const input = tf.ones(inputShape);
	 *
	 * const layer = tf.layers.convLstm2d({filters, kernelSize});
	 *
	 * const output = layer.apply(input);
	 * ```
	 */
	/** @doc {heading: 'Layers', subheading: 'Recurrent', namespace: 'layers'} */
	function convLstm2d(args) {
	  return new ConvLSTM2D(args);
	}
	/**
	 * Cell class for `ConvLSTM2D`.
	 *
	 * `ConvLSTM2DCell` is distinct from the `ConvRNN2D` subclass `ConvLSTM2D` in
	 * that its `call` method takes the input data of only a single time step and
	 * returns the cell's output at the time step, while `ConvLSTM2D` takes the
	 * input data over a number of time steps. For example:
	 *
	 * ```js
	 * const filters = 3;
	 * const kernelSize = 3;
	 *
	 * const sequenceLength = 1;
	 * const size = 5;
	 * const channels = 3;
	 *
	 * const inputShape = [sequenceLength, size, size, channels];
	 * const input = tf.ones(inputShape);
	 *
	 * const cell = tf.layers.convLstm2dCell({filters, kernelSize});
	 *
	 * cell.build(input.shape);
	 *
	 * const outputSize = size - kernelSize + 1;
	 * const outShape = [sequenceLength, outputSize, outputSize, filters];
	 *
	 * const initialH = tf.zeros(outShape);
	 * const initialC = tf.zeros(outShape);
	 *
	 * const [o, h, c] = cell.call([input, initialH, initialC], {});
	 * ```
	 */
	/** @doc {heading: 'Layers', subheading: 'Recurrent', namespace: 'layers'} */
	function convLstm2dCell(args) {
	  return new ConvLSTM2DCell(args);
	}
	/**
	 * Base class for recurrent layers.
	 *
	 * Input shape:
	 *   3D tensor with shape `[batchSize, timeSteps, inputDim]`.
	 *
	 * Output shape:
	 *   - if `returnState`, an Array of tensors (i.e., `tf.Tensor`s). The first
	 *     tensor is the output. The remaining tensors are the states at the
	 *     last time step, each with shape `[batchSize, units]`.
	 *   - if `returnSequences`, the output will have shape
	 *     `[batchSize, timeSteps, units]`.
	 *   - else, the output will have shape `[batchSize, units]`.
	 *
	 * Masking:
	 *   This layer supports masking for input data with a variable number
	 *   of timesteps. To introduce masks to your data,
	 *   use an embedding layer with the `mask_zero` parameter
	 *   set to `True`.
	 *
	 * Notes on using statefulness in RNNs:
	 *   You can set RNN layers to be 'stateful', which means that the states
	 *   computed for the samples in one batch will be reused as initial states
	 *   for the samples in the next batch. This assumes a one-to-one mapping
	 *   between samples in different successive batches.
	 *
	 *   To enable statefulness:
	 *     - specify `stateful: true` in the layer constructor.
	 *     - specify a fixed batch size for your model, by passing
	 *       if sequential model:
	 *         `batchInputShape=[...]` to the first layer in your model.
	 *       else for functional model with 1 or more Input layers:
	 *         `batchShape=[...]` to all the first layers in your model.
	 *       This is the expected shape of your inputs *including the batch size*.
	 *       It should be a tuple of integers, e.g. `(32, 10, 100)`.
	 *     - specify `shuffle=False` when calling fit().
	 *
	 *   To reset the states of your model, call `.resetStates()` on either
	 *   a specific layer, or on your entire model.
	 *
	 * Note on specifying the initial state of RNNs
	 *   You can specify the initial state of RNN layers symbolically by
	 *   calling them with the option `initialState`. The value of
	 *   `initialState` should be a tensor or list of tensors representing
	 *   the initial state of the RNN layer.
	 *
	 *   You can specify the initial state of RNN layers numerically by
	 *   calling `resetStates` with the keyword argument `states`. The value of
	 *   `states` should be a numpy array or list of numpy arrays representing
	 *   the initial state of the RNN layer.
	 *
	 * Note on passing external constants to RNNs
	 *   You can pass "external" constants to the cell using the `constants`
	 *   keyword argument of `RNN.call` method. This requires that the `cell.call`
	 *   method accepts the same keyword argument `constants`. Such constants
	 *   can be used to condition the cell transformation on additional static
	 *   inputs (not changing over time), a.k.a. an attention mechanism.
	 *
	 * @doc {heading: 'Layers', subheading: 'Recurrent', namespace: 'layers'}
	 */
	function rnn(args) {
	  return new RNN(args);
	}
	/**
	 * Wrapper allowing a stack of RNN cells to behave as a single cell.
	 *
	 * Used to implement efficient stacked RNNs.
	 *
	 * @doc {heading: 'Layers', subheading: 'Recurrent', namespace: 'layers'}
	 */
	function stackedRNNCells(args) {
	  return new StackedRNNCells(args);
	}
	// Wrapper Layers.
	/** @doc {heading: 'Layers', subheading: 'Wrapper', namespace: 'layers'} */
	function bidirectional(args) {
	  return new Bidirectional(args);
	}
	/**
	 * This wrapper applies a layer to every temporal slice of an input.
	 *
	 * The input should be at least 3D,  and the dimension of the index `1` will be
	 * considered to be the temporal dimension.
	 *
	 * Consider a batch of 32 samples, where each sample is a sequence of 10 vectors
	 * of 16 dimensions. The batch input shape of the layer is then `[32,  10,
	 * 16]`, and the `inputShape`, not including the sample dimension, is
	 * `[10, 16]`.
	 *
	 * You can then use `TimeDistributed` to apply a `Dense` layer to each of the 10
	 * timesteps, independently:
	 *
	 * ```js
	 * const model = tf.sequential();
	 * model.add(tf.layers.timeDistributed({
	 *   layer: tf.layers.dense({units: 8}),
	 *   inputShape: [10, 16],
	 * }));
	 *
	 * // Now model.outputShape = [null, 10, 8].
	 * // The output will then have shape `[32, 10, 8]`.
	 *
	 * // In subsequent layers, there is no need for `inputShape`:
	 * model.add(tf.layers.timeDistributed({layer: tf.layers.dense({units: 32})}));
	 * console.log(JSON.stringify(model.outputs[0].shape));
	 * // Now model.outputShape = [null, 10, 32].
	 * ```
	 *
	 * The output will then have shape `[32, 10, 32]`.
	 *
	 * `TimeDistributed` can be used with arbitrary layers, not just `Dense`, for
	 * instance a `Conv2D` layer.
	 *
	 * ```js
	 * const model = tf.sequential();
	 * model.add(tf.layers.timeDistributed({
	 *   layer: tf.layers.conv2d({filters: 64, kernelSize: [3, 3]}),
	 *   inputShape: [10, 299, 299, 3],
	 * }));
	 * console.log(JSON.stringify(model.outputs[0].shape));
	 * ```
	 *
	 * @doc {heading: 'Layers', subheading: 'Wrapper', namespace: 'layers'}
	 */
	function timeDistributed(args) {
	  return new TimeDistributed(args);
	}
	// Aliases for pooling.
	var globalMaxPool1d = globalMaxPooling1d;
	var globalMaxPool2d = globalMaxPooling2d;
	var maxPool1d = maxPooling1d;
	var maxPool2d = maxPooling2d;
	/**
	 * Apply additive zero-centered Gaussian noise.
	 *
	 * As it is a regularization layer, it is only active at training time.
	 *
	 * This is useful to mitigate overfitting
	 * (you could see it as a form of random data augmentation).
	 * Gaussian Noise (GS) is a natural choice as corruption process
	 * for real valued inputs.
	 *
	 * # Arguments
	 * stddev: float, standard deviation of the noise distribution.
	 *
	 * # Input shape
	 * Arbitrary. Use the keyword argument `input_shape`
	 * (tuple of integers, does not include the samples axis)
	 * when using this layer as the first layer in a model.
	 *
	 * # Output shape
	 * Same shape as input.
	 *
	 * @doc {heading: 'Layers', subheading: 'Noise', namespace: 'layers'}
	 */
	function gaussianNoise(args) {
	  return new GaussianNoise(args);
	}
	/**
	 * Apply multiplicative 1-centered Gaussian noise.
	 *
	 * As it is a regularization layer, it is only active at training time.
	 *
	 * Arguments:
	 *   - `rate`: float, drop probability (as with `Dropout`).
	 *     The multiplicative noise will have
	 *     standard deviation `sqrt(rate / (1 - rate))`.
	 *
	 * Input shape:
	 *   Arbitrary. Use the keyword argument `inputShape`
	 *   (tuple of integers, does not include the samples axis)
	 *   when using this layer as the first layer in a model.
	 *
	 * Output shape:
	 *   Same shape as input.
	 *
	 * References:
	 *   - [Dropout: A Simple Way to Prevent Neural Networks from Overfitting](
	 *      http://www.cs.toronto.edu/~rsalakhu/papers/srivastava14a.pdf)
	 *
	 * @doc {heading: 'Layers', subheading: 'Noise', namespace: 'layers'}
	 */
	function gaussianDropout(args) {
	  return new GaussianDropout(args);
	}
	/**
	 * Applies Alpha Dropout to the input.
	 *
	 * As it is a regularization layer, it is only active at training time.
	 *
	 * Alpha Dropout is a `Dropout` that keeps mean and variance of inputs
	 * to their original values, in order to ensure the self-normalizing property
	 * even after this dropout.
	 * Alpha Dropout fits well to Scaled Exponential Linear Units
	 * by randomly setting activations to the negative saturation value.
	 *
	 * Arguments:
	 *   - `rate`: float, drop probability (as with `Dropout`).
	 *     The multiplicative noise will have
	 *     standard deviation `sqrt(rate / (1 - rate))`.
	 *   - `noise_shape`: A 1-D `Tensor` of type `int32`, representing the
	 *     shape for randomly generated keep/drop flags.
	 *
	 * Input shape:
	 *   Arbitrary. Use the keyword argument `inputShape`
	 *   (tuple of integers, does not include the samples axis)
	 *   when using this layer as the first layer in a model.
	 *
	 * Output shape:
	 *   Same shape as input.
	 *
	 * References:
	 *   - [Self-Normalizing Neural Networks](https://arxiv.org/abs/1706.02515)
	 *
	 * @doc {heading: 'Layers', subheading: 'Noise', namespace: 'layers'}
	 */
	function alphaDropout(args) {
	  return new AlphaDropout(args);
	}
	/**
	 * Masks a sequence by using a mask value to skip timesteps.
	 *
	 * If all features for a given sample timestep are equal to `mask_value`,
	 * then the sample timestep will be masked (skipped) in all downstream layers
	 * (as long as they support masking).
	 *
	 * If any downstream layer does not support masking yet receives such
	 * an input mask, an exception will be raised.
	 *
	 * Arguments:
	 *   - `maskValue`: Either None or mask value to skip.
	 *
	 * Input shape:
	 *   Arbitrary. Use the keyword argument `inputShape`
	 *   (tuple of integers, does not include the samples axis)
	 *   when using this layer as the first layer in a model.
	 *
	 * Output shape:
	 *   Same shape as input.
	 *
	 * @doc {heading: 'Layers', subheading: 'Mask', namespace: 'layers'}
	 */
	function masking(args) {
	  return new Masking(args);
	}
	/**
	 * A preprocessing layer which rescales input values to a new range.
	 *
	 * This layer rescales every value of an input (often an image) by multiplying
	 * by `scale` and adding `offset`.
	 *
	 * For instance:
	 * 1. To rescale an input in the ``[0, 255]`` range
	 * to be in the `[0, 1]` range, you would pass `scale=1/255`.
	 * 2. To rescale an input in the ``[0, 255]`` range to be in the `[-1, 1]`
	 * range, you would pass `scale=1./127.5, offset=-1`.
	 * The rescaling is applied both during training and inference. Inputs can be
	 * of integer or floating point dtype, and by default the layer will output
	 * floats.
	 *
	 * Arguments:
	 *   - `scale`: Float, the scale to apply to the inputs.
	 *   - `offset`: Float, the offset to apply to the inputs.
	 *
	 * Input shape:
	 *   Arbitrary.
	 *
	 * Output shape:
	 *   Same as input.
	 *
	 * @doc {heading: 'Layers', subheading: 'Rescaling', namespace: 'layers'}
	 */
	function rescaling(args) {
	  return new Rescaling(args);
	}
	/**
	 *  A preprocessing layer which center crops images.
	 *
	 *   This layers crops the central portion of the images to a target size. If an
	 *   image is smaller than the target size, it will be resized and cropped so as
	 *   to return the largest possible window in the image that matches the target
	 *   aspect ratio.
	 *
	 *   Input pixel values can be of any range (e.g. `[0., 1.)` or `[0, 255]`) and
	 *   of integer or floating point dtype.
	 *
	 *   If the input height/width is even and the target height/width is odd (or
	 *   inversely), the input image is left-padded by 1 pixel.
	 *
	 *   Arguments:
	 *     `height`: Integer, the height of the output shape.
	 *     `width`: Integer, the width of the output shape.
	 *
	 *   Input shape:
	 *     3D (unbatched) or 4D (batched) tensor with shape:
	 *     `(..., height, width, channels)`, in `channelsLast` format.
	 *
	 *   Output shape:
	 *     3D (unbatched) or 4D (batched) tensor with shape:
	 *     `(..., targetHeight, targetWidth, channels)`.
	 *
	 *
	 *  @doc {heading: 'Layers', subheading: 'CenterCrop', namespace: 'layers'}
	 */
	function centerCrop(args) {
	  return new CenterCrop(args);
	}
	/**
	 * A preprocessing layer which resizes images.
	 * This layer resizes an image input to a target height and width. The input
	 * should be a 4D (batched) or 3D (unbatched) tensor in `"channels_last"`
	 * format.  Input pixel values can be of any range (e.g. `[0., 1.)` or `[0,
	 * 255]`) and of interger or floating point dtype. By default, the layer will
	 * output floats.
	 *
	 * Arguments:
	 *   - `height`: number, the height for the output tensor.
	 *   - `width`: number, the width for the output tensor.
	 *   - `interpolation`: string, the method for image resizing interpolation.
	 *   - `cropToAspectRatio`: boolean, whether to keep image aspect ratio.
	 *
	 * Input shape:
	 *   Arbitrary.
	 *
	 * Output shape:
	 *   height, width, num channels.
	 *
	 * @doc {heading: 'Layers', subheading: 'Resizing', namespace: 'layers'}
	 */
	function resizing(args) {
	  return new Resizing(args);
	}
	/**
	 * A preprocessing layer which encodes integer features.
	 *
	 * This layer provides options for condensing data into a categorical encoding
	 * when the total number of tokens are known in advance. It accepts integer
	 * values as inputs, and it outputs a dense representation of those
	 * inputs.
	 *
	 * Arguments:
	 *
	 * numTokens: The total number of tokens the layer should support. All
	 *  inputs to the layer must integers in the range `0 <= value <
	 *  numTokens`, or an error will be thrown.
	 *
	 * outputMode: Specification for the output of the layer.
	 *  Defaults to `multiHot`. Values can be `oneHot`, `multiHot` or
	 *  `count`, configuring the layer as follows:
	 *
	 *    oneHot: Encodes each individual element in the input into an
	 *      array of `numTokens` size, containing a 1 at the element index. If
	 *      the last dimension is size 1, will encode on that dimension. If the
	 *      last dimension is not size 1, will append a new dimension for the
	 *      encoded output.
	 *
	 *    multiHot: Encodes each sample in the input into a single array
	 *     of `numTokens` size, containing a 1 for each vocabulary term
	 *     present in the sample. Treats the last dimension as the sample
	 *     dimension, if input shape is `(..., sampleLength)`, output shape
	 *     will be `(..., numTokens)`.
	 *
	 *    count: Like `multiHot`, but the int array contains a count of
	 *     the number of times the token at that index appeared in the sample.
	 *
	 *  For all output modes, currently only output up to rank 2 is supported.
	 *   Call arguments:
	 *    inputs: A 1D or 2D tensor of integer inputs.
	 *    countWeights: A tensor in the same shape as `inputs` indicating the
	 *    weight for each sample value when summing up in `count` mode. Not used
	 *    in `multiHot` or `oneHot` modes.
	 *
	 *
	 * @doc {heading: 'Layers', subheading: 'CategoryEncoding', namespace: 'layers'}
	 */
	function categoryEncoding(args) {
	  return new CategoryEncoding(args);
	}
	/**
	 * A preprocessing layer which randomly varies image width during training.
	 *
	 * This layer will randomly adjusts the width of a batch of images of a batch
	 * of images by a random factor.
	 *
	 * The input should be a 3D (unbatched) or 4D (batched) tensor in
	 * the `"channels_last"` image data format. Input pixel values can be of any
	 * range (e.g. `[0., 1.)` or `[0, 255]`) and of integer or floating point
	 * dtype. By default, the layer will output floats. By default, this layer is
	 * inactive during inference. For an overview and full list of preprocessing
	 * layers, see the preprocessing [guide]
	 * (https://www.tensorflow.org/guide/keras/preprocessing_layers).
	 *
	 * Arguments:
	 *
	 * factor:
	 *   A positive float (fraction of original width), or a tuple of size 2
	 *   representing lower and upper bound for resizing vertically.
	 *   When represented as a single float, this value is used for both the upper
	 *   and lower bound. For instance, `factor=(0.2, 0.3)` results in an output
	 *   with width changed by a random amount in the range `[20%, 30%]`.
	 *   `factor=(-0.2, 0.3)` results in an output with width changed by a random
	 *   amount in the range `[-20%, +30%]`. `factor=0.2` results in an output
	 *   with width changed by a random amount in the range `[-20%, +20%]`.
	 * interpolation:
	 *   String, the interpolation method.
	 *   Defaults to `bilinear`.
	 *   Supports `"bilinear"`, `"nearest"`.
	 *   The tf methods `"bicubic"`, `"area"`, `"lanczos3"`, `"lanczos5"`,
	 *   `"gaussian"`, `"mitchellcubic"` are unimplemented in tfjs.
	 * seed:
	 *   Integer. Used to create a random seed.
	 *
	 * Input shape:
	 *     3D (unbatched) or 4D (batched) tensor with shape:
	 *     `(..., height, width, channels)`, in `"channels_last"` format.
	 * Output shape:
	 *     3D (unbatched) or 4D (batched) tensor with shape:
	 *     `(..., height, random_width, channels)`.
	 *
	 *
	 * @doc {heading: 'Layers', subheading: 'RandomWidth', namespace: 'layers'}
	 */
	function randomWidth(args) {
	  return new RandomWidth(args);
	}

	var exports_layers = {
		__proto__: null,
		Layer: Layer,
		RNN: RNN,
		RNNCell: RNNCell,
		activation: activation,
		add: add$1,
		alphaDropout: alphaDropout,
		average: average,
		averagePooling1d: averagePooling1d,
		averagePooling2d: averagePooling2d,
		averagePooling3d: averagePooling3d,
		avgPool1d: avgPool1d,
		avgPool2d: avgPool2d,
		avgPool3d: avgPool3d,
		avgPooling1d: avgPooling1d,
		avgPooling2d: avgPooling2d,
		avgPooling3d: avgPooling3d,
		batchNormalization: batchNormalization,
		bidirectional: bidirectional,
		categoryEncoding: categoryEncoding,
		centerCrop: centerCrop,
		concatenate: concatenate,
		conv1d: conv1d,
		conv2d: conv2d$1,
		conv2dTranspose: conv2dTranspose,
		conv3d: conv3d,
		conv3dTranspose: conv3dTranspose,
		convLstm2d: convLstm2d,
		convLstm2dCell: convLstm2dCell,
		cropping2D: cropping2D,
		dense: dense,
		depthwiseConv2d: depthwiseConv2d,
		dot: dot,
		dropout: dropout,
		elu: elu$2,
		embedding: embedding,
		flatten: flatten,
		gaussianDropout: gaussianDropout,
		gaussianNoise: gaussianNoise,
		globalAveragePooling1d: globalAveragePooling1d,
		globalAveragePooling2d: globalAveragePooling2d,
		globalMaxPool1d: globalMaxPool1d,
		globalMaxPool2d: globalMaxPool2d,
		globalMaxPooling1d: globalMaxPooling1d,
		globalMaxPooling2d: globalMaxPooling2d,
		gru: gru,
		gruCell: gruCell,
		input: input,
		inputLayer: inputLayer,
		layerNormalization: layerNormalization,
		leakyReLU: leakyReLU,
		lstm: lstm,
		lstmCell: lstmCell,
		masking: masking,
		maxPool1d: maxPool1d,
		maxPool2d: maxPool2d,
		maxPooling1d: maxPooling1d,
		maxPooling2d: maxPooling2d,
		maxPooling3d: maxPooling3d,
		maximum: maximum$2,
		minimum: minimum$2,
		multiply: multiply$2,
		permute: permute,
		prelu: prelu$2,
		randomWidth: randomWidth,
		reLU: reLU,
		repeatVector: repeatVector,
		rescaling: rescaling,
		reshape: reshape$2,
		resizing: resizing,
		rnn: rnn,
		separableConv2d: separableConv2d,
		simpleRNN: simpleRNN,
		simpleRNNCell: simpleRNNCell,
		softmax: softmax$2,
		spatialDropout1d: spatialDropout1d,
		stackedRNNCells: stackedRNNCells,
		thresholdedReLU: thresholdedReLU,
		timeDistributed: timeDistributed,
		upSampling2d: upSampling2d,
		zeroPadding2d: zeroPadding2d
	};

	/**
	 * Binary accuracy metric function.
	 *
	 * `yTrue` and `yPred` can have 0-1 values. Example:
	 * ```js
	 * const x = tf.tensor2d([[1, 1, 1, 1], [0, 0, 0, 0]], [2, 4]);
	 * const y = tf.tensor2d([[1, 0, 1, 0], [0, 0, 0, 1]], [2, 4]);
	 * const accuracy = tf.metrics.binaryAccuracy(x, y);
	 * accuracy.print();
	 * ```
	 *
	 * `yTrue` and `yPred` can also have floating-number values between 0 and 1, in
	 * which case the values will be thresholded at 0.5 to yield 0-1 values (i.e.,
	 * a value >= 0.5 and <= 1.0 is interpreted as 1).
	 *
	 * Example:
	 * ```js
	 * const x = tf.tensor1d([1, 1, 1, 1, 0, 0, 0, 0]);
	 * const y = tf.tensor1d([0.2, 0.4, 0.6, 0.8, 0.2, 0.3, 0.4, 0.7]);
	 * const accuracy = tf.metrics.binaryAccuracy(x, y);
	 * accuracy.print();
	 * ```
	 *
	 * @param yTrue Binary Tensor of truth.
	 * @param yPred Binary Tensor of prediction.
	 * @return Accuracy Tensor.
	 *
	 * @doc {heading: 'Metrics', namespace: 'metrics'}
	 */
	function binaryAccuracy(yTrue, yPred) {
	  return binaryAccuracy$1(yTrue, yPred);
	}
	/**
	 * Binary crossentropy metric function.
	 *
	 * Example:
	 * ```js
	 * const x = tf.tensor2d([[0], [1], [1], [1]]);
	 * const y = tf.tensor2d([[0], [0], [0.5], [1]]);
	 * const crossentropy = tf.metrics.binaryCrossentropy(x, y);
	 * crossentropy.print();
	 * ```
	 *
	 * @param yTrue Binary Tensor of truth.
	 * @param yPred Binary Tensor of prediction, probabilities for the `1` case.
	 * @return Accuracy Tensor.
	 *
	 * @doc {heading: 'Metrics', namespace: 'metrics'}
	 */
	function binaryCrossentropy(yTrue, yPred) {
	  return binaryCrossentropy$1(yTrue, yPred);
	}
	/**
	 * Sparse categorical accuracy metric function.
	 *
	 * Example:
	 * ```js
	 *
	 * const yTrue = tf.tensor1d([1, 1, 2, 2, 0]);
	 * const yPred = tf.tensor2d(
	 *      [[0, 1, 0], [1, 0, 0], [0, 0.4, 0.6], [0, 0.6, 0.4], [0.7, 0.3, 0]]);
	 * const crossentropy = tf.metrics.sparseCategoricalAccuracy(yTrue, yPred);
	 * crossentropy.print();
	 * ```
	 *
	 * @param yTrue True labels: indices.
	 * @param yPred Predicted probabilities or logits.
	 * @returns Accuracy tensor.
	 *
	 * @doc {heading: 'Metrics', namespace: 'metrics'}
	 */
	function sparseCategoricalAccuracy(yTrue, yPred) {
	  return sparseCategoricalAccuracy$1(yTrue, yPred);
	}
	/**
	 * Categorical accuracy metric function.
	 *
	 * Example:
	 * ```js
	 * const x = tf.tensor2d([[0, 0, 0, 1], [0, 0, 0, 1]]);
	 * const y = tf.tensor2d([[0.1, 0.8, 0.05, 0.05], [0.1, 0.05, 0.05, 0.8]]);
	 * const accuracy = tf.metrics.categoricalAccuracy(x, y);
	 * accuracy.print();
	 * ```
	 *
	 * @param yTrue Binary Tensor of truth: one-hot encoding of categories.
	 * @param yPred Binary Tensor of prediction: probabilities or logits for the
	 *   same categories as in `yTrue`.
	 * @return Accuracy Tensor.
	 *
	 * @doc {heading: 'Metrics', namespace: 'metrics'}
	 */
	function categoricalAccuracy(yTrue, yPred) {
	  return categoricalAccuracy$1(yTrue, yPred);
	}
	/**
	 * Categorical crossentropy between an output tensor and a target tensor.
	 *
	 * @param target A tensor of the same shape as `output`.
	 * @param output A tensor resulting from a softmax (unless `fromLogits` is
	 *  `true`, in which case `output` is expected to be the logits).
	 * @param fromLogits Boolean, whether `output` is the result of a softmax, or is
	 *   a tensor of logits.
	 *
	 * @doc {heading: 'Metrics', namespace: 'metrics'}
	 */
	function categoricalCrossentropy(yTrue, yPred) {
	  return categoricalCrossentropy$1(yTrue, yPred);
	}
	/**
	 * Computes the precision of the predictions with respect to the labels.
	 *
	 * Example:
	 * ```js
	 * const x = tf.tensor2d(
	 *    [
	 *      [0, 0, 0, 1],
	 *      [0, 1, 0, 0],
	 *      [0, 0, 0, 1],
	 *      [1, 0, 0, 0],
	 *      [0, 0, 1, 0]
	 *    ]
	 * );
	 *
	 * const y = tf.tensor2d(
	 *    [
	 *      [0, 0, 1, 0],
	 *      [0, 1, 0, 0],
	 *      [0, 0, 0, 1],
	 *      [0, 1, 0, 0],
	 *      [0, 1, 0, 0]
	 *    ]
	 * );
	 *
	 * const precision = tf.metrics.precision(x, y);
	 * precision.print();
	 * ```
	 *
	 * @param yTrue The ground truth values. Expected to contain only 0-1 values.
	 * @param yPred The predicted values. Expected to contain only 0-1 values.
	 * @return Precision Tensor.
	 *
	 * @doc {heading: 'Metrics', namespace: 'metrics'}
	 */
	function precision(yTrue, yPred) {
	  return precision$1(yTrue, yPred);
	}
	/**
	 * Computes the recall of the predictions with respect to the labels.
	 *
	 * Example:
	 * ```js
	 * const x = tf.tensor2d(
	 *    [
	 *      [0, 0, 0, 1],
	 *      [0, 1, 0, 0],
	 *      [0, 0, 0, 1],
	 *      [1, 0, 0, 0],
	 *      [0, 0, 1, 0]
	 *    ]
	 * );
	 *
	 * const y = tf.tensor2d(
	 *    [
	 *      [0, 0, 1, 0],
	 *      [0, 1, 0, 0],
	 *      [0, 0, 0, 1],
	 *      [0, 1, 0, 0],
	 *      [0, 1, 0, 0]
	 *    ]
	 * );
	 *
	 * const recall = tf.metrics.recall(x, y);
	 * recall.print();
	 * ```
	 *
	 * @param yTrue The ground truth values. Expected to contain only 0-1 values.
	 * @param yPred The predicted values. Expected to contain only 0-1 values.
	 * @return Recall Tensor.
	 *
	 * @doc {heading: 'Metrics', namespace: 'metrics'}
	 */
	function recall(yTrue, yPred) {
	  return recall$1(yTrue, yPred);
	}
	/**
	 * Loss or metric function: Cosine proximity.
	 *
	 * Mathematically, cosine proximity is defined as:
	 *   `-sum(l2Normalize(yTrue) * l2Normalize(yPred))`,
	 * wherein `l2Normalize()` normalizes the L2 norm of the input to 1 and `*`
	 * represents element-wise multiplication.
	 *
	 * ```js
	 * const yTrue = tf.tensor2d([[1, 0], [1, 0]]);
	 * const yPred = tf.tensor2d([[1 / Math.sqrt(2), 1 / Math.sqrt(2)], [0, 1]]);
	 * const proximity = tf.metrics.cosineProximity(yTrue, yPred);
	 * proximity.print();
	 * ```
	 *
	 * @param yTrue Truth Tensor.
	 * @param yPred Prediction Tensor.
	 * @return Cosine proximity Tensor.
	 *
	 * @doc {heading: 'Metrics', namespace: 'metrics'}
	 */
	function cosineProximity(yTrue, yPred) {
	  return cosineProximity$1(yTrue, yPred);
	}
	/**
	 * Loss or metric function: Mean absolute error.
	 *
	 * Mathematically, mean absolute error is defined as:
	 *   `mean(abs(yPred - yTrue))`,
	 * wherein the `mean` is applied over feature dimensions.
	 *
	 * ```js
	 * const yTrue = tf.tensor2d([[0, 1], [0, 0], [2, 3]]);
	 * const yPred = tf.tensor2d([[0, 1], [0, 1], [-2, -3]]);
	 * const mse = tf.metrics.meanAbsoluteError(yTrue, yPred);
	 * mse.print();
	 * ```
	 *
	 * @param yTrue Truth Tensor.
	 * @param yPred Prediction Tensor.
	 * @return Mean absolute error Tensor.
	 *
	 * @doc {heading: 'Metrics', namespace: 'metrics'}
	 */
	function meanAbsoluteError(yTrue, yPred) {
	  return meanAbsoluteError$1(yTrue, yPred);
	}
	/**
	 * Loss or metric function: Mean absolute percentage error.
	 *
	 * ```js
	 * const yTrue = tf.tensor2d([[0, 1], [10, 20]]);
	 * const yPred = tf.tensor2d([[0, 1], [11, 24]]);
	 * const mse = tf.metrics.meanAbsolutePercentageError(yTrue, yPred);
	 * mse.print();
	 * ```
	 *
	 * Aliases: `tf.metrics.MAPE`, `tf.metrics.mape`.
	 *
	 * @param yTrue Truth Tensor.
	 * @param yPred Prediction Tensor.
	 * @return Mean absolute percentage error Tensor.
	 *
	 * @doc {heading: 'Metrics', namespace: 'metrics'}
	 */
	function meanAbsolutePercentageError(yTrue, yPred) {
	  return meanAbsolutePercentageError$1(yTrue, yPred);
	}
	function MAPE(yTrue, yPred) {
	  return meanAbsolutePercentageError$1(yTrue, yPred);
	}
	function mape(yTrue, yPred) {
	  return meanAbsolutePercentageError$1(yTrue, yPred);
	}
	/**
	 * Loss or metric function: Mean squared error.
	 *
	 * ```js
	 * const yTrue = tf.tensor2d([[0, 1], [3, 4]]);
	 * const yPred = tf.tensor2d([[0, 1], [-3, -4]]);
	 * const mse = tf.metrics.meanSquaredError(yTrue, yPred);
	 * mse.print();
	 * ```
	 *
	 * Aliases: `tf.metrics.MSE`, `tf.metrics.mse`.
	 *
	 * @param yTrue Truth Tensor.
	 * @param yPred Prediction Tensor.
	 * @return Mean squared error Tensor.
	 *
	 * @doc {heading: 'Metrics', namespace: 'metrics'}
	 */
	function meanSquaredError(yTrue, yPred) {
	  return meanSquaredError$1(yTrue, yPred);
	}
	function MSE(yTrue, yPred) {
	  return meanSquaredError$1(yTrue, yPred);
	}
	function mse(yTrue, yPred) {
	  return meanSquaredError$1(yTrue, yPred);
	}
	/**
	 * Computes R2 score.
	 *
	 * ```js
	 * const yTrue = tf.tensor2d([[0, 1], [3, 4]]);
	 * const yPred = tf.tensor2d([[0, 1], [-3, -4]]);
	 * const r2Score = tf.metrics.r2Score(yTrue, yPred);
	 * r2Score.print();
	 * ```
	 * @param yTrue Truth Tensor.
	 * @param yPred Prediction Tensor.
	 * @return R2 score Tensor.
	 *
	 * @doc {heading: 'Metrics', namespace: 'metrics'}
	 */
	function r2Score(yTrue, yPred) {
	  return r2Score$1(yTrue, yPred);
	}

	var exports_metrics = {
		__proto__: null,
		MAPE: MAPE,
		MSE: MSE,
		binaryAccuracy: binaryAccuracy,
		binaryCrossentropy: binaryCrossentropy,
		categoricalAccuracy: categoricalAccuracy,
		categoricalCrossentropy: categoricalCrossentropy,
		cosineProximity: cosineProximity,
		mape: mape,
		meanAbsoluteError: meanAbsoluteError,
		meanAbsolutePercentageError: meanAbsolutePercentageError,
		meanSquaredError: meanSquaredError,
		mse: mse,
		precision: precision,
		r2Score: r2Score,
		recall: recall,
		sparseCategoricalAccuracy: sparseCategoricalAccuracy
	};

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */

	var exports_models = {
		__proto__: null,
		modelFromJSON: modelFromJSON
	};

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */
	/**
	 * Regularizer for L1 and L2 regularization.
	 *
	 * Adds a term to the loss to penalize large weights:
	 * loss += sum(l1 * abs(x)) + sum(l2 * x^2)
	 *
	 * @doc {heading: 'Regularizers', namespace: 'regularizers'}
	 */
	function l1l2(config) {
	  return new L1L2(config);
	}
	/**
	 * Regularizer for L1 regularization.
	 *
	 * Adds a term to the loss to penalize large weights:
	 * loss += sum(l1 * abs(x))
	 * @param args l1 config.
	 *
	 * @doc {heading: 'Regularizers', namespace: 'regularizers'}
	 */
	function l1(config) {
	  return l1$1(config);
	}
	/**
	 * Regularizer for L2 regularization.
	 *
	 * Adds a term to the loss to penalize large weights:
	 * loss += sum(l2 * x^2)
	 * @param args l2 config.
	 *
	 * @doc {heading: 'Regularizers', namespace: 'regularizers'}
	 */
	function l2(config) {
	  return l2$1(config);
	}

	var exports_regularizers = {
		__proto__: null,
		l1: l1,
		l1l2: l1l2,
		l2: l2
	};

	var Callback = /*#__PURE__*/function (_BaseCallback) {
	  _inherits(Callback, _BaseCallback);
	  var _super = _createSuper(Callback);
	  function Callback() {
	    var _this;
	    _classCallCheck(this, Callback);
	    _this = _super.apply(this, arguments);
	    /** Instance of `keras.models.Model`. Reference of the model being trained. */
	    _this.model = null;
	    return _this;
	  }
	  _createClass(Callback, [{
	    key: "setModel",
	    value: function setModel(model) {
	      if (!(model instanceof LayersModel)) {
	        throw new Error('model must be a LayersModel, not some other Container');
	      }
	      this.model = model;
	    }
	  }]);
	  return Callback;
	}(BaseCallback);
	function less$2(currVal, prevVal) {
	  return currVal < prevVal;
	}
	function greater$2(currVal, prevVal) {
	  return currVal > prevVal;
	}
	/**
	 * A Callback that stops training when a monitored quantity has stopped
	 * improving.
	 */
	var EarlyStopping = /*#__PURE__*/function (_Callback) {
	  _inherits(EarlyStopping, _Callback);
	  var _super2 = _createSuper(EarlyStopping);
	  function EarlyStopping(args) {
	    var _this2;
	    _classCallCheck(this, EarlyStopping);
	    _this2 = _super2.call(this);
	    if (args == null) {
	      args = {};
	    }
	    if (args.restoreBestWeights) {
	      throw new NotImplementedError('restoreBestWeights = True is not implemented in EarlyStopping yet.');
	    }
	    _this2.monitor = args.monitor || 'val_loss';
	    _this2.minDelta = Math.abs(args.minDelta || 0);
	    _this2.patience = args.patience || 0;
	    _this2.verbose = args.verbose || 0;
	    _this2.mode = args.mode || 'auto';
	    _this2.baseline = args.baseline;
	    if (['auto', 'min', 'max'].indexOf(_this2.mode) === -1) {
	      console.warn("EarlyStopping mode '".concat(_this2.mode, "' is invalid. ") + "Falling back to mode 'auto'.");
	      _this2.mode = 'auto';
	    }
	    if (_this2.mode === 'min') {
	      _this2.monitorFunc = less$2;
	    } else if (_this2.mode === 'max') {
	      _this2.monitorFunc = greater$2;
	    } else {
	      // For mode === 'auto'.
	      if (_this2.monitor.indexOf('acc') !== -1) {
	        _this2.monitorFunc = greater$2;
	      } else {
	        _this2.monitorFunc = less$2;
	      }
	    }
	    if (_this2.monitorFunc === less$2) {
	      _this2.minDelta *= -1;
	    }
	    return _this2;
	  }
	  _createClass(EarlyStopping, [{
	    key: "onTrainBegin",
	    value: function () {
	      var _onTrainBegin = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(logs) {
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              this.wait = 0;
	              this.stoppedEpoch = 0;
	              if (this.baseline != null) {
	                this.best = this.baseline;
	              } else {
	                this.best = this.monitorFunc === less$2 ? Infinity : -Infinity;
	              }
	            case 3:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function onTrainBegin(_x) {
	        return _onTrainBegin.apply(this, arguments);
	      }
	      return onTrainBegin;
	    }()
	  }, {
	    key: "onEpochEnd",
	    value: function () {
	      var _onEpochEnd = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(epoch, logs) {
	        var current;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              _context2.next = 2;
	              return resolveScalarsInLogs(logs);
	            case 2:
	              current = this.getMonitorValue(logs);
	              if (!(current == null)) {
	                _context2.next = 5;
	                break;
	              }
	              return _context2.abrupt("return");
	            case 5:
	              if (this.monitorFunc(current - this.minDelta, this.best)) {
	                this.best = current;
	                this.wait = 0;
	                // TODO(cais): Logic for restoreBestWeights.
	              } else {
	                this.wait++;
	                if (this.wait >= this.patience) {
	                  this.stoppedEpoch = epoch;
	                  this.model.stopTraining = true;
	                }
	                // TODO(cais): Logic for restoreBestWeights.
	              }
	            case 6:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function onEpochEnd(_x2, _x3) {
	        return _onEpochEnd.apply(this, arguments);
	      }
	      return onEpochEnd;
	    }()
	  }, {
	    key: "onTrainEnd",
	    value: function () {
	      var _onTrainEnd = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3(logs) {
	        return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	          while (1) switch (_context3.prev = _context3.next) {
	            case 0:
	              if (this.stoppedEpoch > 0 && this.verbose) {
	                console.log("Epoch ".concat(this.stoppedEpoch, ": early stopping."));
	              }
	            case 1:
	            case "end":
	              return _context3.stop();
	          }
	        }, _callee3, this);
	      }));
	      function onTrainEnd(_x4) {
	        return _onTrainEnd.apply(this, arguments);
	      }
	      return onTrainEnd;
	    }()
	  }, {
	    key: "getMonitorValue",
	    value: function getMonitorValue(logs) {
	      if (logs == null) {
	        logs = {};
	      }
	      var monitorValue = logs[this.monitor];
	      if (monitorValue == null) {
	        console.warn("Metric for EarlyStopping ".concat(this.monitor, " is not available. ") + "Available metrics are: ".concat(Object.keys(logs)));
	      }
	      return monitorValue;
	    }
	  }]);
	  return EarlyStopping;
	}(Callback);
	/**
	 * Factory function for a Callback that stops training when a monitored
	 * quantity has stopped improving.
	 *
	 * Early stopping is a type of regularization, and protects model against
	 * overfitting.
	 *
	 * The following example based on fake data illustrates how this callback
	 * can be used during `tf.LayersModel.fit()`:
	 *
	 * ```js
	 * const model = tf.sequential();
	 * model.add(tf.layers.dense({
	 *   units: 3,
	 *   activation: 'softmax',
	 *   kernelInitializer: 'ones',
	 *   inputShape: [2]
	 * }));
	 * const xs = tf.tensor2d([1, 2, 3, 4], [2, 2]);
	 * const ys = tf.tensor2d([[1, 0, 0], [0, 1, 0]], [2, 3]);
	 * const xsVal = tf.tensor2d([4, 3, 2, 1], [2, 2]);
	 * const ysVal = tf.tensor2d([[0, 0, 1], [0, 1, 0]], [2, 3]);
	 * model.compile(
	 *     {loss: 'categoricalCrossentropy', optimizer: 'sgd', metrics: ['acc']});
	 *
	 * // Without the EarlyStopping callback, the val_acc value would be:
	 * //   0.5, 0.5, 0.5, 0.5, ...
	 * // With val_acc being monitored, training should stop after the 2nd epoch.
	 * const history = await model.fit(xs, ys, {
	 *   epochs: 10,
	 *   validationData: [xsVal, ysVal],
	 *   callbacks: tf.callbacks.earlyStopping({monitor: 'val_acc'})
	 * });
	 *
	 * // Expect to see a length-2 array.
	 * console.log(history.history.val_acc);
	 * ```
	 *
	 * @doc {
	 *   heading: 'Callbacks',
	 *   namespace: 'callbacks'
	 * }
	 */
	function earlyStopping(args) {
	  return new EarlyStopping(args);
	}
	var callbacks = {
	  earlyStopping: earlyStopping
	};

	/**
	 * @license
	 * Copyright 2018 Google LLC
	 *
	 * Use of this source code is governed by an MIT-style
	 * license that can be found in the LICENSE file or at
	 * https://opensource.org/licenses/MIT.
	 * =============================================================================
	 */

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ENV$1 = env();
	/** Whether to keep intermediate tensors. */
	ENV$1.registerFlag('KEEP_INTERMEDIATE_TENSORS', function () {
	  return false;
	}, function (debugValue) {
	  if (debugValue) {
	    console.warn('Keep intermediate tensors is ON. This will print the values of all ' + 'intermediate tensors during model inference. Not all models ' + 'support this mode. For details, check e2e/benchmarks/ ' + 'model_config.js. This significantly impacts performance.');
	  }
	});

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 *
	 * =============================================================================
	 */
	/** DataType enum. */
	var DataType;
	(function (DataType) {
	  // These properties must be quoted since they are used by parseDtypeParam
	  // in tfjs-converter/src/operations/operation_mapper.ts to look up dtypes
	  // by string name. If they are not quoted, Closure will mangle their names.
	  // Not a legal value for DataType.  Used to indicate a DataType field
	  // has not been set.
	  DataType[DataType["DT_INVALID"] = 0] = "DT_INVALID";
	  // Data types that all computation devices are expected to be
	  // capable to support.
	  DataType[DataType["DT_FLOAT"] = 1] = "DT_FLOAT";
	  DataType[DataType["DT_DOUBLE"] = 2] = "DT_DOUBLE";
	  DataType[DataType["DT_INT32"] = 3] = "DT_INT32";
	  DataType[DataType["DT_UINT8"] = 4] = "DT_UINT8";
	  DataType[DataType["DT_INT16"] = 5] = "DT_INT16";
	  DataType[DataType["DT_INT8"] = 6] = "DT_INT8";
	  DataType[DataType["DT_STRING"] = 7] = "DT_STRING";
	  DataType[DataType["DT_COMPLEX64"] = 8] = "DT_COMPLEX64";
	  DataType[DataType["DT_INT64"] = 9] = "DT_INT64";
	  DataType[DataType["DT_BOOL"] = 10] = "DT_BOOL";
	  DataType[DataType["DT_QINT8"] = 11] = "DT_QINT8";
	  DataType[DataType["DT_QUINT8"] = 12] = "DT_QUINT8";
	  DataType[DataType["DT_QINT32"] = 13] = "DT_QINT32";
	  DataType[DataType["DT_BFLOAT16"] = 14] = "DT_BFLOAT16";
	  DataType[DataType["DT_QINT16"] = 15] = "DT_QINT16";
	  DataType[DataType["DT_QUINT16"] = 16] = "DT_QUINT16";
	  DataType[DataType["DT_UINT16"] = 17] = "DT_UINT16";
	  DataType[DataType["DT_COMPLEX128"] = 18] = "DT_COMPLEX128";
	  DataType[DataType["DT_HALF"] = 19] = "DT_HALF";
	  DataType[DataType["DT_RESOURCE"] = 20] = "DT_RESOURCE";
	  DataType[DataType["DT_VARIANT"] = 21] = "DT_VARIANT";
	  DataType[DataType["DT_UINT32"] = 22] = "DT_UINT32";
	  DataType[DataType["DT_UINT64"] = 23] = "DT_UINT64";
	  // Do not use!  These are only for parameters.  Every enum above
	  // should have a corresponding value below (verified by types_test).
	  DataType[DataType["DT_FLOAT_REF"] = 101] = "DT_FLOAT_REF";
	  DataType[DataType["DT_DOUBLE_REF"] = 102] = "DT_DOUBLE_REF";
	  DataType[DataType["DT_INT32_REF"] = 103] = "DT_INT32_REF";
	  DataType[DataType["DT_UINT8_REF"] = 104] = "DT_UINT8_REF";
	  DataType[DataType["DT_INT16_REF"] = 105] = "DT_INT16_REF";
	  DataType[DataType["DT_INT8_REF"] = 106] = "DT_INT8_REF";
	  DataType[DataType["DT_STRING_REF"] = 107] = "DT_STRING_REF";
	  DataType[DataType["DT_COMPLEX64_REF"] = 108] = "DT_COMPLEX64_REF";
	  DataType[DataType["DT_INT64_REF"] = 109] = "DT_INT64_REF";
	  DataType[DataType["DT_BOOL_REF"] = 110] = "DT_BOOL_REF";
	  DataType[DataType["DT_QINT8_REF"] = 111] = "DT_QINT8_REF";
	  DataType[DataType["DT_QUINT8_REF"] = 112] = "DT_QUINT8_REF";
	  DataType[DataType["DT_QINT32_REF"] = 113] = "DT_QINT32_REF";
	  DataType[DataType["DT_BFLOAT16_REF"] = 114] = "DT_BFLOAT16_REF";
	  DataType[DataType["DT_QINT16_REF"] = 115] = "DT_QINT16_REF";
	  DataType[DataType["DT_QUINT16_REF"] = 116] = "DT_QUINT16_REF";
	  DataType[DataType["DT_UINT16_REF"] = 117] = "DT_UINT16_REF";
	  DataType[DataType["DT_COMPLEX128_REF"] = 118] = "DT_COMPLEX128_REF";
	  DataType[DataType["DT_HALF_REF"] = 119] = "DT_HALF_REF";
	  DataType[DataType["DT_RESOURCE_REF"] = 120] = "DT_RESOURCE_REF";
	  DataType[DataType["DT_VARIANT_REF"] = 121] = "DT_VARIANT_REF";
	  DataType[DataType["DT_UINT32_REF"] = 122] = "DT_UINT32_REF";
	  DataType[DataType["DT_UINT64_REF"] = 123] = "DT_UINT64_REF";
	})(DataType || (DataType = {}));
	var SaverDef;
	(function (SaverDef) {
	  /** CheckpointFormatVersion enum. */
	  var CheckpointFormatVersion;
	  (function (CheckpointFormatVersion) {
	    CheckpointFormatVersion[CheckpointFormatVersion["LEGACY"] = 0] = "LEGACY";
	    CheckpointFormatVersion[CheckpointFormatVersion["V1"] = 1] = "V1";
	    CheckpointFormatVersion[CheckpointFormatVersion["V2"] = 2] = "V2";
	  })(CheckpointFormatVersion = SaverDef.CheckpointFormatVersion || (SaverDef.CheckpointFormatVersion = {}));
	})(SaverDef || (SaverDef = {}));

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var CUSTOM_OPS = {};
	/**
	 * Register an Op for graph model executor. This allows you to register
	 * TensorFlow custom op or override existing op.
	 *
	 * Here is an example of registering a new MatMul Op.
	 * ```js
	 * const customMatmul = (node) =>
	 *    tf.matMul(
	 *        node.inputs[0], node.inputs[1],
	 *        node.attrs['transpose_a'], node.attrs['transpose_b']);
	 *
	 * tf.registerOp('MatMul', customMatmul);
	 * ```
	 * The inputs and attrs of the node object are based on the TensorFlow op
	 * registry.
	 *
	 * @param name The Tensorflow Op name.
	 * @param opFunc An op function which is called with the current graph node
	 * during execution and needs to return a tensor or a list of tensors. The node
	 * has the following attributes:
	 *    - attr: A map from attribute name to its value
	 *    - inputs: A list of input tensors
	 *
	 * @doc {heading: 'Models', subheading: 'Op Registry'}
	 */
	function registerOp(name, opFunc) {
	  var opMapper = {
	    tfOpName: name,
	    category: 'custom',
	    inputs: [],
	    attrs: [],
	    customExecutor: opFunc
	  };
	  CUSTOM_OPS[name] = opMapper;
	}
	/**
	 * Retrieve the OpMapper object for the registered op.
	 *
	 * @param name The Tensorflow Op name.
	 *
	 * @doc {heading: 'Models', subheading: 'Op Registry'}
	 */
	function getRegisteredOp(name) {
	  return CUSTOM_OPS[name];
	}
	/**
	 * Deregister the Op for graph model executor.
	 *
	 * @param name The Tensorflow Op name.
	 *
	 * @doc {heading: 'Models', subheading: 'Op Registry'}
	 */
	function deregisterOp(name) {
	  delete CUSTOM_OPS[name];
	}

	function getParamValue(paramName, node, tensorMap, context, resourceManager) {
	  var inputParam = node.inputParams[paramName];
	  if (inputParam && inputParam.inputIndexStart !== undefined) {
	    var start = inputParam.inputIndexStart;
	    var end = inputParam.inputIndexEnd === 0 ? undefined : inputParam.inputIndexEnd === undefined ? start + 1 : inputParam.inputIndexEnd;
	    var shiftedStart = start < 0 ? node.inputNames.length + start : start;
	    if (inputParam.type === 'tensor') {
	      return getTensor(node.inputNames[shiftedStart], tensorMap, context, resourceManager);
	    }
	    if (inputParam.type === 'tensors') {
	      // TODO(mattSoulanille): This filters out NoOp nodes during execution, but
	      // these should really never be in the execution graph in the first place.
	      // They're necessary for ordering the graph, but should not be visible
	      // during execution. Perhaps have different sets of children, one for
	      // control dependencies and another for real dependencies.
	      var inputs = node.inputs.slice(start, end);
	      var inputNames = node.inputNames.slice(start, end).filter(function (_name, index) {
	        var _a;
	        return ((_a = inputs[index]) === null || _a === void 0 ? void 0 : _a.op) !== 'NoOp';
	      });
	      return inputNames.map(function (name) {
	        return getTensor(name, tensorMap, context, resourceManager);
	      });
	    }
	    var tensor = getTensor(node.inputNames[shiftedStart], tensorMap, context, resourceManager);
	    var data = tensor.dataSync();
	    return inputParam.type === 'number' ? data[0] : toNestedArray(tensor.shape, data);
	  }
	  var attrParam = node.attrParams[paramName];
	  return attrParam && attrParam.value;
	}
	/**
	 * Retrieve the tensor from tensorsMap based on input name.
	 * @param name Node input name
	 * @param tensorsMap Tensors map keyed by the node
	 * @param context contains tensors and information for running the current node.
	 * @param resourceManager Optional. Contains global resources of the model.
	 */
	function getTensor(name, tensorsMap, context, resourceManager) {
	  var _parseNodeName = parseNodeName(name, context),
	    _parseNodeName2 = _slicedToArray(_parseNodeName, 2),
	    nodeName = _parseNodeName2[0],
	    index = _parseNodeName2[1];
	  if (resourceManager != null) {
	    var tensor = resourceManager.getHashTableHandleByName(nodeName);
	    if (tensor != null) {
	      return tensor;
	    }
	  }
	  var contextId = context.currentContextIds.find(function (contextId) {
	    return !!tensorsMap[getNodeNameWithContextId(nodeName, contextId)];
	  });
	  return contextId !== undefined ? tensorsMap[getNodeNameWithContextId(nodeName, contextId)][index] : undefined;
	}
	/**
	 * Retrieve the tensors based on input name for current context.
	 * @param name Node input name
	 * @param tensorsMap Tensors map keyed by the node
	 */
	function getTensorsForCurrentContext(name, tensorsMap, context) {
	  return tensorsMap[getNodeNameWithContextId(name, context.currentContextId)];
	}
	/**
	 * Returns the node name, outputName and index from the Node input name.
	 * @param inputName The input name of the node, in format of
	 * node_name:output_index, i.e. MatMul:0, if the output_index is not set, it is
	 * default to 0.
	 * If the input name contains output name i.e. StringSplit:indices:0, it will
	 * return ['StringSplit', 0, 'indices'].
	 */
	function getNodeNameAndIndex(inputName, context) {
	  var _parseNodeName3 = parseNodeName(inputName, context),
	    _parseNodeName4 = _slicedToArray(_parseNodeName3, 3),
	    nodeName = _parseNodeName4[0],
	    index = _parseNodeName4[1],
	    outputName = _parseNodeName4[2];
	  return [getNodeNameWithContextId(nodeName, context && context.currentContextId), index, outputName];
	}
	function getNodeNameWithContextId(name, contextId) {
	  return !!contextId ? "".concat(name, "-").concat(contextId) : name;
	}
	function parseNodeName(name, context) {
	  if (name === '') {
	    return ['', 0, undefined];
	  }
	  var isCacheEnabled = context != null && context.parseNodeNameCache != null;
	  if (isCacheEnabled) {
	    var cachedResult = context.parseNodeNameCache.get(name);
	    if (cachedResult != null) {
	      return cachedResult;
	    }
	  }
	  var parts = name.split(':');
	  var result;
	  if (parts.length === 1) {
	    result = [name, 0, undefined];
	  } else {
	    var nodeName = parts[0];
	    var outputName = parts.length === 3 ? parts[1] : undefined;
	    var index = Number(parts[parts.length - 1]);
	    result = [nodeName, index, outputName];
	  }
	  if (isCacheEnabled) {
	    context.parseNodeNameCache.set(name, result);
	  }
	  return result;
	}
	function split$2(arr, size) {
	  var res = [];
	  for (var i = 0; i < arr.length; i += size) {
	    res.push(arr.slice(i, i + size));
	  }
	  return res;
	}
	function getPadding(node, tensorMap, context) {
	  var pad = getParamValue('pad', node, tensorMap, context);
	  if (pad === 'explicit') {
	    // This is 1d array, we need to convert it to 2d array
	    pad = getParamValue('explicitPaddings', node, tensorMap, context);
	    var explicitPadding = [[0, 0], [0, 0], [0, 0], [0, 0]];
	    for (var i = 0; i < 4; i++) {
	      explicitPadding[i][0] = pad[i * 2];
	      explicitPadding[i][1] = pad[i * 2 + 1];
	    }
	    return explicitPadding;
	  }
	  return pad;
	}
	/**
	 *  Reuse the tensor if it is marked as keep, otherwise clone the tensor to
	 *  avoid disposal. This is important for TensorArray and TensorList ops, since
	 *  internally they use a tensor as the id for TensorArray and TensorList, and
	 * to simplify lookup, they also use Tensor.id as the key to the internal map.
	 * These id tensors have been marked as kept in the backend, we need avoid clone
	 * them in order to create new Tensor.id.
	 * @param tensor
	 */
	function cloneTensor(tensor) {
	  return tensor.kept ? tensor : clone(tensor);
	}

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json$i = [{
	  'tfOpName': 'Add',
	  'category': 'arithmetic',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'AddV2',
	  'category': 'arithmetic',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'AddN',
	  'category': 'arithmetic',
	  'inputs': [{
	    'start': 0,
	    'end': 0,
	    'name': 'tensors',
	    'type': 'tensors'
	  }]
	}, {
	  'tfOpName': 'BiasAdd',
	  'category': 'arithmetic',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }, {
	    'tfName': 'data_format',
	    'name': 'dataFormat',
	    'type': 'string',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Sub',
	  'category': 'arithmetic',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'RealDiv',
	  'category': 'arithmetic',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Div',
	  'category': 'arithmetic',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'DivNoNan',
	  'category': 'arithmetic',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'FloorDiv',
	  'category': 'arithmetic',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Mul',
	  'category': 'arithmetic',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Maximum',
	  'category': 'arithmetic',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Minimum',
	  'category': 'arithmetic',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Pow',
	  'category': 'arithmetic',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'SquaredDifference',
	  'category': 'arithmetic',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Mod',
	  'category': 'arithmetic',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'FloorMod',
	  'category': 'arithmetic',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}];

	var arithmetic = {
		__proto__: null,
		json: json$i
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json$h = [{
	  'tfOpName': 'Abs',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Acos',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Asin',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Atan',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Atan2',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'y',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Ceil',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'ClipByValue',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'clipValueMin',
	    'type': 'number'
	  }, {
	    'start': 2,
	    'name': 'clipValueMax',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Complex',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'real',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'imag',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'ComplexAbs',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Cos',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Cosh',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Elu',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Exp',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Floor',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Log',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Imag',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }, {
	    'tfName': 'Tout',
	    'name': 'outputType',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Neg',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Real',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }, {
	    'tfName': 'Tout',
	    'name': 'outputType',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Prelu',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'alpha',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Relu',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Relu6',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Selu',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Sigmoid',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Sin',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Sinh',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Sqrt',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Rsqrt',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Square',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Tan',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Tanh',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Sign',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Round',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Expm1',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Log1p',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Reciprocal',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Softplus',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Asinh',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Acosh',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Atanh',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Erf',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'LeakyRelu',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'alpha',
	    'name': 'alpha',
	    'type': 'number',
	    'defaultValue': 0.2
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'IsNan',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'IsFinite',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'IsInf',
	  'category': 'basic_math',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}];

	var basicMath = {
		__proto__: null,
		json: json$h
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json$g = [{
	  'tfOpName': 'EmptyTensorList',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'elementShape',
	    'type': 'shape'
	  }, {
	    'start': 1,
	    'name': 'maxNumElements',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'element_dtype',
	    'name': 'elementDType',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'LoopCond',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'pred',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'Switch',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'data',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'pred',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'Merge',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'end': 0,
	    'name': 'tensors',
	    'type': 'tensors'
	  }]
	}, {
	  'tfOpName': 'Enter',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensor',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }, {
	    'tfName': 'frame_name',
	    'name': 'frameName',
	    'type': 'string'
	  }, {
	    'tfName': 'is_constant',
	    'name': 'isConstant',
	    'type': 'bool'
	  }]
	}, {
	  'tfOpName': 'Exit',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensor',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'NextIteration',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensor',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'TensorArrayV3',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'size',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'dtype',
	    'name': 'dtype',
	    'type': 'dtype'
	  }, {
	    'tfName': 'element_shape',
	    'name': 'elementShape',
	    'type': 'shape'
	  }, {
	    'tfName': 'dynamic_size',
	    'name': 'dynamicSize',
	    'type': 'bool'
	  }, {
	    'tfName': 'clear_after_read',
	    'name': 'clearAfterRead',
	    'type': 'bool'
	  }, {
	    'tfName': 'identical_element_shapes',
	    'name': 'identicalElementShapes',
	    'type': 'bool'
	  }, {
	    'tfName': 'tensor_array_name',
	    'name': 'name',
	    'type': 'string'
	  }]
	}, {
	  'tfOpName': 'TensorArrayWriteV3',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensorArrayId',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'index',
	    'type': 'number'
	  }, {
	    'start': 2,
	    'name': 'tensor',
	    'type': 'tensor'
	  }, {
	    'start': 3,
	    'name': 'flowIn',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'TensorArrayReadV3',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensorArrayId',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'index',
	    'type': 'number'
	  }, {
	    'start': 2,
	    'name': 'flowIn',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'dtype',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'TensorArrayGatherV3',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensorArrayId',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'indices',
	    'type': 'number[]'
	  }, {
	    'start': 2,
	    'name': 'flowIn',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'dtype',
	    'name': 'dtype',
	    'type': 'dtype'
	  }, {
	    'tfName': 'element_shape',
	    'name': 'elementShape',
	    'type': 'shape'
	  }]
	}, {
	  'tfOpName': 'TensorArrayScatterV3',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensorArrayId',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'indices',
	    'type': 'number[]'
	  }, {
	    'start': 2,
	    'name': 'tensor',
	    'type': 'tensor'
	  }, {
	    'start': 3,
	    'name': 'flowIn',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'TensorArrayConcatV3',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensorArrayId',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'flowIn',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'dtype',
	    'name': 'dtype',
	    'type': 'dtype'
	  }, {
	    'tfName': 'element_shape_except0',
	    'name': 'elementShapeExcept0',
	    'type': 'shape',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'TensorArraySplitV3',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensorArrayId',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'tensor',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'lengths',
	    'type': 'number[]'
	  }, {
	    'start': 3,
	    'name': 'flowIn',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'TensorArraySizeV3',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensorArrayId',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'flowIn',
	    'type': 'number'
	  }]
	}, {
	  'tfOpName': 'TensorArrayCloseV3',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensorArrayId',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'StatelessIf',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'cond',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'end': 0,
	    'name': 'args',
	    'type': 'tensors'
	  }],
	  'attrs': [{
	    'tfName': 'then_branch',
	    'name': 'thenBranch',
	    'type': 'func'
	  }, {
	    'tfName': 'else_branch',
	    'name': 'elseBranch',
	    'type': 'func'
	  }]
	}, {
	  'tfOpName': 'If',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'cond',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'end': 0,
	    'name': 'args',
	    'type': 'tensors'
	  }],
	  'attrs': [{
	    'tfName': 'then_branch',
	    'name': 'thenBranch',
	    'type': 'func'
	  }, {
	    'tfName': 'else_branch',
	    'name': 'elseBranch',
	    'type': 'func'
	  }]
	}, {
	  'tfOpName': 'StatelessWhile',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'end': 0,
	    'name': 'args',
	    'type': 'tensors'
	  }],
	  'attrs': [{
	    'tfName': 'cond',
	    'name': 'cond',
	    'type': 'func'
	  }, {
	    'tfName': 'body',
	    'name': 'body',
	    'type': 'func'
	  }]
	}, {
	  'tfOpName': 'While',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'end': 0,
	    'name': 'args',
	    'type': 'tensors'
	  }],
	  'attrs': [{
	    'tfName': 'cond',
	    'name': 'cond',
	    'type': 'func'
	  }, {
	    'tfName': 'body',
	    'name': 'body',
	    'type': 'func'
	  }]
	}, {
	  'tfOpName': 'TensorListScatter',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensor',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'indices',
	    'type': 'number[]'
	  }, {
	    'start': 2,
	    'name': 'elementShape',
	    'type': 'shape'
	  }],
	  'attrs': [{
	    'tfName': 'element_dtype',
	    'name': 'elementDType',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'TensorListScatterV2',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensor',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'indices',
	    'type': 'number[]'
	  }, {
	    'start': 2,
	    'name': 'elementShape',
	    'type': 'shape'
	  }, {
	    'start': 3,
	    'name': 'numElements',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'element_dtype',
	    'name': 'elementDType',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'TensorListGather',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensorListId',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'indices',
	    'type': 'number[]'
	  }, {
	    'start': 2,
	    'name': 'elementShape',
	    'type': 'shape'
	  }],
	  'attrs': [{
	    'tfName': 'element_dtype',
	    'name': 'elementDType',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'TensorListGetItem',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensorListId',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'index',
	    'type': 'number'
	  }, {
	    'start': 2,
	    'name': 'elementShape',
	    'type': 'shape'
	  }],
	  'attrs': [{
	    'tfName': 'element_dtype',
	    'name': 'elementDType',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'TensorListSetItem',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensorListId',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'index',
	    'type': 'number'
	  }, {
	    'start': 2,
	    'name': 'tensor',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'element_dtype',
	    'name': 'elementDType',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'TensorListReserve',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'elementShape',
	    'type': 'shape'
	  }, {
	    'start': 1,
	    'name': 'numElements',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'element_dtype',
	    'name': 'elementDType',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'TensorListFromTensor',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensor',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'elementShape',
	    'type': 'shape'
	  }],
	  'attrs': [{
	    'tfName': 'element_dtype',
	    'name': 'elementDType',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'TensorListStack',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensorListId',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'elementShape',
	    'type': 'shape'
	  }],
	  'attrs': [{
	    'tfName': 'element_dtype',
	    'name': 'elementDType',
	    'type': 'dtype'
	  }, {
	    'tfName': 'num_elements',
	    'name': 'numElements',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'TensorListSplit',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensor',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'elementShape',
	    'type': 'shape'
	  }, {
	    'start': 2,
	    'name': 'lengths',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'element_dtype',
	    'name': 'elementDType',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'TensorListConcat',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensorListId',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'element_shape',
	    'name': 'elementShape',
	    'type': 'shape'
	  }, {
	    'tfName': 'element_dtype',
	    'name': 'elementDType',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'TensorListConcatV2',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensorListId',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'element_shape',
	    'name': 'elementShape',
	    'type': 'shape'
	  }, {
	    'tfName': 'element_dtype',
	    'name': 'elementDType',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'TensorListPopBack',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensorListId',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'elementShape',
	    'type': 'shape'
	  }],
	  'attrs': [{
	    'tfName': 'element_dtype',
	    'name': 'elementDType',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'TensorListPushBack',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensorListId',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'tensor',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'element_dtype',
	    'name': 'elementDType',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'TensorListLength',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensorListId',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'TensorListResize',
	  'category': 'control',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensorListId',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'size',
	    'type': 'number'
	  }]
	}];

	var control = {
		__proto__: null,
		json: json$g
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json$f = [{
	  'tfOpName': 'AvgPool',
	  'category': 'convolution',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'strides',
	    'name': 'strides',
	    'type': 'number[]'
	  }, {
	    'tfName': 'padding',
	    'name': 'pad',
	    'type': 'string'
	  }, {
	    'tfName': 'data_format',
	    'name': 'dataFormat',
	    'type': 'string',
	    'notSupported': true
	  }, {
	    'tfName': 'ksize',
	    'name': 'kernelSize',
	    'type': 'number[]'
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'MaxPool',
	  'category': 'convolution',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'strides',
	    'name': 'strides',
	    'type': 'number[]'
	  }, {
	    'tfName': 'padding',
	    'name': 'pad',
	    'type': 'string'
	  }, {
	    'tfName': 'data_format',
	    'name': 'dataFormat',
	    'type': 'string',
	    'notSupported': true
	  }, {
	    'tfName': 'ksize',
	    'name': 'kernelSize',
	    'type': 'number[]'
	  }, {
	    'tfName': 'explicit_paddings',
	    'name': 'explicitPaddings',
	    'type': 'number[]',
	    'defaultValue': [],
	    'notSupported': true
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'MaxPoolWithArgmax',
	  'category': 'convolution',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'strides',
	    'name': 'strides',
	    'type': 'number[]'
	  }, {
	    'tfName': 'padding',
	    'name': 'pad',
	    'type': 'string'
	  }, {
	    'tfName': 'ksize',
	    'name': 'kernelSize',
	    'type': 'number[]'
	  }, {
	    'tfName': 'include_batch_in_index',
	    'name': 'includeBatchInIndex',
	    'type': 'bool'
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'AvgPool3D',
	  'category': 'convolution',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'strides',
	    'name': 'strides',
	    'type': 'number[]'
	  }, {
	    'tfName': 'padding',
	    'name': 'pad',
	    'type': 'string'
	  }, {
	    'tfName': 'data_format',
	    'name': 'dataFormat',
	    'type': 'string',
	    'notSupported': true
	  }, {
	    'tfName': 'ksize',
	    'name': 'kernelSize',
	    'type': 'number[]'
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'MaxPool3D',
	  'category': 'convolution',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'strides',
	    'name': 'strides',
	    'type': 'number[]'
	  }, {
	    'tfName': 'padding',
	    'name': 'pad',
	    'type': 'string'
	  }, {
	    'tfName': 'data_format',
	    'name': 'dataFormat',
	    'type': 'string',
	    'notSupported': true
	  }, {
	    'tfName': 'ksize',
	    'name': 'kernelSize',
	    'type': 'number[]'
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Conv1D',
	  'category': 'convolution',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'filter',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'stride',
	    'name': 'stride',
	    'type': 'number'
	  }, {
	    'tfName': 'padding',
	    'name': 'pad',
	    'type': 'string'
	  }, {
	    'tfName': 'data_format',
	    'name': 'dataFormat',
	    'type': 'string',
	    'defaultValue': 'NWC'
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }, {
	    'tfName': 'dilation',
	    'name': 'dilation',
	    'type': 'number',
	    'defaultValue': 1
	  }]
	}, {
	  'tfOpName': 'Conv2D',
	  'category': 'convolution',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'filter',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }, {
	    'tfName': 'strides',
	    'name': 'strides',
	    'type': 'number[]'
	  }, {
	    'tfName': 'padding',
	    'name': 'pad',
	    'type': 'string'
	  }, {
	    'tfName': 'useCudnnOnGpu',
	    'name': 'useCudnnOnGpu',
	    'type': 'bool'
	  }, {
	    'tfName': 'data_format',
	    'name': 'dataFormat',
	    'type': 'string',
	    'defaultValue': 'NHWC'
	  }, {
	    'tfName': 'explicit_paddings',
	    'name': 'explicitPaddings',
	    'type': 'number[]',
	    'defaultValue': []
	  }, {
	    'tfName': 'dilations',
	    'name': 'dilations',
	    'type': 'number[]'
	  }]
	}, {
	  'tfOpName': '_FusedConv2D',
	  'category': 'convolution',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'filter',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'end': 0,
	    'name': 'args',
	    'type': 'tensors'
	  }],
	  'attrs': [{
	    'tfName': 'num_args',
	    'name': 'numArgs',
	    'type': 'number'
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }, {
	    'tfName': 'strides',
	    'name': 'strides',
	    'type': 'number[]'
	  }, {
	    'tfName': 'padding',
	    'name': 'pad',
	    'type': 'string'
	  }, {
	    'tfName': 'explicit_paddings',
	    'name': 'explicitPaddings',
	    'type': 'number[]',
	    'defaultValue': []
	  }, {
	    'tfName': 'use_cudnn_on_gpu',
	    'name': 'useCudnnOnGpu',
	    'type': 'bool',
	    'defaultValue': true
	  }, {
	    'tfName': 'data_format',
	    'name': 'dataFormat',
	    'type': 'string',
	    'defaultValue': 'NHWC'
	  }, {
	    'tfName': 'dilations',
	    'name': 'dilations',
	    'type': 'number[]',
	    'defaultValue': [1, 1, 1, 1]
	  }, {
	    'tfName': 'fused_ops',
	    'name': 'fusedOps',
	    'type': 'string[]',
	    'defaultValue': []
	  }, {
	    'tfName': 'epsilon',
	    'name': 'epsilon',
	    'type': 'number',
	    'defaultValue': 0.0001
	  }, {
	    'tfName': 'leakyrelu_alpha',
	    'name': 'leakyreluAlpha',
	    'type': 'number',
	    'defaultValue': 0.2
	  }]
	}, {
	  'tfOpName': 'Conv2DBackpropInput',
	  'category': 'convolution',
	  'inputs': [{
	    'start': 2,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'filter',
	    'type': 'tensor'
	  }, {
	    'start': 0,
	    'name': 'outputShape',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'strides',
	    'name': 'strides',
	    'type': 'number[]'
	  }, {
	    'tfName': 'padding',
	    'name': 'pad',
	    'type': 'string'
	  }, {
	    'tfName': 'data_format',
	    'name': 'dataFormat',
	    'type': 'string',
	    'notSupported': true
	  }, {
	    'tfName': 'explicit_paddings',
	    'name': 'explicitPaddings',
	    'type': 'number[]',
	    'defaultValue': []
	  }, {
	    'tfName': 'dilations',
	    'name': 'dilations',
	    'type': 'number[]',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'DepthwiseConv2d',
	  'category': 'convolution',
	  'inputs': [{
	    'start': 0,
	    'name': 'input',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'filter',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'strides',
	    'name': 'strides',
	    'type': 'number[]'
	  }, {
	    'tfName': 'padding',
	    'name': 'pad',
	    'type': 'string'
	  }, {
	    'tfName': 'data_format',
	    'name': 'dataFormat',
	    'type': 'string',
	    'defaultValue': 'NHWC'
	  }, {
	    'tfName': 'explicit_paddings',
	    'name': 'explicitPaddings',
	    'type': 'number[]',
	    'defaultValue': []
	  }, {
	    'tfName': 'dilations',
	    'name': 'dilations',
	    'type': 'number[]'
	  }]
	}, {
	  'tfOpName': 'DepthwiseConv2dNative',
	  'category': 'convolution',
	  'inputs': [{
	    'start': 0,
	    'name': 'input',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'filter',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'strides',
	    'name': 'strides',
	    'type': 'number[]'
	  }, {
	    'tfName': 'padding',
	    'name': 'pad',
	    'type': 'string'
	  }, {
	    'tfName': 'data_format',
	    'name': 'dataFormat',
	    'type': 'string',
	    'defaultValue': 'NHWC'
	  }, {
	    'tfName': 'explicit_paddings',
	    'name': 'explicitPaddings',
	    'type': 'number[]',
	    'defaultValue': []
	  }, {
	    'tfName': 'dilations',
	    'name': 'dilations',
	    'type': 'number[]'
	  }]
	}, {
	  'tfOpName': 'FusedDepthwiseConv2dNative',
	  'category': 'convolution',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'filter',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'end': 0,
	    'name': 'args',
	    'type': 'tensors'
	  }],
	  'attrs': [{
	    'tfName': 'num_args',
	    'name': 'numArgs',
	    'type': 'number'
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }, {
	    'tfName': 'strides',
	    'name': 'strides',
	    'type': 'number[]'
	  }, {
	    'tfName': 'padding',
	    'name': 'pad',
	    'type': 'string'
	  }, {
	    'tfName': 'data_format',
	    'name': 'dataFormat',
	    'type': 'string',
	    'defaultValue': 'NHWC'
	  }, {
	    'tfName': 'dilations',
	    'name': 'dilations',
	    'type': 'number[]',
	    'defaultValue': [1, 1, 1, 1]
	  }, {
	    'tfName': 'fused_ops',
	    'name': 'fusedOps',
	    'type': 'string[]',
	    'defaultValue': []
	  }, {
	    'tfName': 'explicit_paddings',
	    'name': 'explicitPaddings',
	    'type': 'number[]',
	    'defaultValue': []
	  }]
	}, {
	  'tfOpName': 'Conv3D',
	  'category': 'convolution',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'filter',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'strides',
	    'name': 'strides',
	    'type': 'number[]'
	  }, {
	    'tfName': 'padding',
	    'name': 'pad',
	    'type': 'string'
	  }, {
	    'tfName': 'data_format',
	    'name': 'dataFormat',
	    'type': 'string',
	    'defaultValue': 'NHWC'
	  }, {
	    'tfName': 'dilations',
	    'name': 'dilations',
	    'type': 'number[]'
	  }]
	}, {
	  'tfOpName': 'Dilation2D',
	  'category': 'convolution',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'filter',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'strides',
	    'name': 'strides',
	    'type': 'number[]'
	  }, {
	    'tfName': 'rates',
	    'name': 'dilations',
	    'type': 'number[]'
	  }, {
	    'tfName': 'padding',
	    'name': 'pad',
	    'type': 'string'
	  }]
	}];

	var convolution = {
		__proto__: null,
		json: json$f
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json$e = [{
	  'tfOpName': 'Fill',
	  'category': 'creation',
	  'inputs': [{
	    'start': 0,
	    'name': 'shape',
	    'type': 'number[]'
	  }, {
	    'start': 1,
	    'name': 'value',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'LinSpace',
	  'category': 'creation',
	  'inputs': [{
	    'start': 0,
	    'name': 'start',
	    'type': 'number'
	  }, {
	    'start': 1,
	    'name': 'stop',
	    'type': 'number'
	  }, {
	    'start': 2,
	    'name': 'num',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'OneHot',
	  'category': 'creation',
	  'inputs': [{
	    'start': 0,
	    'name': 'indices',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'depth',
	    'type': 'number'
	  }, {
	    'start': 2,
	    'name': 'onValue',
	    'type': 'number',
	    'defaultValue': 1
	  }, {
	    'start': 3,
	    'name': 'offValue',
	    'type': 'number',
	    'defaultValue': 0
	  }],
	  'attrs': [{
	    'tfName': 'axis',
	    'name': 'axis',
	    'type': 'number',
	    'notSupported': true
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'Ones',
	  'category': 'creation',
	  'inputs': [{
	    'start': 0,
	    'name': 'shape',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'OnesLike',
	  'category': 'creation',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'dtype',
	    'name': 'dtype',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'RandomStandardNormal',
	  'category': 'creation',
	  'inputs': [{
	    'start': 0,
	    'name': 'shape',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'seed',
	    'name': 'seed',
	    'type': 'number',
	    'defaultValue': 0
	  }, {
	    'tfName': 'seed2',
	    'name': 'seed2',
	    'type': 'number',
	    'defaultValue': 0,
	    'notSupported': true
	  }, {
	    'tfName': 'dtype',
	    'name': 'dtype',
	    'type': 'dtype'
	  }, {
	    'tfName': 'T',
	    'name': 'T',
	    'type': 'number',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'RandomUniform',
	  'category': 'creation',
	  'inputs': [{
	    'start': 0,
	    'name': 'shape',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'minval',
	    'name': 'minval',
	    'type': 'number',
	    'defaultValue': 0
	  }, {
	    'tfName': 'maxval',
	    'name': 'maxval',
	    'type': 'number',
	    'defaultValue': 1
	  }, {
	    'tfName': 'dtype',
	    'name': 'dtype',
	    'type': 'dtype'
	  }, {
	    'tfName': 'seed',
	    'name': 'seed',
	    'type': 'number',
	    'defaultValue': 0
	  }, {
	    'tfName': 'seed2',
	    'name': 'seed2',
	    'type': 'number',
	    'defaultValue': 0,
	    'notSupported': true
	  }, {
	    'tfName': 'T',
	    'name': 'T',
	    'type': 'number',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'RandomUniformInt',
	  'category': 'creation',
	  'inputs': [{
	    'start': 0,
	    'name': 'shape',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'minval',
	    'name': 'minval',
	    'type': 'number'
	  }, {
	    'tfName': 'maxval',
	    'name': 'maxval',
	    'type': 'number'
	  }, {
	    'tfName': 'seed',
	    'name': 'seed',
	    'type': 'number',
	    'defaultValue': 0
	  }, {
	    'tfName': 'seed2',
	    'name': 'seed2',
	    'type': 'number',
	    'defaultValue': 0,
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Range',
	  'category': 'creation',
	  'inputs': [{
	    'start': 0,
	    'name': 'start',
	    'type': 'number'
	  }, {
	    'start': 1,
	    'name': 'stop',
	    'type': 'number'
	  }, {
	    'start': 2,
	    'name': 'step',
	    'type': 'number',
	    'defaultValue': 0
	  }],
	  'attrs': [{
	    'tfName': 'Tidx',
	    'name': 'dtype',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'TruncatedNormal',
	  'category': 'creation',
	  'inputs': [{
	    'start': 0,
	    'name': 'shape',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'means',
	    'name': 'mean',
	    'type': 'number',
	    'defaultValue': 0
	  }, {
	    'tfName': 'stddev',
	    'name': 'stdDev',
	    'type': 'number',
	    'defaultValue': 1
	  }, {
	    'tfName': 'seed',
	    'name': 'seed',
	    'type': 'number'
	  }, {
	    'tfName': 'seed2',
	    'name': 'seed2',
	    'type': 'number',
	    'defaultValue': 0,
	    'notSupported': true
	  }, {
	    'tfName': 'dtype',
	    'name': 'dtype',
	    'type': 'dtype'
	  }, {
	    'tfName': 'T',
	    'name': 'T',
	    'type': 'number',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Zeros',
	  'category': 'creation',
	  'inputs': [{
	    'start': 0,
	    'name': 'shape',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'ZerosLike',
	  'category': 'creation',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'Multinomial',
	  'category': 'creation',
	  'inputs': [{
	    'start': 0,
	    'name': 'logits',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'numSamples',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'seed',
	    'name': 'seed',
	    'type': 'number'
	  }, {
	    'tfName': 'seed2',
	    'name': 'seed2',
	    'type': 'number'
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype'
	  }, {
	    'tfName': 'output_dtype',
	    'name': 'output_dtype',
	    'type': 'dtype'
	  }]
	}];

	var creation = {
		__proto__: null,
		json: json$e
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json$d = [{
	  'tfOpName': 'NonMaxSuppressionV2',
	  'category': 'dynamic',
	  'inputs': [{
	    'start': 0,
	    'name': 'boxes',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'scores',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'maxOutputSize',
	    'type': 'number'
	  }, {
	    'start': 3,
	    'name': 'iouThreshold',
	    'type': 'number'
	  }]
	}, {
	  'tfOpName': 'NonMaxSuppressionV3',
	  'category': 'dynamic',
	  'inputs': [{
	    'start': 0,
	    'name': 'boxes',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'scores',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'maxOutputSize',
	    'type': 'number'
	  }, {
	    'start': 3,
	    'name': 'iouThreshold',
	    'type': 'number'
	  }, {
	    'start': 4,
	    'name': 'scoreThreshold',
	    'type': 'number'
	  }]
	}, {
	  'tfOpName': 'NonMaxSuppressionV4',
	  'category': 'dynamic',
	  'inputs': [{
	    'start': 0,
	    'name': 'boxes',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'scores',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'maxOutputSize',
	    'type': 'number'
	  }, {
	    'start': 3,
	    'name': 'iouThreshold',
	    'type': 'number'
	  }, {
	    'start': 4,
	    'name': 'scoreThreshold',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }, {
	    'tfName': 'T_threshold',
	    'name': 'threshold',
	    'type': 'dtype',
	    'notSupported': true
	  }, {
	    'tfName': 'pad_to_max_output_size',
	    'name': 'padToMaxOutputSize',
	    'type': 'bool'
	  }]
	}, {
	  'tfOpName': 'NonMaxSuppressionV5',
	  'category': 'dynamic',
	  'inputs': [{
	    'start': 0,
	    'name': 'boxes',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'scores',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'maxOutputSize',
	    'type': 'number'
	  }, {
	    'start': 3,
	    'name': 'iouThreshold',
	    'type': 'number'
	  }, {
	    'start': 4,
	    'name': 'scoreThreshold',
	    'type': 'number'
	  }, {
	    'start': 5,
	    'name': 'softNmsSigma',
	    'type': 'number'
	  }]
	}, {
	  'tfOpName': 'Where',
	  'category': 'dynamic',
	  'inputs': [{
	    'start': 0,
	    'name': 'condition',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'ListDiff',
	  'category': 'dynamic',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'y',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}];

	var dynamic = {
		__proto__: null,
		json: json$d
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json$c = [{
	  'tfOpName': 'LowerBound',
	  'category': 'evaluation',
	  'inputs': [{
	    'start': 0,
	    'name': 'sortedSequence',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'values',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'TopKV2',
	  'category': 'evaluation',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'k',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'sorted',
	    'name': 'sorted',
	    'type': 'bool'
	  }]
	}, {
	  'tfOpName': 'UpperBound',
	  'category': 'evaluation',
	  'inputs': [{
	    'start': 0,
	    'name': 'sortedSequence',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'values',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'Unique',
	  'category': 'evaluation',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'UniqueV2',
	  'category': 'evaluation',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'axis',
	    'type': 'number'
	  }]
	}];

	var evaluation = {
		__proto__: null,
		json: json$c
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json$b = [{
	  'tfOpName': 'PlaceholderWithDefault',
	  'category': 'graph',
	  'inputs': [{
	    'start': 0,
	    'name': 'default',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'shape',
	    'name': 'shape',
	    'type': 'shape'
	  }, {
	    'tfName': 'dtype',
	    'name': 'dtype',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'Placeholder',
	  'category': 'graph',
	  'attrs': [{
	    'tfName': 'shape',
	    'name': 'shape',
	    'type': 'shape'
	  }, {
	    'tfName': 'dtype',
	    'name': 'dtype',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'Const',
	  'category': 'graph'
	}, {
	  'tfOpName': 'Identity',
	  'category': 'graph',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'IdentityN',
	  'category': 'graph',
	  'inputs': [{
	    'start': 0,
	    'end': 0,
	    'name': 'x',
	    'type': 'tensors'
	  }]
	}, {
	  'tfOpName': 'Snapshot',
	  'category': 'graph',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'Rank',
	  'category': 'graph',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'Size',
	  'category': 'graph',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'Shape',
	  'category': 'graph',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'ShapeN',
	  'category': 'graph',
	  'inputs': [{
	    'start': 0,
	    'end': 0,
	    'name': 'x',
	    'type': 'tensors'
	  }]
	}, {
	  'tfOpName': 'Print',
	  'category': 'graph',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'data',
	    'type': 'tensors'
	  }],
	  'attrs': [{
	    'tfName': 'message',
	    'name': 'message',
	    'type': 'string'
	  }, {
	    'tfName': 'first_n',
	    'name': 'firstN',
	    'type': 'number',
	    'notSupported': true
	  }, {
	    'tfName': 'summarize',
	    'name': 'summarize',
	    'type': 'number',
	    'defaultValue': 3
	  }]
	}, {
	  'tfOpName': 'NoOp',
	  'category': 'graph',
	  'inputs': []
	}, {
	  'tfOpName': 'StopGradient',
	  'category': 'graph',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'FakeQuantWithMinMaxVars',
	  'category': 'graph',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'min',
	    'name': 'min',
	    'type': 'number'
	  }, {
	    'tfName': 'max',
	    'name': 'max',
	    'type': 'number'
	  }]
	}];

	var graph = {
		__proto__: null,
		json: json$b
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json$a = [{
	  'tfOpName': 'HashTable',
	  'category': 'hash_table',
	  'inputs': [],
	  'attrs': [{
	    'tfName': 'shared_name',
	    'name': 'sharedName',
	    'type': 'string'
	  }, {
	    'tfName': 'use_node_name_sharing',
	    'name': 'useNodeNameSharing',
	    'type': 'bool'
	  }, {
	    'tfName': 'key_dtype',
	    'name': 'keyDType',
	    'type': 'dtype'
	  }, {
	    'tfName': 'value_dtype',
	    'name': 'valueDType',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'HashTableV2',
	  'category': 'hash_table',
	  'inputs': [],
	  'attrs': [{
	    'tfName': 'shared_name',
	    'name': 'sharedName',
	    'type': 'string'
	  }, {
	    'tfName': 'use_node_name_sharing',
	    'name': 'useNodeNameSharing',
	    'type': 'bool'
	  }, {
	    'tfName': 'key_dtype',
	    'name': 'keyDType',
	    'type': 'dtype'
	  }, {
	    'tfName': 'value_dtype',
	    'name': 'valueDType',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'LookupTableImport',
	  'category': 'hash_table',
	  'inputs': [{
	    'start': 0,
	    'name': 'tableHandle',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'keys',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'values',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'Tin',
	    'name': 'tIn',
	    'type': 'dtype',
	    'notSupported': true
	  }, {
	    'tfName': 'Tout',
	    'name': 'tOut',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'LookupTableImportV2',
	  'category': 'hash_table',
	  'inputs': [{
	    'start': 0,
	    'name': 'tableHandle',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'keys',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'values',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'Tin',
	    'name': 'tIn',
	    'type': 'dtype',
	    'notSupported': true
	  }, {
	    'tfName': 'Tout',
	    'name': 'tOut',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'LookupTableFind',
	  'category': 'hash_table',
	  'inputs': [{
	    'start': 0,
	    'name': 'tableHandle',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'keys',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'defaultValue',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'Tin',
	    'name': 'tIn',
	    'type': 'dtype',
	    'notSupported': true
	  }, {
	    'tfName': 'Tout',
	    'name': 'tOut',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'LookupTableFindV2',
	  'category': 'hash_table',
	  'inputs': [{
	    'start': 0,
	    'name': 'tableHandle',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'keys',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'defaultValue',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'Tin',
	    'name': 'tIn',
	    'type': 'dtype',
	    'notSupported': true
	  }, {
	    'tfName': 'Tout',
	    'name': 'tOut',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'LookupTableSize',
	  'category': 'hash_table',
	  'inputs': [{
	    'start': 0,
	    'name': 'tableHandle',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'LookupTableSizeV2',
	  'category': 'hash_table',
	  'inputs': [{
	    'start': 0,
	    'name': 'tableHandle',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'InitializeTable',
	  'category': 'hash_table',
	  'inputs': [{
	    'start': 0,
	    'name': 'tableHandle',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'keys',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'values',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'InitializeTableV2',
	  'category': 'hash_table',
	  'inputs': [{
	    'start': 0,
	    'name': 'tableHandle',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'keys',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'values',
	    'type': 'tensor'
	  }]
	}];

	var hashTable = {
		__proto__: null,
		json: json$a
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json$9 = [{
	  'tfOpName': 'ResizeBilinear',
	  'category': 'image',
	  'inputs': [{
	    'start': 0,
	    'name': 'images',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'size',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'align_corners',
	    'name': 'alignCorners',
	    'type': 'bool'
	  }, {
	    'tfName': 'half_pixel_centers',
	    'name': 'halfPixelCenters',
	    'type': 'bool'
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'ResizeNearestNeighbor',
	  'category': 'image',
	  'inputs': [{
	    'start': 0,
	    'name': 'images',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'size',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'align_corners',
	    'name': 'alignCorners',
	    'type': 'bool'
	  }, {
	    'tfName': 'half_pixel_centers',
	    'name': 'halfPixelCenters',
	    'type': 'bool'
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'CropAndResize',
	  'category': 'image',
	  'inputs': [{
	    'start': 0,
	    'name': 'image',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'boxes',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'boxInd',
	    'type': 'tensor'
	  }, {
	    'start': 3,
	    'name': 'cropSize',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'method',
	    'name': 'method',
	    'type': 'string'
	  }, {
	    'tfName': 'extrapolation_value',
	    'name': 'extrapolationValue',
	    'type': 'number'
	  }]
	}, {
	  'tfOpName': 'ImageProjectiveTransformV3',
	  'category': 'image',
	  'inputs': [{
	    'start': 0,
	    'name': 'images',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'transforms',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'outputShape',
	    'type': 'number[]'
	  }, {
	    'start': 3,
	    'name': 'fillValue',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'interpolation',
	    'name': 'interpolation',
	    'type': 'string'
	  }, {
	    'tfName': 'fill_mode',
	    'name': 'fillMode',
	    'type': 'string'
	  }]
	}];

	var image = {
		__proto__: null,
		json: json$9
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json$8 = [{
	  'tfOpName': 'Equal',
	  'category': 'logical',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'NotEqual',
	  'category': 'logical',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Greater',
	  'category': 'logical',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'GreaterEqual',
	  'category': 'logical',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Less',
	  'category': 'logical',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'LessEqual',
	  'category': 'logical',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'LogicalAnd',
	  'category': 'logical',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'LogicalNot',
	  'category': 'logical',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'LogicalOr',
	  'category': 'logical',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Select',
	  'category': 'logical',
	  'inputs': [{
	    'start': 0,
	    'name': 'condition',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'SelectV2',
	  'category': 'logical',
	  'inputs': [{
	    'start': 0,
	    'name': 'condition',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'BitwiseAnd',
	  'category': 'logical',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'y',
	    'type': 'tensor'
	  }]
	}];

	var logical = {
		__proto__: null,
		json: json$8
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json$7 = [{
	  'tfOpName': '_FusedMatMul',
	  'category': 'matrices',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'end': 0,
	    'name': 'args',
	    'type': 'tensors'
	  }],
	  'attrs': [{
	    'tfName': 'num_args',
	    'name': 'numArgs',
	    'type': 'number'
	  }, {
	    'tfName': 'fused_ops',
	    'name': 'fusedOps',
	    'type': 'string[]',
	    'defaultValue': []
	  }, {
	    'tfName': 'epsilon',
	    'name': 'epsilon',
	    'type': 'number',
	    'defaultValue': 0.0001
	  }, {
	    'tfName': 'transpose_a',
	    'name': 'transposeA',
	    'type': 'bool',
	    'defaultValue': false
	  }, {
	    'tfName': 'transpose_b',
	    'name': 'transposeB',
	    'type': 'bool',
	    'defaultValue': false
	  }, {
	    'tfName': 'leakyrelu_alpha',
	    'name': 'leakyreluAlpha',
	    'type': 'number',
	    'defaultValue': 0.2
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'MatMul',
	  'category': 'matrices',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'transpose_a',
	    'name': 'transposeA',
	    'type': 'bool',
	    'defaultValue': false
	  }, {
	    'tfName': 'transpose_b',
	    'name': 'transposeB',
	    'type': 'bool',
	    'defaultValue': false
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'BatchMatMul',
	  'category': 'matrices',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'adj_x',
	    'name': 'transposeA',
	    'type': 'bool',
	    'defaultValue': false
	  }, {
	    'tfName': 'adj_y',
	    'name': 'transposeB',
	    'type': 'bool',
	    'defaultValue': false
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'BatchMatMulV2',
	  'category': 'matrices',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'b',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'adj_x',
	    'name': 'transposeA',
	    'type': 'bool',
	    'defaultValue': false
	  }, {
	    'tfName': 'adj_y',
	    'name': 'transposeB',
	    'type': 'bool',
	    'defaultValue': false
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Transpose',
	  'category': 'matrices',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'perm',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Einsum',
	  'category': 'matrices',
	  'inputs': [{
	    'start': 0,
	    'end': 0,
	    'name': 'tensors',
	    'type': 'tensors'
	  }],
	  'attrs': [{
	    'tfName': 'equation',
	    'name': 'equation',
	    'type': 'string'
	  }, {
	    'tfName': 'N',
	    'name': 'n',
	    'type': 'number',
	    'defaultValue': 2
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'MatrixBandPart',
	  'category': 'matrices',
	  'inputs': [{
	    'start': 0,
	    'name': 'a',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'numLower',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'numUpper',
	    'type': 'tensor'
	  }]
	}];

	var matrices = {
		__proto__: null,
		json: json$7
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json$6 = [{
	  'tfOpName': 'EuclideanNorm',
	  'category': 'normalization',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'axis',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'keep_dims',
	    'name': 'keepDims',
	    'type': 'bool',
	    'defaultValue': false
	  }]
	}, {
	  'tfOpName': 'FusedBatchNorm',
	  'category': 'normalization',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'scale',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'offset',
	    'type': 'tensor'
	  }, {
	    'start': 3,
	    'name': 'mean',
	    'type': 'tensor'
	  }, {
	    'start': 4,
	    'name': 'variance',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'epsilon',
	    'name': 'epsilon',
	    'type': 'number',
	    'defaultValue': 0.001
	  }, {
	    'tfName': 'data_format',
	    'name': 'dataFormat',
	    'type': 'string',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'FusedBatchNormV2',
	  'category': 'normalization',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'scale',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'offset',
	    'type': 'tensor'
	  }, {
	    'start': 3,
	    'name': 'mean',
	    'type': 'tensor'
	  }, {
	    'start': 4,
	    'name': 'variance',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'epsilon',
	    'name': 'epsilon',
	    'type': 'number',
	    'defaultValue': 0.001
	  }, {
	    'tfName': 'data_format',
	    'name': 'dataFormat',
	    'type': 'string',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'FusedBatchNormV3',
	  'category': 'normalization',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'scale',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'offset',
	    'type': 'tensor'
	  }, {
	    'start': 3,
	    'name': 'mean',
	    'type': 'tensor'
	  }, {
	    'start': 4,
	    'name': 'variance',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'epsilon',
	    'name': 'epsilon',
	    'type': 'number',
	    'defaultValue': 0.001
	  }, {
	    'tfName': 'data_format',
	    'name': 'dataFormat',
	    'type': 'string',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'LRN',
	  'category': 'normalization',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'depth_radius',
	    'name': 'radius',
	    'type': 'number',
	    'defaultValue': 5
	  }, {
	    'tfName': 'bias',
	    'name': 'bias',
	    'type': 'number',
	    'defaultValue': 1
	  }, {
	    'tfName': 'alpha',
	    'name': 'alpha',
	    'type': 'number',
	    'defaultValue': 1
	  }, {
	    'tfName': 'beta',
	    'name': 'beta',
	    'type': 'number',
	    'defaultValue': 0.5
	  }]
	}, {
	  'tfOpName': 'Softmax',
	  'category': 'normalization',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'LogSoftmax',
	  'category': 'normalization',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }]
	}];

	var normalization = {
		__proto__: null,
		json: json$6
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json$5 = [{
	  'tfOpName': 'Bincount',
	  'category': 'reduction',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'size',
	    'type': 'number'
	  }, {
	    'start': 2,
	    'name': 'weights',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'DenseBincount',
	  'category': 'reduction',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'size',
	    'type': 'number'
	  }, {
	    'start': 2,
	    'name': 'weights',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'binary_output',
	    'name': 'binaryOutput',
	    'type': 'bool'
	  }]
	}, {
	  'tfOpName': 'Max',
	  'category': 'reduction',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'axis',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'keep_dims',
	    'name': 'keepDims',
	    'type': 'bool'
	  }]
	}, {
	  'tfOpName': 'Mean',
	  'category': 'reduction',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'axis',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'keep_dims',
	    'name': 'keepDims',
	    'type': 'bool'
	  }]
	}, {
	  'tfOpName': 'Min',
	  'category': 'reduction',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'axis',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'keep_dims',
	    'name': 'keepDims',
	    'type': 'bool'
	  }]
	}, {
	  'tfOpName': 'Sum',
	  'category': 'reduction',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'axis',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'keep_dims',
	    'name': 'keepDims',
	    'type': 'bool'
	  }]
	}, {
	  'tfOpName': 'All',
	  'category': 'reduction',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'axis',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'keep_dims',
	    'name': 'keepDims',
	    'type': 'bool'
	  }]
	}, {
	  'tfOpName': 'Any',
	  'category': 'reduction',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'axis',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'keep_dims',
	    'name': 'keepDims',
	    'type': 'bool'
	  }]
	}, {
	  'tfOpName': 'ArgMax',
	  'category': 'reduction',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'axis',
	    'type': 'number'
	  }]
	}, {
	  'tfOpName': 'ArgMin',
	  'category': 'reduction',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'axis',
	    'type': 'number'
	  }]
	}, {
	  'tfOpName': 'Prod',
	  'category': 'reduction',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'axis',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'keep_dims',
	    'name': 'keepDims',
	    'type': 'bool'
	  }, {
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Cumprod',
	  'category': 'reduction',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'axis',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'exclusive',
	    'name': 'exclusive',
	    'type': 'bool'
	  }, {
	    'tfName': 'reverse',
	    'name': 'reverse',
	    'type': 'bool'
	  }]
	}, {
	  'tfOpName': 'Cumsum',
	  'category': 'reduction',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'axis',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'exclusive',
	    'name': 'exclusive',
	    'type': 'bool'
	  }, {
	    'tfName': 'reverse',
	    'name': 'reverse',
	    'type': 'bool'
	  }]
	}];

	var reduction = {
		__proto__: null,
		json: json$5
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json$4 = [{
	  'tfOpName': 'ConcatV2',
	  'category': 'slice_join',
	  'inputs': [{
	    'start': 0,
	    'end': -1,
	    'name': 'tensors',
	    'type': 'tensors'
	  }, {
	    'start': -1,
	    'name': 'axis',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'N',
	    'name': 'n',
	    'type': 'number',
	    'defaultValue': 2
	  }]
	}, {
	  'tfOpName': 'Concat',
	  'category': 'slice_join',
	  'inputs': [{
	    'start': 1,
	    'end': 0,
	    'name': 'tensors',
	    'type': 'tensors'
	  }, {
	    'start': 0,
	    'name': 'axis',
	    'type': 'number'
	  }],
	  'attrs': [{
	    'tfName': 'N',
	    'name': 'n',
	    'type': 'number',
	    'defaultValue': 2
	  }]
	}, {
	  'tfOpName': 'GatherV2',
	  'category': 'slice_join',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'indices',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'axis',
	    'type': 'number',
	    'defaultValue': 0
	  }],
	  'attrs': [{
	    'tfName': 'batch_dims',
	    'name': 'batchDims',
	    'type': 'number',
	    'defaultValue': 0
	  }]
	}, {
	  'tfOpName': 'Gather',
	  'category': 'slice_join',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'indices',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'validate_indices',
	    'name': 'validateIndices',
	    'type': 'bool',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Reverse',
	  'category': 'slice_join',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'dims',
	    'type': 'bool[]'
	  }]
	}, {
	  'tfOpName': 'ReverseV2',
	  'category': 'slice_join',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'axis',
	    'type': 'number[]'
	  }]
	}, {
	  'tfOpName': 'Slice',
	  'category': 'slice_join',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'begin',
	    'type': 'number[]'
	  }, {
	    'start': 2,
	    'name': 'size',
	    'type': 'number[]'
	  }]
	}, {
	  'tfOpName': 'StridedSlice',
	  'category': 'slice_join',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'begin',
	    'type': 'number[]'
	  }, {
	    'start': 2,
	    'name': 'end',
	    'type': 'number[]'
	  }, {
	    'start': 3,
	    'name': 'strides',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'begin_mask',
	    'name': 'beginMask',
	    'type': 'number',
	    'defaultValue': 0
	  }, {
	    'tfName': 'end_mask',
	    'name': 'endMask',
	    'type': 'number',
	    'defaultValue': 0
	  }, {
	    'tfName': 'new_axis_mask',
	    'name': 'newAxisMask',
	    'type': 'number',
	    'defaultValue': 0
	  }, {
	    'tfName': 'ellipsis_mask',
	    'name': 'ellipsisMask',
	    'type': 'number',
	    'defaultValue': 0
	  }, {
	    'tfName': 'shrink_axis_mask',
	    'name': 'shrinkAxisMask',
	    'type': 'number',
	    'defaultValue': 0
	  }]
	}, {
	  'tfOpName': 'Pack',
	  'category': 'slice_join',
	  'inputs': [{
	    'start': 0,
	    'end': 0,
	    'name': 'tensors',
	    'type': 'tensors'
	  }],
	  'attrs': [{
	    'tfName': 'axis',
	    'name': 'axis',
	    'type': 'number',
	    'defaultValue': 0
	  }]
	}, {
	  'tfOpName': 'Unpack',
	  'category': 'slice_join',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensor',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'axis',
	    'name': 'axis',
	    'type': 'number',
	    'defaultValue': 0
	  }, {
	    'tfName': 'num',
	    'name': 'num',
	    'type': 'number',
	    'defaultValue': 0,
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'Tile',
	  'category': 'slice_join',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'reps',
	    'type': 'number[]'
	  }]
	}, {
	  'tfOpName': 'Split',
	  'category': 'slice_join',
	  'inputs': [{
	    'start': 0,
	    'name': 'axis',
	    'type': 'number',
	    'defaultValue': 0
	  }, {
	    'start': 1,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'num_split',
	    'name': 'numOrSizeSplits',
	    'type': 'number',
	    'defaultValue': 1
	  }]
	}, {
	  'tfOpName': 'SplitV',
	  'category': 'slice_join',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'numOrSizeSplits',
	    'type': 'number[]'
	  }, {
	    'start': 2,
	    'name': 'axis',
	    'type': 'number',
	    'defaultValue': 0
	  }]
	}, {
	  'tfOpName': 'ScatterNd',
	  'category': 'slice_join',
	  'inputs': [{
	    'start': 0,
	    'name': 'indices',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'values',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'shape',
	    'type': 'number[]'
	  }]
	}, {
	  'tfOpName': 'GatherNd',
	  'category': 'slice_join',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'indices',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'SparseToDense',
	  'category': 'slice_join',
	  'inputs': [{
	    'start': 0,
	    'name': 'sparseIndices',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'outputShape',
	    'type': 'number[]'
	  }, {
	    'start': 2,
	    'name': 'sparseValues',
	    'type': 'tensor'
	  }, {
	    'start': 3,
	    'name': 'defaultValue',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'validate_indices',
	    'name': 'validateIndices',
	    'type': 'bool',
	    'defaultValue': false,
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'TensorScatterUpdate',
	  'category': 'slice_join',
	  'inputs': [{
	    'start': 0,
	    'name': 'tensor',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'indices',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'values',
	    'type': 'tensor'
	  }]
	}];

	var sliceJoin = {
		__proto__: null,
		json: json$4
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json$3 = [{
	  'tfOpName': 'SparseFillEmptyRows',
	  'category': 'sparse',
	  'inputs': [{
	    'start': 0,
	    'name': 'indices',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'values',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'denseShape',
	    'type': 'tensor'
	  }, {
	    'start': 3,
	    'name': 'defaultValue',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'SparseReshape',
	  'category': 'sparse',
	  'inputs': [{
	    'start': 0,
	    'name': 'inputIndices',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'inputShape',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'newShape',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'T',
	    'name': 'dtype',
	    'type': 'dtype',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'SparseSegmentMean',
	  'category': 'sparse',
	  'inputs': [{
	    'start': 0,
	    'name': 'data',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'indices',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'segmentIds',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'SparseSegmentSum',
	  'category': 'sparse',
	  'inputs': [{
	    'start': 0,
	    'name': 'data',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'indices',
	    'type': 'tensor'
	  }, {
	    'start': 2,
	    'name': 'segmentIds',
	    'type': 'tensor'
	  }]
	}];

	var sparse = {
		__proto__: null,
		json: json$3
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json$2 = [{
	  'tfOpName': 'FFT',
	  'category': 'spectral',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'IFFT',
	  'category': 'spectral',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }]
	}, {
	  'tfOpName': 'RFFT',
	  'category': 'spectral',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'fft_length',
	    'type': 'number',
	    'notSupported': true
	  }]
	}, {
	  'tfOpName': 'IRFFT',
	  'category': 'spectral',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'fft_length',
	    'type': 'number',
	    'notSupported': true
	  }]
	}];

	var spectral = {
		__proto__: null,
		json: json$2
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json$1 = [{
	  'tfOpName': 'StaticRegexReplace',
	  'category': 'string',
	  'inputs': [{
	    'start': 0,
	    'name': 'input',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'pattern',
	    'name': 'pattern',
	    'type': 'string'
	  }, {
	    'tfName': 'rewrite',
	    'name': 'rewrite',
	    'type': 'string'
	  }, {
	    'tfName': 'replace_global',
	    'name': 'replaceGlobal',
	    'type': 'bool'
	  }]
	}, {
	  'tfOpName': 'StringNGrams',
	  'category': 'string',
	  'inputs': [{
	    'start': 0,
	    'name': 'data',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'dataSplits',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'separator',
	    'name': 'separator',
	    'type': 'string'
	  }, {
	    'tfName': 'ngram_widths',
	    'name': 'nGramWidths',
	    'type': 'number[]'
	  }, {
	    'tfName': 'left_pad',
	    'name': 'leftPad',
	    'type': 'string'
	  }, {
	    'tfName': 'right_pad',
	    'name': 'rightPad',
	    'type': 'string'
	  }, {
	    'tfName': 'pad_width',
	    'name': 'padWidth',
	    'type': 'number'
	  }, {
	    'tfName': 'preserve_short_sequences',
	    'name': 'preserveShortSequences',
	    'type': 'bool'
	  }],
	  'outputs': ['ngrams', 'ngrams_splits']
	}, {
	  'tfOpName': 'StringSplit',
	  'category': 'string',
	  'inputs': [{
	    'start': 0,
	    'name': 'input',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'delimiter',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'skip_empty',
	    'name': 'skipEmpty',
	    'type': 'bool'
	  }],
	  'outputs': ['indices', 'values', 'shape']
	}, {
	  'tfOpName': 'StringToHashBucketFast',
	  'category': 'string',
	  'inputs': [{
	    'start': 0,
	    'name': 'input',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'num_buckets',
	    'name': 'numBuckets',
	    'type': 'number'
	  }]
	}];

	var string = {
		__proto__: null,
		json: json$1
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var json = [{
	  'tfOpName': 'Cast',
	  'category': 'transformation',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'SrcT',
	    'name': 'sdtype',
	    'type': 'dtype',
	    'notSupported': true
	  }, {
	    'tfName': 'DstT',
	    'name': 'dtype',
	    'type': 'dtype'
	  }]
	}, {
	  'tfOpName': 'ExpandDims',
	  'category': 'transformation',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'axis',
	    'type': 'number'
	  }]
	}, {
	  'tfOpName': 'MirrorPad',
	  'category': 'transformation',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'padding',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'mode',
	    'name': 'mode',
	    'type': 'string'
	  }]
	}, {
	  'tfOpName': 'Pad',
	  'category': 'transformation',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'padding',
	    'type': 'number[]'
	  }],
	  'attrs': [{
	    'tfName': 'constant_value',
	    'name': 'constantValue',
	    'type': 'number',
	    'defaultValue': 0
	  }]
	}, {
	  'tfOpName': 'PadV2',
	  'category': 'transformation',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'padding',
	    'type': 'number[]'
	  }, {
	    'start': 2,
	    'name': 'constantValue',
	    'type': 'number',
	    'defaultValue': 0
	  }]
	}, {
	  'tfOpName': 'Reshape',
	  'category': 'transformation',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'shape',
	    'type': 'number[]'
	  }]
	}, {
	  'tfOpName': 'EnsureShape',
	  'category': 'transformation',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'shape',
	    'type': 'number[]'
	  }]
	}, {
	  'tfOpName': 'Squeeze',
	  'category': 'transformation',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'axis',
	    'tfDeprecatedName': 'squeeze_dims',
	    'name': 'axis',
	    'type': 'number[]'
	  }]
	}, {
	  'tfOpName': 'SpaceToBatchND',
	  'category': 'transformation',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'blockShape',
	    'type': 'number[]'
	  }, {
	    'start': 2,
	    'name': 'paddings',
	    'type': 'number[]'
	  }]
	}, {
	  'tfOpName': 'BatchToSpaceND',
	  'category': 'transformation',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'blockShape',
	    'type': 'number[]'
	  }, {
	    'start': 2,
	    'name': 'crops',
	    'type': 'number[]'
	  }]
	}, {
	  'tfOpName': 'DepthToSpace',
	  'category': 'transformation',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }],
	  'attrs': [{
	    'tfName': 'block_size',
	    'name': 'blockSize',
	    'type': 'number'
	  }, {
	    'tfName': 'data_format',
	    'name': 'dataFormat',
	    'type': 'string'
	  }]
	}, {
	  'tfOpName': 'BroadcastTo',
	  'category': 'transformation',
	  'inputs': [{
	    'start': 0,
	    'name': 'x',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 'shape',
	    'type': 'number[]'
	  }],
	  'attrs': []
	}, {
	  'tfOpName': 'BroadcastArgs',
	  'category': 'transformation',
	  'inputs': [{
	    'start': 0,
	    'name': 's0',
	    'type': 'tensor'
	  }, {
	    'start': 1,
	    'name': 's1',
	    'type': 'tensor'
	  }],
	  'attrs': []
	}];

	var transformation = {
		__proto__: null,
		json: json
	};

	var OperationMapper = /*#__PURE__*/function () {
	  // Loads the op mapping from the JSON file.
	  function OperationMapper() {
	    var _ref;
	    _classCallCheck(this, OperationMapper);
	    var ops = [arithmetic, basicMath, control, convolution, creation, dynamic, evaluation, graph, hashTable, image, logical, matrices, normalization, reduction, sliceJoin, sparse, spectral, string, transformation];
	    var mappersJson = (_ref = []).concat.apply(_ref, _toConsumableArray(ops.map(function (op) {
	      return op.json;
	    })));
	    this.opMappers = mappersJson.reduce(function (map, mapper) {
	      map[mapper.tfOpName] = mapper;
	      return map;
	    }, {});
	  }
	  // Converts the model inference graph from Tensorflow GraphDef to local
	  // representation for TensorFlow.js API
	  _createClass(OperationMapper, [{
	    key: "transformGraph",
	    value: function transformGraph(graph) {
	      var _this = this;
	      var signature = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	      var tfNodes = graph.node;
	      var placeholders = [];
	      var weights = [];
	      var initNodes = [];
	      var nodes = tfNodes.reduce(function (map, node) {
	        map[node.name] = _this.mapNode(node);
	        if (node.op.startsWith('Placeholder')) {
	          placeholders.push(map[node.name]);
	        } else if (node.op === 'Const') {
	          weights.push(map[node.name]);
	        } else if (node.input == null || node.input.length === 0) {
	          initNodes.push(map[node.name]);
	        }
	        return map;
	      }, {});
	      var inputs = [];
	      var outputs = [];
	      var inputNodeNameToKey = {};
	      var outputNodeNameToKey = {};
	      if (signature != null) {
	        inputNodeNameToKey = this.mapSignatureEntries(signature.inputs);
	        outputNodeNameToKey = this.mapSignatureEntries(signature.outputs);
	      }
	      var allNodes = Object.keys(nodes);
	      allNodes.forEach(function (key) {
	        var node = nodes[key];
	        node.inputNames.forEach(function (name, index) {
	          var _getNodeNameAndIndex = getNodeNameAndIndex(name),
	            _getNodeNameAndIndex2 = _slicedToArray(_getNodeNameAndIndex, 3),
	            nodeName = _getNodeNameAndIndex2[0],
	            outputName = _getNodeNameAndIndex2[2];
	          var inputNode = nodes[nodeName];
	          if (inputNode.outputs != null) {
	            var outputIndex = inputNode.outputs.indexOf(outputName);
	            if (outputIndex !== -1) {
	              var inputName = "".concat(nodeName, ":").concat(outputIndex);
	              // update the input name to use the mapped output index directly.
	              node.inputNames[index] = inputName;
	            }
	          }
	          node.inputs.push(inputNode);
	          inputNode.children.push(node);
	        });
	      });
	      // if signature has not outputs set, add any node that does not have
	      // outputs.
	      if (Object.keys(outputNodeNameToKey).length === 0) {
	        allNodes.forEach(function (key) {
	          var node = nodes[key];
	          if (node.children.length === 0) {
	            outputs.push(node);
	          }
	        });
	      } else {
	        Object.keys(outputNodeNameToKey).forEach(function (name) {
	          var _getNodeNameAndIndex3 = getNodeNameAndIndex(name),
	            _getNodeNameAndIndex4 = _slicedToArray(_getNodeNameAndIndex3, 1),
	            nodeName = _getNodeNameAndIndex4[0];
	          var node = nodes[nodeName];
	          if (node != null) {
	            node.signatureKey = outputNodeNameToKey[name];
	            outputs.push(node);
	          }
	        });
	      }
	      if (Object.keys(inputNodeNameToKey).length > 0) {
	        Object.keys(inputNodeNameToKey).forEach(function (name) {
	          var _getNodeNameAndIndex5 = getNodeNameAndIndex(name),
	            _getNodeNameAndIndex6 = _slicedToArray(_getNodeNameAndIndex5, 1),
	            nodeName = _getNodeNameAndIndex6[0];
	          var node = nodes[nodeName];
	          if (node) {
	            node.signatureKey = inputNodeNameToKey[name];
	            inputs.push(node);
	          }
	        });
	      } else {
	        inputs = placeholders;
	      }
	      var functions = {};
	      if (graph.library != null && graph.library.function != null) {
	        functions = graph.library.function.reduce(function (functions, func) {
	          functions[func.signature.name] = _this.mapFunction(func);
	          return functions;
	        }, {});
	      }
	      var result = {
	        nodes: nodes,
	        inputs: inputs,
	        outputs: outputs,
	        weights: weights,
	        placeholders: placeholders,
	        signature: signature,
	        functions: functions
	      };
	      if (initNodes.length > 0) {
	        result.initNodes = initNodes;
	      }
	      return result;
	    }
	  }, {
	    key: "mapSignatureEntries",
	    value: function mapSignatureEntries(entries) {
	      return Object.keys(entries || {}).reduce(function (prev, curr) {
	        prev[entries[curr].name] = curr;
	        return prev;
	      }, {});
	    }
	  }, {
	    key: "mapNode",
	    value: function mapNode(node) {
	      // Unsupported ops will cause an error at run-time (not parse time), since
	      // they may not be used by the actual execution subgraph.
	      var mapper = getRegisteredOp(node.op) || this.opMappers[node.op] || {};
	      if (node.attr == null) {
	        node.attr = {};
	      }
	      var newNode = {
	        name: node.name,
	        op: node.op,
	        category: mapper.category,
	        inputNames: (node.input || []).map(function (input) {
	          return input.startsWith('^') ? input.slice(1) : input;
	        }),
	        inputs: [],
	        children: [],
	        inputParams: {},
	        attrParams: {},
	        rawAttrs: node.attr,
	        outputs: mapper.outputs
	      };
	      if (mapper.inputs != null) {
	        newNode.inputParams = mapper.inputs.reduce(function (map, param) {
	          map[param.name] = {
	            type: param.type,
	            inputIndexStart: param.start,
	            inputIndexEnd: param.end
	          };
	          return map;
	        }, {});
	      }
	      if (mapper.attrs != null) {
	        newNode.attrParams = mapper.attrs.reduce(function (map, param) {
	          var type = param.type;
	          var value = undefined;
	          switch (param.type) {
	            case 'string':
	              value = getStringParam(node.attr, param.tfName, param.defaultValue);
	              if (value === undefined && !!param.tfDeprecatedName) {
	                value = getStringParam(node.attr, param.tfDeprecatedName, param.defaultValue);
	              }
	              break;
	            case 'string[]':
	              value = getStringArrayParam(node.attr, param.tfName, param.defaultValue);
	              if (value === undefined && !!param.tfDeprecatedName) {
	                value = getStringArrayParam(node.attr, param.tfDeprecatedName, param.defaultValue);
	              }
	              break;
	            case 'number':
	              value = getNumberParam(node.attr, param.tfName, param.defaultValue || 0);
	              if (value === undefined && !!param.tfDeprecatedName) {
	                value = getNumberParam(node.attr, param.tfDeprecatedName, param.defaultValue);
	              }
	              break;
	            case 'number[]':
	              value = getNumericArrayParam(node.attr, param.tfName, param.defaultValue);
	              if (value === undefined && !!param.tfDeprecatedName) {
	                value = getNumericArrayParam(node.attr, param.tfDeprecatedName, param.defaultValue);
	              }
	              break;
	            case 'bool':
	              value = getBoolParam(node.attr, param.tfName, param.defaultValue);
	              if (value === undefined && !!param.tfDeprecatedName) {
	                value = getBoolParam(node.attr, param.tfDeprecatedName, param.defaultValue);
	              }
	              break;
	            case 'bool[]':
	              value = getBoolArrayParam(node.attr, param.tfName, param.defaultValue);
	              if (value === undefined && !!param.tfDeprecatedName) {
	                value = getBoolArrayParam(node.attr, param.tfDeprecatedName, param.defaultValue);
	              }
	              break;
	            case 'shape':
	              value = getTensorShapeParam(node.attr, param.tfName, param.defaultValue);
	              if (value === undefined && !!param.tfDeprecatedName) {
	                value = getTensorShapeParam(node.attr, param.tfDeprecatedName, param.defaultValue);
	              }
	              break;
	            case 'shape[]':
	              value = getTensorShapeArrayParam(node.attr, param.tfName, param.defaultValue);
	              if (value === undefined && !!param.tfDeprecatedName) {
	                value = getTensorShapeArrayParam(node.attr, param.tfDeprecatedName, param.defaultValue);
	              }
	              break;
	            case 'dtype':
	              value = getDtypeParam(node.attr, param.tfName, param.defaultValue);
	              if (value === undefined && !!param.tfDeprecatedName) {
	                value = getDtypeParam(node.attr, param.tfDeprecatedName, param.defaultValue);
	              }
	              break;
	            case 'dtype[]':
	              value = getDtypeArrayParam(node.attr, param.tfName, param.defaultValue);
	              if (value === undefined && !!param.tfDeprecatedName) {
	                value = getDtypeArrayParam(node.attr, param.tfDeprecatedName, param.defaultValue);
	              }
	              break;
	            case 'func':
	              value = getFuncParam(node.attr, param.tfName, param.defaultValue);
	              if (value === undefined && !!param.tfDeprecatedName) {
	                value = getFuncParam(node.attr, param.tfDeprecatedName, param.defaultValue);
	              }
	              break;
	            case 'tensor':
	            case 'tensors':
	              break;
	            default:
	              throw new Error("Unsupported param type: ".concat(param.type, " for op: ").concat(node.op));
	          }
	          map[param.name] = {
	            value: value,
	            type: type
	          };
	          return map;
	        }, {});
	      }
	      return newNode;
	    }
	    // map the TFunctionDef to TFJS graph object
	  }, {
	    key: "mapFunction",
	    value: function mapFunction(functionDef) {
	      var _this2 = this;
	      var tfNodes = functionDef.nodeDef;
	      var placeholders = [];
	      var weights = [];
	      var nodes = {};
	      if (tfNodes != null) {
	        nodes = tfNodes.reduce(function (map, node) {
	          map[node.name] = _this2.mapNode(node);
	          if (node.op === 'Const') {
	            weights.push(map[node.name]);
	          }
	          return map;
	        }, {});
	      }
	      var inputs = [];
	      var outputs = [];
	      functionDef.signature.inputArg.forEach(function (arg) {
	        var _getNodeNameAndIndex7 = getNodeNameAndIndex(arg.name),
	          _getNodeNameAndIndex8 = _slicedToArray(_getNodeNameAndIndex7, 1),
	          nodeName = _getNodeNameAndIndex8[0];
	        var node = {
	          name: nodeName,
	          op: 'Placeholder',
	          inputs: [],
	          inputNames: [],
	          category: 'graph',
	          inputParams: {},
	          attrParams: {
	            dtype: {
	              value: parseDtypeParam(arg.type),
	              type: 'dtype'
	            }
	          },
	          children: []
	        };
	        node.signatureKey = arg.name;
	        inputs.push(node);
	        nodes[nodeName] = node;
	      });
	      var allNodes = Object.keys(nodes);
	      allNodes.forEach(function (key) {
	        var node = nodes[key];
	        node.inputNames.forEach(function (name, index) {
	          var _getNodeNameAndIndex9 = getNodeNameAndIndex(name),
	            _getNodeNameAndIndex10 = _slicedToArray(_getNodeNameAndIndex9, 3),
	            nodeName = _getNodeNameAndIndex10[0],
	            outputName = _getNodeNameAndIndex10[2];
	          var inputNode = nodes[nodeName];
	          if (inputNode.outputs != null) {
	            var outputIndex = inputNode.outputs.indexOf(outputName);
	            if (outputIndex !== -1) {
	              var inputName = "".concat(nodeName, ":").concat(outputIndex);
	              // update the input name to use the mapped output index directly.
	              node.inputNames[index] = inputName;
	            }
	          }
	          node.inputs.push(inputNode);
	          inputNode.children.push(node);
	        });
	      });
	      var returnNodeMap = functionDef.ret;
	      functionDef.signature.outputArg.forEach(function (output) {
	        var _getNodeNameAndIndex11 = getNodeNameAndIndex(returnNodeMap[output.name]),
	          _getNodeNameAndIndex12 = _slicedToArray(_getNodeNameAndIndex11, 2),
	          nodeName = _getNodeNameAndIndex12[0],
	          index = _getNodeNameAndIndex12[1];
	        var node = nodes[nodeName];
	        if (node != null) {
	          node.defaultOutput = index;
	          outputs.push(node);
	        }
	      });
	      var signature = this.mapArgsToSignature(functionDef);
	      return {
	        nodes: nodes,
	        inputs: inputs,
	        outputs: outputs,
	        weights: weights,
	        placeholders: placeholders,
	        signature: signature
	      };
	    }
	  }, {
	    key: "mapArgsToSignature",
	    value: function mapArgsToSignature(functionDef) {
	      var _this3 = this;
	      return {
	        methodName: functionDef.signature.name,
	        inputs: functionDef.signature.inputArg.reduce(function (map, arg) {
	          map[arg.name] = _this3.mapArgToTensorInfo(arg);
	          return map;
	        }, {}),
	        outputs: functionDef.signature.outputArg.reduce(function (map, arg) {
	          map[arg.name] = _this3.mapArgToTensorInfo(arg, functionDef.ret);
	          return map;
	        }, {})
	      };
	    }
	  }, {
	    key: "mapArgToTensorInfo",
	    value: function mapArgToTensorInfo(arg, nameMap) {
	      var name = arg.name;
	      if (nameMap != null) {
	        name = nameMap[name];
	      }
	      return {
	        name: name,
	        dtype: arg.type
	      };
	    }
	  }], [{
	    key: "Instance",
	    get:
	    // Singleton instance for the mapper
	    function get() {
	      return this._instance || (this._instance = new this());
	    }
	  }]);
	  return OperationMapper;
	}();
	function decodeBase64(text) {
	  var global = env().global;
	  if (typeof global.atob !== 'undefined') {
	    return global.atob(text);
	  } else if (typeof Buffer !== 'undefined') {
	    return new Buffer(text, 'base64').toString();
	  } else {
	    throw new Error('Unable to decode base64 in this environment. ' + 'Missing built-in atob() or Buffer()');
	  }
	}
	function parseStringParam(s, keepCase) {
	  var value = Array.isArray(s) ? String.fromCharCode.apply(null, s) : decodeBase64(s);
	  return keepCase ? value : value.toLowerCase();
	}
	function getStringParam(attrs, name, def) {
	  var keepCase = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var param = attrs[name];
	  if (param != null) {
	    return parseStringParam(param.s, keepCase);
	  }
	  return def;
	}
	function getBoolParam(attrs, name, def) {
	  var param = attrs[name];
	  return param ? param.b : def;
	}
	function getNumberParam(attrs, name, def) {
	  var param = attrs[name] || {};
	  var value = param['i'] != null ? param['i'] : param['f'] != null ? param['f'] : def;
	  return typeof value === 'number' ? value : parseInt(value, 10);
	}
	function parseDtypeParam(value) {
	  if (typeof value === 'string') {
	    // tslint:disable-next-line:no-any
	    value = DataType[value];
	  }
	  switch (value) {
	    case DataType.DT_FLOAT:
	    case DataType.DT_HALF:
	      return 'float32';
	    case DataType.DT_INT32:
	    case DataType.DT_INT64:
	    case DataType.DT_INT8:
	    case DataType.DT_UINT8:
	      return 'int32';
	    case DataType.DT_BOOL:
	      return 'bool';
	    case DataType.DT_DOUBLE:
	      return 'float32';
	    case DataType.DT_STRING:
	      return 'string';
	    case DataType.DT_COMPLEX64:
	    case DataType.DT_COMPLEX128:
	      return 'complex64';
	    default:
	      // Unknown dtype error will happen at runtime (instead of parse time),
	      // since these nodes might not be used by the actual subgraph execution.
	      return null;
	  }
	}
	function getFuncParam(attrs, name, def) {
	  var param = attrs[name];
	  if (param && param.func) {
	    return param.func.name;
	  }
	  return def;
	}
	function getDtypeParam(attrs, name, def) {
	  var param = attrs[name];
	  if (param && param.type) {
	    return parseDtypeParam(param.type);
	  }
	  return def;
	}
	function getDtypeArrayParam(attrs, name, def) {
	  var param = attrs[name];
	  if (param && param.list && param.list.type) {
	    return param.list.type.map(function (v) {
	      return parseDtypeParam(v);
	    });
	  }
	  return def;
	}
	function parseTensorShapeParam(shape) {
	  if (shape.unknownRank) {
	    return undefined;
	  }
	  if (shape.dim != null) {
	    return shape.dim.map(function (dim) {
	      return typeof dim.size === 'number' ? dim.size : parseInt(dim.size, 10);
	    });
	  }
	  return [];
	}
	function getTensorShapeParam(attrs, name, def) {
	  var param = attrs[name];
	  if (param && param.shape) {
	    return parseTensorShapeParam(param.shape);
	  }
	  return def;
	}
	function getNumericArrayParam(attrs, name, def) {
	  var param = attrs[name];
	  if (param) {
	    return ((param.list.f && param.list.f.length ? param.list.f : param.list.i) || []).map(function (v) {
	      return typeof v === 'number' ? v : parseInt(v, 10);
	    });
	  }
	  return def;
	}
	function getStringArrayParam(attrs, name, def) {
	  var keepCase = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var param = attrs[name];
	  if (param && param.list && param.list.s) {
	    return param.list.s.map(function (v) {
	      return parseStringParam(v, keepCase);
	    });
	  }
	  return def;
	}
	function getTensorShapeArrayParam(attrs, name, def) {
	  var param = attrs[name];
	  if (param && param.list && param.list.shape) {
	    return param.list.shape.map(function (v) {
	      return parseTensorShapeParam(v);
	    });
	  }
	  return def;
	}
	function getBoolArrayParam(attrs, name, def) {
	  var param = attrs[name];
	  if (param && param.list && param.list.b) {
	    return param.list.b;
	  }
	  return def;
	}

	/**
	 * Helper class for lookup inputs and params for nodes in the model graph.
	 */
	var NodeValueImpl = /*#__PURE__*/function () {
	  function NodeValueImpl(node, tensorMap, context) {
	    var _this = this;
	    _classCallCheck(this, NodeValueImpl);
	    this.node = node;
	    this.tensorMap = tensorMap;
	    this.context = context;
	    this.inputs = [];
	    this.attrs = {};
	    this.inputs = node.inputNames.map(function (name) {
	      return _this.getInput(name);
	    });
	    if (node.rawAttrs != null) {
	      this.attrs = Object.keys(node.rawAttrs).reduce(function (attrs, key) {
	        attrs[key] = _this.getAttr(key);
	        return attrs;
	      }, {});
	    }
	  }
	  /**
	   * Return the value of the attribute or input param.
	   * @param name String: name of attribute or input param.
	   */
	  _createClass(NodeValueImpl, [{
	    key: "getInput",
	    value: function getInput(name) {
	      return getTensor(name, this.tensorMap, this.context);
	    }
	    /**
	     * Return the value of the attribute or input param.
	     * @param name String: name of attribute or input param.
	     */
	  }, {
	    key: "getAttr",
	    value: function getAttr(name, defaultValue) {
	      var value = this.node.rawAttrs[name];
	      if (value.tensor != null) {
	        return getTensor(name, this.tensorMap, this.context);
	      }
	      if (value.i != null || value.f != null) {
	        return getNumberParam(this.node.rawAttrs, name, defaultValue);
	      }
	      if (value.s != null) {
	        return getStringParam(this.node.rawAttrs, name, defaultValue);
	      }
	      if (value.b != null) {
	        return getBoolParam(this.node.rawAttrs, name, defaultValue);
	      }
	      if (value.shape != null) {
	        return getTensorShapeParam(this.node.rawAttrs, name, defaultValue);
	      }
	      if (value.type != null) {
	        return getDtypeParam(this.node.rawAttrs, name, defaultValue);
	      }
	      if (value.list != null) {
	        if (value.list.i != null || value.list.f != null) {
	          return getNumericArrayParam(this.node.rawAttrs, name, defaultValue);
	        }
	        if (value.list.s != null) {
	          return getStringArrayParam(this.node.rawAttrs, name, defaultValue);
	        }
	        if (value.list.shape != null) {
	          return getTensorShapeArrayParam(this.node.rawAttrs, name, defaultValue);
	        }
	        if (value.list.b != null) {
	          return getBoolArrayParam(this.node.rawAttrs, name, defaultValue);
	        }
	        if (value.list.type != null) {
	          return getDtypeArrayParam(this.node.rawAttrs, name, defaultValue);
	        }
	      }
	      return defaultValue;
	    }
	  }]);
	  return NodeValueImpl;
	}();

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */

	var tfOps = {
		__proto__: null,
		OP_SCOPE_SUFFIX: OP_SCOPE_SUFFIX,
		abs: abs$2,
		acos: acos$2,
		acosh: acosh$2,
		add: add$3,
		addN: addN$2,
		all: all$2,
		any: any$2,
		argMax: argMax$2,
		argMin: argMin$2,
		asin: asin$2,
		asinh: asinh$2,
		atan: atan$2,
		atan2: atan2$2,
		atanh: atanh$2,
		avgPool: avgPool$2,
		avgPool3d: avgPool3d$1,
		basicLSTMCell: basicLSTMCell,
		batchNorm: batchNorm$2,
		batchNorm2d: batchNorm2d,
		batchNorm3d: batchNorm3d,
		batchNorm4d: batchNorm4d,
		batchToSpaceND: batchToSpaceND$2,
		bincount: bincount$2,
		bitwiseAnd: bitwiseAnd$2,
		booleanMaskAsync: booleanMaskAsync,
		broadcastArgs: broadcastArgs$2,
		broadcastTo: broadcastTo,
		buffer: buffer,
		cast: cast$3,
		ceil: ceil$2,
		clipByValue: clipByValue$2,
		clone: clone,
		complex: complex$2,
		concat: concat$2,
		concat1d: concat1d,
		concat2d: concat2d,
		concat3d: concat3d,
		concat4d: concat4d,
		conv1d: conv1d$2,
		conv2d: conv2d$4,
		conv2dTranspose: conv2dTranspose$1,
		conv3d: conv3d$2,
		conv3dTranspose: conv3dTranspose$1,
		cos: cos$2,
		cosh: cosh$2,
		cosineWindow: cosineWindow,
		cumprod: cumprod$2,
		cumsum: cumsum$2,
		denseBincount: denseBincount$2,
		depthToSpace: depthToSpace$2,
		depthwiseConv2d: depthwiseConv2d$3,
		diag: diag$2,
		dilation2d: dilation2d,
		div: div$1,
		divNoNan: divNoNan,
		dot: dot$2,
		dropout: dropout$2,
		einsum: einsum$2,
		elu: elu$4,
		enclosingPowerOfTwo: enclosingPowerOfTwo,
		ensureShape: ensureShape,
		equal: equal$2,
		erf: erf$2,
		euclideanNorm: euclideanNorm,
		exp: exp$2,
		expandDims: expandDims$3,
		expm1: expm1$2,
		eye: eye,
		fft: fft$2,
		fill: fill$2,
		floor: floor$2,
		floorDiv: floorDiv$2,
		fused: fused_ops,
		gather: gather$1,
		gatherND: gatherND,
		greater: greater$3,
		greaterEqual: greaterEqual$2,
		ifft: ifft$2,
		imag: imag$2,
		image: image$1,
		inTopKAsync: inTopKAsync,
		irfft: irfft,
		isFinite: isFinite$3,
		isInf: isInf$2,
		isNaN: isNaN$3,
		leakyRelu: leakyRelu$2,
		less: less$3,
		lessEqual: lessEqual$2,
		linalg: linalg,
		linspace: linspace,
		localResponseNormalization: localResponseNormalization,
		log: log$2,
		log1p: log1p$2,
		logSigmoid: logSigmoid,
		logSoftmax: logSoftmax,
		logSumExp: logSumExp,
		logicalAnd: logicalAnd$2,
		logicalNot: logicalNot$2,
		logicalOr: logicalOr$2,
		logicalXor: logicalXor,
		losses: losses,
		lowerBound: lowerBound$1,
		matMul: matMul$1,
		max: max$3,
		maxPool: maxPool$2,
		maxPool3d: maxPool3d$1,
		maxPoolWithArgmax: maxPoolWithArgmax,
		maximum: maximum$4,
		mean: mean$3,
		meshgrid: meshgrid,
		min: min$3,
		minimum: minimum$4,
		mirrorPad: mirrorPad$1,
		mod: mod$2,
		moments: moments,
		movingAverage: movingAverage,
		mul: mul,
		multiRNNCell: multiRNNCell,
		multinomial: multinomial$2,
		neg: neg$2,
		norm: norm,
		notEqual: notEqual$2,
		oneHot: oneHot$3,
		ones: ones$1,
		onesLike: onesLike$3,
		op: op,
		outerProduct: outerProduct,
		pad: pad,
		pad1d: pad1d,
		pad2d: pad2d,
		pad3d: pad3d,
		pad4d: pad4d,
		pool: pool$1,
		pow: pow$3,
		prelu: prelu$3,
		print: print,
		prod: prod$2,
		raggedGather: raggedGather$2,
		raggedRange: raggedRange$2,
		raggedTensorToTensor: raggedTensorToTensor$2,
		rand: rand,
		randomGamma: randomGamma,
		randomNormal: randomNormal$2,
		randomStandardNormal: randomStandardNormal,
		randomUniform: randomUniform$1,
		randomUniformInt: randomUniformInt,
		range: range$3,
		real: real$2,
		reciprocal: reciprocal$2,
		relu: relu$2,
		relu6: relu6$2,
		reshape: reshape$3,
		reverse: reverse$2,
		reverse1d: reverse1d,
		reverse2d: reverse2d,
		reverse3d: reverse3d,
		reverse4d: reverse4d,
		rfft: rfft,
		round: round$2,
		rsqrt: rsqrt$2,
		scalar: scalar,
		scatterND: scatterND,
		searchSorted: searchSorted$2,
		selu: selu$2,
		separableConv2d: separableConv2d$1,
		setdiff1dAsync: setdiff1dAsync,
		sigmoid: sigmoid$2,
		sign: sign$3,
		signal: signal,
		sin: sin$2,
		sinh: sinh$2,
		slice: slice$2,
		slice1d: slice1d,
		slice2d: slice2d,
		slice3d: slice3d,
		slice4d: slice4d,
		softmax: softmax$3,
		softplus: softplus$2,
		spaceToBatchND: spaceToBatchND$2,
		sparse: sparse$1,
		sparseToDense: sparseToDense$2,
		spectral: spectral$1,
		split: split$3,
		sqrt: sqrt$2,
		square: square$2,
		squaredDifference: squaredDifference$2,
		squeeze: squeeze,
		stack: stack,
		step: step$2,
		stridedSlice: stridedSlice$2,
		string: string$1,
		sub: sub$2,
		sum: sum$3,
		tan: tan$2,
		tanh: tanh$2,
		tensor: tensor,
		tensor1d: tensor1d,
		tensor2d: tensor2d,
		tensor3d: tensor3d,
		tensor4d: tensor4d,
		tensor5d: tensor5d,
		tensor6d: tensor6d,
		tensorScatterUpdate: tensorScatterUpdate$2,
		tile: tile$3,
		topk: topk,
		transpose: transpose$2,
		truncatedNormal: truncatedNormal$1,
		unique: unique$3,
		unsortedSegmentSum: unsortedSegmentSum$2,
		unstack: unstack,
		upperBound: upperBound$1,
		variable: variable$1,
		where: where,
		whereAsync: whereAsync,
		zeros: zeros$2,
		zerosLike: zerosLike$3
	};

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var executeOp$k = function executeOp(node, tensorMap, context) {
	  var ops = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : tfOps;
	  switch (node.op) {
	    case 'BiasAdd':
	    case 'AddV2':
	    case 'Add':
	      {
	        return [ops.add(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    case 'AddN':
	      {
	        return [ops.addN(getParamValue('tensors', node, tensorMap, context))];
	      }
	    case 'FloorMod':
	    case 'Mod':
	      return [ops.mod(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	    case 'Mul':
	      return [ops.mul(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	    case 'RealDiv':
	    case 'Div':
	      {
	        return [ops.div(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    case 'DivNoNan':
	      {
	        return [ops.divNoNan(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    case 'FloorDiv':
	      {
	        return [ops.floorDiv(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    case 'Sub':
	      {
	        return [ops.sub(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    case 'Minimum':
	      {
	        return [ops.minimum(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    case 'Maximum':
	      {
	        return [ops.maximum(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    case 'Pow':
	      {
	        return [ops.pow(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    case 'SquaredDifference':
	      {
	        return [ops.squaredDifference(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    default:
	      throw TypeError("Node type ".concat(node.op, " is not implemented"));
	  }
	};
	var CATEGORY$j = 'arithmetic';

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var executeOp$j = function executeOp(node, tensorMap, context) {
	  var ops = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : tfOps;
	  switch (node.op) {
	    case 'Abs':
	    case 'ComplexAbs':
	      return [ops.abs(getParamValue('x', node, tensorMap, context))];
	    case 'Acos':
	      return [ops.acos(getParamValue('x', node, tensorMap, context))];
	    case 'Acosh':
	      return [ops.acosh(getParamValue('x', node, tensorMap, context))];
	    case 'Asin':
	      return [ops.asin(getParamValue('x', node, tensorMap, context))];
	    case 'Asinh':
	      return [ops.asinh(getParamValue('x', node, tensorMap, context))];
	    case 'Atan':
	      return [ops.atan(getParamValue('x', node, tensorMap, context))];
	    case 'Atan2':
	      return [ops.atan2(getParamValue('x', node, tensorMap, context), getParamValue('y', node, tensorMap, context))];
	    case 'Atanh':
	      return [ops.atanh(getParamValue('x', node, tensorMap, context))];
	    case 'Ceil':
	      return [ops.ceil(getParamValue('x', node, tensorMap, context))];
	    case 'Complex':
	      return [ops.complex(getParamValue('real', node, tensorMap, context), getParamValue('imag', node, tensorMap, context))];
	    case 'Cos':
	      return [ops.cos(getParamValue('x', node, tensorMap, context))];
	    case 'Cosh':
	      return [ops.cosh(getParamValue('x', node, tensorMap, context))];
	    case 'Elu':
	      return [ops.elu(getParamValue('x', node, tensorMap, context))];
	    case 'Erf':
	      return [ops.erf(getParamValue('x', node, tensorMap, context))];
	    case 'Exp':
	      return [ops.exp(getParamValue('x', node, tensorMap, context))];
	    case 'Expm1':
	      {
	        return [ops.expm1(getParamValue('x', node, tensorMap, context))];
	      }
	    case 'Floor':
	      return [ops.floor(getParamValue('x', node, tensorMap, context))];
	    case 'Log':
	      return [ops.log(getParamValue('x', node, tensorMap, context))];
	    case 'Log1p':
	      {
	        return [ops.log1p(getParamValue('x', node, tensorMap, context))];
	      }
	    case 'Imag':
	      return [ops.imag(getParamValue('x', node, tensorMap, context))];
	    case 'Neg':
	      return [ops.neg(getParamValue('x', node, tensorMap, context))];
	    case 'Reciprocal':
	      {
	        return [ops.reciprocal(getParamValue('x', node, tensorMap, context))];
	      }
	    case 'Real':
	      return [ops.real(getParamValue('x', node, tensorMap, context))];
	    case 'Relu':
	      return [ops.relu(getParamValue('x', node, tensorMap, context))];
	    case 'Round':
	      {
	        return [ops.round(getParamValue('x', node, tensorMap, context))];
	      }
	    case 'Selu':
	      return [ops.selu(getParamValue('x', node, tensorMap, context))];
	    case 'Sigmoid':
	      return [ops.sigmoid(getParamValue('x', node, tensorMap, context))];
	    case 'Sin':
	      return [ops.sin(getParamValue('x', node, tensorMap, context))];
	    case 'Sign':
	      {
	        return [ops.sign(getParamValue('x', node, tensorMap, context))];
	      }
	    case 'Sinh':
	      {
	        return [ops.sinh(getParamValue('x', node, tensorMap, context))];
	      }
	    case 'Softplus':
	      {
	        return [ops.softplus(getParamValue('x', node, tensorMap, context))];
	      }
	    case 'Sqrt':
	      {
	        return [ops.sqrt(getParamValue('x', node, tensorMap, context))];
	      }
	    case 'Square':
	      {
	        return [ops.square(getParamValue('x', node, tensorMap, context))];
	      }
	    case 'Tanh':
	      {
	        return [ops.tanh(getParamValue('x', node, tensorMap, context))];
	      }
	    case 'Tan':
	      return [ops.tan(getParamValue('x', node, tensorMap, context))];
	    case 'ClipByValue':
	      return [ops.clipByValue(getParamValue('x', node, tensorMap, context), getParamValue('clipValueMin', node, tensorMap, context), getParamValue('clipValueMax', node, tensorMap, context))];
	    case 'Relu6':
	      return [ops.relu6(getParamValue('x', node, tensorMap, context))];
	    case 'Rsqrt':
	      return [ops.rsqrt(getTensor(node.inputNames[0], tensorMap, context))];
	    case 'LeakyRelu':
	      return [ops.leakyRelu(getParamValue('x', node, tensorMap, context), getParamValue('alpha', node, tensorMap, context))];
	    case 'Prelu':
	      return [ops.prelu(getParamValue('x', node, tensorMap, context), getParamValue('alpha', node, tensorMap, context))];
	    case 'IsNan':
	      return [ops.isNaN(getTensor(node.inputNames[0], tensorMap, context))];
	    case 'IsInf':
	      return [ops.isInf(getTensor(node.inputNames[0], tensorMap, context))];
	    case 'IsFinite':
	      return [ops.isFinite(getTensor(node.inputNames[0], tensorMap, context))];
	    default:
	      throw TypeError("Node type ".concat(node.op, " is not implemented"));
	  }
	};
	var CATEGORY$i = 'basic_math';

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Used by TensorList and TensorArray to verify if elementShape matches, support
	 * negative value as the dim shape.
	 * @param shapeA
	 * @param shapeB
	 * @param errorMessagePrefix
	 */
	function assertShapesMatchAllowUndefinedSize(shapeA, shapeB) {
	  var errorMessagePrefix = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '';
	  // constant shape means unknown rank
	  if (typeof shapeA === 'number' || typeof shapeB === 'number') {
	    return;
	  }
	  assert$1(shapeA.length === shapeB.length, function () {
	    return errorMessagePrefix + " Shapes ".concat(shapeA, " and ").concat(shapeB, " must match");
	  });
	  for (var i = 0; i < shapeA.length; i++) {
	    var dim0 = shapeA[i];
	    var dim1 = shapeB[i];
	    assert$1(dim0 < 0 || dim1 < 0 || dim0 === dim1, function () {
	      return errorMessagePrefix + " Shapes ".concat(shapeA, " and ").concat(shapeB, " must match");
	    });
	  }
	}
	function fullDefinedShape(elementShape) {
	  if (typeof elementShape === 'number' || elementShape.some(function (dim) {
	    return dim < 0;
	  })) {
	    return false;
	  }
	  return true;
	}
	/**
	 * Generate the output element shape from the list elementShape, list tensors
	 * and input param.
	 * @param listElementShape
	 * @param tensors
	 * @param elementShape
	 */
	function inferElementShape(listElementShape, tensors, elementShape) {
	  var partialShape = mergeElementShape(listElementShape, elementShape);
	  var notfullDefinedShape = !fullDefinedShape(partialShape);
	  if (notfullDefinedShape && tensors.length === 0) {
	    throw new Error("Tried to calculate elements of an empty list" + " with non-fully-defined elementShape: ".concat(partialShape));
	  }
	  if (notfullDefinedShape) {
	    tensors.forEach(function (tensor) {
	      partialShape = mergeElementShape(tensor.shape, partialShape);
	    });
	  }
	  if (!fullDefinedShape(partialShape)) {
	    throw new Error("Non-fully-defined elementShape: ".concat(partialShape));
	  }
	  return partialShape;
	}
	function mergeElementShape(elementShapeA, elementShapeB) {
	  if (typeof elementShapeA === 'number') {
	    return elementShapeB;
	  }
	  if (typeof elementShapeB === 'number') {
	    return elementShapeA;
	  }
	  if (elementShapeA.length !== elementShapeB.length) {
	    throw new Error("Incompatible ranks during merge: ".concat(elementShapeA, " vs. ").concat(elementShapeB));
	  }
	  var result = [];
	  for (var i = 0; i < elementShapeA.length; ++i) {
	    var dim0 = elementShapeA[i];
	    var dim1 = elementShapeB[i];
	    if (dim0 >= 0 && dim1 >= 0 && dim0 !== dim1) {
	      throw new Error("Incompatible shape during merge: ".concat(elementShapeA, " vs. ").concat(elementShapeB));
	    }
	    result[i] = dim0 >= 0 ? dim0 : dim1;
	  }
	  return result;
	}

	/**
	 * The TensorArray object keeps an array of Tensors.  It
	 * allows reading from the array and writing to the array.
	 */
	var TensorArray = /*#__PURE__*/function () {
	  function TensorArray(name, dtype, maxSize, elementShape, identicalElementShapes, dynamicSize, clearAfterRead) {
	    _classCallCheck(this, TensorArray);
	    this.name = name;
	    this.dtype = dtype;
	    this.maxSize = maxSize;
	    this.elementShape = elementShape;
	    this.identicalElementShapes = identicalElementShapes;
	    this.dynamicSize = dynamicSize;
	    this.clearAfterRead = clearAfterRead;
	    this.tensors = [];
	    this.closed_ = false;
	    this.idTensor = scalar(0);
	    keep(this.idTensor);
	  }
	  _createClass(TensorArray, [{
	    key: "id",
	    get: function get() {
	      return this.idTensor.id;
	    }
	  }, {
	    key: "closed",
	    get: function get() {
	      return this.closed_;
	    }
	    /**
	     * Dispose the tensors and idTensor and mark the TensoryArray as closed.
	     */
	  }, {
	    key: "clearAndClose",
	    value: function clearAndClose(keepIds) {
	      this.tensors.forEach(function (tensor) {
	        if (keepIds == null || !keepIds.has(tensor.tensor.id)) {
	          tensor.tensor.dispose();
	        }
	      });
	      this.tensors = [];
	      this.closed_ = true;
	      this.idTensor.dispose();
	    }
	  }, {
	    key: "size",
	    value: function size() {
	      return this.tensors.length;
	    }
	    /**
	     * Read the value at location index in the TensorArray.
	     * @param index Number the index to read from.
	     */
	  }, {
	    key: "read",
	    value: function read(index) {
	      if (this.closed_) {
	        throw new Error("TensorArray ".concat(this.name, " has already been closed."));
	      }
	      if (index < 0 || index >= this.size()) {
	        throw new Error("Tried to read from index ".concat(index, ", but array size is: ").concat(this.size()));
	      }
	      var tensorWithState = this.tensors[index];
	      if (tensorWithState.cleared) {
	        throw new Error("TensorArray ".concat(this.name, ": Could not read index ").concat(index, " twice because it was cleared after a previous read ") + "(perhaps try setting clear_after_read = false?).");
	      }
	      if (this.clearAfterRead) {
	        tensorWithState.cleared = true;
	      }
	      tensorWithState.read = true;
	      return tensorWithState.tensor;
	    }
	    /**
	     * Helper method to read multiple tensors from the specified indices.
	     */
	  }, {
	    key: "readMany",
	    value: function readMany(indices) {
	      var _this = this;
	      return indices.map(function (index) {
	        return _this.read(index);
	      });
	    }
	    /**
	     * Write value into the index of the TensorArray.
	     * @param index number the index to write to.
	     * @param tensor
	     */
	  }, {
	    key: "write",
	    value: function write(index, tensor) {
	      if (this.closed_) {
	        throw new Error("TensorArray ".concat(this.name, " has already been closed."));
	      }
	      if (index < 0 || !this.dynamicSize && index >= this.maxSize) {
	        throw new Error("Tried to write to index ".concat(index, ", but array is not resizeable and size is: ").concat(this.maxSize));
	      }
	      var t = this.tensors[index] || {};
	      if (tensor.dtype !== this.dtype) {
	        throw new Error("TensorArray ".concat(this.name, ": Could not write to TensorArray index ").concat(index, ",\n          because the value dtype is ").concat(tensor.dtype, ", but TensorArray dtype is ").concat(this.dtype, "."));
	      }
	      // Set the shape for the first time write to unknow shape tensor array
	      if (this.size() === 0 && (this.elementShape == null || this.elementShape.length === 0)) {
	        this.elementShape = tensor.shape;
	      }
	      assertShapesMatchAllowUndefinedSize(this.elementShape, tensor.shape, "TensorArray ".concat(this.name, ": Could not write to TensorArray index ").concat(index, "."));
	      if (t.read) {
	        throw new Error("TensorArray ".concat(this.name, ": Could not write to TensorArray index ").concat(index, ", because it has already been read."));
	      }
	      if (t.written) {
	        throw new Error("TensorArray ".concat(this.name, ": Could not write to TensorArray index ").concat(index, ", because it has already been written."));
	      }
	      t.tensor = tensor;
	      keep(tensor);
	      t.written = true;
	      this.tensors[index] = t;
	    }
	    /**
	     * Helper method to write multiple tensors to the specified indices.
	     */
	  }, {
	    key: "writeMany",
	    value: function writeMany(indices, tensors) {
	      var _this2 = this;
	      if (indices.length !== tensors.length) {
	        throw new Error("TensorArray ".concat(this.name, ": could not write multiple tensors,") + "because the index size: ".concat(indices.length, " is not the same as tensors size: ").concat(tensors.length, "."));
	      }
	      indices.forEach(function (i, index) {
	        return _this2.write(i, tensors[index]);
	      });
	    }
	    /**
	     * Return selected values in the TensorArray as a packed Tensor. All of
	     * selected values must have been written and their shapes must all match.
	     * @param [indices] number[] Optional. Taking values in [0, max_value). If the
	     *    TensorArray is not dynamic, max_value=size(). If not specified returns
	     *    all tensors in the original order.
	     * @param [dtype]
	     */
	  }, {
	    key: "gather",
	    value: function gather(indices, dtype) {
	      if (!!dtype && dtype !== this.dtype) {
	        throw new Error("TensorArray dtype is ".concat(this.dtype, " but gather requested dtype ").concat(dtype));
	      }
	      if (!indices) {
	        indices = [];
	        for (var i = 0; i < this.size(); i++) {
	          indices.push(i);
	        }
	      } else {
	        indices = indices.slice(0, this.size());
	      }
	      if (indices.length === 0) {
	        return tensor([], [0].concat(this.elementShape));
	      }
	      // Read all the PersistentTensors into a vector to keep track of
	      // their memory.
	      var tensors = this.readMany(indices);
	      assertShapesMatchAllowUndefinedSize(this.elementShape, tensors[0].shape, 'TensorArray shape mismatch: ');
	      return stack(tensors, 0);
	    }
	    /**
	     * Return the values in the TensorArray as a concatenated Tensor.
	     */
	  }, {
	    key: "concat",
	    value: function concat(dtype) {
	      if (!!dtype && dtype !== this.dtype) {
	        throw new Error("TensorArray dtype is ".concat(this.dtype, " but concat requested dtype ").concat(dtype));
	      }
	      if (this.size() === 0) {
	        return tensor([], [0].concat(this.elementShape));
	      }
	      var indices = [];
	      for (var i = 0; i < this.size(); i++) {
	        indices.push(i);
	      }
	      // Collect all the tensors from the tensors array.
	      var tensors = this.readMany(indices);
	      assertShapesMatchAllowUndefinedSize(this.elementShape, tensors[0].shape, "TensorArray shape mismatch: tensor array shape (".concat(this.elementShape, ") vs first tensor shape (").concat(tensors[0].shape, ")"));
	      return concat$2(tensors, 0);
	    }
	    /**
	     * Scatter the values of a Tensor in specific indices of a TensorArray.
	     * @param indices number[] values in [0, max_value). If the
	     *    TensorArray is not dynamic, max_value=size().
	     * @param tensor Tensor input tensor.
	     */
	  }, {
	    key: "scatter",
	    value: function scatter(indices, tensor) {
	      if (tensor.dtype !== this.dtype) {
	        throw new Error("TensorArray dtype is ".concat(this.dtype, " but tensor has dtype ").concat(tensor.dtype));
	      }
	      if (indices.length !== tensor.shape[0]) {
	        throw new Error("Expected len(indices) == tensor.shape[0], but saw: ".concat(indices.length, " vs. ").concat(tensor.shape[0]));
	      }
	      var maxIndex = Math.max.apply(Math, _toConsumableArray(indices));
	      if (!this.dynamicSize && maxIndex >= this.maxSize) {
	        throw new Error("Max index must be < array size (".concat(maxIndex, "  vs. ").concat(this.maxSize, ")"));
	      }
	      this.writeMany(indices, unstack(tensor, 0));
	    }
	    /**
	     * Split the values of a Tensor into the TensorArray.
	     * @param length number[] with the lengths to use when splitting value along
	     *    its first dimension.
	     * @param tensor Tensor, the tensor to split.
	     */
	  }, {
	    key: "split",
	    value: function split(length, tensor) {
	      var _this3 = this;
	      if (tensor.dtype !== this.dtype) {
	        throw new Error("TensorArray dtype is ".concat(this.dtype, " but tensor has dtype ").concat(tensor.dtype));
	      }
	      var totalLength = 0;
	      var cumulativeLengths = length.map(function (len) {
	        totalLength += len;
	        return totalLength;
	      });
	      if (totalLength !== tensor.shape[0]) {
	        throw new Error("Expected sum of lengths to be equal to\n          tensor.shape[0], but sum of lengths is\n        ".concat(totalLength, ", and tensor's shape is: ").concat(tensor.shape));
	      }
	      if (!this.dynamicSize && length.length !== this.maxSize) {
	        throw new Error("TensorArray's size is not equal to the size of lengths (".concat(this.maxSize, " vs. ").concat(length.length, "), ") + 'and the TensorArray is not marked as dynamically resizeable');
	      }
	      var elementPerRow = totalLength === 0 ? 0 : tensor.size / totalLength;
	      var tensors = [];
	      tidy(function () {
	        tensor = reshape$3(tensor, [1, totalLength, elementPerRow]);
	        for (var i = 0; i < length.length; ++i) {
	          var previousLength = i === 0 ? 0 : cumulativeLengths[i - 1];
	          var _indices = [0, previousLength, 0];
	          var sizes = [1, length[i], elementPerRow];
	          tensors[i] = reshape$3(slice$2(tensor, _indices, sizes), _this3.elementShape);
	        }
	        return tensors;
	      });
	      var indices = [];
	      for (var i = 0; i < length.length; i++) {
	        indices[i] = i;
	      }
	      this.writeMany(indices, tensors);
	    }
	  }]);
	  return TensorArray;
	}();

	/**
	 * TensorList stores a container of `tf.Tensor` objects, which are accessible
	 * via tensors field.
	 *
	 * In order to get a copy of the underlying list, use the copy method:
	 * ```
	 *    TensorList b = a.copy();
	 *    b.tensors().pushBack(t);  // This does not modify a.tensors().
	 * ```
	 *
	 * Note that this is not a deep copy: the memory locations of the underlying
	 * tensors will still point to the same locations of the corresponding tensors
	 * in the original.
	 */
	var TensorList = /*#__PURE__*/function () {
	  /**
	   *
	   * @param tensors list of tensors
	   * @param elementShape shape of each tensor, this can be a single number (any
	   * shape is allowed) or partial shape (dim = -1).
	   * @param elementDtype data type of each tensor
	   * @param maxNumElements The maximum allowed size of `tensors`. Defaults to -1
	   *   meaning that the size of `tensors` is unbounded.
	   */
	  function TensorList(tensors, elementShape, elementDtype) {
	    var maxNumElements = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : -1;
	    _classCallCheck(this, TensorList);
	    this.tensors = tensors;
	    this.elementShape = elementShape;
	    this.elementDtype = elementDtype;
	    if (tensors != null) {
	      tensors.forEach(function (tensor) {
	        if (elementDtype !== tensor.dtype) {
	          throw new Error("Invalid data types; op elements ".concat(elementDtype, ", but list elements ").concat(tensor.dtype));
	        }
	        assertShapesMatchAllowUndefinedSize(elementShape, tensor.shape, 'TensorList shape mismatch: ');
	        keep(tensor);
	      });
	    }
	    this.idTensor = scalar(0);
	    this.maxNumElements = maxNumElements;
	    keep(this.idTensor);
	  }
	  /**
	   * Get a new TensorList containing a copy of the underlying tensor container.
	   */
	  _createClass(TensorList, [{
	    key: "id",
	    get: function get() {
	      return this.idTensor.id;
	    }
	  }, {
	    key: "copy",
	    value: function copy() {
	      return new TensorList(_toConsumableArray(this.tensors), this.elementShape, this.elementDtype);
	    }
	    /**
	     * Dispose the tensors and idTensor and clear the tensor list.
	     */
	  }, {
	    key: "clearAndClose",
	    value: function clearAndClose(keepIds) {
	      this.tensors.forEach(function (tensor) {
	        if (keepIds == null || !keepIds.has(tensor.id)) {
	          tensor.dispose();
	        }
	      });
	      this.tensors.length = 0;
	      this.idTensor.dispose();
	    }
	    /**
	     * The size of the tensors in the tensor list.
	     */
	  }, {
	    key: "size",
	    value: function size() {
	      return this.tensors.length;
	    }
	    /**
	     * Return a tensor that stacks a list of rank-R tf.Tensors into one rank-(R+1)
	     * tf.Tensor.
	     * @param elementShape shape of each tensor
	     * @param elementDtype data type of each tensor
	     * @param numElements the number of elements to stack
	     */
	  }, {
	    key: "stack",
	    value: function stack$1(elementShape, elementDtype) {
	      var _this = this;
	      var numElements = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : -1;
	      if (elementDtype !== this.elementDtype) {
	        throw new Error("Invalid data types; op elements ".concat(elementDtype, ", but list elements ").concat(this.elementDtype));
	      }
	      if (numElements !== -1 && this.tensors.length !== numElements) {
	        throw new Error("Operation expected a list with ".concat(numElements, " elements but got a list with ").concat(this.tensors.length, " elements."));
	      }
	      assertShapesMatchAllowUndefinedSize(elementShape, this.elementShape, 'TensorList shape mismatch: ');
	      var outputElementShape = inferElementShape(this.elementShape, this.tensors, elementShape);
	      return tidy(function () {
	        var reshapedTensors = _this.tensors.map(function (tensor) {
	          return reshape$3(tensor, outputElementShape);
	        });
	        return stack(reshapedTensors, 0);
	      });
	    }
	    /**
	     * Pop a tensor from the end of the list.
	     * @param elementShape shape of the tensor
	     * @param elementDtype data type of the tensor
	     */
	  }, {
	    key: "popBack",
	    value: function popBack(elementShape, elementDtype) {
	      if (elementDtype !== this.elementDtype) {
	        throw new Error("Invalid data types; op elements ".concat(elementDtype, ", but list elements ").concat(this.elementDtype));
	      }
	      if (this.size() === 0) {
	        throw new Error('Trying to pop from an empty list.');
	      }
	      var outputElementShape = inferElementShape(this.elementShape, this.tensors, elementShape);
	      var tensor = this.tensors.pop();
	      tensor.kept = false;
	      assertShapesMatchAllowUndefinedSize(tensor.shape, elementShape, 'TensorList shape mismatch: ');
	      return reshape$3(tensor, outputElementShape);
	    }
	    /**
	     * Push a tensor to the end of the list.
	     * @param tensor Tensor to be pushed.
	     */
	  }, {
	    key: "pushBack",
	    value: function pushBack(tensor) {
	      if (tensor.dtype !== this.elementDtype) {
	        throw new Error("Invalid data types; op elements ".concat(tensor.dtype, ", but list elements ").concat(this.elementDtype));
	      }
	      assertShapesMatchAllowUndefinedSize(tensor.shape, this.elementShape, 'TensorList shape mismatch: ');
	      if (this.maxNumElements === this.size()) {
	        throw new Error("Trying to push element into a full list.");
	      }
	      keep(tensor);
	      this.tensors.push(tensor);
	    }
	    /**
	     * Update the size of the list.
	     * @param size the new size of the list.
	     */
	  }, {
	    key: "resize",
	    value: function resize(size) {
	      if (size < 0) {
	        throw new Error("TensorListResize expects size to be non-negative. Got: ".concat(size));
	      }
	      if (this.maxNumElements !== -1 && size > this.maxNumElements) {
	        throw new Error("TensorListResize input size ".concat(size, " is greater maxNumElement ").concat(this.maxNumElements, "."));
	      }
	      var destTensorList = new TensorList([], this.elementShape, this.elementDtype, this.maxNumElements);
	      destTensorList.tensors.length = size;
	      for (var i = 0; i < Math.min(this.tensors.length, size); ++i) {
	        destTensorList.tensors[i] = this.tensors[i];
	      }
	      return destTensorList;
	    }
	    /**
	     * Retrieve the element at the provided index
	     * @param elementShape shape of the tensor
	     * @param elementDtype dtype of the tensor
	     * @param elementIndex index of the tensor
	     */
	  }, {
	    key: "getItem",
	    value: function getItem(elementIndex, elementShape, elementDtype) {
	      if (elementDtype !== this.elementDtype) {
	        throw new Error("Invalid data types; op elements ".concat(elementDtype, ", but list elements ").concat(this.elementDtype));
	      }
	      if (elementIndex < 0 || elementIndex > this.tensors.length) {
	        throw new Error("Trying to access element ".concat(elementIndex, " in a list with ").concat(this.tensors.length, " elements."));
	      }
	      if (this.tensors[elementIndex] == null) {
	        throw new Error("element at index ".concat(elementIndex, " is null."));
	      }
	      assertShapesMatchAllowUndefinedSize(this.tensors[elementIndex].shape, elementShape, 'TensorList shape mismatch: ');
	      var outputElementShape = inferElementShape(this.elementShape, this.tensors, elementShape);
	      return reshape$3(this.tensors[elementIndex], outputElementShape);
	    }
	    /**
	     * Set the tensor at the index
	     * @param elementIndex index of the tensor
	     * @param tensor the tensor to be inserted into the list
	     */
	  }, {
	    key: "setItem",
	    value: function setItem(elementIndex, tensor) {
	      if (tensor.dtype !== this.elementDtype) {
	        throw new Error("Invalid data types; op elements ".concat(tensor.dtype, ", but list elements ").concat(this.elementDtype));
	      }
	      if (elementIndex < 0 || this.maxNumElements !== -1 && elementIndex >= this.maxNumElements) {
	        throw new Error("Trying to set element ".concat(elementIndex, " in a list with max ").concat(this.maxNumElements, " elements."));
	      }
	      assertShapesMatchAllowUndefinedSize(this.elementShape, tensor.shape, 'TensorList shape mismatch: ');
	      keep(tensor);
	      // dispose the previous value if it is replacing.
	      if (this.tensors[elementIndex] != null) {
	        this.tensors[elementIndex].kept = false;
	      }
	      this.tensors[elementIndex] = tensor;
	    }
	    /**
	     * Return selected values in the TensorList as a stacked Tensor. All of
	     * selected values must have been written and their shapes must all match.
	     * @param indices indices of tensors to gather
	     * @param elementDtype output tensor dtype
	     * @param elementShape output tensor element shape
	     */
	  }, {
	    key: "gather",
	    value: function gather(indices, elementDtype, elementShape) {
	      var _this2 = this;
	      if (elementDtype !== this.elementDtype) {
	        throw new Error("Invalid data types; op elements ".concat(elementDtype, ", but list elements ").concat(this.elementDtype));
	      }
	      assertShapesMatchAllowUndefinedSize(this.elementShape, elementShape, 'TensorList shape mismatch: ');
	      // When indices is greater than the size of the list, indices beyond the
	      // size of the list are ignored.
	      indices = indices.slice(0, this.size());
	      var outputElementShape = inferElementShape(this.elementShape, this.tensors, elementShape);
	      if (indices.length === 0) {
	        return tensor([], [0].concat(outputElementShape));
	      }
	      return tidy(function () {
	        var tensors = indices.map(function (i) {
	          return reshape$3(_this2.tensors[i], outputElementShape);
	        });
	        return stack(tensors, 0);
	      });
	    }
	    /**
	     * Return the values in the TensorList as a concatenated Tensor.
	     * @param elementDtype output tensor dtype
	     * @param elementShape output tensor element shape
	     */
	  }, {
	    key: "concat",
	    value: function concat(elementDtype, elementShape) {
	      var _this3 = this;
	      if (!!elementDtype && elementDtype !== this.elementDtype) {
	        throw new Error("TensorList dtype is ".concat(this.elementDtype, " but concat requested dtype ").concat(elementDtype));
	      }
	      assertShapesMatchAllowUndefinedSize(this.elementShape, elementShape, 'TensorList shape mismatch: ');
	      var outputElementShape = inferElementShape(this.elementShape, this.tensors, elementShape);
	      if (this.size() === 0) {
	        return tensor([], [0].concat(outputElementShape));
	      }
	      return tidy(function () {
	        var tensors = _this3.tensors.map(function (t) {
	          return reshape$3(t, outputElementShape);
	        });
	        return concat$2(tensors, 0);
	      });
	    }
	  }]);
	  return TensorList;
	}();
	/**
	 * Creates a TensorList which, when stacked, has the value of tensor.
	 * @param tensor from tensor
	 * @param elementShape output tensor element shape
	 */
	function fromTensor(tensor, elementShape, elementDtype) {
	  var dtype = tensor.dtype;
	  if (tensor.shape.length < 1) {
	    throw new Error("Tensor must be at least a vector, but saw shape: ".concat(tensor.shape));
	  }
	  if (tensor.dtype !== elementDtype) {
	    throw new Error("Invalid data types; op elements ".concat(tensor.dtype, ", but list elements ").concat(elementDtype));
	  }
	  var tensorElementShape = tensor.shape.slice(1);
	  assertShapesMatchAllowUndefinedSize(tensorElementShape, elementShape, 'TensorList shape mismatch: ');
	  var tensorList = unstack(tensor);
	  return new TensorList(tensorList, elementShape, dtype);
	}
	/**
	 * Return a TensorList of the given size with empty elements.
	 * @param elementShape the shape of the future elements of the list
	 * @param elementDtype the desired type of elements in the list
	 * @param numElements the number of elements to reserve
	 * @param maxNumElements the maximum number of elements in th list
	 */
	function reserve(elementShape, elementDtype, numElements, maxNumElements) {
	  return new TensorList([], elementShape, elementDtype, maxNumElements);
	}
	/**
	 * Put tensors at specific indices of a stacked tensor into a TensorList.
	 * @param indices list of indices on how to scatter the tensor.
	 * @param tensor input tensor.
	 * @param elementShape the shape of the future elements of the list
	 * @param numElements the number of elements to scatter
	 */
	function scatter(tensor, indices, elementShape, numElements) {
	  if (indices.length !== tensor.shape[0]) {
	    throw new Error("Expected len(indices) == tensor.shape[0], but saw: ".concat(indices.length, " vs. ").concat(tensor.shape[0]));
	  }
	  var maxIndex = Math.max.apply(Math, _toConsumableArray(indices));
	  if (numElements != null && numElements !== -1 && maxIndex >= numElements) {
	    throw new Error("Max index must be < array size (".concat(maxIndex, "  vs. ").concat(numElements, ")"));
	  }
	  var list = new TensorList([], elementShape, tensor.dtype, numElements);
	  var tensors = unstack(tensor, 0);
	  indices.forEach(function (value, index) {
	    list.setItem(value, tensors[index]);
	  });
	  return list;
	}
	/**
	 * Split the values of a Tensor into a TensorList.
	 * @param length the lengths to use when splitting value along
	 *    its first dimension.
	 * @param tensor the tensor to split.
	 * @param elementShape the shape of the future elements of the list
	 */
	function split$1(tensor, length, elementShape) {
	  var totalLength = 0;
	  var cumulativeLengths = length.map(function (len) {
	    totalLength += len;
	    return totalLength;
	  });
	  if (totalLength !== tensor.shape[0]) {
	    throw new Error("Expected sum of lengths to be equal to\n          tensor.shape[0], but sum of lengths is\n        ".concat(totalLength, ", and tensor's shape is: ").concat(tensor.shape));
	  }
	  var shapeWithoutFirstDim = tensor.shape.slice(1);
	  var outputElementShape = mergeElementShape(shapeWithoutFirstDim, elementShape);
	  var elementPerRow = totalLength === 0 ? 0 : tensor.size / totalLength;
	  var tensors = tidy(function () {
	    var tensors = [];
	    tensor = reshape$3(tensor, [1, totalLength, elementPerRow]);
	    for (var i = 0; i < length.length; ++i) {
	      var previousLength = i === 0 ? 0 : cumulativeLengths[i - 1];
	      var indices = [0, previousLength, 0];
	      var sizes = [1, length[i], elementPerRow];
	      tensors[i] = reshape$3(slice$2(tensor, indices, sizes), outputElementShape);
	    }
	    tensor.dispose();
	    return tensors;
	  });
	  var list = new TensorList([], elementShape, tensor.dtype, length.length);
	  for (var i = 0; i < tensors.length; i++) {
	    list.setItem(i, tensors[i]);
	  }
	  return list;
	}

	var executeOp$i = /*#__PURE__*/function () {
	  var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(node, tensorMap, context) {
	    var thenFunc, elseFunc, cond, args, condValue, bodyFunc, condFunc, _args, condResult, argIds, _condValue, result, _loop, pred, _pred, data, inputName, _data, frameId, _data2, _data3, _data4, size, dtype, elementShape, dynamicSize, clearAfterRead, identicalElementShapes, name, tensorArray, id, index, writeTensor, writeTensorArray, readId, readIndex, readTensorArray, gatherId, gatherIndices, gatherDtype, gatherTensorArray, scatterId, scatterIndices, scatterTensor, scatterTensorArray, concatId, concatTensorArray, concatDtype, splitId, splitTensor, lengths, splitTensorArray, sizeId, sizeTensorArray, closeId, closeTensorArray, idTensor, _index, _writeTensor, tensorList, _idTensor, _readIndex, _elementShape, elementDType, _tensorList, _scatterIndices, _scatterTensor, _elementShape2, numElements, _tensorList2, _elementShape3, elementDtype, numElementsParam, _numElements, maxNumElements, _tensorList3, _gatherId, _gatherIndices, _elementShape4, _elementDtype, _tensorList4, _idTensor2, _elementShape5, _elementDtype2, _numElements2, _tensorList5, tensor, _elementShape6, _elementDtype3, _tensorList6, _concatId, _tensorList7, _concatDtype, _elementShape7, _idTensor3, _writeTensor2, _tensorList8, _idTensor4, _elementShape8, _elementDType, _tensorList9, _splitTensor, _elementShape9, _lengths, _tensorList10, _idTensor5, _tensorList11, _idTensor6, _size, srcTensorList, destTensorList;
	    return _regeneratorRuntime().wrap(function _callee$(_context2) {
	      while (1) switch (_context2.prev = _context2.next) {
	        case 0:
	          _context2.t0 = node.op;
	          _context2.next = _context2.t0 === 'If' ? 3 : _context2.t0 === 'StatelessIf' ? 3 : _context2.t0 === 'While' ? 15 : _context2.t0 === 'StatelessWhile' ? 15 : _context2.t0 === 'LoopCond' ? 33 : _context2.t0 === 'Switch' ? 35 : _context2.t0 === 'Merge' ? 46 : _context2.t0 === 'Enter' ? 51 : _context2.t0 === 'Exit' ? 55 : _context2.t0 === 'NextIteration' ? 58 : _context2.t0 === 'TensorArrayV3' ? 61 : _context2.t0 === 'TensorArrayWriteV3' ? 71 : _context2.t0 === 'TensorArrayReadV3' ? 77 : _context2.t0 === 'TensorArrayGatherV3' ? 81 : _context2.t0 === 'TensorArrayScatterV3' ? 86 : _context2.t0 === 'TensorArrayConcatV3' ? 92 : _context2.t0 === 'TensorArraySplitV3' ? 96 : _context2.t0 === 'TensorArraySizeV3' ? 102 : _context2.t0 === 'TensorArrayCloseV3' ? 105 : _context2.t0 === 'TensorListSetItem' ? 109 : _context2.t0 === 'TensorListGetItem' ? 115 : _context2.t0 === 'TensorListScatterV2' ? 121 : _context2.t0 === 'TensorListScatter' ? 121 : _context2.t0 === 'TensorListReserve' ? 128 : _context2.t0 === 'EmptyTensorList' ? 128 : _context2.t0 === 'TensorListGather' ? 136 : _context2.t0 === 'TensorListStack' ? 142 : _context2.t0 === 'TensorListFromTensor' ? 148 : _context2.t0 === 'TensorListConcat' ? 154 : _context2.t0 === 'TensorListConcatV2' ? 154 : _context2.t0 === 'TensorListPushBack' ? 159 : _context2.t0 === 'TensorListPopBack' ? 164 : _context2.t0 === 'TensorListSplit' ? 169 : _context2.t0 === 'TensorListLength' ? 175 : _context2.t0 === 'TensorListResize' ? 178 : 184;
	          break;
	        case 3:
	          thenFunc = getParamValue('thenBranch', node, tensorMap, context);
	          elseFunc = getParamValue('elseBranch', node, tensorMap, context);
	          cond = getParamValue('cond', node, tensorMap, context);
	          args = getParamValue('args', node, tensorMap, context);
	          _context2.next = 9;
	          return cond.data();
	        case 9:
	          condValue = _context2.sent;
	          if (!condValue[0]) {
	            _context2.next = 14;
	            break;
	          }
	          return _context2.abrupt("return", context.functionMap[thenFunc].executeFunctionAsync(args, context.tensorArrayMap, context.tensorListMap));
	        case 14:
	          return _context2.abrupt("return", context.functionMap[elseFunc].executeFunctionAsync(args, context.tensorArrayMap, context.tensorListMap));
	        case 15:
	          bodyFunc = getParamValue('body', node, tensorMap, context);
	          condFunc = getParamValue('cond', node, tensorMap, context);
	          _args = getParamValue('args', node, tensorMap, context); // Calculate the condition of the loop
	          _context2.next = 20;
	          return context.functionMap[condFunc].executeFunctionAsync(_args, context.tensorArrayMap, context.tensorListMap);
	        case 20:
	          condResult = _context2.sent;
	          argIds = _args.map(function (tensor) {
	            return tensor.id;
	          });
	          _context2.next = 24;
	          return condResult[0].data();
	        case 24:
	          _condValue = _context2.sent;
	          // Dispose the intermediate tensors for condition function
	          condResult.forEach(function (tensor) {
	            if (!tensor.kept && argIds.indexOf(tensor.id) === -1) {
	              tensor.dispose();
	            }
	          });
	          result = _args;
	          _loop = /*#__PURE__*/_regeneratorRuntime().mark(function _loop() {
	            var origResult, resultIds, condResult;
	            return _regeneratorRuntime().wrap(function _loop$(_context) {
	              while (1) switch (_context.prev = _context.next) {
	                case 0:
	                  // Record the previous result for intermediate tensor tracking
	                  origResult = result; // Execution the body of the loop
	                  _context.next = 3;
	                  return context.functionMap[bodyFunc].executeFunctionAsync(result, context.tensorArrayMap, context.tensorListMap);
	                case 3:
	                  result = _context.sent;
	                  resultIds = result.map(function (tensor) {
	                    return tensor.id;
	                  }); // Dispose the intermediate tensor for body function that is not global
	                  // kept, not input/output of the body function
	                  origResult.forEach(function (tensor) {
	                    if (!tensor.kept && argIds.indexOf(tensor.id) === -1 && resultIds.indexOf(tensor.id) === -1) {
	                      tensor.dispose();
	                    }
	                  });
	                  // Recalcuate the condition of the loop using the latest results.
	                  _context.next = 8;
	                  return context.functionMap[condFunc].executeFunctionAsync(result, context.tensorArrayMap, context.tensorListMap);
	                case 8:
	                  condResult = _context.sent;
	                  _context.next = 11;
	                  return condResult[0].data();
	                case 11:
	                  _condValue = _context.sent;
	                  // Dispose the intermediate tensors for condition function
	                  condResult.forEach(function (tensor) {
	                    if (!tensor.kept && argIds.indexOf(tensor.id) === -1 && resultIds.indexOf(tensor.id) === -1) {
	                      tensor.dispose();
	                    }
	                  });
	                case 13:
	                case "end":
	                  return _context.stop();
	              }
	            }, _loop);
	          });
	        case 28:
	          if (!_condValue[0]) {
	            _context2.next = 32;
	            break;
	          }
	          return _context2.delegateYield(_loop(), "t1", 30);
	        case 30:
	          _context2.next = 28;
	          break;
	        case 32:
	          return _context2.abrupt("return", result);
	        case 33:
	          pred = getParamValue('pred', node, tensorMap, context);
	          return _context2.abrupt("return", [cloneTensor(pred)]);
	        case 35:
	          _pred = getParamValue('pred', node, tensorMap, context);
	          data = getParamValue('data', node, tensorMap, context);
	          if (!data.kept) {
	            data = cloneTensor(data);
	          }
	          // Outputs nodes :0 => false, :1 => true
	          _context2.next = 40;
	          return _pred.data();
	        case 40:
	          if (!_context2.sent[0]) {
	            _context2.next = 44;
	            break;
	          }
	          _context2.t2 = [undefined, data];
	          _context2.next = 45;
	          break;
	        case 44:
	          _context2.t2 = [data, undefined];
	        case 45:
	          return _context2.abrupt("return", _context2.t2);
	        case 46:
	          inputName = node.inputNames.find(function (name) {
	            return getTensor(name, tensorMap, context) !== undefined;
	          });
	          if (!inputName) {
	            _context2.next = 50;
	            break;
	          }
	          _data = getTensor(inputName, tensorMap, context);
	          return _context2.abrupt("return", [cloneTensor(_data)]);
	        case 50:
	          return _context2.abrupt("return", undefined);
	        case 51:
	          frameId = getParamValue('frameName', node, tensorMap, context);
	          _data2 = getParamValue('tensor', node, tensorMap, context);
	          context.enterFrame(frameId);
	          return _context2.abrupt("return", [cloneTensor(_data2)]);
	        case 55:
	          _data3 = getParamValue('tensor', node, tensorMap, context);
	          context.exitFrame();
	          return _context2.abrupt("return", [cloneTensor(_data3)]);
	        case 58:
	          _data4 = getParamValue('tensor', node, tensorMap, context);
	          context.nextIteration();
	          return _context2.abrupt("return", [cloneTensor(_data4)]);
	        case 61:
	          size = getParamValue('size', node, tensorMap, context);
	          dtype = getParamValue('dtype', node, tensorMap, context);
	          elementShape = getParamValue('elementShape', node, tensorMap, context);
	          dynamicSize = getParamValue('dynamicSize', node, tensorMap, context);
	          clearAfterRead = getParamValue('clearAfterRead', node, tensorMap, context);
	          identicalElementShapes = getParamValue('identicalElementShapes', node, tensorMap, context);
	          name = getParamValue('name', node, tensorMap, context);
	          tensorArray = new TensorArray(name, dtype, size, elementShape, identicalElementShapes, dynamicSize, clearAfterRead);
	          context.addTensorArray(tensorArray);
	          return _context2.abrupt("return", [tensorArray.idTensor, scalar(1.0)]);
	        case 71:
	          id = getParamValue('tensorArrayId', node, tensorMap, context);
	          index = getParamValue('index', node, tensorMap, context);
	          writeTensor = getParamValue('tensor', node, tensorMap, context);
	          writeTensorArray = context.getTensorArray(id.id);
	          writeTensorArray.write(index, writeTensor);
	          return _context2.abrupt("return", [writeTensorArray.idTensor]);
	        case 77:
	          readId = getParamValue('tensorArrayId', node, tensorMap, context);
	          readIndex = getParamValue('index', node, tensorMap, context);
	          readTensorArray = context.getTensorArray(readId.id);
	          return _context2.abrupt("return", [readTensorArray.read(readIndex)]);
	        case 81:
	          gatherId = getParamValue('tensorArrayId', node, tensorMap, context);
	          gatherIndices = getParamValue('indices', node, tensorMap, context);
	          gatherDtype = getParamValue('dtype', node, tensorMap, context);
	          gatherTensorArray = context.getTensorArray(gatherId.id);
	          return _context2.abrupt("return", [gatherTensorArray.gather(gatherIndices, gatherDtype)]);
	        case 86:
	          scatterId = getParamValue('tensorArrayId', node, tensorMap, context);
	          scatterIndices = getParamValue('indices', node, tensorMap, context);
	          scatterTensor = getParamValue('tensor', node, tensorMap, context);
	          scatterTensorArray = context.getTensorArray(scatterId.id);
	          scatterTensorArray.scatter(scatterIndices, scatterTensor);
	          return _context2.abrupt("return", [scatterTensorArray.idTensor]);
	        case 92:
	          concatId = getParamValue('tensorArrayId', node, tensorMap, context);
	          concatTensorArray = context.getTensorArray(concatId.id);
	          concatDtype = getParamValue('dtype', node, tensorMap, context);
	          return _context2.abrupt("return", [concatTensorArray.concat(concatDtype)]);
	        case 96:
	          splitId = getParamValue('tensorArrayId', node, tensorMap, context);
	          splitTensor = getParamValue('tensor', node, tensorMap, context);
	          lengths = getParamValue('lengths', node, tensorMap, context);
	          splitTensorArray = context.getTensorArray(splitId.id);
	          splitTensorArray.split(lengths, splitTensor);
	          return _context2.abrupt("return", [splitTensorArray.idTensor]);
	        case 102:
	          sizeId = getParamValue('tensorArrayId', node, tensorMap, context);
	          sizeTensorArray = context.getTensorArray(sizeId.id);
	          return _context2.abrupt("return", [scalar(sizeTensorArray.size(), 'int32')]);
	        case 105:
	          closeId = getParamValue('tensorArrayId', node, tensorMap, context);
	          closeTensorArray = context.getTensorArray(closeId.id);
	          closeTensorArray.clearAndClose();
	          return _context2.abrupt("return", [closeTensorArray.idTensor]);
	        case 109:
	          idTensor = getParamValue('tensorListId', node, tensorMap, context);
	          _index = getParamValue('index', node, tensorMap, context);
	          _writeTensor = getParamValue('tensor', node, tensorMap, context);
	          tensorList = context.getTensorList(idTensor.id);
	          tensorList.setItem(_index, _writeTensor);
	          return _context2.abrupt("return", [tensorList.idTensor]);
	        case 115:
	          _idTensor = getParamValue('tensorListId', node, tensorMap, context);
	          _readIndex = getParamValue('index', node, tensorMap, context);
	          _elementShape = getParamValue('elementShape', node, tensorMap, context);
	          elementDType = getParamValue('elementDType', node, tensorMap, context);
	          _tensorList = context.getTensorList(_idTensor.id);
	          return _context2.abrupt("return", [_tensorList.getItem(_readIndex, _elementShape, elementDType)]);
	        case 121:
	          _scatterIndices = getParamValue('indices', node, tensorMap, context);
	          _scatterTensor = getParamValue('tensor', node, tensorMap, context);
	          _elementShape2 = getParamValue('elementShape', node, tensorMap, context);
	          numElements = getParamValue('numElements', node, tensorMap, context);
	          _tensorList2 = scatter(_scatterTensor, _scatterIndices, _elementShape2, numElements);
	          context.addTensorList(_tensorList2);
	          return _context2.abrupt("return", [_tensorList2.idTensor]);
	        case 128:
	          _elementShape3 = getParamValue('elementShape', node, tensorMap, context);
	          elementDtype = getParamValue('elementDType', node, tensorMap, context);
	          if (node.op === 'TensorListReserve') {
	            numElementsParam = 'numElements';
	          } else {
	            numElementsParam = 'maxNumElements';
	          }
	          _numElements = getParamValue(numElementsParam, node, tensorMap, context);
	          maxNumElements = node.op === 'TensorListReserve' ? -1 : _numElements;
	          _tensorList3 = reserve(_elementShape3, elementDtype, _numElements, maxNumElements);
	          context.addTensorList(_tensorList3);
	          return _context2.abrupt("return", [_tensorList3.idTensor]);
	        case 136:
	          _gatherId = getParamValue('tensorListId', node, tensorMap, context);
	          _gatherIndices = getParamValue('indices', node, tensorMap, context);
	          _elementShape4 = getParamValue('elementShape', node, tensorMap, context);
	          _elementDtype = getParamValue('elementDType', node, tensorMap, context);
	          _tensorList4 = context.getTensorList(_gatherId.id);
	          return _context2.abrupt("return", [_tensorList4.gather(_gatherIndices, _elementDtype, _elementShape4)]);
	        case 142:
	          _idTensor2 = getParamValue('tensorListId', node, tensorMap, context);
	          _elementShape5 = getParamValue('elementShape', node, tensorMap, context);
	          _elementDtype2 = getParamValue('elementDType', node, tensorMap, context);
	          _numElements2 = getParamValue('numElements', node, tensorMap, context);
	          _tensorList5 = context.getTensorList(_idTensor2.id);
	          return _context2.abrupt("return", [_tensorList5.stack(_elementShape5, _elementDtype2, _numElements2)]);
	        case 148:
	          tensor = getParamValue('tensor', node, tensorMap, context);
	          _elementShape6 = getParamValue('elementShape', node, tensorMap, context);
	          _elementDtype3 = getParamValue('elementDType', node, tensorMap, context);
	          _tensorList6 = fromTensor(tensor, _elementShape6, _elementDtype3);
	          context.addTensorList(_tensorList6);
	          return _context2.abrupt("return", [_tensorList6.idTensor]);
	        case 154:
	          _concatId = getParamValue('tensorListId', node, tensorMap, context);
	          _tensorList7 = context.getTensorList(_concatId.id);
	          _concatDtype = getParamValue('dtype', node, tensorMap, context);
	          _elementShape7 = getParamValue('elementShape', node, tensorMap, context);
	          return _context2.abrupt("return", [_tensorList7.concat(_concatDtype, _elementShape7)]);
	        case 159:
	          _idTensor3 = getParamValue('tensorListId', node, tensorMap, context);
	          _writeTensor2 = getParamValue('tensor', node, tensorMap, context);
	          _tensorList8 = context.getTensorList(_idTensor3.id);
	          _tensorList8.pushBack(_writeTensor2);
	          return _context2.abrupt("return", [_tensorList8.idTensor]);
	        case 164:
	          _idTensor4 = getParamValue('tensorListId', node, tensorMap, context);
	          _elementShape8 = getParamValue('elementShape', node, tensorMap, context);
	          _elementDType = getParamValue('elementDType', node, tensorMap, context);
	          _tensorList9 = context.getTensorList(_idTensor4.id);
	          return _context2.abrupt("return", [_tensorList9.popBack(_elementShape8, _elementDType)]);
	        case 169:
	          _splitTensor = getParamValue('tensor', node, tensorMap, context);
	          _elementShape9 = getParamValue('elementShape', node, tensorMap, context);
	          _lengths = getParamValue('lengths', node, tensorMap, context);
	          _tensorList10 = split$1(_splitTensor, _lengths, _elementShape9);
	          context.addTensorList(_tensorList10);
	          return _context2.abrupt("return", [_tensorList10.idTensor]);
	        case 175:
	          _idTensor5 = getParamValue('tensorListId', node, tensorMap, context);
	          _tensorList11 = context.getTensorList(_idTensor5.id);
	          return _context2.abrupt("return", [scalar(_tensorList11.size(), 'int32')]);
	        case 178:
	          _idTensor6 = getParamValue('tensorListId', node, tensorMap, context);
	          _size = getParamValue('size', node, tensorMap, context);
	          srcTensorList = context.getTensorList(_idTensor6.id);
	          destTensorList = srcTensorList.resize(_size);
	          context.addTensorList(destTensorList);
	          return _context2.abrupt("return", [destTensorList.idTensor]);
	        case 184:
	          throw TypeError("Node type ".concat(node.op, " is not implemented"));
	        case 185:
	        case "end":
	          return _context2.stop();
	      }
	    }, _callee);
	  }));
	  return function executeOp(_x, _x2, _x3) {
	    return _ref.apply(this, arguments);
	  };
	}();
	var CATEGORY$h = 'control';

	function fusedConvAndDepthWiseParams(node, tensorMap, context) {
	  var _getParamValue = getParamValue('fusedOps', node, tensorMap, context),
	    _getParamValue2 = _slicedToArray(_getParamValue, 2),
	    extraOp = _getParamValue2[0],
	    activationFunc = _getParamValue2[1];
	  var isBiasAdd = extraOp === 'biasadd';
	  var noBiasAdd = !isBiasAdd;
	  var isPrelu = activationFunc === 'prelu';
	  var isBatchNorm = extraOp === 'fusedbatchnorm';
	  var numArgs = getParamValue('numArgs', node, tensorMap, context);
	  if (isBiasAdd) {
	    if (isPrelu && numArgs !== 2) {
	      throw new Error('FusedConv2d and DepthwiseConv2d with BiasAdd and Prelu ' + 'must have two extra arguments: bias and alpha.');
	    }
	    if (!isPrelu && isBiasAdd && numArgs !== 1) {
	      throw new Error('FusedConv2d and DepthwiseConv2d with BiasAdd must have ' + 'one extra argument: bias.');
	    }
	  }
	  if (isBatchNorm) {
	    throw new Error('FusedConv2d and DepthwiseConv2d with FusedBatchNorm is not supported');
	  }
	  var stride = getParamValue('strides', node, tensorMap, context);
	  var pad = getPadding(node, tensorMap, context);
	  var dataFormat = getParamValue('dataFormat', node, tensorMap, context).toUpperCase();
	  var dilations = getParamValue('dilations', node, tensorMap, context);
	  var _getParamValue3 = getParamValue('args', node, tensorMap, context),
	    _getParamValue4 = _slicedToArray(_getParamValue3, 2),
	    biasArg = _getParamValue4[0],
	    preluArg = _getParamValue4[1];
	  if (noBiasAdd) {
	    preluArg = biasArg;
	    biasArg = undefined;
	  }
	  var leakyreluAlpha = getParamValue('leakyreluAlpha', node, tensorMap, context);
	  return {
	    stride: stride,
	    pad: pad,
	    dataFormat: dataFormat,
	    dilations: dilations,
	    biasArg: biasArg,
	    preluArg: preluArg,
	    activationFunc: activationFunc,
	    leakyreluAlpha: leakyreluAlpha
	  };
	}
	var executeOp$h = function executeOp(node, tensorMap, context) {
	  var ops = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : tfOps;
	  switch (node.op) {
	    case 'Conv1D':
	      {
	        var stride = getParamValue('stride', node, tensorMap, context);
	        var pad = getParamValue('pad', node, tensorMap, context);
	        var dataFormat = getParamValue('dataFormat', node, tensorMap, context).toUpperCase();
	        var dilation = getParamValue('dilation', node, tensorMap, context);
	        return [ops.conv1d(getParamValue('x', node, tensorMap, context), getParamValue('filter', node, tensorMap, context), stride, pad, dataFormat, dilation)];
	      }
	    case 'Conv2D':
	      {
	        var _stride = getParamValue('strides', node, tensorMap, context);
	        var _pad = getPadding(node, tensorMap, context);
	        var _dataFormat = getParamValue('dataFormat', node, tensorMap, context).toUpperCase();
	        var dilations = getParamValue('dilations', node, tensorMap, context);
	        return [ops.conv2d(getParamValue('x', node, tensorMap, context), getParamValue('filter', node, tensorMap, context), [_stride[1], _stride[2]], _pad, _dataFormat, [dilations[1], dilations[2]])];
	      }
	    case '_FusedConv2D':
	      {
	        var _fusedConvAndDepthWis = fusedConvAndDepthWiseParams(node, tensorMap, context),
	          _stride2 = _fusedConvAndDepthWis.stride,
	          _pad2 = _fusedConvAndDepthWis.pad,
	          _dataFormat2 = _fusedConvAndDepthWis.dataFormat,
	          _dilations = _fusedConvAndDepthWis.dilations,
	          biasArg = _fusedConvAndDepthWis.biasArg,
	          preluArg = _fusedConvAndDepthWis.preluArg,
	          activationFunc = _fusedConvAndDepthWis.activationFunc,
	          leakyreluAlpha = _fusedConvAndDepthWis.leakyreluAlpha;
	        return [ops.fused.conv2d({
	          x: getParamValue('x', node, tensorMap, context),
	          filter: getParamValue('filter', node, tensorMap, context),
	          strides: [_stride2[1], _stride2[2]],
	          pad: _pad2,
	          dataFormat: _dataFormat2,
	          dilations: [_dilations[1], _dilations[2]],
	          bias: biasArg,
	          activation: activationFunc,
	          preluActivationWeights: preluArg,
	          leakyreluAlpha: leakyreluAlpha
	        })];
	      }
	    case 'FusedDepthwiseConv2dNative':
	      {
	        var _fusedConvAndDepthWis2 = fusedConvAndDepthWiseParams(node, tensorMap, context),
	          _stride3 = _fusedConvAndDepthWis2.stride,
	          _pad3 = _fusedConvAndDepthWis2.pad,
	          _dataFormat3 = _fusedConvAndDepthWis2.dataFormat,
	          _dilations2 = _fusedConvAndDepthWis2.dilations,
	          _biasArg = _fusedConvAndDepthWis2.biasArg,
	          _preluArg = _fusedConvAndDepthWis2.preluArg,
	          _activationFunc = _fusedConvAndDepthWis2.activationFunc,
	          _leakyreluAlpha = _fusedConvAndDepthWis2.leakyreluAlpha;
	        return [ops.fused.depthwiseConv2d({
	          x: getParamValue('x', node, tensorMap, context),
	          filter: getParamValue('filter', node, tensorMap, context),
	          strides: [_stride3[1], _stride3[2]],
	          pad: _pad3,
	          dataFormat: _dataFormat3,
	          dilations: [_dilations2[1], _dilations2[2]],
	          bias: _biasArg,
	          activation: _activationFunc,
	          preluActivationWeights: _preluArg,
	          leakyreluAlpha: _leakyreluAlpha
	        })];
	      }
	    case 'Conv2DBackpropInput':
	    case 'Conv2dTranspose':
	      {
	        var shape = getParamValue('outputShape', node, tensorMap, context);
	        var _stride4 = getParamValue('strides', node, tensorMap, context);
	        var _pad4 = getPadding(node, tensorMap, context);
	        return [ops.conv2dTranspose(getParamValue('x', node, tensorMap, context), getParamValue('filter', node, tensorMap, context), shape, [_stride4[1], _stride4[2]], _pad4)];
	      }
	    case 'DepthwiseConv2dNative':
	    case 'DepthwiseConv2d':
	      {
	        var _stride5 = getParamValue('strides', node, tensorMap, context);
	        var _pad5 = getPadding(node, tensorMap, context);
	        var _dilations3 = getParamValue('dilations', node, tensorMap, context);
	        var _dataFormat4 = getParamValue('dataFormat', node, tensorMap, context).toUpperCase();
	        return [ops.depthwiseConv2d(getParamValue('input', node, tensorMap, context), getParamValue('filter', node, tensorMap, context), [_stride5[1], _stride5[2]], _pad5, _dataFormat4, [_dilations3[1], _dilations3[2]])];
	      }
	    case 'Conv3D':
	      {
	        var _stride6 = getParamValue('strides', node, tensorMap, context);
	        var _pad6 = getParamValue('pad', node, tensorMap, context);
	        var _dataFormat5 = getParamValue('dataFormat', node, tensorMap, context).toUpperCase();
	        var _dilations4 = getParamValue('dilations', node, tensorMap, context);
	        return [ops.conv3d(getParamValue('x', node, tensorMap, context), getParamValue('filter', node, tensorMap, context), [_stride6[1], _stride6[2], _stride6[3]], _pad6, _dataFormat5, [_dilations4[1], _dilations4[2], _dilations4[3]])];
	      }
	    case 'AvgPool':
	      {
	        var _stride7 = getParamValue('strides', node, tensorMap, context);
	        var _pad7 = getParamValue('pad', node, tensorMap, context);
	        var kernelSize = getParamValue('kernelSize', node, tensorMap, context);
	        return [ops.avgPool(getParamValue('x', node, tensorMap, context), [kernelSize[1], kernelSize[2]], [_stride7[1], _stride7[2]], _pad7)];
	      }
	    case 'MaxPool':
	      {
	        var _stride8 = getParamValue('strides', node, tensorMap, context);
	        var _pad8 = getParamValue('pad', node, tensorMap, context);
	        var _kernelSize = getParamValue('kernelSize', node, tensorMap, context);
	        return [ops.maxPool(getParamValue('x', node, tensorMap, context), [_kernelSize[1], _kernelSize[2]], [_stride8[1], _stride8[2]], _pad8)];
	      }
	    case 'MaxPoolWithArgmax':
	      {
	        var _stride9 = getParamValue('strides', node, tensorMap, context);
	        var _pad9 = getParamValue('pad', node, tensorMap, context);
	        var _kernelSize2 = getParamValue('kernelSize', node, tensorMap, context);
	        var includeBatchInIndex = getParamValue('includeBatchInIndex', node, tensorMap, context);
	        var _ops$maxPoolWithArgma = ops.maxPoolWithArgmax(getParamValue('x', node, tensorMap, context), [_kernelSize2[1], _kernelSize2[2]], [_stride9[1], _stride9[2]], _pad9, includeBatchInIndex),
	          result = _ops$maxPoolWithArgma.result,
	          indexes = _ops$maxPoolWithArgma.indexes;
	        return [result, indexes];
	      }
	    case 'AvgPool3D':
	      {
	        var _stride10 = getParamValue('strides', node, tensorMap, context);
	        var _pad10 = getParamValue('pad', node, tensorMap, context);
	        var _kernelSize3 = getParamValue('kernelSize', node, tensorMap, context);
	        return [ops.avgPool3d(getParamValue('x', node, tensorMap, context), [_kernelSize3[1], _kernelSize3[2], _kernelSize3[3]], [_stride10[1], _stride10[2], _stride10[3]], _pad10)];
	      }
	    case 'MaxPool3D':
	      {
	        var _stride11 = getParamValue('strides', node, tensorMap, context);
	        var _pad11 = getParamValue('pad', node, tensorMap, context);
	        var _kernelSize4 = getParamValue('kernelSize', node, tensorMap, context);
	        return [ops.maxPool3d(getParamValue('x', node, tensorMap, context), [_kernelSize4[1], _kernelSize4[2], _kernelSize4[3]], [_stride11[1], _stride11[2], _stride11[3]], _pad11)];
	      }
	    case 'Dilation2D':
	      {
	        var strides = getParamValue('strides', node, tensorMap, context);
	        var _pad12 = getParamValue('pad', node, tensorMap, context);
	        var _dilations5 = getParamValue('dilations', node, tensorMap, context);
	        // strides: [1, stride_height, stride_width, 1].
	        var strideHeight = strides[1];
	        var strideWidth = strides[2];
	        // dilations: [1, dilation_height, dilation_width, 1].
	        var dilationHeight = _dilations5[1];
	        var dilationWidth = _dilations5[2];
	        return [ops.dilation2d(getParamValue('x', node, tensorMap, context), getParamValue('filter', node, tensorMap, context), [strideHeight, strideWidth], _pad12, [dilationHeight, dilationWidth], 'NHWC' /* dataFormat */)];
	      }

	    default:
	      throw TypeError("Node type ".concat(node.op, " is not implemented"));
	  }
	};
	var CATEGORY$g = 'convolution';

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var executeOp$g = function executeOp(node, tensorMap, context) {
	  var ops = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : tfOps;
	  switch (node.op) {
	    case 'Fill':
	      {
	        var shape = getParamValue('shape', node, tensorMap, context);
	        var dtype = getParamValue('dtype', node, tensorMap, context);
	        var value = getParamValue('value', node, tensorMap, context);
	        return [ops.fill(shape, value, dtype)];
	      }
	    case 'LinSpace':
	      {
	        var start = getParamValue('start', node, tensorMap, context);
	        var stop = getParamValue('stop', node, tensorMap, context);
	        var num = getParamValue('num', node, tensorMap, context);
	        return [ops.linspace(start, stop, num)];
	      }
	    case 'Multinomial':
	      {
	        var logits = getParamValue('logits', node, tensorMap, context);
	        var numSamples = getParamValue('numSamples', node, tensorMap, context);
	        var seed = getParamValue('seed', node, tensorMap, context);
	        return [ops.multinomial(logits, numSamples, seed)];
	      }
	    case 'OneHot':
	      {
	        var indices = getParamValue('indices', node, tensorMap, context);
	        var depth = getParamValue('depth', node, tensorMap, context);
	        var onValue = getParamValue('onValue', node, tensorMap, context);
	        var offValue = getParamValue('offValue', node, tensorMap, context);
	        var _dtype = getParamValue('dtype', node, tensorMap, context);
	        return [ops.oneHot(indices, depth, onValue, offValue, _dtype)];
	      }
	    case 'Ones':
	      {
	        return [ops.ones(getParamValue('shape', node, tensorMap, context), getParamValue('dtype', node, tensorMap, context))];
	      }
	    case 'OnesLike':
	      {
	        return [ops.onesLike(getParamValue('x', node, tensorMap, context))];
	      }
	    case 'RandomStandardNormal':
	      {
	        return [ops.randomStandardNormal(getParamValue('shape', node, tensorMap, context), getParamValue('dtype', node, tensorMap, context), getParamValue('seed', node, tensorMap, context))];
	      }
	    case 'RandomUniform':
	      {
	        return [ops.randomUniform(
	        // tslint:disable-next-line:no-any
	        getParamValue('shape', node, tensorMap, context), getParamValue('minval', node, tensorMap, context), getParamValue('maxval', node, tensorMap, context), getParamValue('dtype', node, tensorMap, context))];
	      }
	    case 'RandomUniformInt':
	      {
	        return [ops.randomUniformInt(getParamValue('shape', node, tensorMap, context), getParamValue('minval', node, tensorMap, context), getParamValue('maxval', node, tensorMap, context), getParamValue('seed', node, tensorMap, context))];
	      }
	    case 'Range':
	      {
	        var _start = getParamValue('start', node, tensorMap, context);
	        var _stop = getParamValue('stop', node, tensorMap, context);
	        var step = getParamValue('step', node, tensorMap, context);
	        return [ops.range(_start, _stop, step, getParamValue('dtype', node, tensorMap, context))];
	      }
	    case 'TruncatedNormal':
	      {
	        var _shape = getParamValue('shape', node, tensorMap, context);
	        var mean = getParamValue('mean', node, tensorMap, context);
	        var stdDev = getParamValue('stdDev', node, tensorMap, context);
	        var _seed = getParamValue('seed', node, tensorMap, context);
	        return [ops.truncatedNormal(_shape, mean, stdDev, getParamValue('dtype', node, tensorMap, context), _seed)];
	      }
	    case 'Zeros':
	      {
	        return [ops.zeros(getParamValue('shape', node, tensorMap, context), getParamValue('dtype', node, tensorMap, context))];
	      }
	    case 'ZerosLike':
	      {
	        return [ops.zerosLike(getParamValue('x', node, tensorMap, context))];
	      }
	    default:
	      throw TypeError("Node type ".concat(node.op, " is not implemented"));
	  }
	};
	var CATEGORY$f = 'creation';

	function nmsParams(node, tensorMap, context) {
	  var boxes = getParamValue('boxes', node, tensorMap, context);
	  var scores = getParamValue('scores', node, tensorMap, context);
	  var maxOutputSize = getParamValue('maxOutputSize', node, tensorMap, context);
	  var iouThreshold = getParamValue('iouThreshold', node, tensorMap, context);
	  var scoreThreshold = getParamValue('scoreThreshold', node, tensorMap, context);
	  var softNmsSigma = getParamValue('softNmsSigma', node, tensorMap, context);
	  return {
	    boxes: boxes,
	    scores: scores,
	    maxOutputSize: maxOutputSize,
	    iouThreshold: iouThreshold,
	    scoreThreshold: scoreThreshold,
	    softNmsSigma: softNmsSigma
	  };
	}
	var executeOp$f = /*#__PURE__*/function () {
	  var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(node, tensorMap, context, resourceManager) {
	    var ops,
	      _nmsParams,
	      boxes,
	      scores,
	      maxOutputSize,
	      iouThreshold,
	      scoreThreshold,
	      softNmsSigma,
	      result,
	      _nmsParams2,
	      _boxes,
	      _scores,
	      _maxOutputSize,
	      _iouThreshold,
	      _scoreThreshold,
	      padToMaxOutputSize,
	      _result,
	      _nmsParams3,
	      _boxes2,
	      _scores2,
	      _maxOutputSize2,
	      _iouThreshold2,
	      _scoreThreshold2,
	      condition,
	      _result2,
	      _args = arguments;
	    return _regeneratorRuntime().wrap(function _callee$(_context) {
	      while (1) switch (_context.prev = _context.next) {
	        case 0:
	          ops = _args.length > 4 && _args[4] !== undefined ? _args[4] : tfOps;
	          _context.t0 = node.op;
	          _context.next = _context.t0 === 'NonMaxSuppressionV5' ? 4 : _context.t0 === 'NonMaxSuppressionV4' ? 9 : _context.t0 === 'NonMaxSuppressionV3' ? 15 : _context.t0 === 'NonMaxSuppressionV2' ? 15 : _context.t0 === 'Where' ? 20 : _context.t0 === 'ListDiff' ? 27 : 28;
	          break;
	        case 4:
	          _nmsParams = nmsParams(node, tensorMap, context), boxes = _nmsParams.boxes, scores = _nmsParams.scores, maxOutputSize = _nmsParams.maxOutputSize, iouThreshold = _nmsParams.iouThreshold, scoreThreshold = _nmsParams.scoreThreshold, softNmsSigma = _nmsParams.softNmsSigma;
	          _context.next = 7;
	          return ops.image.nonMaxSuppressionWithScoreAsync(boxes, scores, maxOutputSize, iouThreshold, scoreThreshold, softNmsSigma);
	        case 7:
	          result = _context.sent;
	          return _context.abrupt("return", [result.selectedIndices, result.selectedScores]);
	        case 9:
	          _nmsParams2 = nmsParams(node, tensorMap, context), _boxes = _nmsParams2.boxes, _scores = _nmsParams2.scores, _maxOutputSize = _nmsParams2.maxOutputSize, _iouThreshold = _nmsParams2.iouThreshold, _scoreThreshold = _nmsParams2.scoreThreshold;
	          padToMaxOutputSize = getParamValue('padToMaxOutputSize', node, tensorMap, context);
	          _context.next = 13;
	          return ops.image.nonMaxSuppressionPaddedAsync(_boxes, _scores, _maxOutputSize, _iouThreshold, _scoreThreshold, padToMaxOutputSize);
	        case 13:
	          _result = _context.sent;
	          return _context.abrupt("return", [_result.selectedIndices, _result.validOutputs]);
	        case 15:
	          _nmsParams3 = nmsParams(node, tensorMap, context), _boxes2 = _nmsParams3.boxes, _scores2 = _nmsParams3.scores, _maxOutputSize2 = _nmsParams3.maxOutputSize, _iouThreshold2 = _nmsParams3.iouThreshold, _scoreThreshold2 = _nmsParams3.scoreThreshold;
	          _context.next = 18;
	          return ops.image.nonMaxSuppressionAsync(_boxes2, _scores2, _maxOutputSize2, _iouThreshold2, _scoreThreshold2);
	        case 18:
	          _context.t1 = _context.sent;
	          return _context.abrupt("return", [_context.t1]);
	        case 20:
	          condition = ops.cast(getParamValue('condition', node, tensorMap, context), 'bool');
	          _context.next = 23;
	          return ops.whereAsync(condition);
	        case 23:
	          _context.t2 = _context.sent;
	          _result2 = [_context.t2];
	          condition.dispose();
	          return _context.abrupt("return", _result2);
	        case 27:
	          return _context.abrupt("return", ops.setdiff1dAsync(getParamValue('x', node, tensorMap, context), getParamValue('y', node, tensorMap, context)));
	        case 28:
	          throw TypeError("Node type ".concat(node.op, " is not implemented"));
	        case 29:
	        case "end":
	          return _context.stop();
	      }
	    }, _callee);
	  }));
	  return function executeOp(_x, _x2, _x3, _x4) {
	    return _ref.apply(this, arguments);
	  };
	}();
	var CATEGORY$e = 'dynamic';

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var executeOp$e = function executeOp(node, tensorMap, context) {
	  var ops = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : tfOps;
	  switch (node.op) {
	    case 'LowerBound':
	      {
	        var sortedSequence = getParamValue('sortedSequence', node, tensorMap, context);
	        var values = getParamValue('values', node, tensorMap, context);
	        return [ops.lowerBound(sortedSequence, values)];
	      }
	    case 'TopKV2':
	      {
	        var x = getParamValue('x', node, tensorMap, context);
	        var k = getParamValue('k', node, tensorMap, context);
	        var sorted = getParamValue('sorted', node, tensorMap, context);
	        var result = ops.topk(x, k, sorted);
	        return [result.values, result.indices];
	      }
	    case 'UpperBound':
	      {
	        var _sortedSequence = getParamValue('sortedSequence', node, tensorMap, context);
	        var _values = getParamValue('values', node, tensorMap, context);
	        return [ops.upperBound(_sortedSequence, _values)];
	      }
	    case 'Unique':
	      {
	        var _x = getParamValue('x', node, tensorMap, context);
	        var _result = ops.unique(_x);
	        return [_result.values, _result.indices];
	      }
	    case 'UniqueV2':
	      {
	        var _x2 = getParamValue('x', node, tensorMap, context);
	        var axis = getParamValue('axis', node, tensorMap, context);
	        var _result2 = ops.unique(_x2, axis);
	        return [_result2.values, _result2.indices];
	      }
	    default:
	      throw TypeError("Node type ".concat(node.op, " is not implemented"));
	  }
	};
	var CATEGORY$d = 'evaluation';

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var executeOp$d = function executeOp(node, tensorMap, context) {
	  var ops = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : tfOps;
	  switch (node.op) {
	    case 'Const':
	      {
	        return tensorMap[node.name];
	      }
	    case 'PlaceholderWithDefault':
	      var def = getParamValue('default', node, tensorMap, context);
	      return [getTensor(node.name, tensorMap, context) || def];
	    case 'Placeholder':
	      return [getTensor(node.name, tensorMap, context)];
	    case 'Identity':
	    case 'StopGradient':
	    case 'FakeQuantWithMinMaxVars':
	      {
	        // This op is currently ignored.
	        var _data = getParamValue('x', node, tensorMap, context);
	        return [cloneTensor(_data)];
	      }
	    case 'IdentityN':
	      return getParamValue('x', node, tensorMap, context).map(function (t) {
	        return cloneTensor(t);
	      });
	    case 'Snapshot':
	      var snapshot = getParamValue('x', node, tensorMap, context);
	      return [cloneTensor(snapshot)];
	    case 'Shape':
	      return [ops.tensor1d(getParamValue('x', node, tensorMap, context).shape, 'int32')];
	    case 'ShapeN':
	      return getParamValue('x', node, tensorMap, context).map(function (t) {
	        return ops.tensor1d(t.shape);
	      });
	    case 'Size':
	      return [ops.scalar(getParamValue('x', node, tensorMap, context).size, 'int32')];
	    case 'Rank':
	      return [ops.scalar(getParamValue('x', node, tensorMap, context).rank, 'int32')];
	    case 'NoOp':
	      return [ops.scalar(1)];
	    case 'Print':
	      var input = getParamValue('x', node, tensorMap, context);
	      var data = getParamValue('data', node, tensorMap, context);
	      var message = getParamValue('message', node, tensorMap, context);
	      var summarize = getParamValue('summarize', node, tensorMap, context);
	      console.warn('The graph has a tf.print() operation,' + 'usually used for debugging, which slows down performance.');
	      console.log(message);
	      for (var i = 0; i < data.length; i++) {
	        console.log(Array.prototype.slice.call(data[i].dataSync()).slice(0, summarize));
	      }
	      return [input];
	    default:
	      throw TypeError("Node type ".concat(node.op, " is not implemented"));
	  }
	};
	var CATEGORY$c = 'graph';

	/**
	 * Hashtable contains a set of tensors, which can be accessed by key.
	 */
	var HashTable = /*#__PURE__*/function () {
	  /**
	   * Constructor of HashTable. Creates a hash table.
	   *
	   * @param keyDType `dtype` of the table keys.
	   * @param valueDType `dtype` of the table values.
	   */
	  function HashTable(keyDType, valueDType) {
	    _classCallCheck(this, HashTable);
	    this.keyDType = keyDType;
	    this.valueDType = valueDType;
	    this.handle = scalar(0);
	    // tslint:disable-next-line: no-any
	    this.tensorMap = new Map();
	    keep(this.handle);
	  }
	  /**
	   * Dispose the tensors and handle and clear the hashtable.
	   */
	  _createClass(HashTable, [{
	    key: "id",
	    get: function get() {
	      return this.handle.id;
	    }
	  }, {
	    key: "clearAndClose",
	    value: function clearAndClose() {
	      this.tensorMap.forEach(function (value) {
	        return value.dispose();
	      });
	      this.tensorMap.clear();
	      this.handle.dispose();
	    }
	    /**
	     * The number of items in the hash table.
	     */
	  }, {
	    key: "size",
	    value: function size() {
	      return this.tensorMap.size;
	    }
	    /**
	     * The number of items in the hash table as a rank-0 tensor.
	     */
	  }, {
	    key: "tensorSize",
	    value: function tensorSize() {
	      return scalar(this.size(), 'int32');
	    }
	    /**
	     * Replaces the contents of the table with the specified keys and values.
	     * @param keys Keys to store in the hashtable.
	     * @param values Values to store in the hashtable.
	     */
	  }, {
	    key: "import",
	    value: function () {
	      var _import2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(keys, values) {
	        var _this = this;
	        var $keys;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              this.checkKeyAndValueTensor(keys, values);
	              // We only store the primitive values of the keys, this allows lookup
	              // to be O(1).
	              _context.next = 3;
	              return keys.data();
	            case 3:
	              $keys = _context.sent;
	              // Clear the hashTable before inserting new values.
	              this.tensorMap.forEach(function (value) {
	                return value.dispose();
	              });
	              this.tensorMap.clear();
	              return _context.abrupt("return", tidy(function () {
	                var $values = unstack(values);
	                var keysLength = $keys.length;
	                var valuesLength = $values.length;
	                assert$1(keysLength === valuesLength, function () {
	                  return "The number of elements doesn't match, keys has " + "".concat(keysLength, " elements, the values has ").concat(valuesLength, " ") + "elements.";
	                });
	                for (var i = 0; i < keysLength; i++) {
	                  var key = $keys[i];
	                  var value = $values[i];
	                  keep(value);
	                  _this.tensorMap.set(key, value);
	                }
	                return _this.handle;
	              }));
	            case 7:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function _import(_x, _x2) {
	        return _import2.apply(this, arguments);
	      }
	      return _import;
	    }()
	    /**
	     * Looks up keys in a hash table, outputs the corresponding values.
	     *
	     * Performs batch lookups, for every element in the key tensor, `find`
	     * stacks the corresponding value into the return tensor.
	     *
	     * If an element is not present in the table, the given `defaultValue` is
	     * used.
	     *
	     * @param keys Keys to look up. Must have the same type as the keys of the
	     *     table.
	     * @param defaultValue The scalar `defaultValue` is the value output for keys
	     *     not present in the table. It must also be of the same type as the
	     *     table values.
	     */
	  }, {
	    key: "find",
	    value: function () {
	      var _find = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(keys, defaultValue) {
	        var _this2 = this;
	        var $keys;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              this.checkKeyAndValueTensor(keys, defaultValue);
	              _context2.next = 3;
	              return keys.data();
	            case 3:
	              $keys = _context2.sent;
	              return _context2.abrupt("return", tidy(function () {
	                var result = [];
	                for (var i = 0; i < $keys.length; i++) {
	                  var key = $keys[i];
	                  var value = _this2.findWithDefault(key, defaultValue);
	                  result.push(value);
	                }
	                return stack(result);
	              }));
	            case 5:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function find(_x3, _x4) {
	        return _find.apply(this, arguments);
	      }
	      return find;
	    }() // tslint:disable-next-line: no-any
	  }, {
	    key: "findWithDefault",
	    value: function findWithDefault(key, defaultValue) {
	      var result = this.tensorMap.get(key);
	      return result != null ? result : defaultValue;
	    }
	  }, {
	    key: "checkKeyAndValueTensor",
	    value: function checkKeyAndValueTensor(key, value) {
	      if (key.dtype !== this.keyDType) {
	        throw new Error("Expect key dtype ".concat(this.keyDType, ", but got ") + "".concat(key.dtype));
	      }
	      if (value.dtype !== this.valueDType) {
	        throw new Error("Expect value dtype ".concat(this.valueDType, ", but got ") + "".concat(value.dtype));
	      }
	    }
	  }]);
	  return HashTable;
	}();

	var executeOp$c = /*#__PURE__*/function () {
	  var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(node, tensorMap, context, resourceManager) {
	    var existingTableHandle, keyDType, valueDType, hashTable, handle, keys, values, _hashTable, _handle, _keys, defaultValue, _hashTable2, _handle2, _hashTable3;
	    return _regeneratorRuntime().wrap(function _callee$(_context) {
	      while (1) switch (_context.prev = _context.next) {
	        case 0:
	          _context.t0 = node.op;
	          _context.next = _context.t0 === 'HashTable' ? 3 : _context.t0 === 'HashTableV2' ? 3 : _context.t0 === 'InitializeTable' ? 13 : _context.t0 === 'InitializeTableV2' ? 13 : _context.t0 === 'LookupTableImport' ? 13 : _context.t0 === 'LookupTableImportV2' ? 13 : _context.t0 === 'LookupTableFind' ? 21 : _context.t0 === 'LookupTableFindV2' ? 21 : _context.t0 === 'LookupTableSize' ? 29 : _context.t0 === 'LookupTableSizeV2' ? 29 : 32;
	          break;
	        case 3:
	          existingTableHandle = resourceManager.getHashTableHandleByName(node.name); // Table is shared with initializer.
	          if (!(existingTableHandle != null)) {
	            _context.next = 8;
	            break;
	          }
	          return _context.abrupt("return", [existingTableHandle]);
	        case 8:
	          keyDType = getParamValue('keyDType', node, tensorMap, context);
	          valueDType = getParamValue('valueDType', node, tensorMap, context);
	          hashTable = new HashTable(keyDType, valueDType);
	          resourceManager.addHashTable(node.name, hashTable);
	          return _context.abrupt("return", [hashTable.handle]);
	        case 13:
	          handle = getParamValue('tableHandle', node, tensorMap, context, resourceManager);
	          keys = getParamValue('keys', node, tensorMap, context);
	          values = getParamValue('values', node, tensorMap, context);
	          _hashTable = resourceManager.getHashTableById(handle.id);
	          _context.next = 19;
	          return _hashTable.import(keys, values);
	        case 19:
	          _context.t1 = _context.sent;
	          return _context.abrupt("return", [_context.t1]);
	        case 21:
	          _handle = getParamValue('tableHandle', node, tensorMap, context, resourceManager);
	          _keys = getParamValue('keys', node, tensorMap, context);
	          defaultValue = getParamValue('defaultValue', node, tensorMap, context);
	          _hashTable2 = resourceManager.getHashTableById(_handle.id);
	          _context.next = 27;
	          return _hashTable2.find(_keys, defaultValue);
	        case 27:
	          _context.t2 = _context.sent;
	          return _context.abrupt("return", [_context.t2]);
	        case 29:
	          _handle2 = getParamValue('tableHandle', node, tensorMap, context, resourceManager);
	          _hashTable3 = resourceManager.getHashTableById(_handle2.id);
	          return _context.abrupt("return", [_hashTable3.tensorSize()]);
	        case 32:
	          throw TypeError("Node type ".concat(node.op, " is not implemented"));
	        case 33:
	        case "end":
	          return _context.stop();
	      }
	    }, _callee);
	  }));
	  return function executeOp(_x, _x2, _x3, _x4) {
	    return _ref.apply(this, arguments);
	  };
	}();
	var CATEGORY$b = 'hash_table';

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var executeOp$b = function executeOp(node, tensorMap, context) {
	  var ops = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : tfOps;
	  switch (node.op) {
	    case 'ResizeBilinear':
	      {
	        var images = getParamValue('images', node, tensorMap, context);
	        var size = getParamValue('size', node, tensorMap, context);
	        var alignCorners = getParamValue('alignCorners', node, tensorMap, context);
	        var halfPixelCenters = getParamValue('halfPixelCenters', node, tensorMap, context);
	        return [ops.image.resizeBilinear(images, [size[0], size[1]], alignCorners, halfPixelCenters)];
	      }
	    case 'ResizeNearestNeighbor':
	      {
	        var _images = getParamValue('images', node, tensorMap, context);
	        var _size = getParamValue('size', node, tensorMap, context);
	        var _alignCorners = getParamValue('alignCorners', node, tensorMap, context);
	        var _halfPixelCenters = getParamValue('halfPixelCenters', node, tensorMap, context);
	        return [ops.image.resizeNearestNeighbor(_images, [_size[0], _size[1]], _alignCorners, _halfPixelCenters)];
	      }
	    case 'CropAndResize':
	      {
	        var image = getParamValue('image', node, tensorMap, context);
	        var boxes = getParamValue('boxes', node, tensorMap, context);
	        var boxInd = getParamValue('boxInd', node, tensorMap, context);
	        var cropSize = getParamValue('cropSize', node, tensorMap, context);
	        var method = getParamValue('method', node, tensorMap, context);
	        var extrapolationValue = getParamValue('extrapolationValue', node, tensorMap, context);
	        return [ops.image.cropAndResize(image, boxes, boxInd, cropSize, method, extrapolationValue)];
	      }
	    case 'ImageProjectiveTransformV3':
	      {
	        var _images2 = getParamValue('images', node, tensorMap, context);
	        var transforms = getParamValue('transforms', node, tensorMap, context);
	        var outputShape = getParamValue('outputShape', node, tensorMap, context);
	        var fillValue = getParamValue('fillValue', node, tensorMap, context);
	        var interpolation = getParamValue('interpolation', node, tensorMap, context);
	        var fillMode = getParamValue('fillMode', node, tensorMap, context);
	        return [ops.image.transform(_images2, transforms, interpolation.toLowerCase(), fillMode.toLowerCase(), fillValue, outputShape)];
	      }
	    default:
	      throw TypeError("Node type ".concat(node.op, " is not implemented"));
	  }
	};
	var CATEGORY$a = 'image';

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var executeOp$a = function executeOp(node, tensorMap, context) {
	  var ops = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : tfOps;
	  switch (node.op) {
	    case 'Equal':
	      {
	        return [ops.equal(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    case 'NotEqual':
	      {
	        return [ops.notEqual(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    case 'Greater':
	      {
	        return [ops.greater(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    case 'GreaterEqual':
	      {
	        return [ops.greaterEqual(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    case 'Less':
	      {
	        return [ops.less(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    case 'LessEqual':
	      {
	        return [ops.lessEqual(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    case 'LogicalAnd':
	      {
	        return [ops.logicalAnd(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    case 'LogicalNot':
	      {
	        return [ops.logicalNot(getParamValue('a', node, tensorMap, context))];
	      }
	    case 'LogicalOr':
	      {
	        return [ops.logicalOr(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    case 'Select':
	    case 'SelectV2':
	      {
	        return [ops.where(getParamValue('condition', node, tensorMap, context), getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    case 'BitwiseAnd':
	      {
	        return [ops.bitwiseAnd(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context))];
	      }
	    default:
	      throw TypeError("Node type ".concat(node.op, " is not implemented"));
	  }
	};
	var CATEGORY$9 = 'logical';

	var executeOp$9 = function executeOp(node, tensorMap, context) {
	  var ops = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : tfOps;
	  switch (node.op) {
	    case 'BatchMatMul':
	    case 'BatchMatMulV2':
	    case 'MatMul':
	      return [ops.matMul(getParamValue('a', node, tensorMap, context), getParamValue('b', node, tensorMap, context), getParamValue('transposeA', node, tensorMap, context), getParamValue('transposeB', node, tensorMap, context))];
	    case 'Einsum':
	      return [ops.einsum.apply(ops, [getParamValue('equation', node, tensorMap, context)].concat(_toConsumableArray(getParamValue('tensors', node, tensorMap, context))))];
	    case 'Transpose':
	      return [ops.transpose(getParamValue('x', node, tensorMap, context), getParamValue('perm', node, tensorMap, context))];
	    case '_FusedMatMul':
	      var _getParamValue = getParamValue('fusedOps', node, tensorMap, context),
	        _getParamValue2 = _slicedToArray(_getParamValue, 2),
	        extraOp = _getParamValue2[0],
	        activationFunc = _getParamValue2[1];
	      var isBiasAdd = extraOp === 'biasadd';
	      var isPrelu = activationFunc === 'prelu';
	      var numArgs = getParamValue('numArgs', node, tensorMap, context);
	      var leakyreluAlpha = getParamValue('leakyreluAlpha', node, tensorMap, context);
	      if (isBiasAdd) {
	        if (isPrelu && numArgs !== 2) {
	          throw new Error('Fused MatMul with BiasAdd and Prelu must have two ' + 'extra arguments: bias and alpha.');
	        }
	        if (!isPrelu && numArgs !== 1) {
	          throw new Error('Fused MatMul with BiasAdd must have one extra argument: bias.');
	        }
	      }
	      var _getParamValue3 = getParamValue('args', node, tensorMap, context),
	        _getParamValue4 = _slicedToArray(_getParamValue3, 2),
	        biasArg = _getParamValue4[0],
	        preluArg = _getParamValue4[1];
	      return [ops.fused.matMul({
	        a: getParamValue('a', node, tensorMap, context),
	        b: getParamValue('b', node, tensorMap, context),
	        transposeA: getParamValue('transposeA', node, tensorMap, context),
	        transposeB: getParamValue('transposeB', node, tensorMap, context),
	        bias: biasArg,
	        activation: activationFunc,
	        preluActivationWeights: preluArg,
	        leakyreluAlpha: leakyreluAlpha
	      })];
	    case 'MatrixBandPart':
	      return [ops.linalg.bandPart(getParamValue('a', node, tensorMap, context), getParamValue('numLower', node, tensorMap, context), getParamValue('numUpper', node, tensorMap, context))];
	    default:
	      throw TypeError("Node type ".concat(node.op, " is not implemented"));
	  }
	};
	var CATEGORY$8 = 'matrices';

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var executeOp$8 = function executeOp(node, tensorMap, context) {
	  var ops = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : tfOps;
	  switch (node.op) {
	    case 'EuclideanNorm':
	      return [ops.euclideanNorm(getParamValue('x', node, tensorMap, context), getParamValue('axis', node, tensorMap, context), getParamValue('keepDims', node, tensorMap, context))];
	    case 'FusedBatchNorm':
	    case 'FusedBatchNormV2':
	      {
	        return [ops.batchNorm(getParamValue('x', node, tensorMap, context), getParamValue('mean', node, tensorMap, context), getParamValue('variance', node, tensorMap, context), getParamValue('offset', node, tensorMap, context), getParamValue('scale', node, tensorMap, context), getParamValue('epsilon', node, tensorMap, context))];
	      }
	    case 'FusedBatchNormV3':
	      {
	        return [ops.batchNorm(getParamValue('x', node, tensorMap, context), getParamValue('mean', node, tensorMap, context), getParamValue('variance', node, tensorMap, context), getParamValue('offset', node, tensorMap, context), getParamValue('scale', node, tensorMap, context), getParamValue('epsilon', node, tensorMap, context))];
	      }
	    case 'LRN':
	      {
	        return [ops.localResponseNormalization(getParamValue('x', node, tensorMap, context), getParamValue('radius', node, tensorMap, context), getParamValue('bias', node, tensorMap, context), getParamValue('alpha', node, tensorMap, context), getParamValue('beta', node, tensorMap, context))];
	      }
	    case 'Softmax':
	      {
	        return [ops.softmax(getParamValue('x', node, tensorMap, context))];
	      }
	    case 'LogSoftmax':
	      {
	        return [ops.logSoftmax(getParamValue('x', node, tensorMap, context))];
	      }
	    default:
	      throw TypeError("Node type ".concat(node.op, " is not implemented"));
	  }
	};
	var CATEGORY$7 = 'normalization';

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var executeOp$7 = function executeOp(node, tensorMap, context) {
	  var ops = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : tfOps;
	  switch (node.op) {
	    case 'RaggedGather':
	      {
	        var _ops$raggedGather = ops.raggedGather(getParamValue('paramsNestedSplits', node, tensorMap, context), getParamValue('paramsDenseValues', node, tensorMap, context), getParamValue('indices', node, tensorMap, context), getParamValue('outputRaggedRank', node, tensorMap, context)),
	          outputNestedSplits = _ops$raggedGather.outputNestedSplits,
	          outputDenseValues = _ops$raggedGather.outputDenseValues;
	        return outputNestedSplits.concat(outputDenseValues);
	      }
	    case 'RaggedRange':
	      {
	        var _ops$raggedRange = ops.raggedRange(getParamValue('starts', node, tensorMap, context), getParamValue('limits', node, tensorMap, context), getParamValue('splits', node, tensorMap, context)),
	          rtNestedSplits = _ops$raggedRange.rtNestedSplits,
	          rtDenseValues = _ops$raggedRange.rtDenseValues;
	        return [rtNestedSplits, rtDenseValues];
	      }
	    case 'RaggedTensorToTensor':
	      {
	        return [ops.raggedTensorToTensor(getParamValue('shape', node, tensorMap, context), getParamValue('values', node, tensorMap, context), getParamValue('defaultValue', node, tensorMap, context), getParamValue('rowPartitionTensors', node, tensorMap, context), getParamValue('rowPartitionTypes', node, tensorMap, context))];
	      }
	    default:
	      throw TypeError("Node type ".concat(node.op, " is not implemented"));
	  }
	};
	var CATEGORY$6 = 'ragged';

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var executeOp$6 = function executeOp(node, tensorMap, context) {
	  var ops = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : tfOps;
	  switch (node.op) {
	    case 'Max':
	      {
	        var axis = getParamValue('axis', node, tensorMap, context);
	        var keepDims = getParamValue('keepDims', node, tensorMap, context);
	        return [ops.max(getParamValue('x', node, tensorMap, context), axis, keepDims)];
	      }
	    case 'Mean':
	      {
	        var _axis = getParamValue('axis', node, tensorMap, context);
	        var _keepDims = getParamValue('keepDims', node, tensorMap, context);
	        return [ops.mean(getParamValue('x', node, tensorMap, context), _axis, _keepDims)];
	      }
	    case 'Min':
	      {
	        var _axis2 = getParamValue('axis', node, tensorMap, context);
	        var _keepDims2 = getParamValue('keepDims', node, tensorMap, context);
	        return [ops.min(getParamValue('x', node, tensorMap, context), _axis2, _keepDims2)];
	      }
	    case 'Sum':
	      {
	        var _axis3 = getParamValue('axis', node, tensorMap, context);
	        var _keepDims3 = getParamValue('keepDims', node, tensorMap, context);
	        return [ops.sum(getParamValue('x', node, tensorMap, context), _axis3, _keepDims3)];
	      }
	    case 'All':
	      {
	        var _axis4 = getParamValue('axis', node, tensorMap, context);
	        var _keepDims4 = getParamValue('keepDims', node, tensorMap, context);
	        return [ops.all(getParamValue('x', node, tensorMap, context), _axis4, _keepDims4)];
	      }
	    case 'Any':
	      {
	        var _axis5 = getParamValue('axis', node, tensorMap, context);
	        var _keepDims5 = getParamValue('keepDims', node, tensorMap, context);
	        return [ops.any(getParamValue('x', node, tensorMap, context), _axis5, _keepDims5)];
	      }
	    case 'ArgMax':
	      {
	        var _axis6 = getParamValue('axis', node, tensorMap, context);
	        return [ops.argMax(getParamValue('x', node, tensorMap, context), _axis6)];
	      }
	    case 'ArgMin':
	      {
	        var _axis7 = getParamValue('axis', node, tensorMap, context);
	        return [ops.argMin(getParamValue('x', node, tensorMap, context), _axis7)];
	      }
	    case 'Prod':
	      {
	        var _axis8 = getParamValue('axis', node, tensorMap, context);
	        var _keepDims6 = getParamValue('keepDims', node, tensorMap, context);
	        return [ops.prod(getParamValue('x', node, tensorMap, context), _axis8, _keepDims6)];
	      }
	    case 'Cumprod':
	      {
	        var _axis9 = getParamValue('axis', node, tensorMap, context);
	        var exclusive = getParamValue('exclusive', node, tensorMap, context);
	        var reverse = getParamValue('reverse', node, tensorMap, context);
	        return [ops.cumprod(getParamValue('x', node, tensorMap, context), _axis9, exclusive, reverse)];
	      }
	    case 'Cumsum':
	      {
	        var _axis10 = getParamValue('axis', node, tensorMap, context);
	        var _exclusive = getParamValue('exclusive', node, tensorMap, context);
	        var _reverse = getParamValue('reverse', node, tensorMap, context);
	        return [ops.cumsum(getParamValue('x', node, tensorMap, context), _axis10, _exclusive, _reverse)];
	      }
	    case 'Bincount':
	      var x = getParamValue('x', node, tensorMap, context);
	      var weights = getParamValue('weights', node, tensorMap, context);
	      var size = getParamValue('size', node, tensorMap, context);
	      return [ops.bincount(x, weights, size)];
	    case 'DenseBincount':
	      {
	        var _x = getParamValue('x', node, tensorMap, context);
	        var _weights = getParamValue('weights', node, tensorMap, context);
	        var _size = getParamValue('size', node, tensorMap, context);
	        var binaryOutput = getParamValue('binaryOutput', node, tensorMap, context);
	        return [ops.denseBincount(_x, _weights, _size, binaryOutput)];
	      }
	    default:
	      throw TypeError("Node type ".concat(node.op, " is not implemented"));
	  }
	};
	var CATEGORY$5 = 'reduction';

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var executeOp$5 = function executeOp(node, tensorMap, context) {
	  var ops = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : tfOps;
	  switch (node.op) {
	    case 'ConcatV2':
	    case 'Concat':
	      {
	        var n = getParamValue('n', node, tensorMap, context);
	        var axis = getParamValue('axis', node, tensorMap, context);
	        var inputs = getParamValue('tensors', node, tensorMap, context);
	        inputs = inputs.slice(0, n);
	        return [ops.concat(inputs, axis)];
	      }
	    case 'Gather':
	      {
	        var input = getParamValue('x', node, tensorMap, context);
	        var indices = getParamValue('indices', node, tensorMap, context);
	        return [ops.gather(input, ops.cast(indices, 'int32'), 0)];
	      }
	    case 'GatherV2':
	      {
	        var _axis = getParamValue('axis', node, tensorMap, context);
	        var batchDims = getParamValue('batchDims', node, tensorMap, context);
	        var _input = getParamValue('x', node, tensorMap, context);
	        var _indices = getParamValue('indices', node, tensorMap, context);
	        return [ops.gather(_input, ops.cast(_indices, 'int32'), _axis, batchDims)];
	      }
	    case 'Reverse':
	      {
	        var dims = getParamValue('dims', node, tensorMap, context);
	        var _axis2 = [];
	        for (var i = 0; i < dims.length; i++) {
	          if (dims[i]) {
	            _axis2.push(i);
	          }
	        }
	        var _input2 = getParamValue('x', node, tensorMap, context);
	        return [ops.reverse(_input2, _axis2)];
	      }
	    case 'ReverseV2':
	      {
	        var _axis3 = getParamValue('axis', node, tensorMap, context);
	        var _input3 = getParamValue('x', node, tensorMap, context);
	        return [ops.reverse(_input3, _axis3)];
	      }
	    case 'Slice':
	      {
	        // tslint:disable-next-line:no-any
	        var begin = getParamValue('begin', node, tensorMap, context);
	        // tslint:disable-next-line:no-any
	        var size = getParamValue('size', node, tensorMap, context);
	        return [ops.slice(getParamValue('x', node, tensorMap, context), begin, size)];
	      }
	    case 'StridedSlice':
	      {
	        var _begin = getParamValue('begin', node, tensorMap, context);
	        var end = getParamValue('end', node, tensorMap, context);
	        var strides = getParamValue('strides', node, tensorMap, context);
	        var beginMask = getParamValue('beginMask', node, tensorMap, context);
	        var endMask = getParamValue('endMask', node, tensorMap, context);
	        var ellipsisMask = getParamValue('ellipsisMask', node, tensorMap, context);
	        var newAxisMask = getParamValue('newAxisMask', node, tensorMap, context);
	        var shrinkAxisMask = getParamValue('shrinkAxisMask', node, tensorMap, context);
	        var tensor = getParamValue('x', node, tensorMap, context);
	        return [ops.stridedSlice(tensor, _begin, end, strides, beginMask, endMask, ellipsisMask, newAxisMask, shrinkAxisMask)];
	      }
	    case 'Pack':
	      {
	        return tidy(function () {
	          var axis = getParamValue('axis', node, tensorMap, context);
	          var tensors = getParamValue('tensors', node, tensorMap, context);
	          // Reshape the tensors to the first tensor's shape if they don't
	          // match.
	          var shape = tensors[0].shape;
	          var squeezedShape = ops.squeeze(tensors[0]).shape;
	          var mapped = tensors.map(function (tensor) {
	            var sameShape = arraysEqual(tensor.shape, shape);
	            if (!sameShape && !arraysEqual(ops.squeeze(tensor).shape, squeezedShape)) {
	              throw new Error('the input tensors shape does not match');
	            }
	            return sameShape ? tensor : ops.reshape(tensor, shape);
	          });
	          return [ops.stack(mapped, axis)];
	        });
	      }
	    case 'Unpack':
	      {
	        var _axis4 = getParamValue('axis', node, tensorMap, context);
	        var _tensor = getParamValue('tensor', node, tensorMap, context);
	        return ops.unstack(_tensor, _axis4);
	      }
	    case 'Tile':
	      {
	        var reps = getParamValue('reps', node, tensorMap, context);
	        return [ops.tile(getParamValue('x', node, tensorMap, context), reps)];
	      }
	    case 'Split':
	    case 'SplitV':
	      {
	        var _axis5 = getParamValue('axis', node, tensorMap, context);
	        var numOrSizeSplits = getParamValue('numOrSizeSplits', node, tensorMap, context);
	        var _tensor2 = getParamValue('x', node, tensorMap, context);
	        return ops.split(_tensor2, numOrSizeSplits, _axis5);
	      }
	    case 'ScatterNd':
	      {
	        var _indices2 = getParamValue('indices', node, tensorMap, context);
	        var values = getParamValue('values', node, tensorMap, context);
	        var shape = getParamValue('shape', node, tensorMap, context);
	        return [ops.scatterND(_indices2, values, shape)];
	      }
	    case 'GatherNd':
	      {
	        var x = getParamValue('x', node, tensorMap, context);
	        var _indices3 = getParamValue('indices', node, tensorMap, context);
	        return [ops.gatherND(x, _indices3)];
	      }
	    case 'SparseToDense':
	      {
	        var _indices4 = getParamValue('sparseIndices', node, tensorMap, context);
	        var _shape = getParamValue('outputShape', node, tensorMap, context);
	        var sparseValues = getParamValue('sparseValues', node, tensorMap, context);
	        var defaultValue = getParamValue('defaultValue', node, tensorMap, context);
	        return [ops.sparseToDense(_indices4, sparseValues, _shape, sparseValues.dtype === defaultValue.dtype ? defaultValue : ops.cast(defaultValue, sparseValues.dtype))];
	      }
	    case 'TensorScatterUpdate':
	      {
	        var _indices5 = getParamValue('indices', node, tensorMap, context);
	        var _values = getParamValue('values', node, tensorMap, context);
	        var _tensor3 = getParamValue('tensor', node, tensorMap, context);
	        return [ops.tensorScatterUpdate(_tensor3, _indices5, _values)];
	      }
	    default:
	      throw TypeError("Node type ".concat(node.op, " is not implemented"));
	  }
	};
	var CATEGORY$4 = 'slice_join';

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var executeOp$4 = function executeOp(node, tensorMap, context) {
	  var ops = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : tfOps;
	  switch (node.op) {
	    case 'SparseFillEmptyRows':
	      {
	        var _ops$sparse$sparseFil = ops.sparse.sparseFillEmptyRows(getParamValue('indices', node, tensorMap, context), getParamValue('values', node, tensorMap, context), getParamValue('denseShape', node, tensorMap, context), getParamValue('defaultValue', node, tensorMap, context)),
	          outputIndices = _ops$sparse$sparseFil.outputIndices,
	          outputValues = _ops$sparse$sparseFil.outputValues,
	          emptyRowIndicator = _ops$sparse$sparseFil.emptyRowIndicator,
	          reverseIndexMap = _ops$sparse$sparseFil.reverseIndexMap;
	        return [outputIndices, outputValues, emptyRowIndicator, reverseIndexMap];
	      }
	    case 'SparseReshape':
	      {
	        var _ops$sparse$sparseRes = ops.sparse.sparseReshape(getParamValue('inputIndices', node, tensorMap, context), getParamValue('inputShape', node, tensorMap, context), getParamValue('newShape', node, tensorMap, context)),
	          _outputIndices = _ops$sparse$sparseRes.outputIndices,
	          outputShape = _ops$sparse$sparseRes.outputShape;
	        return [_outputIndices, outputShape];
	      }
	    case 'SparseSegmentMean':
	      {
	        var outputData = ops.sparse.sparseSegmentMean(getParamValue('data', node, tensorMap, context), getParamValue('indices', node, tensorMap, context), getParamValue('segmentIds', node, tensorMap, context));
	        return [outputData];
	      }
	    case 'SparseSegmentSum':
	      {
	        var _outputData = ops.sparse.sparseSegmentSum(getParamValue('data', node, tensorMap, context), getParamValue('indices', node, tensorMap, context), getParamValue('segmentIds', node, tensorMap, context));
	        return [_outputData];
	      }
	    default:
	      throw TypeError("Node type ".concat(node.op, " is not implemented"));
	  }
	};
	var CATEGORY$3 = 'sparse';

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var executeOp$3 = function executeOp(node, tensorMap, context) {
	  var ops = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : tfOps;
	  switch (node.op) {
	    case 'FFT':
	      {
	        return [ops.fft(getParamValue('x', node, tensorMap, context))];
	      }
	    case 'IFFT':
	      {
	        return [ops.ifft(getParamValue('x', node, tensorMap, context))];
	      }
	    case 'RFFT':
	      {
	        return [ops.rfft(getParamValue('x', node, tensorMap, context))];
	      }
	    case 'IRFFT':
	      {
	        return [ops.irfft(getParamValue('x', node, tensorMap, context))];
	      }
	    default:
	      throw TypeError("Node type ".concat(node.op, " is not implemented"));
	  }
	};
	var CATEGORY$2 = 'spectral';

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var executeOp$2 = function executeOp(node, tensorMap, context) {
	  var ops = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : tfOps;
	  switch (node.op) {
	    case 'StaticRegexReplace':
	      {
	        return [ops.string.staticRegexReplace(getParamValue('input', node, tensorMap, context), getParamValue('pattern', node, tensorMap, context), getParamValue('rewrite', node, tensorMap, context), getParamValue('replaceGlobal', node, tensorMap, context))];
	      }
	    case 'StringNGrams':
	      {
	        var _ops$string$stringNGr = ops.string.stringNGrams(getParamValue('data', node, tensorMap, context), getParamValue('dataSplits', node, tensorMap, context), getParamValue('separator', node, tensorMap, context), getParamValue('nGramWidths', node, tensorMap, context), getParamValue('leftPad', node, tensorMap, context), getParamValue('rightPad', node, tensorMap, context), getParamValue('padWidth', node, tensorMap, context), getParamValue('preserveShortSequences', node, tensorMap, context)),
	          nGrams = _ops$string$stringNGr.nGrams,
	          nGramsSplits = _ops$string$stringNGr.nGramsSplits;
	        return [nGrams, nGramsSplits];
	      }
	    case 'StringSplit':
	      {
	        var _ops$string$stringSpl = ops.string.stringSplit(getParamValue('input', node, tensorMap, context), getParamValue('delimiter', node, tensorMap, context), getParamValue('skipEmpty', node, tensorMap, context)),
	          indices = _ops$string$stringSpl.indices,
	          values = _ops$string$stringSpl.values,
	          shape = _ops$string$stringSpl.shape;
	        return [indices, values, shape];
	      }
	    case 'StringToHashBucketFast':
	      {
	        var output = ops.string.stringToHashBucketFast(getParamValue('input', node, tensorMap, context), getParamValue('numBuckets', node, tensorMap, context));
	        return [output];
	      }
	    default:
	      throw TypeError("Node type ".concat(node.op, " is not implemented"));
	  }
	};
	var CATEGORY$1 = 'string';

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var executeOp$1 = function executeOp(node, tensorMap, context) {
	  var ops = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : tfOps;
	  switch (node.op) {
	    case 'Cast':
	      {
	        return [ops.cast(getParamValue('x', node, tensorMap, context), getParamValue('dtype', node, tensorMap, context))];
	      }
	    case 'ExpandDims':
	      {
	        var axis = getParamValue('axis', node, tensorMap, context);
	        return [ops.expandDims(getParamValue('x', node, tensorMap, context), axis)];
	      }
	    case 'Squeeze':
	      {
	        var _axis = getParamValue('axis', node, tensorMap, context);
	        return [ops.squeeze(getParamValue('x', node, tensorMap, context), _axis)];
	      }
	    case 'Reshape':
	      {
	        return [ops.reshape(getParamValue('x', node, tensorMap, context), getParamValue('shape', node, tensorMap, context))];
	      }
	    case 'EnsureShape':
	      {
	        return [ops.ensureShape(getParamValue('x', node, tensorMap, context), getParamValue('shape', node, tensorMap, context))];
	      }
	    case 'MirrorPad':
	      {
	        return [ops.mirrorPad(getParamValue('x', node, tensorMap, context), getParamValue('padding', node, tensorMap, context), getParamValue('mode', node, tensorMap, context))];
	      }
	    case 'PadV2':
	    case 'Pad':
	      {
	        return [ops.pad(getParamValue('x', node, tensorMap, context), getParamValue('padding', node, tensorMap, context), getParamValue('constantValue', node, tensorMap, context))];
	      }
	    case 'SpaceToBatchND':
	      {
	        var blockShape = getParamValue('blockShape', node, tensorMap, context);
	        var paddings = getParamValue('paddings', node, tensorMap, context);
	        return [ops.spaceToBatchND(getParamValue('x', node, tensorMap, context), blockShape, paddings)];
	      }
	    case 'BatchToSpaceND':
	      {
	        var _blockShape = getParamValue('blockShape', node, tensorMap, context);
	        var crops = getParamValue('crops', node, tensorMap, context);
	        return [ops.batchToSpaceND(getParamValue('x', node, tensorMap, context), _blockShape, crops)];
	      }
	    case 'DepthToSpace':
	      {
	        var blockSize = getParamValue('blockSize', node, tensorMap, context);
	        var dataFormat = getParamValue('dataFormat', node, tensorMap, context).toUpperCase();
	        return [ops.depthToSpace(getParamValue('x', node, tensorMap, context), blockSize, dataFormat)];
	      }
	    case 'BroadcastTo':
	      {
	        return [ops.broadcastTo(getParamValue('x', node, tensorMap, context), getParamValue('shape', node, tensorMap, context))];
	      }
	    case 'BroadcastArgs':
	      {
	        return [ops.broadcastArgs(getParamValue('s0', node, tensorMap, context), getParamValue('s1', node, tensorMap, context))];
	      }
	    default:
	      throw TypeError("Node type ".concat(node.op, " is not implemented"));
	  }
	};
	var CATEGORY = 'transformation';

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Executes the op defined by the node object.
	 * @param node
	 * @param tensorMap contains tensors for executed nodes and weights
	 * @param context contains tensors and information for running the current node.
	 * @param resourceManager Optional. Contains global resources of the model.
	 */
	function executeOp(node, tensorMap, context, resourceManager) {
	  var tidy$1 = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : tidy;
	  var value = function (node, tensorMap, context) {
	    switch (node.category) {
	      case 'arithmetic':
	        return tidy$1(function () {
	          return executeOp$k(node, tensorMap, context);
	        });
	      case 'basic_math':
	        return tidy$1(function () {
	          return executeOp$j(node, tensorMap, context);
	        });
	      case 'control':
	        return executeOp$i(node, tensorMap, context);
	      case 'convolution':
	        return tidy$1(function () {
	          return executeOp$h(node, tensorMap, context);
	        });
	      case 'creation':
	        return tidy$1(function () {
	          return executeOp$g(node, tensorMap, context);
	        });
	      case 'dynamic':
	        return executeOp$f(node, tensorMap, context);
	      case 'evaluation':
	        return tidy$1(function () {
	          return executeOp$e(node, tensorMap, context);
	        });
	      case 'image':
	        return tidy$1(function () {
	          return executeOp$b(node, tensorMap, context);
	        });
	      case 'graph':
	        return tidy$1(function () {
	          return executeOp$d(node, tensorMap, context);
	        });
	      case 'logical':
	        return tidy$1(function () {
	          return executeOp$a(node, tensorMap, context);
	        });
	      case 'matrices':
	        return tidy$1(function () {
	          return executeOp$9(node, tensorMap, context);
	        });
	      case 'normalization':
	        return tidy$1(function () {
	          return executeOp$8(node, tensorMap, context);
	        });
	      case 'ragged':
	        return tidy$1(function () {
	          return executeOp$7(node, tensorMap, context);
	        });
	      case 'reduction':
	        return tidy$1(function () {
	          return executeOp$6(node, tensorMap, context);
	        });
	      case 'slice_join':
	        return tidy$1(function () {
	          return executeOp$5(node, tensorMap, context);
	        });
	      case 'sparse':
	        return tidy$1(function () {
	          return executeOp$4(node, tensorMap, context);
	        });
	      case 'spectral':
	        return tidy$1(function () {
	          return executeOp$3(node, tensorMap, context);
	        });
	      case 'string':
	        return tidy$1(function () {
	          return executeOp$2(node, tensorMap, context);
	        });
	      case 'transformation':
	        return tidy$1(function () {
	          return executeOp$1(node, tensorMap, context);
	        });
	      case 'hash_table':
	        return executeOp$c(node, tensorMap, context, resourceManager);
	      case 'custom':
	        var opMapper = getRegisteredOp(node.op);
	        if (opMapper && opMapper.customExecutor) {
	          return opMapper.customExecutor(new NodeValueImpl(node, tensorMap, context));
	        } else {
	          throw TypeError("Custom op ".concat(node.op, " is not registered."));
	        }
	      default:
	        throw TypeError("Unknown op '".concat(node.op, "'. File an issue at ") + "https://github.com/tensorflow/tfjs/issues so we can add it" + ", or register a custom execution with tf.registerOp()");
	    }
	  }(node, tensorMap, context);
	  if (isPromise(value)) {
	    return value.then(function (data) {
	      return [].concat(data);
	    });
	  }
	  return [].concat(value);
	}

	/**
	 * ExecutionContext captures the runtime environment of the node. It keeps
	 * track of the current frame and iteration for the control flow ops.
	 *
	 * For example, typical Dynamic RNN model may contain loops, for which
	 * TensorFlow will generate graphs with Enter/Exit nodes to control the
	 * current execution frame, and NextIteration Nodes for iteration id increment.
	 * For model with branch logic, TensorFLow will generate Switch/Merge ops.
	 */
	var ExecutionContext = /*#__PURE__*/function () {
	  function ExecutionContext() {
	    var weightMap = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
	    var tensorArrayMap = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	    var tensorListMap = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
	    var functionMap = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
	    var parseNodeNameCache = arguments.length > 4 ? arguments[4] : undefined;
	    _classCallCheck(this, ExecutionContext);
	    this.weightMap = weightMap;
	    this.tensorArrayMap = tensorArrayMap;
	    this.tensorListMap = tensorListMap;
	    this.functionMap = functionMap;
	    this.parseNodeNameCache = parseNodeNameCache;
	    this.rootContext = {
	      id: 0,
	      frameName: '',
	      iterationId: 0
	    };
	    this.contexts = [this.rootContext];
	    this.lastId = 0;
	    this.generateCurrentContextIds();
	  }
	  _createClass(ExecutionContext, [{
	    key: "newFrame",
	    value: function newFrame(id, frameName) {
	      return {
	        id: id,
	        frameName: frameName,
	        iterationId: 0
	      };
	    }
	    /**
	     * Set the current context
	     * @param contexts: ExecutionContextInfo[] the current path of execution
	     * frames
	     */
	  }, {
	    key: "currentContext",
	    get: function get() {
	      return this.contexts;
	    }
	    /**
	     * Returns the current context in string format.
	     */,
	    set: function set(contexts) {
	      if (this.contexts !== contexts) {
	        this.contexts = contexts;
	        this.generateCurrentContextIds();
	      }
	    }
	  }, {
	    key: "currentContextId",
	    get: function get() {
	      return this._currentContextIds[0];
	    }
	    /**
	     * Returns the current context and all parent contexts in string format.
	     * This allow access to the nodes in the current and parent frames.
	     */
	  }, {
	    key: "currentContextIds",
	    get: function get() {
	      return this._currentContextIds;
	    }
	  }, {
	    key: "generateCurrentContextIds",
	    value: function generateCurrentContextIds() {
	      var names = [];
	      for (var i = 0; i < this.contexts.length - 1; i++) {
	        var contexts = this.contexts.slice(0, this.contexts.length - i);
	        names.push(this.contextIdforContexts(contexts));
	      }
	      names.push('');
	      this._currentContextIds = names;
	    }
	  }, {
	    key: "contextIdforContexts",
	    value: function contextIdforContexts(contexts) {
	      return contexts ? contexts.map(function (context) {
	        return context.id === 0 && context.iterationId === 0 ? '' : "".concat(context.frameName, "-").concat(context.iterationId);
	      }).join('/') : '';
	    }
	    /**
	     * Enter a new frame, a new context is pushed on the current context list.
	     * @param frameId new frame id
	     */
	  }, {
	    key: "enterFrame",
	    value: function enterFrame(frameId) {
	      if (this.contexts) {
	        this.lastId++;
	        this.contexts = this.contexts.slice();
	        this.contexts.push(this.newFrame(this.lastId, frameId));
	        this._currentContextIds.unshift(this.contextIdforContexts(this.contexts));
	      }
	    }
	    /**
	     * Exit the current frame, the last context is removed from the current
	     * context list.
	     */
	  }, {
	    key: "exitFrame",
	    value: function exitFrame() {
	      if (this.contexts && this.contexts.length > 1) {
	        this.contexts = this.contexts.slice();
	        this.contexts.splice(-1);
	        this.currentContextIds.shift();
	      } else {
	        throw new Error('Cannot exit frame, the context is empty');
	      }
	    }
	    /**
	     * Enter the next iteration of a loop, the iteration id of last context is
	     * increased.
	     */
	  }, {
	    key: "nextIteration",
	    value: function nextIteration() {
	      if (this.contexts && this.contexts.length > 0) {
	        this.contexts = this.contexts.slice();
	        this.lastId++;
	        var context = Object.assign({}, this.contexts[this.contexts.length - 1]);
	        context.iterationId += 1;
	        context.id = this.lastId;
	        this.contexts.splice(-1, 1, context);
	        this._currentContextIds.splice(0, 1, this.contextIdforContexts(this.contexts));
	      } else {
	        throw new Error('Cannot increase frame iteration, the context is empty');
	      }
	    }
	  }, {
	    key: "getWeight",
	    value: function getWeight(name) {
	      return this.weightMap[name];
	    }
	  }, {
	    key: "addTensorArray",
	    value: function addTensorArray(tensorArray) {
	      this.tensorArrayMap[tensorArray.id] = tensorArray;
	    }
	  }, {
	    key: "getTensorArray",
	    value: function getTensorArray(id) {
	      return this.tensorArrayMap[id];
	    }
	  }, {
	    key: "addTensorList",
	    value: function addTensorList(tensorList) {
	      this.tensorListMap[tensorList.id] = tensorList;
	    }
	  }, {
	    key: "getTensorList",
	    value: function getTensorList(id) {
	      return this.tensorListMap[id];
	    }
	  }, {
	    key: "dispose",
	    value: function dispose(keepIds) {
	      for (var key in this.tensorArrayMap) {
	        this.tensorArrayMap[key].clearAndClose(keepIds);
	      }
	      for (var _key in this.tensorListMap) {
	        this.tensorListMap[_key].clearAndClose(keepIds);
	      }
	    }
	  }]);
	  return ExecutionContext;
	}();

	/**
	 * Given graph inputs and desired outputs, find the minimal set of nodes
	 * to execute in order to compute the outputs. In addition return other useful
	 * info such:
	 * - Missing inputs needed to compute the output.
	 * - Whether the subgraph contains dynamic ops (control flow, dynamic shape).
	 * - Alternative inputs in order to avoid async (dynamic op) execution.
	 */
	function getExecutionSubgraph(inputs, outputs, weightMap, initNodes) {
	  var usedNodes = new Set();
	  var missingInputs = [];
	  var dynamicNode = null;
	  var syncInputs = null;
	  // Start with the outputs, going backwards and find all the nodes that are
	  // needed to compute those outputs.
	  var seen = new Set();
	  var inputNodeNames = new Set(Object.keys(inputs).map(function (name) {
	    return parseNodeName(name)[0];
	  }));
	  initNodes = initNodes || [];
	  var initNodeNames = new Set(initNodes.map(function (node) {
	    return parseNodeName(node.name)[0];
	  }));
	  var frontier = _toConsumableArray(outputs);
	  while (frontier.length > 0) {
	    var node = frontier.pop();
	    if (isControlFlow(node) || isDynamicShape(node) || isHashTable(node)) {
	      if (dynamicNode == null) {
	        dynamicNode = node;
	        syncInputs = dynamicNode.children.map(function (child) {
	          return child.name;
	        }).filter(function (name) {
	          return usedNodes.has(name);
	        });
	      }
	    }
	    usedNodes.add(node.name);
	    // Weights are dead end since we already have their values.
	    if (weightMap[node.name] != null) {
	      continue;
	    }
	    // This node is a dead end since it's one of the user-provided inputs.
	    if (inputNodeNames.has(node.name)) {
	      continue;
	    }
	    // This node is a dead end since it doesn't have any inputs.
	    if (initNodeNames.has(node.name)) {
	      continue;
	    }
	    if (node.inputs.length === 0) {
	      missingInputs.push(node.name);
	      continue;
	    }
	    node.inputs.forEach(function (input) {
	      // Don't add to the frontier if it is already there.
	      if (seen.has(input.name)) {
	        return;
	      }
	      seen.add(input.name);
	      frontier.push(input);
	    });
	  }
	  return {
	    inputs: inputs,
	    outputs: outputs,
	    usedNodes: usedNodes,
	    missingInputs: missingInputs,
	    dynamicNode: dynamicNode,
	    syncInputs: syncInputs
	  };
	}
	/**
	 * Given the execution info, return a list of nodes in topological order that
	 * need to be executed to compute the output.
	 */
	function getNodesInTopologicalOrder(graph, executionInfo) {
	  var usedNodes = executionInfo.usedNodes,
	    inputs = executionInfo.inputs;
	  var inputNodes = Object.keys(inputs).map(function (name) {
	    return parseNodeName(name)[0];
	  }).map(function (name) {
	    return graph.nodes[name];
	  });
	  var initNodes = graph.initNodes || [];
	  var isUsed = function isUsed(node) {
	    return usedNodes.has(typeof node === 'string' ? node : node.name);
	  };
	  function unique(nodes) {
	    return _toConsumableArray(new Map(nodes.map(function (node) {
	      return [node.name, node];
	    })).values());
	  }
	  var predefinedNodes = unique([].concat(_toConsumableArray(inputNodes), _toConsumableArray(graph.weights), _toConsumableArray(initNodes))).filter(isUsed);
	  var allNodes = unique([].concat(_toConsumableArray(predefinedNodes), _toConsumableArray(Object.values(graph.nodes)))).filter(isUsed);
	  var nameToNode = new Map(allNodes.map(function (node) {
	    return [node.name, node];
	  }));
	  var inCounts = {};
	  var _iterator = _createForOfIteratorHelper(allNodes),
	    _step;
	  try {
	    for (_iterator.s(); !(_step = _iterator.n()).done;) {
	      var _node = _step.value;
	      inCounts[_node.name] = inCounts[_node.name] || 0;
	      var _iterator3 = _createForOfIteratorHelper(_node.children),
	        _step3;
	      try {
	        for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
	          var _child = _step3.value;
	          // When the child is unused, set in counts to infinity so that it will
	          // never be decreased to 0 and added to the execution list.
	          if (!isUsed(_child)) {
	            inCounts[_child.name] = Number.POSITIVE_INFINITY;
	          }
	          inCounts[_child.name] = (inCounts[_child.name] || 0) + 1;
	        }
	      } catch (err) {
	        _iterator3.e(err);
	      } finally {
	        _iterator3.f();
	      }
	    }
	    // Build execution order for all used nodes regardless whether they are
	    // predefined or not.
	  } catch (err) {
	    _iterator.e(err);
	  } finally {
	    _iterator.f();
	  }
	  var frontier = Object.entries(inCounts).filter(function (_ref) {
	    var _ref2 = _slicedToArray(_ref, 2),
	      inCount = _ref2[1];
	    return inCount === 0;
	  }).map(function (_ref3) {
	    var _ref4 = _slicedToArray(_ref3, 1),
	      name = _ref4[0];
	    return name;
	  });
	  var orderedNodeNames = _toConsumableArray(frontier);
	  while (frontier.length > 0) {
	    var nodeName = frontier.pop();
	    var node = nameToNode.get(nodeName);
	    var _iterator2 = _createForOfIteratorHelper(node.children.filter(isUsed)),
	      _step2;
	    try {
	      for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	        var child = _step2.value;
	        if (--inCounts[child.name] === 0) {
	          orderedNodeNames.push(child.name);
	          frontier.push(child.name);
	        }
	      }
	    } catch (err) {
	      _iterator2.e(err);
	    } finally {
	      _iterator2.f();
	    }
	  }
	  var orderedNodes = orderedNodeNames.map(function (name) {
	    return nameToNode.get(name);
	  });
	  var filteredOrderedNodes = filterPredefinedReachableNodes(orderedNodes, predefinedNodes);
	  // TODO: Turn validation on/off with tf env flag.
	  validateNodesExecutionOrder(filteredOrderedNodes, predefinedNodes);
	  return filteredOrderedNodes;
	}
	/**
	 * This is a helper function of `getNodesInTopologicalOrder`.
	 * Returns ordered nodes reachable by at least one predefined node.
	 * This can help us filter out redundant nodes from the returned node list.
	 * For example:
	 * If we have four nodes with dependencies like this:
	 *   a --> b --> c --> d
	 * when node `c` is predefined (e.g. given as an input tensor), we can
	 * skip node `a` and `b` since their outputs will never be used.
	 *
	 * @param orderedNodes Graph nodes in execution order.
	 * @param predefinedNodes Graph inputs, weights, and init nodes. Nodes in this
	 *     list must have distinct names.
	 */
	function filterPredefinedReachableNodes(orderedNodes, predefinedNodes) {
	  var nameToNode = new Map(orderedNodes.map(function (node) {
	    return [node.name, node];
	  }));
	  // TODO: Filter out more nodes when >=2 nodes are predefined in a path.
	  var stack = predefinedNodes.map(function (node) {
	    return node.name;
	  });
	  var predefinedReachableNodeNames = new Set(stack);
	  // Perform a DFS starting from the set of all predefined nodes
	  // to find the set of all nodes reachable from the predefined nodes.
	  while (stack.length > 0) {
	    var nodeName = stack.pop();
	    var node = nameToNode.get(nodeName);
	    var _iterator4 = _createForOfIteratorHelper(node.children),
	      _step4;
	    try {
	      for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
	        var child = _step4.value;
	        if (!nameToNode.has(child.name) || predefinedReachableNodeNames.has(child.name)) {
	          continue;
	        }
	        predefinedReachableNodeNames.add(child.name);
	        stack.push(child.name);
	      }
	    } catch (err) {
	      _iterator4.e(err);
	    } finally {
	      _iterator4.f();
	    }
	  }
	  // Filter out unreachable nodes and build the ordered node list.
	  var filteredOrderedNodes = orderedNodes.filter(function (node) {
	    return predefinedReachableNodeNames.has(node.name);
	  });
	  return filteredOrderedNodes;
	}
	var NodesExecutionOrderError = /*#__PURE__*/function (_Error) {
	  _inherits(NodesExecutionOrderError, _Error);
	  var _super = _createSuper(NodesExecutionOrderError);
	  function NodesExecutionOrderError(message) {
	    _classCallCheck(this, NodesExecutionOrderError);
	    return _super.call(this, "NodesExecutionOrderError: ".concat(message));
	  }
	  return _createClass(NodesExecutionOrderError);
	}( /*#__PURE__*/_wrapNativeSuper(Error));
	/**
	 * This is a helper function of `getNodesInTopologicalOrder`.
	 * Validates property: given nodes `a` and `b`, Order(a) > Order(b) if `a`
	 * is a child of `b`. This function throws an error if validation fails.
	 *
	 * @param orderedNodes Graph nodes in execution order.
	 * @param predefinedNodes Graph inputs, weights, and init nodes. Nodes in this
	 *     list must have distinct names.
	 */
	function validateNodesExecutionOrder(orderedNodes, predefinedNodes) {
	  var nodeNameToOrder = new Map(orderedNodes.map(function (node, order) {
	    return [node.name, order];
	  }));
	  var predefinedNodeNames = new Set(predefinedNodes.map(function (node) {
	    return node.name;
	  }));
	  var isPredefined = function isPredefined(node) {
	    return predefinedNodeNames.has(typeof node === 'string' ? node : node.name);
	  };
	  var willBeExecutedNodeNames = new Set(orderedNodes.map(function (node) {
	    return node.name;
	  }));
	  var willBeExecuted = function willBeExecuted(node) {
	    return willBeExecutedNodeNames.has(typeof node === 'string' ? node : node.name);
	  };
	  var _iterator5 = _createForOfIteratorHelper(orderedNodes),
	    _step5;
	  try {
	    for (_iterator5.s(); !(_step5 = _iterator5.n()).done;) {
	      var node = _step5.value;
	      var _iterator6 = _createForOfIteratorHelper(node.children.filter(willBeExecuted)),
	        _step6;
	      try {
	        for (_iterator6.s(); !(_step6 = _iterator6.n()).done;) {
	          var child = _step6.value;
	          if (!nodeNameToOrder.has(child.name)) {
	            throw new NodesExecutionOrderError("Child ".concat(child.name, " of node ").concat(node.name, " is unreachable."));
	          }
	          if (nodeNameToOrder.get(node.name) > nodeNameToOrder.get(child.name)) {
	            throw new NodesExecutionOrderError("Node ".concat(node.name, " is scheduled to run after its child ").concat(child.name, "."));
	          }
	        }
	      } catch (err) {
	        _iterator6.e(err);
	      } finally {
	        _iterator6.f();
	      }
	      if (!isPredefined(node)) {
	        var _iterator7 = _createForOfIteratorHelper(node.inputs),
	          _step7;
	        try {
	          for (_iterator7.s(); !(_step7 = _iterator7.n()).done;) {
	            var input = _step7.value;
	            if (!nodeNameToOrder.has(input.name)) {
	              throw new NodesExecutionOrderError("Input ".concat(input.name, " of node ").concat(node.name, " is unreachable."));
	            }
	            if (nodeNameToOrder.get(input.name) > nodeNameToOrder.get(node.name)) {
	              throw new NodesExecutionOrderError("Node ".concat(node.name, " is scheduled to run before its input ").concat(input.name, "."));
	            }
	          }
	        } catch (err) {
	          _iterator7.e(err);
	        } finally {
	          _iterator7.f();
	        }
	      }
	    }
	  } catch (err) {
	    _iterator5.e(err);
	  } finally {
	    _iterator5.f();
	  }
	}
	/**
	 * Given the execution info, return a map from node name to the disposable
	 * node name list after its execution.
	 *
	 * @returns A map from node name to disposable nodes after its
	 *     execution. That is, for a node `x`, `nodeLiveUntilMap[x]` indicates
	 *     all nodes which their intermediate tensors should be disposed after `x`
	 *     being executed.
	 */
	function getNodeLiveUntilMap(orderedNodes) {
	  var nodeNameToOrder = new Map(orderedNodes.map(function (node, order) {
	    return [node.name, order];
	  }));
	  var INF_LIFE = Number.MAX_SAFE_INTEGER;
	  // Make control flow nodes (and consequently their direct parents)
	  // live forever since they're tricky to track correctly.
	  var selfLifespans = orderedNodes.map(function (node, nodeOrder) {
	    return isControlFlow(node) ? INF_LIFE : nodeOrder;
	  });
	  var getSelfLifeSpan = function getSelfLifeSpan(node) {
	    var selfLife = selfLifespans[nodeNameToOrder.get(node.name)];
	    if (selfLife == null) {
	      // If nodeToOrder does not contain the node, it is unused or
	      // unreachable in graph.
	      return -1;
	    }
	    return selfLife;
	  };
	  // `liveUntil[i]` points to the last node in the `orderedNodes` array that
	  // may depend on tensors from node `i`. It indicates that all the
	  // intermediate tensors from `orderedNodes[i]` should be disposed after
	  // `orderedNodes[liveUntil[i]]` is executed.
	  // A node lives long enough to pass on its tensors to its children.
	  // It lives until at least `max(node's position, children's positions)`.
	  var liveUntilOrders = orderedNodes.map(function (node, nodeOrder) {
	    return node.children.map(getSelfLifeSpan).reduce(function (a, b) {
	      return Math.max(a, b);
	    }, selfLifespans[nodeOrder]);
	  });
	  // liveUntilMap:
	  // - Key: Name of a node `x`
	  // - Values: All nodes whose intermediate tensors should be disposed
	  //           after `x` is executed.
	  var liveUntilMap = new Map();
	  for (var nodeOrder = 0; nodeOrder < orderedNodes.length; ++nodeOrder) {
	    var liveUntilOrder = liveUntilOrders[nodeOrder];
	    if (liveUntilOrder === INF_LIFE) {
	      continue;
	    }
	    var node = orderedNodes[nodeOrder];
	    var liveUntilNode = orderedNodes[liveUntilOrder];
	    if (!liveUntilMap.has(liveUntilNode.name)) {
	      liveUntilMap.set(liveUntilNode.name, []);
	    }
	    liveUntilMap.get(liveUntilNode.name).push(node);
	  }
	  return liveUntilMap;
	}
	var CONTROL_FLOW_OPS = new Set(['Switch', 'Merge', 'Enter', 'Exit', 'NextIteration', 'StatelessIf', 'StatelessWhile', 'if', 'While']);
	var DYNAMIC_SHAPE_OPS = new Set(['NonMaxSuppressionV2', 'NonMaxSuppressionV3', 'NonMaxSuppressionV5', 'Where']);
	var HASH_TABLE_OPS = new Set(['HashTable', 'HashTableV2', 'LookupTableImport', 'LookupTableImportV2', 'LookupTableFind', 'LookupTableFindV2', 'LookupTableSize', 'LookupTableSizeV2']);
	function isControlFlow(node) {
	  return CONTROL_FLOW_OPS.has(node.op);
	}
	function isDynamicShape(node) {
	  return DYNAMIC_SHAPE_OPS.has(node.op);
	}
	function isHashTable(node) {
	  return HASH_TABLE_OPS.has(node.op);
	}

	var GraphExecutor = /*#__PURE__*/function () {
	  /**
	   *
	   * @param graph Graph the model or function graph to be executed.
	   * @param parent When building function exector you need to set the parent
	   * executor. Since the weights and function executor maps are set at parant
	   * level, that function executor can access the function maps and weight maps
	   * through the parent.
	   */
	  function GraphExecutor(graph, parent) {
	    var _this = this;
	    _classCallCheck(this, GraphExecutor);
	    this.graph = graph;
	    this.parent = parent;
	    this.compiledMap = new Map();
	    this.parseNodeNameCache = new Map();
	    this._weightMap = {};
	    this.SEPARATOR = ',';
	    this._functions = {};
	    this._functionExecutorMap = {};
	    this.keepIntermediateTensors = false;
	    this._outputs = graph.outputs;
	    this._inputs = graph.inputs;
	    this._initNodes = graph.initNodes;
	    this._signature = graph.signature;
	    this._functions = graph.functions;
	    // create sub-graph executors
	    if (graph.functions != null) {
	      Object.keys(graph.functions).forEach(function (name) {
	        _this._functionExecutorMap[name] = new GraphExecutor(graph.functions[name], _this);
	      });
	    }
	  }
	  _createClass(GraphExecutor, [{
	    key: "weightIds",
	    get: function get() {
	      return this.parent ? this.parent.weightIds : this._weightIds;
	    }
	  }, {
	    key: "functionExecutorMap",
	    get: function get() {
	      return this.parent ? this.parent.functionExecutorMap : this._functionExecutorMap;
	    }
	  }, {
	    key: "weightMap",
	    get: function get() {
	      return this.parent ? this.parent.weightMap : this._weightMap;
	    },
	    set: function set(weightMap) {
	      var _ref;
	      var weightIds = Object.keys(weightMap).map(function (key) {
	        return weightMap[key].map(function (tensor) {
	          return tensor.id;
	        });
	      });
	      this._weightIds = (_ref = []).concat.apply(_ref, _toConsumableArray(weightIds));
	      this._weightMap = weightMap;
	    }
	    /**
	     * Set `ResourceManager` shared by executors of a model.
	     * @param resourceManager: `ResourceManager` of the `GraphModel`.
	     */
	  }, {
	    key: "resourceManager",
	    set: function set(resourceManager) {
	      this._resourceManager = resourceManager;
	    }
	  }, {
	    key: "inputs",
	    get: function get() {
	      return this._inputs.map(function (node) {
	        return {
	          name: node.name,
	          shape: node.attrParams['shape'] ? node.attrParams['shape'].value : undefined,
	          dtype: node.attrParams['dtype'] ? node.attrParams['dtype'].value : undefined
	        };
	      });
	    }
	  }, {
	    key: "outputs",
	    get: function get() {
	      return this._outputs.map(function (node) {
	        return {
	          name: node.name,
	          shape: node.attrParams['shape'] ? node.attrParams['shape'].value : undefined,
	          dtype: node.attrParams['dtype'] ? node.attrParams['dtype'].value : undefined
	        };
	      });
	    }
	  }, {
	    key: "inputNodes",
	    get: function get() {
	      return this._inputs.map(function (node) {
	        return node.signatureKey || node.name;
	      });
	    }
	  }, {
	    key: "outputNodes",
	    get: function get() {
	      return this._outputs.map(function (node) {
	        var name = node.signatureKey || node.name;
	        return node.defaultOutput ? "".concat(name, ":").concat(node.defaultOutput) : name;
	      });
	    }
	  }, {
	    key: "functions",
	    get: function get() {
	      var _this2 = this;
	      return Object.keys(this._functions).reduce(function (map, key) {
	        map[key] = _this2._functions[key].signature;
	        return map;
	      }, {});
	    }
	  }, {
	    key: "getCompilationKey",
	    value: function getCompilationKey(inputs, outputs) {
	      var sortedInputs = inputs.map(function (node) {
	        return node.name;
	      }).sort();
	      var sortedOutputs = outputs.map(function (node) {
	        return node.name;
	      }).sort();
	      return sortedInputs.join(this.SEPARATOR) + '--' + sortedOutputs.join(this.SEPARATOR);
	    }
	    /**
	     * Compiles the inference graph and returns the minimal set of nodes that are
	     * required for execution, in the correct execution order.
	     * @returns {Object} compilation The compile result.
	     * @returns {Node[]} compilation.orderedNodes Nodes in the correct execution
	     *     order.
	     * @returns {Map<string, Node[]>} compilation.nodeLiveUntilMap A map from node
	     *     to disposable nodes after its execution. That is, for a node `x`,
	     *     `nodeLiveUntilMap[x]` indicates all nodes whose intermediate
	     *     tensors should be disposed after `x` is executed.
	     */
	  }, {
	    key: "compile",
	    value: function compile(inputs, outputs) {
	      var executionInfo = getExecutionSubgraph(inputs, outputs, this.weightMap, this._initNodes);
	      var missingInputs = executionInfo.missingInputs,
	        dynamicNode = executionInfo.dynamicNode,
	        syncInputs = executionInfo.syncInputs;
	      if (dynamicNode != null) {
	        throw new Error("This execution contains the node '".concat(dynamicNode.name, "', which has ") + "the dynamic op '".concat(dynamicNode.op, "'. Please use ") + "model.executeAsync() instead. Alternatively, to avoid the " + "dynamic ops, specify the inputs [".concat(syncInputs, "]"));
	      }
	      if (missingInputs.length > 0) {
	        var outNames = outputs.map(function (n) {
	          return n.name;
	        });
	        var inNames = Object.keys(inputs);
	        throw new Error("Cannot compute the outputs [".concat(outNames, "] from the provided inputs ") + "[".concat(inNames, "]. Missing the following inputs: [").concat(missingInputs, "]"));
	      }
	      var orderedNodes = getNodesInTopologicalOrder(this.graph, executionInfo);
	      var nodeLiveUntilMap = getNodeLiveUntilMap(orderedNodes);
	      return {
	        orderedNodes: orderedNodes,
	        nodeLiveUntilMap: nodeLiveUntilMap
	      };
	    }
	  }, {
	    key: "cloneAndKeepTensor",
	    value: function cloneAndKeepTensor(tensor) {
	      if (tensor == null) {
	        return null;
	      }
	      var clone = tensor.clone();
	      // Keep the clone because`model.execute()` may be called within
	      // a `tidy()`, but the user may inspect these tensors after the
	      // tidy.
	      keep(clone);
	      return clone;
	    }
	  }, {
	    key: "cloneTensorList",
	    value: function cloneTensorList(tensors) {
	      var _this3 = this;
	      if (!tensors) {
	        return null;
	      }
	      var clonedTensor = tensors.map(function (tensor) {
	        return _this3.cloneAndKeepTensor(tensor);
	      });
	      return clonedTensor;
	    }
	  }, {
	    key: "cloneTensorMap",
	    value: function cloneTensorMap(tensorsMap) {
	      var _this4 = this;
	      return Object.fromEntries(Object.entries(tensorsMap).map(function (_ref2) {
	        var _ref3 = _slicedToArray(_ref2, 2),
	          name = _ref3[0],
	          tensorsList = _ref3[1];
	        return [name, _this4.cloneTensorList(tensorsList)];
	      }));
	    }
	    /**
	     * Executes the inference for given input tensors.
	     * @param inputs Tensor map for the model inputs, keyed by the input node
	     * names.
	     * @param outputs Optional. output node name from the Tensorflow model, if
	     * no outputs are specified, the default outputs of the model would be used.
	     * You can inspect intermediate nodes of the model by adding them to the
	     * outputs array.
	     */
	  }, {
	    key: "execute",
	    value: function execute(inputs, outputs) {
	      var _this5 = this;
	      // Dispose any tensors from a prior run to avoid leaking them.
	      this.disposeIntermediateTensors();
	      inputs = this.mapInputs(inputs);
	      var names = Object.keys(inputs).sort();
	      this.checkInputs(inputs);
	      this.checkInputShapeAndType(inputs);
	      outputs = this.mapOutputs(outputs);
	      this.checkOutputs(outputs);
	      var inputNodes = names.map(function (name) {
	        return _this5.graph.nodes[parseNodeName(name)[0]];
	      });
	      var outputNodeNames = outputs.map(function (name) {
	        return parseNodeName(name)[0];
	      });
	      var outputNodeNameSet = new Set(outputNodeNames);
	      var outputNodes = outputNodeNames.map(function (name) {
	        return _this5.graph.nodes[name];
	      });
	      // If no outputs are specified, then use the default outputs of the model.
	      if (outputNodes.length === 0) {
	        outputNodes = this._outputs;
	      }
	      var compilationKey = this.getCompilationKey(inputNodes, outputNodes);
	      // Do nothing if the compiled graph cache contains the input.
	      var compilation = this.compiledMap.get(compilationKey);
	      if (compilation == null) {
	        compilation = this.compile(inputs, outputNodes);
	        this.compiledMap.set(compilationKey, compilation);
	      }
	      // Keep tensors if KEEP_INTERMEDIATE_TENSORS is on.
	      try {
	        this.keepIntermediateTensors = env().getBool('KEEP_INTERMEDIATE_TENSORS');
	      } catch (e) {
	        this.keepIntermediateTensors = false;
	        console.warn(e.message);
	      }
	      var tensorArrayMap = {};
	      var tensorListMap = {};
	      return tidy(function () {
	        var context = new ExecutionContext(_this5.weightMap, tensorArrayMap, tensorListMap, _this5.functionExecutorMap, _this5.parseNodeNameCache);
	        var tensorsMap = Object.assign({}, _this5.weightMap);
	        if (_this5.keepIntermediateTensors) {
	          _this5.clonedTensorsMap = _this5.cloneTensorMap(_this5.weightMap);
	        }
	        Object.keys(inputs).forEach(function (name) {
	          var _parseNodeName = parseNodeName(name, context),
	            _parseNodeName2 = _slicedToArray(_parseNodeName, 2),
	            nodeName = _parseNodeName2[0],
	            index = _parseNodeName2[1];
	          var tensors = [];
	          tensors[index] = inputs[name];
	          tensorsMap[nodeName] = tensors;
	          if (_this5.keepIntermediateTensors) {
	            _this5.clonedTensorsMap[nodeName] = _this5.cloneTensorList(tensors);
	          }
	        });
	        var tensorsToKeep = _this5.getFrozenTensorIds(tensorsMap);
	        var _compilation = compilation,
	          orderedNodes = _compilation.orderedNodes,
	          nodeLiveUntilMap = _compilation.nodeLiveUntilMap;
	        var _iterator = _createForOfIteratorHelper(orderedNodes),
	          _step;
	        try {
	          for (_iterator.s(); !(_step = _iterator.n()).done;) {
	            var node = _step.value;
	            if (tensorsMap[node.name]) {
	              continue;
	            }
	            var tensors = executeOp(node, tensorsMap, context, _this5._resourceManager);
	            if (isPromise(tensors)) {
	              throw new Error("The execution of the op '".concat(node.op, "' returned a promise. ") + "Please use model.executeAsync() instead.");
	            }
	            tensorsMap[node.name] = tensors;
	            if (_this5.keepIntermediateTensors) {
	              _this5.clonedTensorsMap[node.name] = _this5.cloneTensorList(tensors);
	            }
	            _this5.checkTensorForDisposalWithNodeLiveUntilInfo(node, tensorsMap, context, tensorsToKeep, outputNodeNameSet, nodeLiveUntilMap.get(node.name));
	          }
	          // dispose the context for the root executor
	        } catch (err) {
	          _iterator.e(err);
	        } finally {
	          _iterator.f();
	        }
	        if (_this5.parent == null) {
	          context.dispose(tensorsToKeep);
	        }
	        return outputs.map(function (name) {
	          return getTensor(name, tensorsMap, context);
	        });
	      });
	    }
	  }, {
	    key: "getFrozenTensorIds",
	    value: function getFrozenTensorIds(tensorMap) {
	      var ids = [].concat.apply([], Object.keys(tensorMap).map(function (key) {
	        return tensorMap[key];
	      }).map(function (tensors) {
	        return tensors.map(function (tensor) {
	          return tensor.id;
	        });
	      }));
	      return new Set(ids);
	    }
	  }, {
	    key: "checkTensorForDisposal",
	    value: function checkTensorForDisposal(nodeName, node, tensorMap, context, tensorsToKeep, outputNodeNameSet, intermediateTensorConsumerCount) {
	      // Skip output nodes and any control flow nodes, since its dependency is
	      // tricky to track correctly.
	      if (isControlFlow(node) || outputNodeNameSet.has(nodeName)) {
	        return;
	      }
	      var _iterator2 = _createForOfIteratorHelper(tensorMap[nodeName]),
	        _step2;
	      try {
	        for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	          var tensor = _step2.value;
	          if (tensor == null) {
	            continue;
	          }
	          intermediateTensorConsumerCount[tensor.id] = (intermediateTensorConsumerCount[tensor.id] || 0) + node.children.length;
	        }
	      } catch (err) {
	        _iterator2.e(err);
	      } finally {
	        _iterator2.f();
	      }
	      var _iterator3 = _createForOfIteratorHelper(node.inputs),
	        _step3;
	      try {
	        for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
	          var input = _step3.value;
	          // Skip any control flow nodes, since its dependency is tricky to track
	          // correctly.
	          if (isControlFlow(input)) {
	            continue;
	          }
	          var tensors = getTensorsForCurrentContext(input.name, tensorMap, context);
	          if (tensors == null) {
	            continue;
	          }
	          var _iterator4 = _createForOfIteratorHelper(tensors),
	            _step4;
	          try {
	            for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
	              var _tensor = _step4.value;
	              if (!_tensor || _tensor.kept || tensorsToKeep.has(_tensor.id)) {
	                continue;
	              }
	              // Only intermediate nodes' tensors have counts set, not marked as
	              // kept, and not in `tensorsToKeep`.
	              // Input and weight nodes' tensors should exist in `tensorsToKeep`.
	              // Output and control flow nodes' tensors should never have count set.
	              var count = intermediateTensorConsumerCount[_tensor.id];
	              if (count === 1) {
	                _tensor.dispose();
	                delete intermediateTensorConsumerCount[_tensor.id];
	              } else if (count != null) {
	                intermediateTensorConsumerCount[_tensor.id]--;
	              }
	            }
	          } catch (err) {
	            _iterator4.e(err);
	          } finally {
	            _iterator4.f();
	          }
	        }
	      } catch (err) {
	        _iterator3.e(err);
	      } finally {
	        _iterator3.f();
	      }
	    }
	  }, {
	    key: "checkTensorForDisposalWithNodeLiveUntilInfo",
	    value: function checkTensorForDisposalWithNodeLiveUntilInfo(node, tensorMap, context, tensorsToKeep, outputNodeNameSet, liveUntilNodes) {
	      function isNonDisposableNode(node) {
	        // Skip output nodes and any control flow nodes, since its dependency is
	        // tricky to track correctly.
	        return isControlFlow(node) || outputNodeNameSet.has(node.name);
	      }
	      if (isControlFlow(node) || liveUntilNodes == null) {
	        return;
	      }
	      var _iterator5 = _createForOfIteratorHelper(liveUntilNodes),
	        _step5;
	      try {
	        for (_iterator5.s(); !(_step5 = _iterator5.n()).done;) {
	          var nodeToDispose = _step5.value;
	          if (isNonDisposableNode(nodeToDispose)) {
	            continue;
	          }
	          var tensors = getTensorsForCurrentContext(nodeToDispose.name, tensorMap, context);
	          var _iterator6 = _createForOfIteratorHelper(tensors),
	            _step6;
	          try {
	            for (_iterator6.s(); !(_step6 = _iterator6.n()).done;) {
	              var tensor = _step6.value;
	              if (!tensor || tensor.kept || tensorsToKeep.has(tensor.id)) {
	                continue;
	              }
	              tensor.dispose();
	            }
	          } catch (err) {
	            _iterator6.e(err);
	          } finally {
	            _iterator6.f();
	          }
	        }
	      } catch (err) {
	        _iterator5.e(err);
	      } finally {
	        _iterator5.f();
	      }
	    }
	    /**
	     * Executes the inference for given input tensors in Async fashion.
	     * @param inputs Tensor map for the model inputs, keyed by the input node
	     * names.
	     * @param outputs output node name from the Tensorflow model, if no outputs
	     * are specified, the default outputs of the model would be used. You can
	     * inspect intermediate nodes of the model by adding them to the outputs
	     * array.
	     */
	  }, {
	    key: "executeAsync",
	    value: function () {
	      var _executeAsync2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(inputs, outputs) {
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              return _context.abrupt("return", this._executeAsync(inputs, outputs));
	            case 1:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function executeAsync(_x, _x2) {
	        return _executeAsync2.apply(this, arguments);
	      }
	      return executeAsync;
	    }()
	  }, {
	    key: "disposeIntermediateTensors",
	    value: function disposeIntermediateTensors() {
	      if (!this.clonedTensorsMap) {
	        return;
	      }
	      Object.values(this.clonedTensorsMap).forEach(function (tensorsList) {
	        var _iterator7 = _createForOfIteratorHelper(tensorsList),
	          _step7;
	        try {
	          for (_iterator7.s(); !(_step7 = _iterator7.n()).done;) {
	            var tensor = _step7.value;
	            if (tensor && !tensor.isDisposed) {
	              tensor.dispose();
	            }
	          }
	        } catch (err) {
	          _iterator7.e(err);
	        } finally {
	          _iterator7.f();
	        }
	      });
	      this.clonedTensorsMap = null;
	    }
	  }, {
	    key: "getIntermediateTensors",
	    value: function getIntermediateTensors() {
	      return this.clonedTensorsMap;
	    }
	    /**
	     * Executes the inference for given input tensors in Async fashion.
	     * @param inputs Tensor map for the model inputs, keyed by the input node
	     * names.
	     * @param outputs Optional. output node name from the Tensorflow model,
	     * if no outputs are specified, the default outputs of the model would be
	     * used. You can inspect intermediate nodes of the model by adding them to
	     * the outputs array.
	     * @param isFunctionExecution Optional. Flag for executing a function.
	     * @param tensorArrayMap Optional, global TensorArray map by id. Used for
	     * function execution.
	     * @param tensorArrayMap Optional global TensorList map by id. Used for
	     * function execution.
	     */
	  }, {
	    key: "_executeAsync",
	    value: function () {
	      var _executeAsync3 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(inputs, outputs) {
	        var isFunctionExecution,
	          tensorArrayMap,
	          tensorListMap,
	          context,
	          tensorsMap,
	          results,
	          outputIds,
	          inputIds,
	          keepIds,
	          _args2 = arguments;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              isFunctionExecution = _args2.length > 2 && _args2[2] !== undefined ? _args2[2] : false;
	              tensorArrayMap = _args2.length > 3 && _args2[3] !== undefined ? _args2[3] : {};
	              tensorListMap = _args2.length > 4 && _args2[4] !== undefined ? _args2[4] : {};
	              // Dispose any tensors from a prior run to avoid leaking them.
	              this.disposeIntermediateTensors();
	              if (!isFunctionExecution) {
	                inputs = this.mapInputs(inputs);
	                this.checkInputs(inputs);
	                this.checkInputShapeAndType(inputs);
	                outputs = this.mapOutputs(outputs);
	                this.checkOutputs(outputs);
	              }
	              // Keep tensors if KEEP_INTERMEDIATE_TENSORS is on.
	              try {
	                this.keepIntermediateTensors = env().getBool('KEEP_INTERMEDIATE_TENSORS');
	              } catch (e) {
	                this.keepIntermediateTensors = false;
	                console.warn(e.message);
	              }
	              context = new ExecutionContext(this.weightMap, tensorArrayMap, tensorListMap, this.functionExecutorMap, this.parseNodeNameCache);
	              if (this.keepIntermediateTensors) {
	                this.clonedTensorsMap = this.cloneTensorMap(this.weightMap);
	              }
	              // Graph with control flow op requires runtime evaluation of the execution
	              // order, while without control flow the execution order is pre-determined
	              // in the compile method.
	              _context2.next = 10;
	              return this.executeWithControlFlow(inputs, context, outputs, isFunctionExecution);
	            case 10:
	              tensorsMap = _context2.sent;
	              results = outputs.map(function (name) {
	                return getTensor(name, tensorsMap, context);
	              }); // dispose all the intermediate tensors
	              outputIds = results.map(function (t) {
	                return t.id;
	              });
	              inputIds = Object.keys(inputs).map(function (name) {
	                return inputs[name].id;
	              });
	              keepIds = new Set([].concat(_toConsumableArray(outputIds), _toConsumableArray(inputIds), _toConsumableArray(this.weightIds)));
	              Object.values(tensorsMap).forEach(function (tensorsList) {
	                tensorsList.forEach(function (tensor) {
	                  if (tensor && !tensor.isDisposed && !keepIds.has(tensor.id)) {
	                    tensor.dispose();
	                  }
	                });
	              });
	              // dispose the context for the root executor
	              if (this.parent == null) {
	                context.dispose(keepIds);
	              }
	              return _context2.abrupt("return", results);
	            case 18:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function _executeAsync(_x3, _x4) {
	        return _executeAsync3.apply(this, arguments);
	      }
	      return _executeAsync;
	    }()
	  }, {
	    key: "executeFunctionAsync",
	    value: function () {
	      var _executeFunctionAsync = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3(inputs, tensorArrayMap, tensorListMap) {
	        var _this6 = this;
	        var mappedInputs;
	        return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	          while (1) switch (_context3.prev = _context3.next) {
	            case 0:
	              mappedInputs = inputs.reduce(function (map, tensor, index) {
	                map[_this6.inputs[index].name] = tensor;
	                return map;
	              }, {});
	              return _context3.abrupt("return", this._executeAsync(mappedInputs, this.outputNodes, true, tensorArrayMap, tensorListMap));
	            case 2:
	            case "end":
	              return _context3.stop();
	          }
	        }, _callee3, this);
	      }));
	      function executeFunctionAsync(_x5, _x6, _x7) {
	        return _executeFunctionAsync.apply(this, arguments);
	      }
	      return executeFunctionAsync;
	    }()
	    /**
	     * When there are control flow nodes in the graph, the graph execution use
	     * ExecutionContext to keep track of the frames and loop iterators.
	     * @param inputs placeholder tensors for the graph.
	     * @param context the execution context object for current execution.
	     * @param outputNames Optional. output node name from the Tensorflow model,
	     * if no outputs are specified, the default outputs of the model would be
	     * used. You can inspect intermediate nodes of the model by adding them to
	     * the outputs array.
	     * @param isFunctionExecution Flag for executing a function.
	     */
	  }, {
	    key: "executeWithControlFlow",
	    value: function () {
	      var _executeWithControlFlow = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4(inputs, context, outputNames, isFunctionExecution) {
	        var _this7 = this;
	        var names, inputNodes, outputNodeNames, outputNodeNameSet, outputNodes, _getExecutionSubgraph, usedNodes, missingInputs, dynamicNode, syncInputs, stack, tensorsMap, intermediateTensorConsumerCount, tensorsToKeep, added, promises, missingOutputs, alternativeMsg;
	        return _regeneratorRuntime().wrap(function _callee4$(_context4) {
	          while (1) switch (_context4.prev = _context4.next) {
	            case 0:
	              names = Object.keys(inputs);
	              inputNodes = names.map(function (name) {
	                return _this7.graph.nodes[parseNodeName(name)[0]];
	              });
	              outputNodeNames = outputNames.map(function (name) {
	                return parseNodeName(name)[0];
	              });
	              outputNodeNameSet = new Set(outputNodeNames);
	              outputNodes = outputNodeNames.map(function (name) {
	                return _this7.graph.nodes[name];
	              }); // If no outputs are specified, then use the default outputs of the model.
	              if (outputNodes.length === 0) {
	                outputNodes = this._outputs;
	              }
	              _getExecutionSubgraph = getExecutionSubgraph(inputs, outputNodes, this.weightMap, this._initNodes), usedNodes = _getExecutionSubgraph.usedNodes, missingInputs = _getExecutionSubgraph.missingInputs, dynamicNode = _getExecutionSubgraph.dynamicNode, syncInputs = _getExecutionSubgraph.syncInputs; // First nodes to execute include inputNodes, weights, and initNodes.
	              stack = [].concat(_toConsumableArray(inputNodes), _toConsumableArray(this.graph.weights), _toConsumableArray(this._initNodes || [])).map(function (node) {
	                return {
	                  node: node,
	                  contexts: context.currentContext
	                };
	              });
	              tensorsMap = Object.assign({}, this.weightMap);
	              Object.keys(inputs).forEach(function (name) {
	                var _parseNodeName3 = parseNodeName(name),
	                  _parseNodeName4 = _slicedToArray(_parseNodeName3, 2),
	                  nodeName = _parseNodeName4[0],
	                  index = _parseNodeName4[1];
	                var tensors = [];
	                tensors[index] = inputs[name];
	                tensorsMap[nodeName] = tensors;
	              });
	              intermediateTensorConsumerCount = {};
	              tensorsToKeep = this.getFrozenTensorIds(tensorsMap);
	              added = {};
	            case 13:
	              if (!(stack.length > 0)) {
	                _context4.next = 19;
	                break;
	              }
	              promises = this.processStack(inputNodes, stack, context, tensorsMap, added, tensorsToKeep, outputNodeNameSet, intermediateTensorConsumerCount, usedNodes);
	              _context4.next = 17;
	              return Promise.all(promises);
	            case 17:
	              _context4.next = 13;
	              break;
	            case 19:
	              if (dynamicNode == null && !isFunctionExecution) {
	                console.warn("This model execution did not contain any nodes with control flow " + "or dynamic output shapes. You can use model.execute() instead.");
	              }
	              missingOutputs = outputNodes.filter(function (node) {
	                return !isControlFlow(node) && !getTensor(node.name, tensorsMap, context);
	              }).map(function (node) {
	                return node.name;
	              });
	              if (!(missingOutputs.length > 0)) {
	                _context4.next = 25;
	                break;
	              }
	              alternativeMsg = '';
	              if (dynamicNode != null) {
	                alternativeMsg = "Alternatively, to avoid the dynamic ops, use model.execute() " + "and specify the inputs [".concat(syncInputs, "]");
	              }
	              throw new Error("Cannot compute the outputs [".concat(missingOutputs, "] from the provided ") + "inputs [".concat(names, "]. Consider providing the following inputs: ") + "[".concat(missingInputs, "]. ").concat(alternativeMsg));
	            case 25:
	              return _context4.abrupt("return", tensorsMap);
	            case 26:
	            case "end":
	              return _context4.stop();
	          }
	        }, _callee4, this);
	      }));
	      function executeWithControlFlow(_x8, _x9, _x10, _x11) {
	        return _executeWithControlFlow.apply(this, arguments);
	      }
	      return executeWithControlFlow;
	    }()
	  }, {
	    key: "processStack",
	    value: function processStack(inputNodes, stack, context, tensorMap, added, tensorsToKeep, outputNodeNameSet, intermediateTensorConsumerCount, usedNodes) {
	      var _this8 = this;
	      var promises = [];
	      var _loop = function _loop() {
	        var item = stack.pop();
	        context.currentContext = item.contexts;
	        var nodeName = '';
	        // The tensor of the Enter op with isConstant set should be set
	        // in the parent scope, so it will be available as constant for the
	        // whole loop.
	        if (item.node.op === 'Enter' && getParamValue('isConstant', item.node, tensorMap, context)) {
	          var _getNodeNameAndIndex = getNodeNameAndIndex(item.node.name, context);
	          var _getNodeNameAndIndex2 = _slicedToArray(_getNodeNameAndIndex, 1);
	          nodeName = _getNodeNameAndIndex2[0];
	        }
	        // only process nodes that are not in the tensorMap yet, this include
	        // inputNodes and internal initNodes.
	        if (tensorMap[item.node.name] == null) {
	          var tensors = executeOp(item.node, tensorMap, context, _this8._resourceManager);
	          if (!nodeName) {
	            var _getNodeNameAndIndex3 = getNodeNameAndIndex(item.node.name, context);
	            var _getNodeNameAndIndex4 = _slicedToArray(_getNodeNameAndIndex3, 1);
	            nodeName = _getNodeNameAndIndex4[0];
	          }
	          var currentContext = context.currentContext;
	          if (isPromise(tensors)) {
	            promises.push(tensors.then(function (t) {
	              tensorMap[nodeName] = t;
	              if (_this8.keepIntermediateTensors) {
	                _this8.clonedTensorsMap[nodeName] = _this8.cloneTensorList(t);
	              }
	              context.currentContext = currentContext;
	              _this8.checkTensorForDisposal(nodeName, item.node, tensorMap, context, tensorsToKeep, outputNodeNameSet, intermediateTensorConsumerCount);
	              _this8.processChildNodes(item.node, stack, context, tensorMap, added, usedNodes);
	              return t;
	            }));
	          } else {
	            tensorMap[nodeName] = tensors;
	            if (_this8.keepIntermediateTensors) {
	              _this8.clonedTensorsMap[nodeName] = _this8.cloneTensorList(tensors);
	            }
	            _this8.checkTensorForDisposal(nodeName, item.node, tensorMap, context, tensorsToKeep, outputNodeNameSet, intermediateTensorConsumerCount);
	            _this8.processChildNodes(item.node, stack, context, tensorMap, added, usedNodes);
	          }
	        } else {
	          _this8.processChildNodes(item.node, stack, context, tensorMap, added, usedNodes);
	        }
	      };
	      while (stack.length > 0) {
	        _loop();
	      }
	      return promises;
	    }
	  }, {
	    key: "processChildNodes",
	    value: function processChildNodes(node, stack, context, tensorMap, added, usedNodes) {
	      node.children.forEach(function (childNode) {
	        var _getNodeNameAndIndex5 = getNodeNameAndIndex(childNode.name, context),
	          _getNodeNameAndIndex6 = _slicedToArray(_getNodeNameAndIndex5, 1),
	          nodeName = _getNodeNameAndIndex6[0];
	        if (added[nodeName] || !usedNodes.has(childNode.name)) {
	          return;
	        }
	        // Merge op can be pushed if any of its inputs has value.
	        if (childNode.op === 'Merge') {
	          if (childNode.inputNames.some(function (name) {
	            return !!getTensor(name, tensorMap, context);
	          })) {
	            added[nodeName] = true;
	            stack.push({
	              contexts: context.currentContext,
	              node: childNode
	            });
	          }
	        } else
	          // Otherwise all inputs must to have value.
	          if (childNode.inputNames.every(function (name) {
	            return !!getTensor(name, tensorMap, context);
	          })) {
	            added[nodeName] = true;
	            stack.push({
	              contexts: context.currentContext,
	              node: childNode
	            });
	          }
	      });
	    }
	    /**
	     * Releases the memory used by the weight tensors.
	     */
	  }, {
	    key: "dispose",
	    value: function dispose() {
	      var _this9 = this;
	      Object.keys(this.weightMap).forEach(function (key) {
	        return _this9.weightMap[key].forEach(function (tensor) {
	          return tensor.dispose();
	        });
	      });
	    }
	  }, {
	    key: "checkInputShapeAndType",
	    value: function checkInputShapeAndType(inputs) {
	      var _this10 = this;
	      Object.keys(inputs).forEach(function (name) {
	        var input = inputs[name];
	        var _parseNodeName5 = parseNodeName(name),
	          _parseNodeName6 = _slicedToArray(_parseNodeName5, 1),
	          nodeName = _parseNodeName6[0];
	        var node = _this10.graph.nodes[nodeName];
	        if (node.attrParams['shape'] && node.attrParams['shape'].value) {
	          var shape = node.attrParams['shape'].value;
	          var match = shape.length === input.shape.length && input.shape.every(function (dim, index) {
	            return shape[index] === -1 || shape[index] === dim;
	          });
	          assert$1(match, function () {
	            return "The shape of dict['".concat(node.name, "'] provided in ") + "model.execute(dict) must be [".concat(shape, "], but was ") + "[".concat(input.shape, "]");
	          });
	        }
	        if (node.attrParams['dtype'] && node.attrParams['dtype'].value) {
	          assert$1(input.dtype === node.attrParams['dtype'].value, function () {
	            return "The dtype of dict['".concat(node.name, "'] provided in ") + "model.execute(dict) must be " + "".concat(node.attrParams['dtype'].value, ", but was ").concat(input.dtype);
	          });
	        }
	      });
	    }
	  }, {
	    key: "mapInputs",
	    value: function mapInputs(inputs) {
	      var _a, _b;
	      var result = {};
	      for (var inputName in inputs) {
	        var tensor = (_b = (_a = this._signature) === null || _a === void 0 ? void 0 : _a.inputs) === null || _b === void 0 ? void 0 : _b[inputName];
	        if (tensor != null) {
	          result[tensor.name] = inputs[inputName];
	        } else {
	          result[inputName] = inputs[inputName];
	        }
	      }
	      return result;
	    }
	  }, {
	    key: "checkInputs",
	    value: function checkInputs(inputs) {
	      var _this11 = this;
	      var notInGraph = Object.keys(inputs).filter(function (name) {
	        var _parseNodeName7 = parseNodeName(name),
	          _parseNodeName8 = _slicedToArray(_parseNodeName7, 1),
	          nodeName = _parseNodeName8[0];
	        return _this11.graph.nodes[nodeName] == null;
	      });
	      if (notInGraph.length > 0) {
	        throw new Error("The dict provided in model.execute(dict) has " + "keys: [".concat(notInGraph, "] that are not part of graph"));
	      }
	    }
	  }, {
	    key: "mapOutputs",
	    value: function mapOutputs(outputs) {
	      var _this12 = this;
	      return outputs.map(function (name) {
	        var _a, _b;
	        var tensor = (_b = (_a = _this12._signature) === null || _a === void 0 ? void 0 : _a.outputs) === null || _b === void 0 ? void 0 : _b[name];
	        if (tensor != null) {
	          return tensor.name;
	        }
	        return name;
	      }, {});
	    }
	  }, {
	    key: "checkOutputs",
	    value: function checkOutputs(outputs) {
	      var _this13 = this;
	      outputs.forEach(function (name) {
	        var _parseNodeName9 = parseNodeName(name),
	          _parseNodeName10 = _slicedToArray(_parseNodeName9, 1),
	          normalizedName = _parseNodeName10[0];
	        if (!_this13.graph.nodes[normalizedName]) {
	          throw new Error("The output '".concat(name, "' is not found in the graph"));
	        }
	      });
	    }
	  }]);
	  return GraphExecutor;
	}();

	/**
	 * Contains global resources of a model.
	 */
	var ResourceManager = /*#__PURE__*/function () {
	  function ResourceManager() {
	    var hashTableNameToHandle = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
	    var hashTableMap = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	    _classCallCheck(this, ResourceManager);
	    this.hashTableNameToHandle = hashTableNameToHandle;
	    this.hashTableMap = hashTableMap;
	  }
	  /**
	   * Register a `HashTable` in the resource manager.
	   *
	   * The `HashTable` can be retrieved by `resourceManager.getHashTableById`,
	   * where id is the table handle tensor's id.
	   *
	   * @param name Op node name that creates the `HashTable`.
	   * @param hashTable The `HashTable` to be added to resource manager.
	   */
	  _createClass(ResourceManager, [{
	    key: "addHashTable",
	    value: function addHashTable(name, hashTable) {
	      this.hashTableNameToHandle[name] = hashTable.handle;
	      this.hashTableMap[hashTable.id] = hashTable;
	    }
	    /**
	     * Get the table handle by node name.
	     * @param name Op node name that creates the `HashTable`. This name is also
	     *     used in the inputs list of lookup and import `HashTable` ops.
	     */
	  }, {
	    key: "getHashTableHandleByName",
	    value: function getHashTableHandleByName(name) {
	      return this.hashTableNameToHandle[name];
	    }
	    /**
	     * Get the actual `HashTable` by its handle tensor's id.
	     * @param id The id of the handle tensor.
	     */
	  }, {
	    key: "getHashTableById",
	    value: function getHashTableById(id) {
	      return this.hashTableMap[id];
	    }
	    /**
	     * Dispose `ResourceManager`, including its hashTables and tensors in them.
	     */
	  }, {
	    key: "dispose",
	    value: function dispose() {
	      for (var key in this.hashTableMap) {
	        this.hashTableMap[key].clearAndClose();
	        delete this.hashTableMap[key];
	      }
	      for (var name in this.hashTableNameToHandle) {
	        this.hashTableNameToHandle[name].dispose();
	        delete this.hashTableNameToHandle[name];
	      }
	    }
	  }]);
	  return ResourceManager;
	}();

	var TFHUB_SEARCH_PARAM = '?tfjs-format=file';
	var DEFAULT_MODEL_NAME = 'model.json';
	/**
	 * A `tf.GraphModel` is a directed, acyclic graph built from a
	 * SavedModel GraphDef and allows inference execution.
	 *
	 * A `tf.GraphModel` can only be created by loading from a model converted from
	 * a [TensorFlow SavedModel](https://www.tensorflow.org/guide/saved_model) using
	 * the command line converter tool and loaded via `tf.loadGraphModel`.
	 *
	 * @doc {heading: 'Models', subheading: 'Classes'}
	 */
	var GraphModel = /*#__PURE__*/function () {
	  /**
	   * @param modelUrl url for the model, or an `io.IOHandler`.
	   * @param weightManifestUrl url for the weight file generated by
	   * scripts/convert.py script.
	   * @param requestOption options for Request, which allows to send credentials
	   * and custom headers.
	   * @param onProgress Optional, progress callback function, fired periodically
	   * before the load is completed.
	   */
	  function GraphModel(modelUrl) {
	    var loadOptions = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	    var tfio = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : io;
	    _classCallCheck(this, GraphModel);
	    this.modelUrl = modelUrl;
	    this.loadOptions = loadOptions;
	    this.version = 'n/a';
	    this.io = tfio;
	    if (loadOptions == null) {
	      this.loadOptions = {};
	    }
	    this.resourceManager = new ResourceManager();
	  }
	  _createClass(GraphModel, [{
	    key: "modelVersion",
	    get:
	    // Returns the version information for the tensorflow model GraphDef.
	    function get() {
	      return this.version;
	    }
	  }, {
	    key: "inputNodes",
	    get: function get() {
	      return this.executor.inputNodes;
	    }
	  }, {
	    key: "outputNodes",
	    get: function get() {
	      return this.executor.outputNodes;
	    }
	  }, {
	    key: "inputs",
	    get: function get() {
	      return this.executor.inputs;
	    }
	  }, {
	    key: "outputs",
	    get: function get() {
	      return this.executor.outputs;
	    }
	  }, {
	    key: "weights",
	    get: function get() {
	      return this.executor.weightMap;
	    }
	  }, {
	    key: "metadata",
	    get: function get() {
	      return this.artifacts.userDefinedMetadata;
	    }
	  }, {
	    key: "modelSignature",
	    get: function get() {
	      return this.signature;
	    }
	  }, {
	    key: "modelStructuredOutputKeys",
	    get: function get() {
	      return this.structuredOutputKeys;
	    }
	  }, {
	    key: "findIOHandler",
	    value: function findIOHandler() {
	      var path = this.modelUrl;
	      if (path.load != null) {
	        // Path is an IO Handler.
	        this.handler = path;
	      } else if (this.loadOptions.requestInit != null) {
	        this.handler = this.io.browserHTTPRequest(path, this.loadOptions);
	      } else {
	        var handlers = this.io.getLoadHandlers(path, this.loadOptions);
	        if (handlers.length === 0) {
	          // For backward compatibility: if no load handler can be found,
	          // assume it is a relative http path.
	          handlers.push(this.io.browserHTTPRequest(path, this.loadOptions));
	        } else if (handlers.length > 1) {
	          throw new Error("Found more than one (".concat(handlers.length, ") load handlers for ") + "URL '".concat([path], "'"));
	        }
	        this.handler = handlers[0];
	      }
	    }
	    /**
	     * Loads the model and weight files, construct the in memory weight map and
	     * compile the inference graph.
	     */
	  }, {
	    key: "load",
	    value: function load() {
	      var _this = this;
	      this.findIOHandler();
	      if (this.handler.load == null) {
	        throw new Error('Cannot proceed with model loading because the IOHandler provided ' + 'does not have the `load` method implemented.');
	      }
	      var loadResult = this.handler.load();
	      if (isPromise(loadResult)) {
	        return loadResult.then(function (artifacts) {
	          if (artifacts.getWeightStream == null) {
	            return _this.loadSync(artifacts);
	          }
	          return _this.loadStreaming(artifacts);
	        });
	      }
	      return this.loadSync(loadResult);
	    }
	    /**
	     * Synchronously construct the in memory weight map and
	     * compile the inference graph.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes', ignoreCI: true}
	     */
	  }, {
	    key: "loadSync",
	    value: function loadSync(artifacts) {
	      var weightMap = this.io.decodeWeights(artifacts.weightData, artifacts.weightSpecs);
	      return this.loadWithWeightMap(artifacts, weightMap);
	    }
	  }, {
	    key: "loadStreaming",
	    value: function () {
	      var _loadStreaming = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(artifacts) {
	        var weightMap;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              if (!(artifacts.getWeightStream == null)) {
	                _context.next = 2;
	                break;
	              }
	              throw new Error('Model artifacts missing streamWeights function');
	            case 2:
	              _context.next = 4;
	              return decodeWeightsStream(artifacts.getWeightStream(), artifacts.weightSpecs);
	            case 4:
	              weightMap = _context.sent;
	              return _context.abrupt("return", this.loadWithWeightMap(artifacts, weightMap));
	            case 6:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function loadStreaming(_x) {
	        return _loadStreaming.apply(this, arguments);
	      }
	      return loadStreaming;
	    }()
	  }, {
	    key: "loadWithWeightMap",
	    value: function loadWithWeightMap(artifacts, weightMap) {
	      this.artifacts = artifacts;
	      var graph = this.artifacts.modelTopology;
	      var signature = this.artifacts.signature;
	      if (this.artifacts.userDefinedMetadata != null) {
	        var metadata = this.artifacts.userDefinedMetadata;
	        if (metadata.signature != null) {
	          signature = metadata.signature;
	        }
	        if (metadata.structuredOutputKeys != null) {
	          this.structuredOutputKeys = metadata.structuredOutputKeys;
	        }
	      }
	      this.signature = signature;
	      this.version = "".concat(graph.versions.producer, ".").concat(graph.versions.minConsumer);
	      this.executor = new GraphExecutor(OperationMapper.Instance.transformGraph(graph, this.signature));
	      this.executor.weightMap = this.convertTensorMapToTensorsMap(weightMap);
	      // Attach a model-level resourceManager to each executor to share resources,
	      // such as `HashTable`.
	      this.executor.resourceManager = this.resourceManager;
	      if (artifacts.modelInitializer != null && artifacts.modelInitializer.node != null) {
	        var initializer = OperationMapper.Instance.transformGraph(artifacts.modelInitializer);
	        this.initializer = new GraphExecutor(initializer);
	        this.initializer.weightMap = this.executor.weightMap;
	        // Attach a model-level resourceManager to the initializer, the
	        // hashTables created from when executing the initializer will be stored
	        // in the resourceManager.
	        this.initializer.resourceManager = this.resourceManager;
	        this.initializerSignature = artifacts.initializerSignature;
	      }
	      return true;
	    }
	    /**
	     * Save the configuration and/or weights of the GraphModel.
	     *
	     * An `IOHandler` is an object that has a `save` method of the proper
	     * signature defined. The `save` method manages the storing or
	     * transmission of serialized data ("artifacts") that represent the
	     * model's topology and weights onto or via a specific medium, such as
	     * file downloads, local storage, IndexedDB in the web browser and HTTP
	     * requests to a server. TensorFlow.js provides `IOHandler`
	     * implementations for a number of frequently used saving mediums, such as
	     * `tf.io.browserDownloads` and `tf.io.browserLocalStorage`. See `tf.io`
	     * for more details.
	     *
	     * This method also allows you to refer to certain types of `IOHandler`s
	     * as URL-like string shortcuts, such as 'localstorage://' and
	     * 'indexeddb://'.
	     *
	     * Example 1: Save `model`'s topology and weights to browser [local
	     * storage](https://developer.mozilla.org/en-US/docs/Web/API/Window/localStorage);
	     * then load it back.
	     *
	     * ```js
	     * const modelUrl =
	     *    'https://storage.googleapis.com/tfjs-models/savedmodel/mobilenet_v2_1.0_224/model.json';
	     * const model = await tf.loadGraphModel(modelUrl);
	     * const zeros = tf.zeros([1, 224, 224, 3]);
	     * model.predict(zeros).print();
	     *
	     * const saveResults = await model.save('localstorage://my-model-1');
	     *
	     * const loadedModel = await tf.loadGraphModel('localstorage://my-model-1');
	     * console.log('Prediction from loaded model:');
	     * model.predict(zeros).print();
	     * ```
	     *
	     * @param handlerOrURL An instance of `IOHandler` or a URL-like,
	     * scheme-based string shortcut for `IOHandler`.
	     * @param config Options for saving the model.
	     * @returns A `Promise` of `SaveResult`, which summarizes the result of
	     * the saving, such as byte sizes of the saved artifacts for the model's
	     *   topology and weight values.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes', ignoreCI: true}
	     */
	  }, {
	    key: "save",
	    value: function () {
	      var _save = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(handlerOrURL, config) {
	        var handlers;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              if (!(typeof handlerOrURL === 'string')) {
	                _context2.next = 9;
	                break;
	              }
	              handlers = this.io.getSaveHandlers(handlerOrURL);
	              if (!(handlers.length === 0)) {
	                _context2.next = 6;
	                break;
	              }
	              throw new Error("Cannot find any save handlers for URL '".concat(handlerOrURL, "'"));
	            case 6:
	              if (!(handlers.length > 1)) {
	                _context2.next = 8;
	                break;
	              }
	              throw new Error("Found more than one (".concat(handlers.length, ") save handlers for ") + "URL '".concat(handlerOrURL, "'"));
	            case 8:
	              handlerOrURL = handlers[0];
	            case 9:
	              if (!(handlerOrURL.save == null)) {
	                _context2.next = 11;
	                break;
	              }
	              throw new Error('GraphModel.save() cannot proceed because the IOHandler ' + 'provided does not have the `save` attribute defined.');
	            case 11:
	              return _context2.abrupt("return", handlerOrURL.save(this.artifacts));
	            case 12:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function save(_x2, _x3) {
	        return _save.apply(this, arguments);
	      }
	      return save;
	    }()
	  }, {
	    key: "addStructuredOutputNames",
	    value: function addStructuredOutputNames(outputTensors) {
	      var _this2 = this;
	      if (this.structuredOutputKeys) {
	        var outputTensorsArray = outputTensors instanceof Tensor ? [outputTensors] : outputTensors;
	        var outputTensorMap = {};
	        outputTensorsArray.forEach(function (outputTensor, i) {
	          return outputTensorMap[_this2.structuredOutputKeys[i]] = outputTensor;
	        });
	        return outputTensorMap;
	      }
	      return outputTensors;
	    }
	    /**
	     * Execute the inference for the input tensors.
	     *
	     * @param input The input tensors, when there is single input for the model,
	     * inputs param should be a `tf.Tensor`. For models with multiple inputs,
	     * inputs params should be in either `tf.Tensor`[] if the input order is
	     * fixed, or otherwise NamedTensorMap format.
	     *
	     * For model with multiple inputs, we recommend you use NamedTensorMap as the
	     * input type, if you use `tf.Tensor`[], the order of the array needs to
	     * follow the
	     * order of inputNodes array. @see {@link GraphModel.inputNodes}
	     *
	     * You can also feed any intermediate nodes using the NamedTensorMap as the
	     * input type. For example, given the graph
	     *    InputNode => Intermediate => OutputNode,
	     * you can execute the subgraph Intermediate => OutputNode by calling
	     *    model.execute('IntermediateNode' : tf.tensor(...));
	     *
	     * This is useful for models that uses tf.dynamic_rnn, where the intermediate
	     * state needs to be fed manually.
	     *
	     * For batch inference execution, the tensors for each input need to be
	     * concatenated together. For example with mobilenet, the required input shape
	     * is [1, 244, 244, 3], which represents the [batch, height, width, channel].
	     * If we are provide a batched data of 100 images, the input tensor should be
	     * in the shape of [100, 244, 244, 3].
	     *
	     * @param config Prediction configuration for specifying the batch size.
	     * Currently the batch size option is ignored for graph model.
	     *
	     * @returns Inference result tensors. If the model is converted and it
	     * originally had structured_outputs in tensorflow, then a NamedTensorMap
	     * will be returned matching the structured_outputs. If no structured_outputs
	     * are present, the output will be single `tf.Tensor` if the model has single
	     * output node, otherwise Tensor[].
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "predict",
	    value: function predict(inputs, config) {
	      var outputTensors = this.execute(inputs, this.outputNodes);
	      return this.addStructuredOutputNames(outputTensors);
	    }
	    /**
	     * Execute the inference for the input tensors in async fashion, use this
	     * method when your model contains control flow ops.
	     *
	     * @param input The input tensors, when there is single input for the model,
	     * inputs param should be a `tf.Tensor`. For models with mutliple inputs,
	     * inputs params should be in either `tf.Tensor`[] if the input order is
	     * fixed, or otherwise NamedTensorMap format.
	     *
	     * For model with multiple inputs, we recommend you use NamedTensorMap as the
	     * input type, if you use `tf.Tensor`[], the order of the array needs to
	     * follow the
	     * order of inputNodes array. @see {@link GraphModel.inputNodes}
	     *
	     * You can also feed any intermediate nodes using the NamedTensorMap as the
	     * input type. For example, given the graph
	     *    InputNode => Intermediate => OutputNode,
	     * you can execute the subgraph Intermediate => OutputNode by calling
	     *    model.execute('IntermediateNode' : tf.tensor(...));
	     *
	     * This is useful for models that uses tf.dynamic_rnn, where the intermediate
	     * state needs to be fed manually.
	     *
	     * For batch inference execution, the tensors for each input need to be
	     * concatenated together. For example with mobilenet, the required input shape
	     * is [1, 244, 244, 3], which represents the [batch, height, width, channel].
	     * If we are provide a batched data of 100 images, the input tensor should be
	     * in the shape of [100, 244, 244, 3].
	     *
	     * @param config Prediction configuration for specifying the batch size.
	     * Currently the batch size option is ignored for graph model.
	     *
	     * @returns A Promise of inference result tensors. If the model is converted
	     * and it originally had structured_outputs in tensorflow, then a
	     * NamedTensorMap will be returned matching the structured_outputs. If no
	     * structured_outputs are present, the output will be single `tf.Tensor` if
	     * the model has single output node, otherwise Tensor[].
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "predictAsync",
	    value: function () {
	      var _predictAsync = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3(inputs, config) {
	        var outputTensors;
	        return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	          while (1) switch (_context3.prev = _context3.next) {
	            case 0:
	              _context3.next = 2;
	              return this.executeAsync(inputs, this.outputNodes);
	            case 2:
	              outputTensors = _context3.sent;
	              return _context3.abrupt("return", this.addStructuredOutputNames(outputTensors));
	            case 4:
	            case "end":
	              return _context3.stop();
	          }
	        }, _callee3, this);
	      }));
	      function predictAsync(_x4, _x5) {
	        return _predictAsync.apply(this, arguments);
	      }
	      return predictAsync;
	    }()
	  }, {
	    key: "normalizeInputs",
	    value: function normalizeInputs(inputs) {
	      var _this3 = this;
	      var _a;
	      if (!(inputs instanceof Tensor) && !Array.isArray(inputs)) {
	        // The input is already a NamedTensorMap.
	        var signatureInputs = (_a = this.signature) === null || _a === void 0 ? void 0 : _a.inputs;
	        if (signatureInputs != null) {
	          for (var input in signatureInputs) {
	            var tensor = signatureInputs[input];
	            if (tensor.resourceId != null) {
	              inputs[input] = this.resourceIdToCapturedInput[tensor.resourceId];
	            }
	          }
	        }
	        return inputs;
	      }
	      inputs = Array.isArray(inputs) ? inputs : [inputs];
	      var numCapturedInputs = Object.keys(this.resourceIdToCapturedInput).length;
	      if (inputs.length + numCapturedInputs !== this.inputNodes.length) {
	        throw new Error("Input tensor count mismatch, the graph model has ".concat(this.inputNodes.length - numCapturedInputs, " non-resource placeholders, while there are ").concat(inputs.length, " input tensors provided."));
	      }
	      var inputIndex = 0;
	      return this.inputNodes.reduce(function (map, inputName) {
	        var _a, _b, _c;
	        var resourceId = (_c = (_b = (_a = _this3.signature) === null || _a === void 0 ? void 0 : _a.inputs) === null || _b === void 0 ? void 0 : _b[inputName]) === null || _c === void 0 ? void 0 : _c.resourceId;
	        if (resourceId != null) {
	          map[inputName] = _this3.resourceIdToCapturedInput[resourceId];
	        } else {
	          map[inputName] = inputs[inputIndex++];
	        }
	        return map;
	      }, {});
	    }
	  }, {
	    key: "normalizeOutputs",
	    value: function normalizeOutputs(outputs) {
	      outputs = outputs || this.outputNodes;
	      return !Array.isArray(outputs) ? [outputs] : outputs;
	    }
	  }, {
	    key: "executeInitializerGraph",
	    value: function executeInitializerGraph() {
	      if (this.initializer == null) {
	        return [];
	      }
	      if (this.initializerSignature == null) {
	        return this.initializer.execute({}, []);
	      } else {
	        return this.initializer.execute({}, Object.keys(this.initializerSignature.outputs));
	      }
	    }
	  }, {
	    key: "executeInitializerGraphAsync",
	    value: function () {
	      var _executeInitializerGraphAsync = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4() {
	        return _regeneratorRuntime().wrap(function _callee4$(_context4) {
	          while (1) switch (_context4.prev = _context4.next) {
	            case 0:
	              if (!(this.initializer == null)) {
	                _context4.next = 2;
	                break;
	              }
	              return _context4.abrupt("return", []);
	            case 2:
	              if (!(this.initializerSignature == null)) {
	                _context4.next = 6;
	                break;
	              }
	              return _context4.abrupt("return", this.initializer.executeAsync({}, []));
	            case 6:
	              return _context4.abrupt("return", this.initializer.executeAsync({}, Object.keys(this.initializerSignature.outputs)));
	            case 7:
	            case "end":
	              return _context4.stop();
	          }
	        }, _callee4, this);
	      }));
	      function executeInitializerGraphAsync() {
	        return _executeInitializerGraphAsync.apply(this, arguments);
	      }
	      return executeInitializerGraphAsync;
	    }()
	  }, {
	    key: "setResourceIdToCapturedInput",
	    value: function setResourceIdToCapturedInput(outputs) {
	      this.resourceIdToCapturedInput = {};
	      if (this.initializerSignature) {
	        var signatureOutputs = this.initializerSignature.outputs;
	        var outputNames = Object.keys(signatureOutputs);
	        for (var i = 0; i < outputNames.length; i++) {
	          var outputName = outputNames[i];
	          var tensorInfo = signatureOutputs[outputName];
	          this.resourceIdToCapturedInput[tensorInfo.resourceId] = outputs[i];
	        }
	      }
	    }
	    /**
	     * Executes inference for the model for given input tensors.
	     * @param inputs tensor, tensor array or tensor map of the inputs for the
	     * model, keyed by the input node names.
	     * @param outputs output node name from the TensorFlow model, if no
	     * outputs are specified, the default outputs of the model would be used.
	     * You can inspect intermediate nodes of the model by adding them to the
	     * outputs array.
	     *
	     * @returns A single tensor if provided with a single output or no outputs
	     * are provided and there is only one default output, otherwise return a
	     * tensor array. The order of the tensor array is the same as the outputs
	     * if provided, otherwise the order of outputNodes attribute of the model.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "execute",
	    value: function execute(inputs, outputs) {
	      if (this.resourceIdToCapturedInput == null) {
	        this.setResourceIdToCapturedInput(this.executeInitializerGraph());
	      }
	      inputs = this.normalizeInputs(inputs);
	      outputs = this.normalizeOutputs(outputs);
	      var result = this.executor.execute(inputs, outputs);
	      return result.length > 1 ? result : result[0];
	    }
	    /**
	     * Executes inference for the model for given input tensors in async
	     * fashion, use this method when your model contains control flow ops.
	     * @param inputs tensor, tensor array or tensor map of the inputs for the
	     * model, keyed by the input node names.
	     * @param outputs output node name from the TensorFlow model, if no outputs
	     * are specified, the default outputs of the model would be used. You can
	     * inspect intermediate nodes of the model by adding them to the outputs
	     * array.
	     *
	     * @returns A Promise of single tensor if provided with a single output or
	     * no outputs are provided and there is only one default output, otherwise
	     * return a tensor map.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "executeAsync",
	    value: function () {
	      var _executeAsync = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee5(inputs, outputs) {
	        var result;
	        return _regeneratorRuntime().wrap(function _callee5$(_context5) {
	          while (1) switch (_context5.prev = _context5.next) {
	            case 0:
	              if (!(this.resourceIdToCapturedInput == null)) {
	                _context5.next = 6;
	                break;
	              }
	              _context5.t0 = this;
	              _context5.next = 4;
	              return this.executeInitializerGraphAsync();
	            case 4:
	              _context5.t1 = _context5.sent;
	              _context5.t0.setResourceIdToCapturedInput.call(_context5.t0, _context5.t1);
	            case 6:
	              inputs = this.normalizeInputs(inputs);
	              outputs = this.normalizeOutputs(outputs);
	              _context5.next = 10;
	              return this.executor.executeAsync(inputs, outputs);
	            case 10:
	              result = _context5.sent;
	              return _context5.abrupt("return", result.length > 1 ? result : result[0]);
	            case 12:
	            case "end":
	              return _context5.stop();
	          }
	        }, _callee5, this);
	      }));
	      function executeAsync(_x6, _x7) {
	        return _executeAsync.apply(this, arguments);
	      }
	      return executeAsync;
	    }()
	    /**
	     * Get intermediate tensors for model debugging mode (flag
	     * KEEP_INTERMEDIATE_TENSORS is true).
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "getIntermediateTensors",
	    value: function getIntermediateTensors() {
	      return this.executor.getIntermediateTensors();
	    }
	    /**
	     * Dispose intermediate tensors for model debugging mode (flag
	     * KEEP_INTERMEDIATE_TENSORS is true).
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "disposeIntermediateTensors",
	    value: function disposeIntermediateTensors() {
	      this.executor.disposeIntermediateTensors();
	    }
	  }, {
	    key: "convertTensorMapToTensorsMap",
	    value: function convertTensorMapToTensorsMap(map) {
	      return Object.keys(map).reduce(function (newMap, key) {
	        newMap[key] = [map[key]];
	        return newMap;
	      }, {});
	    }
	    /**
	     * Releases the memory used by the weight tensors and resourceManager.
	     *
	     * @doc {heading: 'Models', subheading: 'Classes'}
	     */
	  }, {
	    key: "dispose",
	    value: function dispose$1() {
	      this.executor.dispose();
	      if (this.initializer) {
	        this.initializer.dispose();
	        if (this.resourceIdToCapturedInput) {
	          dispose(this.resourceIdToCapturedInput);
	        }
	      }
	      this.resourceManager.dispose();
	    }
	  }]);
	  return GraphModel;
	}();
	/**
	 * Load a graph model given a URL to the model definition.
	 *
	 * Example of loading MobileNetV2 from a URL and making a prediction with a
	 * zeros input:
	 *
	 * ```js
	 * const modelUrl =
	 *    'https://storage.googleapis.com/tfjs-models/savedmodel/mobilenet_v2_1.0_224/model.json';
	 * const model = await tf.loadGraphModel(modelUrl);
	 * const zeros = tf.zeros([1, 224, 224, 3]);
	 * model.predict(zeros).print();
	 * ```
	 *
	 * Example of loading MobileNetV2 from a TF Hub URL and making a prediction
	 * with a zeros input:
	 *
	 * ```js
	 * const modelUrl =
	 *    'https://tfhub.dev/google/imagenet/mobilenet_v2_140_224/classification/2';
	 * const model = await tf.loadGraphModel(modelUrl, {fromTFHub: true});
	 * const zeros = tf.zeros([1, 224, 224, 3]);
	 * model.predict(zeros).print();
	 * ```
	 * @param modelUrl The url or an `io.IOHandler` that loads the model.
	 * @param options Options for the HTTP request, which allows to send
	 *     credentials
	 *    and custom headers.
	 *
	 * @doc {heading: 'Models', subheading: 'Loading'}
	 */
	function loadGraphModel(_x8) {
	  return _loadGraphModel.apply(this, arguments);
	}
	/**
	 * Load a graph model given a synchronous IO handler with a 'load' method.
	 *
	 * @param modelSource The `io.IOHandlerSync` that loads the model, or the
	 *     `io.ModelArtifacts` that encode the model, or a tuple of
	 *     `[io.ModelJSON, ArrayBuffer]` of which the first element encodes the
	 *      model and the second contains the weights.
	 *
	 * @doc {heading: 'Models', subheading: 'Loading'}
	 */
	function _loadGraphModel() {
	  _loadGraphModel = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee6(modelUrl) {
	    var options,
	      tfio,
	      model,
	      _args6 = arguments;
	    return _regeneratorRuntime().wrap(function _callee6$(_context6) {
	      while (1) switch (_context6.prev = _context6.next) {
	        case 0:
	          options = _args6.length > 1 && _args6[1] !== undefined ? _args6[1] : {};
	          tfio = _args6.length > 2 && _args6[2] !== undefined ? _args6[2] : io;
	          if (!(modelUrl == null)) {
	            _context6.next = 4;
	            break;
	          }
	          throw new Error('modelUrl in loadGraphModel() cannot be null. Please provide a url ' + 'or an IOHandler that loads the model');
	        case 4:
	          if (options == null) {
	            options = {};
	          }
	          if (options.fromTFHub && typeof modelUrl === 'string') {
	            modelUrl = getTFHubUrl(modelUrl);
	          }
	          model = new GraphModel(modelUrl, options, tfio);
	          _context6.next = 9;
	          return model.load();
	        case 9:
	          return _context6.abrupt("return", model);
	        case 10:
	        case "end":
	          return _context6.stop();
	      }
	    }, _callee6);
	  }));
	  return _loadGraphModel.apply(this, arguments);
	}
	function loadGraphModelSync(modelSource) {
	  if (modelSource == null) {
	    throw new Error('modelUrl in loadGraphModelSync() cannot be null. Please provide ' + 'model artifacts or an IOHandler that loads the model');
	  }
	  var ioHandler;
	  if (modelSource instanceof Array) {
	    var _modelSource = _slicedToArray(modelSource, 2),
	      modelJSON = _modelSource[0],
	      weights = _modelSource[1];
	    if (!modelJSON) {
	      throw new Error('modelJSON must be the first element of the array');
	    }
	    if (!weights || !(weights instanceof ArrayBuffer)) {
	      throw new Error('An ArrayBuffer of weights must be the second element of' + ' the array');
	    }
	    if (!('modelTopology' in modelJSON)) {
	      throw new Error('Model JSON is missing \'modelTopology\'');
	    }
	    if (!('weightsManifest' in modelJSON)) {
	      throw new Error('Model JSON is missing \'weightsManifest\'');
	    }
	    var weightSpecs = getWeightSpecs(modelJSON.weightsManifest);
	    var modelArtifacts = getModelArtifactsForJSONSync(modelJSON, weightSpecs, weights);
	    ioHandler = fromMemorySync(modelArtifacts);
	  } else if ('load' in modelSource) {
	    // Then modelSource is already an IOHandlerSync.
	    ioHandler = modelSource;
	  } else if ('modelTopology' in modelSource && 'weightSpecs' in modelSource && 'weightData' in modelSource) {
	    // modelSource is of type ModelArtifacts.
	    ioHandler = fromMemorySync(modelSource);
	  } else {
	    throw new Error('Unknown model format');
	  }
	  var model = new GraphModel(ioHandler);
	  model.load();
	  return model;
	}
	function getTFHubUrl(modelUrl) {
	  if (!modelUrl.endsWith('/')) {
	    modelUrl = modelUrl + '/';
	  }
	  return "".concat(modelUrl).concat(DEFAULT_MODEL_NAME).concat(TFHUB_SEARCH_PARAM);
	}

	/** @license See the LICENSE file. */
	// This code is auto-generated, do not modify this file!
	var version$5 = '4.22.0';

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */

	/**
	 * Apply a mapping function to a nested structure in a recursive manner.
	 *
	 * The result of the mapping is an object with the same nested structure (i.e.,
	 * of arrays and dicts) as the input, except that some subtrees are replaced,
	 * according to the results of the mapping function.
	 *
	 * Mappings are memoized.  Thus, if the nested structure contains the same
	 * object in multiple positions, the output will contain the same mapped object
	 * in those positions.  Cycles are not supported, however.
	 *
	 * @param input: The object to which to apply the mapping function.
	 * @param mapFn: A function that expects a single node of the object tree, and
	 *   returns a `DeepMapResult`.  The `DeepMapResult` either provides a
	 *   replacement value for that node (i.e., replacing the subtree), or indicates
	 *   that the node should be processed recursively.
	 */
	function deepMap(input, mapFn) {
	  return deepMapInternal(input, mapFn);
	}
	/**
	 * @param seen: A Map of known object mappings (i.e., memoized results of
	 *   `mapFn()`)
	 * @param containedIn: An set containing objects on the reference path currently
	 *   being processed (used to detect cycles).
	 */
	function deepMapInternal(input, mapFn) {
	  var seen = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : new Map();
	  var containedIn = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : new Set();
	  if (input == null) {
	    return null;
	  }
	  if (typeof Blob === 'function' && input instanceof Blob) {
	    return input.slice();
	  }
	  if (containedIn.has(input)) {
	    throw new Error('Circular references are not supported.');
	  }
	  if (seen.has(input)) {
	    return seen.get(input);
	  }
	  var result = mapFn(input);
	  if (result.recurse && result.value !== null) {
	    throw new Error('A deep map function may not return both a value and recurse=true.');
	  }
	  if (!result.recurse) {
	    seen.set(input, result.value);
	    return result.value;
	  } else if (isIterable(input)) {
	    // tslint:disable-next-line:no-any
	    var mappedIterable = Array.isArray(input) ? [] : {};
	    containedIn.add(input);
	    for (var k in input) {
	      var child = input[k];
	      var childResult = deepMapInternal(child, mapFn, seen, containedIn);
	      mappedIterable[k] = childResult;
	    }
	    containedIn.delete(input);
	    if (input.__proto__) {
	      mappedIterable.__proto__ = input.__proto__;
	    }
	    return mappedIterable;
	  } else {
	    throw new Error("Can't recurse into non-iterable type: ".concat(input));
	  }
	}
	// TODO(soergel, kangyizhang) Reconsider naming of deepZip() to avoid confusion
	// with zip()
	/**
	 * Zip nested structures together in a recursive manner.
	 *
	 * This has the effect of transposing or pivoting data, e.g. converting it from
	 * a row-major representation to a column-major representation.
	 *
	 * For example, `deepZip([{a: 1, b: 2}, {a: 3, b: 4}])` returns
	 * `{a: [1, 3], b: [2, 4]}`.
	 *
	 * The inputs should all have the same nested structure (i.e., of arrays and
	 * dicts).  The result is a single object with the same nested structure, where
	 * the leaves are arrays collecting the values of the inputs at that location
	 * (or, optionally, the result of a custom function applied to those arrays).
	 *
	 * @param inputs: An array of the objects to zip together.
	 * @param zipFn: (optional) A function that expects an array of elements at a
	 *   single node of the object tree, and returns a `DeepMapResult`.  The
	 *   `DeepMapResult` either provides a result value for that node (i.e.,
	 *   representing the subtree), or indicates that the node should be processed
	 *   recursively.  The default zipFn recurses as far as possible and places
	 *   arrays at the leaves.
	 */
	function deepZip(inputs) {
	  var zipFn = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : zipToList;
	  return deepZipInternal(inputs, zipFn);
	}
	/**
	 * @param containedIn: An set containing objects on the reference path currently
	 *   being processed (used to detect cycles).
	 */
	function deepZipInternal(inputs, zipFn) {
	  var containedIn = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : new Set();
	  // The recursion follows the structure of input 0; it's assumed that all the
	  // other inputs have the same structure.
	  var input = inputs[0];
	  if (containedIn.has(input)) {
	    throw new Error('Circular references are not supported.');
	  }
	  var result = zipFn(inputs);
	  if (result.recurse && result.value !== null) {
	    throw new Error('A deep zip function may not return both a value and recurse=true.');
	  }
	  if (!result.recurse) {
	    return result.value;
	  } else if (isIterable(input)) {
	    // tslint:disable-next-line:no-any
	    var mappedIterable = Array.isArray(input) ? [] : {};
	    containedIn.add(input);
	    var _loop = function _loop(k) {
	      var children = inputs.map(function (x) {
	        return x[k];
	      });
	      var childResult = deepZipInternal(children, zipFn, containedIn);
	      mappedIterable[k] = childResult;
	    };
	    for (var k in input) {
	      _loop(k);
	    }
	    containedIn.delete(input);
	    return mappedIterable;
	  } else {
	    throw new Error("Can't recurse into non-iterable type: ".concat(input));
	  }
	}
	// tslint:disable-next-line:no-any
	function zipToList(x) {
	  if (x === null) {
	    return null;
	  }
	  // TODO(soergel): validate array type?
	  if (isIterable(x[0])) {
	    return {
	      value: null,
	      recurse: true
	    };
	  } else {
	    return {
	      value: x,
	      recurse: false
	    };
	  }
	}
	/**
	 * Apply an async mapping function to a nested structure in a recursive manner.
	 *
	 * This first creates a nested structure of Promises, and then awaits all of
	 * those, resulting in a single Promise for a resolved nested structure.
	 *
	 * The result of the mapping is an object with the same nested structure (i.e.,
	 * of arrays and dicts) as the input, except that some subtrees are replaced,
	 * according to the results of the mapping function.
	 *
	 * Mappings are memoized.  Thus, if the nested structure contains the same
	 * object in multiple positions, the output will contain the same mapped object
	 * in those positions.  Cycles are not supported, however.
	 *
	 * @param input: The object to which to apply the mapping function.
	 * @param mapFn: A function that expects a single node of the object tree, and
	 *   returns a `DeepMapAsyncResult`.  The `DeepMapAsyncResult` either provides
	 *   a `Promise` for a replacement value for that node (i.e., replacing the
	 *   subtree), or indicates that the node should be processed recursively.  Note
	 *   that the decision whether or not to recurse must be made immediately; only
	 *   the mapped value may be promised.
	 */
	function deepMapAndAwaitAll(_x, _x2) {
	  return _deepMapAndAwaitAll.apply(this, arguments);
	}
	/**
	 * Determine whether the argument is iterable.
	 *
	 * @returns true if the argument is an array or any non-Tensor object.
	 */
	// tslint:disable-next-line:no-any
	function _deepMapAndAwaitAll() {
	  _deepMapAndAwaitAll = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(input, mapFn) {
	    var seen, _i, _Array$from, key, value, mappedValue, result;
	    return _regeneratorRuntime().wrap(function _callee$(_context) {
	      while (1) switch (_context.prev = _context.next) {
	        case 0:
	          seen = new Map(); // First do a normal deepMap, collecting Promises in 'seen' as a side effect.
	          deepMapInternal(input, mapFn, seen);
	          // Replace the Promises in 'seen' in place.
	          // Note TypeScript provides no async map iteration, and regular map iteration
	          // is broken too, so sadly we have to do Array.from() to make it work.
	          // (There's no advantage to Promise.all(), and that would be tricky anyway.)
	          _i = 0, _Array$from = Array.from(seen.keys());
	        case 3:
	          if (!(_i < _Array$from.length)) {
	            _context.next = 14;
	            break;
	          }
	          key = _Array$from[_i];
	          value = seen.get(key);
	          if (!isPromise(value)) {
	            _context.next = 11;
	            break;
	          }
	          _context.next = 9;
	          return value;
	        case 9:
	          mappedValue = _context.sent;
	          seen.set(key, mappedValue);
	        case 11:
	          _i++;
	          _context.next = 3;
	          break;
	        case 14:
	          // Normal deepMap again, this time filling in the resolved values.
	          // It's unfortunate that we have to do two passes.
	          // TODO(soergel): test performance and think harder about a fast solution.
	          result = deepMapInternal(input, mapFn, seen);
	          return _context.abrupt("return", result);
	        case 16:
	        case "end":
	          return _context.stop();
	      }
	    }, _callee);
	  }));
	  return _deepMapAndAwaitAll.apply(this, arguments);
	}
	function isIterable(obj) {
	  var isTextDecoder = false;
	  if (env().get('IS_BROWSER')) {
	    isTextDecoder = obj instanceof TextDecoder;
	  } else {
	    // tslint:disable-next-line:no-require-imports
	    var _require = require('string_decoder'),
	      StringDecoder = _require.StringDecoder;
	    isTextDecoder = obj instanceof StringDecoder;
	  }
	  return obj != null && !ArrayBuffer.isView(obj) && (Array.isArray(obj) || _typeof(obj) === 'object' && !(obj instanceof Tensor) && !(obj instanceof Promise) && !isTextDecoder);
	}
	/**
	 * Determine whether the argument can be converted to Tensor.
	 *
	 * Tensors, primitives, arrays, and TypedArrays all qualify; anything else does
	 * not.
	 *
	 * @returns true if the argument can be converted to Tensor.
	 */
	// tslint:disable-next-line:no-any
	function canTensorify(obj) {
	  return obj == null || isPrimitive(obj) || Array.isArray(obj) || _typeof(obj) === 'object' && obj instanceof Tensor || isTypedArray(obj);
	}
	/**
	 * Returns true if the given `value` is a primitive type. Otherwise returns
	 * false. This is equivalant to node util.isPrimitive
	 */
	function isPrimitive(value) {
	  return value === null || _typeof(value) !== 'object' && typeof value !== 'function';
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 *
	 * =============================================================================
	 */
	function deepClone(container) {
	  return deepMap(container, cloneIfTensor);
	}
	// tslint:disable-next-line: no-any
	function cloneIfTensor(item) {
	  if (item instanceof Tensor) {
	    return {
	      value: item.clone(),
	      recurse: false
	    };
	  } else if (isIterable(item)) {
	    return {
	      value: null,
	      recurse: true
	    };
	  } else {
	    return {
	      value: item,
	      recurse: false
	    };
	  }
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 *
	 * =============================================================================
	 */
	/**
	 * A ring buffer, providing O(1) FIFO, LIFO, and related operations.
	 */
	var RingBuffer = /*#__PURE__*/function () {
	  /**
	   * Constructs a `RingBuffer`.
	   * @param capacity The number of items that the buffer can accomodate.
	   */
	  function RingBuffer(capacity) {
	    _classCallCheck(this, RingBuffer);
	    this.capacity = capacity;
	    // Note we store the indices in the range 0 <= index < 2*capacity.
	    // This allows us to distinguish the full from the empty case.
	    // See https://www.snellman.net/blog/archive/2016-12-13-ring-buffers/
	    this.begin = 0; // inclusive
	    this.end = 0; // exclusive
	    if (capacity == null) {
	      throw new RangeError('Can\'t create a ring buffer of unknown capacity.');
	    }
	    if (capacity < 1) {
	      throw new RangeError('Can\'t create ring buffer of capacity < 1.');
	    }
	    this.data = new Array(capacity);
	    this.doubledCapacity = 2 * capacity;
	  }
	  /**
	   * Map any index into the range 0 <= index < 2*capacity.
	   */
	  _createClass(RingBuffer, [{
	    key: "wrap",
	    value: function wrap(index) {
	      // don't trust % on negative numbers
	      while (index < 0) {
	        index += this.doubledCapacity;
	      }
	      return index % this.doubledCapacity;
	    }
	  }, {
	    key: "get",
	    value: function get(index) {
	      if (index < 0) {
	        throw new RangeError('Can\'t get item at a negative index.');
	      }
	      return this.data[index % this.capacity];
	    }
	  }, {
	    key: "set",
	    value: function set(index, value) {
	      if (index < 0) {
	        throw new RangeError('Can\'t set item at a negative index.');
	      }
	      this.data[index % this.capacity] = value;
	    }
	    /**
	     * Returns the current number of items in the buffer.
	     */
	  }, {
	    key: "length",
	    value: function length() {
	      var length = this.end - this.begin;
	      if (length < 0) {
	        length = this.doubledCapacity + length;
	      }
	      return length;
	    }
	    /**
	     * Reports whether the buffer is full.
	     * @returns true if the number of items in the buffer equals its capacity, and
	     *   false otherwise.
	     */
	  }, {
	    key: "isFull",
	    value: function isFull() {
	      return this.length() === this.capacity;
	    }
	    /**
	     * Reports whether the buffer is empty.
	     * @returns true if the number of items in the buffer equals zero, and
	     *   false otherwise.
	     */
	  }, {
	    key: "isEmpty",
	    value: function isEmpty() {
	      return this.length() === 0;
	    }
	    /**
	     * Adds an item to the end of the buffer.
	     */
	  }, {
	    key: "push",
	    value: function push(value) {
	      if (this.isFull()) {
	        throw new RangeError('Ring buffer is full.');
	      }
	      this.set(this.end, value);
	      this.end = this.wrap(this.end + 1);
	    }
	    /**
	     * Adds many items to the end of the buffer, in order.
	     */
	  }, {
	    key: "pushAll",
	    value: function pushAll(values) {
	      var _iterator = _createForOfIteratorHelper(values),
	        _step;
	      try {
	        for (_iterator.s(); !(_step = _iterator.n()).done;) {
	          var value = _step.value;
	          this.push(value);
	        }
	      } catch (err) {
	        _iterator.e(err);
	      } finally {
	        _iterator.f();
	      }
	    }
	    /**
	     * Removes and returns the last item in the buffer.
	     */
	  }, {
	    key: "pop",
	    value: function pop() {
	      if (this.isEmpty()) {
	        throw new RangeError('Ring buffer is empty.');
	      }
	      this.end = this.wrap(this.end - 1);
	      var result = this.get(this.end);
	      this.set(this.end, undefined);
	      return result;
	    }
	    /**
	     * Adds an item to the beginning of the buffer.
	     */
	  }, {
	    key: "unshift",
	    value: function unshift(value) {
	      if (this.isFull()) {
	        throw new RangeError('Ring buffer is full.');
	      }
	      this.begin = this.wrap(this.begin - 1);
	      this.set(this.begin, value);
	    }
	    /**
	     * Removes and returns the first item in the buffer.
	     */
	  }, {
	    key: "shift",
	    value: function shift() {
	      if (this.isEmpty()) {
	        throw new RangeError('Ring buffer is empty.');
	      }
	      var result = this.get(this.begin);
	      this.set(this.begin, undefined);
	      this.begin = this.wrap(this.begin + 1);
	      return result;
	    }
	    /**
	     * Removes and returns a specific item in the buffer, and moves the last item
	     * to the vacated slot.  This is useful for implementing a shuffling stream.
	     * Note that this operation necessarily scrambles the original order.
	     *
	     * @param relativeIndex: the index of the item to remove, relative to the
	     *   first item in the buffer (e.g., hiding the ring nature of the underlying
	     *   storage).
	     */
	  }, {
	    key: "shuffleExcise",
	    value: function shuffleExcise(relativeIndex) {
	      if (this.isEmpty()) {
	        throw new RangeError('Ring buffer is empty.');
	      }
	      var index = this.wrap(this.begin + relativeIndex);
	      var result = this.get(index);
	      this.set(index, this.pop());
	      return result;
	    }
	  }]);
	  return RingBuffer;
	}();

	var GrowingRingBuffer = /*#__PURE__*/function (_RingBuffer) {
	  _inherits(GrowingRingBuffer, _RingBuffer);
	  var _super = _createSuper(GrowingRingBuffer);
	  /**
	   * Constructs a `GrowingRingBuffer`.
	   */
	  function GrowingRingBuffer() {
	    _classCallCheck(this, GrowingRingBuffer);
	    return _super.call(this, GrowingRingBuffer.INITIAL_CAPACITY);
	  }
	  _createClass(GrowingRingBuffer, [{
	    key: "isFull",
	    value: function isFull() {
	      return false;
	    }
	  }, {
	    key: "push",
	    value: function push(value) {
	      if (_get(_getPrototypeOf(GrowingRingBuffer.prototype), "isFull", this).call(this)) {
	        this.expand();
	      }
	      _get(_getPrototypeOf(GrowingRingBuffer.prototype), "push", this).call(this, value);
	    }
	  }, {
	    key: "unshift",
	    value: function unshift(value) {
	      if (_get(_getPrototypeOf(GrowingRingBuffer.prototype), "isFull", this).call(this)) {
	        this.expand();
	      }
	      _get(_getPrototypeOf(GrowingRingBuffer.prototype), "unshift", this).call(this, value);
	    }
	    /**
	     * Doubles the capacity of the buffer.
	     */
	  }, {
	    key: "expand",
	    value: function expand() {
	      var newCapacity = this.capacity * 2;
	      var newData = new Array(newCapacity);
	      var len = this.length();
	      // Rotate the buffer to start at index 0 again, since we can't just
	      // allocate more space at the end.
	      for (var i = 0; i < len; i++) {
	        newData[i] = this.get(this.wrap(this.begin + i));
	      }
	      this.data = newData;
	      this.capacity = newCapacity;
	      this.doubledCapacity = 2 * this.capacity;
	      this.begin = 0;
	      this.end = len;
	    }
	  }]);
	  return GrowingRingBuffer;
	}(RingBuffer);
	GrowingRingBuffer.INITIAL_CAPACITY = 32;

	// Here we implement a simple asynchronous iterator.
	// This lets us avoid using either third-party stream libraries or
	// recent TypeScript language support requiring polyfills.
	/**
	 * Create a `LazyIterator` from an array of items.
	 */
	function iteratorFromItems(items) {
	  return new ArrayIterator(items);
	}
	/**
	 * Create a `LazyIterator` of incrementing integers.
	 */
	function iteratorFromIncrementing(start) {
	  var i = start;
	  return iteratorFromFunction(function () {
	    return {
	      value: i++,
	      done: false
	    };
	  });
	}
	/**
	 * Create a `LazyIterator` from a function.
	 *
	 * ```js
	 * let i = -1;
	 * const func = () =>
	 *    ++i < 5 ? {value: i, done: false} : {value: null, done: true};
	 * const iter = tf.data.iteratorFromFunction(func);
	 * await iter.forEachAsync(e => console.log(e));
	 * ```
	 *
	 * @param func A function that produces data on each call.
	 */
	function iteratorFromFunction(func) {
	  return new FunctionCallIterator(func);
	}
	/**
	 * Create a `LazyIterator` by concatenating underlying streams, which are
	 * themselves provided as a stream.
	 *
	 * This can also be thought of as a "stream flatten" operation.
	 *
	 * @param baseIterators A stream of streams to be concatenated.
	 * @param baseErrorHandler An optional function that can intercept `Error`s
	 *   raised during a `next()` call on the base stream.  This function can decide
	 *   whether the error should be propagated, whether the error should be
	 *   ignored, or whether the base stream should be terminated.
	 */
	function iteratorFromConcatenated(baseIterators, baseErrorHandler) {
	  return new ChainedIterator(baseIterators, baseErrorHandler);
	}
	/**
	 * Create a `LazyIterator` by concatenating streams produced by calling a
	 * stream-generating function a given number of times.
	 *
	 * Since a `LazyIterator` is read-once, it cannot be repeated, but this
	 * function can be used to achieve a similar effect:
	 *
	 *   LazyIterator.ofConcatenatedFunction(() => new MyIterator(), 6);
	 *
	 * @param iteratorFunc: A function that produces a new stream on each call.
	 * @param count: The number of times to call the function.
	 * @param baseErrorHandler An optional function that can intercept `Error`s
	 *   raised during a `next()` call on the base stream.  This function can decide
	 *   whether the error should be propagated, whether the error should be
	 *   ignored, or whether the base stream should be terminated.
	 */
	function iteratorFromConcatenatedFunction(iteratorFunc, count, baseErrorHandler) {
	  return iteratorFromConcatenated(iteratorFromFunction(iteratorFunc).take(count), baseErrorHandler);
	}
	/**
	 * Create a `LazyIterator` by zipping together an array, dict, or nested
	 * structure of `LazyIterator`s (and perhaps additional constants).
	 *
	 * The underlying streams must provide elements in a consistent order such
	 * that they correspond.
	 *
	 * Typically, the underlying streams should have the same number of
	 * elements. If they do not, the behavior is determined by the
	 * `mismatchMode` argument.
	 *
	 * The nested structure of the `iterators` argument determines the
	 * structure of elements in the resulting iterator.
	 *
	 * @param iterators: An array or object containing LazyIterators at the
	 * leaves.
	 * @param mismatchMode: Determines what to do when one underlying iterator
	 * is exhausted before the others.  `ZipMismatchMode.FAIL` (the default)
	 * causes an error to be thrown in this case.  `ZipMismatchMode.SHORTEST`
	 * causes the zipped iterator to terminate with the furst underlying
	 * streams, so elements remaining on the longer streams are ignored.
	 * `ZipMismatchMode.LONGEST` causes the zipped stream to continue, filling
	 * in nulls for the exhausted streams, until all streams are exhausted.
	 */
	function iteratorFromZipped(iterators) {
	  var mismatchMode = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : ZipMismatchMode.FAIL;
	  return new ZipIterator(iterators, mismatchMode);
	}
	/**
	 * An asynchronous iterator, providing lazy access to a potentially
	 * unbounded stream of elements.
	 *
	 * Iterator can be obtained from a dataset:
	 * `const iter = await dataset.iterator();`
	 */
	var LazyIterator = /*#__PURE__*/function () {
	  function LazyIterator() {
	    _classCallCheck(this, LazyIterator);
	  }
	  _createClass(LazyIterator, [{
	    key: "toArray",
	    value:
	    /**
	     * Collect all remaining elements of a bounded stream into an array.
	     * Obviously this will succeed only for small streams that fit in memory.
	     * Useful for testing.
	     *
	     * @returns A Promise for an array of stream elements, which will resolve
	     *   when the stream is exhausted.
	     */
	    function () {
	      var _toArray = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        var result, x;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              result = [];
	              _context.next = 3;
	              return this.next();
	            case 3:
	              x = _context.sent;
	            case 4:
	              if (x.done) {
	                _context.next = 11;
	                break;
	              }
	              result.push(x.value);
	              _context.next = 8;
	              return this.next();
	            case 8:
	              x = _context.sent;
	              _context.next = 4;
	              break;
	            case 11:
	              return _context.abrupt("return", result);
	            case 12:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function toArray() {
	        return _toArray.apply(this, arguments);
	      }
	      return toArray;
	    }()
	    /**
	     * Collect all elements of this dataset into an array with prefetching 100
	     * elements. This is useful for testing, because the prefetch changes the
	     * order in which the Promises are resolved along the processing pipeline.
	     * This may help expose bugs where results are dependent on the order of
	     * Promise resolution rather than on the logical order of the stream (i.e.,
	     * due to hidden mutable state).
	     *
	     * @returns A Promise for an array of stream elements, which will resolve
	     *   when the stream is exhausted.
	     */
	  }, {
	    key: "toArrayForTest",
	    value: function () {
	      var _toArrayForTest = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2() {
	        var stream, result, x;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              stream = this.prefetch(100);
	              result = [];
	              _context2.next = 4;
	              return stream.next();
	            case 4:
	              x = _context2.sent;
	            case 5:
	              if (x.done) {
	                _context2.next = 12;
	                break;
	              }
	              result.push(x.value);
	              _context2.next = 9;
	              return stream.next();
	            case 9:
	              x = _context2.sent;
	              _context2.next = 5;
	              break;
	            case 12:
	              return _context2.abrupt("return", result);
	            case 13:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function toArrayForTest() {
	        return _toArrayForTest.apply(this, arguments);
	      }
	      return toArrayForTest;
	    }()
	    /**
	     * Draw items from the stream until it is exhausted.
	     *
	     * This can be useful when the stream has side effects but no output.  In
	     * that case, calling this function guarantees that the stream will be
	     * fully processed.
	     */
	  }, {
	    key: "resolveFully",
	    value: function () {
	      var _resolveFully = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3() {
	        var x;
	        return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	          while (1) switch (_context3.prev = _context3.next) {
	            case 0:
	              _context3.next = 2;
	              return this.next();
	            case 2:
	              x = _context3.sent;
	            case 3:
	              if (x.done) {
	                _context3.next = 9;
	                break;
	              }
	              _context3.next = 6;
	              return this.next();
	            case 6:
	              x = _context3.sent;
	              _context3.next = 3;
	              break;
	            case 9:
	            case "end":
	              return _context3.stop();
	          }
	        }, _callee3, this);
	      }));
	      function resolveFully() {
	        return _resolveFully.apply(this, arguments);
	      }
	      return resolveFully;
	    }()
	    /**
	     * Draw items from the stream until it is exhausted, or a predicate fails.
	     *
	     * This can be useful when the stream has side effects but no output.  In
	     * that case, calling this function guarantees that the stream will be
	     * fully processed.
	     */
	  }, {
	    key: "resolveWhile",
	    value: function () {
	      var _resolveWhile = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4(predicate) {
	        var x, shouldContinue;
	        return _regeneratorRuntime().wrap(function _callee4$(_context4) {
	          while (1) switch (_context4.prev = _context4.next) {
	            case 0:
	              _context4.next = 2;
	              return this.next();
	            case 2:
	              x = _context4.sent;
	              shouldContinue = predicate(x.value);
	            case 4:
	              if (!(!x.done && shouldContinue)) {
	                _context4.next = 11;
	                break;
	              }
	              _context4.next = 7;
	              return this.next();
	            case 7:
	              x = _context4.sent;
	              shouldContinue = predicate(x.value);
	              _context4.next = 4;
	              break;
	            case 11:
	            case "end":
	              return _context4.stop();
	          }
	        }, _callee4, this);
	      }));
	      function resolveWhile(_x) {
	        return _resolveWhile.apply(this, arguments);
	      }
	      return resolveWhile;
	    }()
	    /**
	     * Handles errors thrown on this stream using a provided handler function.
	     *
	     * @param handler A function that handles any `Error` thrown during a `next()`
	     *   call and returns true if the stream should continue (dropping the failed
	     *   call) or false if the stream should quietly terminate.  If the handler
	     *   itself throws (or rethrows) an `Error`, that will be propagated.
	     *
	     * @returns A `LazyIterator` of elements passed through from upstream,
	     *   possibly filtering or terminating on upstream `next()` calls that
	     *   throw an `Error`.
	     */
	  }, {
	    key: "handleErrors",
	    value: function handleErrors(handler) {
	      return new ErrorHandlingLazyIterator(this, handler);
	    }
	    // TODO(soergel): Implement reduce() etc.
	    /**
	     * Filters this stream according to `predicate`.
	     *
	     * @param predicate A function mapping a stream element to a boolean or a
	     * `Promise` for one.
	     *
	     * @returns A `LazyIterator` of elements for which the predicate was true.
	     */
	  }, {
	    key: "filter",
	    value: function filter(predicate) {
	      return new FilterIterator(this, predicate);
	    }
	    /**
	     * Maps this stream through a 1-to-1 transform.
	     *
	     * @param transform A function mapping a stream element to a transformed
	     *   element.
	     *
	     * @returns A `LazyIterator` of transformed elements.
	     */
	  }, {
	    key: "map",
	    value: function map(transform) {
	      return new MapIterator(this, transform);
	    }
	    /**
	     * Maps this stream through an async 1-to-1 transform.
	     *
	     * @param transform A function mapping a stream element to a `Promise` for a
	     *   transformed stream element.
	     *
	     * @returns A `LazyIterator` of transformed elements.
	     */
	  }, {
	    key: "mapAsync",
	    value: function mapAsync(transform) {
	      return new AsyncMapIterator(this, transform);
	    }
	    /**
	     * Maps this stream through a 1-to-1 transform, forcing serial execution.
	     *
	     * @param transform A function mapping a stream element to a transformed
	     *   element.
	     *
	     * @returns A `LazyIterator` of transformed elements.
	     */
	  }, {
	    key: "serialMapAsync",
	    value: function serialMapAsync(transform) {
	      return new AsyncMapIterator(this, transform).serial();
	    }
	    /**
	     * Maps this stream through a 1-to-many transform.
	     *
	     * @param transform A function mapping a stream element to an array of
	     *   transformed elements.
	     *
	     * @returns A `DataStream` of transformed elements.
	     */
	  }, {
	    key: "flatmap",
	    value: function flatmap(transform) {
	      return new FlatmapIterator(this, transform);
	    }
	    /**
	     * Apply a function to every element of the stream.
	     *
	     * @param f A function to apply to each stream element.
	     */
	  }, {
	    key: "forEachAsync",
	    value: function () {
	      var _forEachAsync = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee5(f) {
	        return _regeneratorRuntime().wrap(function _callee5$(_context5) {
	          while (1) switch (_context5.prev = _context5.next) {
	            case 0:
	              return _context5.abrupt("return", this.map(f).resolveFully());
	            case 1:
	            case "end":
	              return _context5.stop();
	          }
	        }, _callee5, this);
	      }));
	      function forEachAsync(_x2) {
	        return _forEachAsync.apply(this, arguments);
	      }
	      return forEachAsync;
	    }()
	    /**
	     * Apply a function to every element of the stream, forcing serial execution.
	     *
	     * @param f A function to apply to each stream element.  Should return 'true'
	     *   to indicate that the stream should continue, or 'false' to cause it to
	     *   terminate.
	     */
	  }, {
	    key: "serialForEach",
	    value: function () {
	      var _serialForEach = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee6(f) {
	        return _regeneratorRuntime().wrap(function _callee6$(_context6) {
	          while (1) switch (_context6.prev = _context6.next) {
	            case 0:
	              return _context6.abrupt("return", this.serialMapAsync(f).resolveWhile(function (x) {
	                return x === true;
	              }));
	            case 1:
	            case "end":
	              return _context6.stop();
	          }
	        }, _callee6, this);
	      }));
	      function serialForEach(_x3) {
	        return _serialForEach.apply(this, arguments);
	      }
	      return serialForEach;
	    }()
	    /**
	     * Groups elements into batches, represented as arrays of elements.
	     *
	     * We can think of the elements of this iterator as 'rows' (even if they are
	     * nested structures).  By the same token, consecutive values for a given
	     * key within the elements form a 'column'.  This matches the usual sense of
	     * 'row' and 'column' when processing tabular data (e.g., parsing a CSV).
	     *
	     * Thus, "Row-major" means that the resulting batch is simply a collection of
	     * rows: `[row1, row2, row3, ...]`.  This is contrast to the column-major
	     * form, which is needed for vectorized computation.
	     *
	     * @param batchSize The number of elements desired per batch.
	     * @param smallLastBatch Whether to emit the final batch when it has fewer
	     *   than batchSize elements. Default true.
	     * @returns A `LazyIterator` of batches of elements, represented as arrays
	     *   of the original element type.
	     */
	  }, {
	    key: "rowMajorBatch",
	    value: function rowMajorBatch(batchSize) {
	      var smallLastBatch = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
	      return new RowMajorBatchIterator(this, batchSize, smallLastBatch);
	    }
	    /**
	     * Groups elements into batches, represented in column-major form.
	     *
	     * We can think of the elements of this iterator as 'rows' (even if they are
	     * nested structures).  By the same token, consecutive values for a given
	     * key within the elements form a 'column'.  This matches the usual sense of
	     * 'row' and 'column' when processing tabular data (e.g., parsing a CSV).
	     *
	     * Thus, "column-major" means that the resulting batch is a (potentially
	     * nested) structure representing the columns.  Each column entry, then,
	     * contains a collection of the values found in that column for a range of
	     * input elements.  This representation allows for vectorized computation, in
	     * contrast to the row-major form.
	     *
	     * The inputs should all have the same nested structure (i.e., of arrays and
	     * dicts).  The result is a single object with the same nested structure,
	     * where the leaves are arrays collecting the values of the inputs at that
	     * location (or, optionally, the result of a custom function applied to those
	     * arrays).
	     *
	     * @param batchSize The number of elements desired per batch.
	     * @param smallLastBatch Whether to emit the final batch when it has fewer
	     *   than batchSize elements. Default true.
	     * @param zipFn: (optional) A function that expects an array of elements at a
	     *   single node of the object tree, and returns a `DeepMapResult`.  The
	     *   `DeepMapResult` either provides a result value for that node (i.e.,
	     *   representing the subtree), or indicates that the node should be processed
	     *   recursively.  The default zipFn recurses as far as possible and places
	     *   arrays at the leaves.
	     * @returns A `LazyIterator` of batches of elements, represented as an object
	     *   with collections at the leaves.
	     */
	  }, {
	    key: "columnMajorBatch",
	    value: function columnMajorBatch(batchSize) {
	      var smallLastBatch = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
	      var zipFn = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : zipToList;
	      // First collect the desired number of input elements as a row-major batch.
	      var rowBatches = this.rowMajorBatch(batchSize, smallLastBatch);
	      // Now 'rotate' or 'pivot' the data, collecting all values from each column
	      // in the batch (i.e., for each key within the elements) into an array.
	      return rowBatches.map(function (x) {
	        return deepZip(x, zipFn);
	      });
	    }
	    /**
	     * Concatenate this `LazyIterator` with another.
	     *
	     * @param iterator A `LazyIterator` to be concatenated onto this one.
	     * @param baseErrorHandler An optional function that can intercept `Error`s
	     *   raised during a `next()` call on the base stream.  This function can
	     *   decide whether the error should be propagated, whether the error should
	     *   be ignored, or whether the base stream should be terminated.
	     * @returns A `LazyIterator`.
	     */
	  }, {
	    key: "concatenate",
	    value: function concatenate(iterator, baseErrorHandler) {
	      return new ChainedIterator(iteratorFromItems([this, iterator]), baseErrorHandler);
	    }
	    /**
	     * Limits this stream to return at most `count` items.
	     *
	     * @param count The maximum number of items to provide from the stream. If
	     * a negative or undefined value is given, the entire stream is returned
	     *   unaltered.
	     */
	  }, {
	    key: "take",
	    value: function take(count) {
	      if (count < 0 || count == null) {
	        return this;
	      }
	      return new TakeIterator(this, count);
	    }
	    /**
	     * Skips the first `count` items in this stream.
	     *
	     * @param count The number of items to skip.  If a negative or undefined
	     * value is given, the entire stream is returned unaltered.
	     */
	  }, {
	    key: "skip",
	    value: function skip(count) {
	      if (count < 0 || count == null) {
	        return this;
	      }
	      return new SkipIterator(this, count);
	    }
	    /**
	     * Prefetch the first `bufferSize` items in this stream.
	     *
	     * Note this prefetches Promises, but makes no guarantees about when those
	     * Promises resolve.
	     *
	     * @param bufferSize: An integer specifying the number of elements to be
	     *   prefetched.
	     */
	  }, {
	    key: "prefetch",
	    value: function prefetch(bufferSize) {
	      return new PrefetchIterator(this, bufferSize);
	    }
	    // TODO(soergel): deep sharded shuffle, where supported
	    /**
	     * Randomly shuffles the elements of this stream.
	     *
	     * @param bufferSize: An integer specifying the number of elements from
	     * this stream from which the new stream will sample.
	     * @param seed: (Optional.) An integer specifying the random seed that
	     * will be used to create the distribution.
	     */
	  }, {
	    key: "shuffle",
	    value: function shuffle(windowSize, seed) {
	      return new ShuffleIterator(this, windowSize, seed);
	    }
	    /**
	     * Force an iterator to execute serially: each next() call will await the
	     * prior one, so that they cannot execute concurrently.
	     */
	  }, {
	    key: "serial",
	    value: function serial() {
	      return new SerialIterator(this);
	    }
	  }]);
	  return LazyIterator;
	}();
	// ============================================================================
	// The following private classes serve to implement the chainable methods
	// on LazyIterator.  Unfortunately they can't be placed in separate files,
	// due to resulting trouble with circular imports.
	// ============================================================================
	// Iterators that just extend LazyIterator directly
	// ============================================================================
	var ArrayIterator = /*#__PURE__*/function (_LazyIterator) {
	  _inherits(ArrayIterator, _LazyIterator);
	  var _super = _createSuper(ArrayIterator);
	  function ArrayIterator(items) {
	    var _this;
	    _classCallCheck(this, ArrayIterator);
	    _this = _super.call(this);
	    _this.items = items;
	    _this.trav = 0;
	    return _this;
	  }
	  _createClass(ArrayIterator, [{
	    key: "summary",
	    value: function summary() {
	      return "Array of ".concat(this.items.length, " items");
	    }
	  }, {
	    key: "next",
	    value: function () {
	      var _next = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee7() {
	        var item;
	        return _regeneratorRuntime().wrap(function _callee7$(_context7) {
	          while (1) switch (_context7.prev = _context7.next) {
	            case 0:
	              if (!(this.trav >= this.items.length)) {
	                _context7.next = 2;
	                break;
	              }
	              return _context7.abrupt("return", {
	                value: null,
	                done: true
	              });
	            case 2:
	              item = this.items[this.trav];
	              this.trav++;
	              return _context7.abrupt("return", {
	                value: deepClone(item),
	                done: false
	              });
	            case 5:
	            case "end":
	              return _context7.stop();
	          }
	        }, _callee7, this);
	      }));
	      function next() {
	        return _next.apply(this, arguments);
	      }
	      return next;
	    }()
	  }]);
	  return ArrayIterator;
	}(LazyIterator);
	var FunctionCallIterator = /*#__PURE__*/function (_LazyIterator2) {
	  _inherits(FunctionCallIterator, _LazyIterator2);
	  var _super2 = _createSuper(FunctionCallIterator);
	  function FunctionCallIterator(nextFn) {
	    var _this2;
	    _classCallCheck(this, FunctionCallIterator);
	    _this2 = _super2.call(this);
	    _this2.nextFn = nextFn;
	    return _this2;
	  }
	  _createClass(FunctionCallIterator, [{
	    key: "summary",
	    value: function summary() {
	      return "Function call";
	    }
	  }, {
	    key: "next",
	    value: function () {
	      var _next2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee8() {
	        return _regeneratorRuntime().wrap(function _callee8$(_context8) {
	          while (1) switch (_context8.prev = _context8.next) {
	            case 0:
	              _context8.prev = 0;
	              return _context8.abrupt("return", this.nextFn());
	            case 4:
	              _context8.prev = 4;
	              _context8.t0 = _context8["catch"](0);
	              // Modify the error message but leave the stack trace intact
	              _context8.t0.message = "Error thrown while iterating through a dataset: ".concat(_context8.t0.message);
	              throw _context8.t0;
	            case 8:
	            case "end":
	              return _context8.stop();
	          }
	        }, _callee8, this, [[0, 4]]);
	      }));
	      function next() {
	        return _next2.apply(this, arguments);
	      }
	      return next;
	    }()
	  }]);
	  return FunctionCallIterator;
	}(LazyIterator);
	var SerialIterator = /*#__PURE__*/function (_LazyIterator3) {
	  _inherits(SerialIterator, _LazyIterator3);
	  var _super3 = _createSuper(SerialIterator);
	  function SerialIterator(upstream) {
	    var _this3;
	    _classCallCheck(this, SerialIterator);
	    _this3 = _super3.call(this);
	    _this3.upstream = upstream;
	    _this3.lastRead = Promise.resolve({
	      value: null,
	      done: false
	    });
	    return _this3;
	  }
	  _createClass(SerialIterator, [{
	    key: "summary",
	    value: function summary() {
	      return "".concat(this.upstream.summary(), " -> Serial");
	    }
	  }, {
	    key: "next",
	    value: function () {
	      var _next3 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee9() {
	        var _this4 = this;
	        return _regeneratorRuntime().wrap(function _callee9$(_context9) {
	          while (1) switch (_context9.prev = _context9.next) {
	            case 0:
	              // This sets this.lastRead to a new Promise right away, as opposed to
	              // saying `await this.lastRead; this.lastRead = this.serialNext();` which
	              // would not work because this.nextRead would be updated only after the
	              // promise resolves.
	              this.lastRead = this.lastRead.then(function () {
	                return _this4.serialNext();
	              });
	              return _context9.abrupt("return", this.lastRead);
	            case 2:
	            case "end":
	              return _context9.stop();
	          }
	        }, _callee9, this);
	      }));
	      function next() {
	        return _next3.apply(this, arguments);
	      }
	      return next;
	    }()
	  }, {
	    key: "serialNext",
	    value: function () {
	      var _serialNext = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee10() {
	        return _regeneratorRuntime().wrap(function _callee10$(_context10) {
	          while (1) switch (_context10.prev = _context10.next) {
	            case 0:
	              return _context10.abrupt("return", this.upstream.next());
	            case 1:
	            case "end":
	              return _context10.stop();
	          }
	        }, _callee10, this);
	      }));
	      function serialNext() {
	        return _serialNext.apply(this, arguments);
	      }
	      return serialNext;
	    }()
	  }]);
	  return SerialIterator;
	}(LazyIterator);
	var SkipIterator = /*#__PURE__*/function (_LazyIterator4) {
	  _inherits(SkipIterator, _LazyIterator4);
	  var _super4 = _createSuper(SkipIterator);
	  function SkipIterator(upstream, maxCount) {
	    var _this5;
	    _classCallCheck(this, SkipIterator);
	    _this5 = _super4.call(this);
	    _this5.upstream = upstream;
	    _this5.maxCount = maxCount;
	    // Local state that should not be clobbered by out-of-order execution.
	    _this5.count = 0;
	    _this5.lastRead = Promise.resolve({
	      value: null,
	      done: false
	    });
	    return _this5;
	  }
	  _createClass(SkipIterator, [{
	    key: "summary",
	    value: function summary() {
	      return "".concat(this.upstream.summary(), " -> Skip");
	    }
	  }, {
	    key: "next",
	    value: function () {
	      var _next4 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee11() {
	        var _this6 = this;
	        return _regeneratorRuntime().wrap(function _callee11$(_context11) {
	          while (1) switch (_context11.prev = _context11.next) {
	            case 0:
	              // This sets this.lastRead to a new Promise right away, as opposed to
	              // saying `await this.lastRead; this.lastRead = this.serialNext();` which
	              // would not work because this.nextRead would be updated only after the
	              // promise resolves.
	              this.lastRead = this.lastRead.then(function () {
	                return _this6.serialNext();
	              });
	              return _context11.abrupt("return", this.lastRead);
	            case 2:
	            case "end":
	              return _context11.stop();
	          }
	        }, _callee11, this);
	      }));
	      function next() {
	        return _next4.apply(this, arguments);
	      }
	      return next;
	    }()
	  }, {
	    key: "serialNext",
	    value: function () {
	      var _serialNext2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee12() {
	        var skipped;
	        return _regeneratorRuntime().wrap(function _callee12$(_context12) {
	          while (1) switch (_context12.prev = _context12.next) {
	            case 0:
	              if (!(this.count++ < this.maxCount)) {
	                _context12.next = 9;
	                break;
	              }
	              _context12.next = 3;
	              return this.upstream.next();
	            case 3:
	              skipped = _context12.sent;
	              if (!skipped.done) {
	                _context12.next = 6;
	                break;
	              }
	              return _context12.abrupt("return", skipped);
	            case 6:
	              dispose(skipped.value);
	              _context12.next = 0;
	              break;
	            case 9:
	              return _context12.abrupt("return", this.upstream.next());
	            case 10:
	            case "end":
	              return _context12.stop();
	          }
	        }, _callee12, this);
	      }));
	      function serialNext() {
	        return _serialNext2.apply(this, arguments);
	      }
	      return serialNext;
	    }()
	  }]);
	  return SkipIterator;
	}(LazyIterator);
	var TakeIterator = /*#__PURE__*/function (_LazyIterator5) {
	  _inherits(TakeIterator, _LazyIterator5);
	  var _super5 = _createSuper(TakeIterator);
	  function TakeIterator(upstream, maxCount) {
	    var _this7;
	    _classCallCheck(this, TakeIterator);
	    _this7 = _super5.call(this);
	    _this7.upstream = upstream;
	    _this7.maxCount = maxCount;
	    _this7.count = 0;
	    return _this7;
	  }
	  _createClass(TakeIterator, [{
	    key: "summary",
	    value: function summary() {
	      return "".concat(this.upstream.summary(), " -> Take");
	    }
	  }, {
	    key: "next",
	    value: function () {
	      var _next5 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee13() {
	        return _regeneratorRuntime().wrap(function _callee13$(_context13) {
	          while (1) switch (_context13.prev = _context13.next) {
	            case 0:
	              if (!(this.count++ >= this.maxCount)) {
	                _context13.next = 2;
	                break;
	              }
	              return _context13.abrupt("return", {
	                value: null,
	                done: true
	              });
	            case 2:
	              return _context13.abrupt("return", this.upstream.next());
	            case 3:
	            case "end":
	              return _context13.stop();
	          }
	        }, _callee13, this);
	      }));
	      function next() {
	        return _next5.apply(this, arguments);
	      }
	      return next;
	    }()
	  }]);
	  return TakeIterator;
	}(LazyIterator); // Note this batch just groups items into row-wise element arrays.
	// Rotating these to a column-wise representation happens only at the dataset
	// level.
	var RowMajorBatchIterator = /*#__PURE__*/function (_LazyIterator6) {
	  _inherits(RowMajorBatchIterator, _LazyIterator6);
	  var _super6 = _createSuper(RowMajorBatchIterator);
	  function RowMajorBatchIterator(upstream, batchSize) {
	    var _this8;
	    var enableSmallLastBatch = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
	    _classCallCheck(this, RowMajorBatchIterator);
	    _this8 = _super6.call(this);
	    _this8.upstream = upstream;
	    _this8.batchSize = batchSize;
	    _this8.enableSmallLastBatch = enableSmallLastBatch;
	    _this8.lastRead = Promise.resolve({
	      value: null,
	      done: false
	    });
	    return _this8;
	  }
	  _createClass(RowMajorBatchIterator, [{
	    key: "summary",
	    value: function summary() {
	      return "".concat(this.upstream.summary(), " -> RowMajorBatch");
	    }
	  }, {
	    key: "next",
	    value: function () {
	      var _next6 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee14() {
	        var _this9 = this;
	        return _regeneratorRuntime().wrap(function _callee14$(_context14) {
	          while (1) switch (_context14.prev = _context14.next) {
	            case 0:
	              // This sets this.lastRead to a new Promise right away, as opposed to
	              // saying `await this.lastRead; this.lastRead = this.serialNext();` which
	              // would not work because this.nextRead would be updated only after the
	              // promise resolves.
	              this.lastRead = this.lastRead.then(function () {
	                return _this9.serialNext();
	              });
	              return _context14.abrupt("return", this.lastRead);
	            case 2:
	            case "end":
	              return _context14.stop();
	          }
	        }, _callee14, this);
	      }));
	      function next() {
	        return _next6.apply(this, arguments);
	      }
	      return next;
	    }()
	  }, {
	    key: "serialNext",
	    value: function () {
	      var _serialNext3 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee15() {
	        var batch, item;
	        return _regeneratorRuntime().wrap(function _callee15$(_context15) {
	          while (1) switch (_context15.prev = _context15.next) {
	            case 0:
	              batch = [];
	            case 1:
	              if (!(batch.length < this.batchSize)) {
	                _context15.next = 12;
	                break;
	              }
	              _context15.next = 4;
	              return this.upstream.next();
	            case 4:
	              item = _context15.sent;
	              if (!item.done) {
	                _context15.next = 9;
	                break;
	              }
	              if (!(this.enableSmallLastBatch && batch.length > 0)) {
	                _context15.next = 8;
	                break;
	              }
	              return _context15.abrupt("return", {
	                value: batch,
	                done: false
	              });
	            case 8:
	              return _context15.abrupt("return", {
	                value: null,
	                done: true
	              });
	            case 9:
	              batch.push(item.value);
	              _context15.next = 1;
	              break;
	            case 12:
	              return _context15.abrupt("return", {
	                value: batch,
	                done: false
	              });
	            case 13:
	            case "end":
	              return _context15.stop();
	          }
	        }, _callee15, this);
	      }));
	      function serialNext() {
	        return _serialNext3.apply(this, arguments);
	      }
	      return serialNext;
	    }()
	  }]);
	  return RowMajorBatchIterator;
	}(LazyIterator);
	var FilterIterator = /*#__PURE__*/function (_LazyIterator7) {
	  _inherits(FilterIterator, _LazyIterator7);
	  var _super7 = _createSuper(FilterIterator);
	  function FilterIterator(upstream, predicate) {
	    var _this10;
	    _classCallCheck(this, FilterIterator);
	    _this10 = _super7.call(this);
	    _this10.upstream = upstream;
	    _this10.predicate = predicate;
	    _this10.lastRead = Promise.resolve({
	      value: null,
	      done: false
	    });
	    return _this10;
	  }
	  _createClass(FilterIterator, [{
	    key: "summary",
	    value: function summary() {
	      return "".concat(this.upstream.summary(), " -> Filter");
	    }
	  }, {
	    key: "next",
	    value: function () {
	      var _next7 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee16() {
	        var _this11 = this;
	        return _regeneratorRuntime().wrap(function _callee16$(_context16) {
	          while (1) switch (_context16.prev = _context16.next) {
	            case 0:
	              // This sets this.lastRead to a new Promise right away, as opposed to
	              // saying `await this.lastRead; this.lastRead = this.serialNext();` which
	              // would not work because this.nextRead would be updated only after the
	              // promise resolves.
	              this.lastRead = this.lastRead.then(function () {
	                return _this11.serialNext();
	              });
	              return _context16.abrupt("return", this.lastRead);
	            case 2:
	            case "end":
	              return _context16.stop();
	          }
	        }, _callee16, this);
	      }));
	      function next() {
	        return _next7.apply(this, arguments);
	      }
	      return next;
	    }()
	  }, {
	    key: "serialNext",
	    value: function () {
	      var _serialNext4 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee17() {
	        var item;
	        return _regeneratorRuntime().wrap(function _callee17$(_context17) {
	          while (1) switch (_context17.prev = _context17.next) {
	            case 0:
	              if (!true) {
	                _context17.next = 9;
	                break;
	              }
	              _context17.next = 3;
	              return this.upstream.next();
	            case 3:
	              item = _context17.sent;
	              if (!(item.done || this.predicate(item.value))) {
	                _context17.next = 6;
	                break;
	              }
	              return _context17.abrupt("return", item);
	            case 6:
	              dispose(item.value);
	              _context17.next = 0;
	              break;
	            case 9:
	            case "end":
	              return _context17.stop();
	          }
	        }, _callee17, this);
	      }));
	      function serialNext() {
	        return _serialNext4.apply(this, arguments);
	      }
	      return serialNext;
	    }()
	  }]);
	  return FilterIterator;
	}(LazyIterator);
	var MapIterator = /*#__PURE__*/function (_LazyIterator8) {
	  _inherits(MapIterator, _LazyIterator8);
	  var _super8 = _createSuper(MapIterator);
	  function MapIterator(upstream, transform) {
	    var _this12;
	    _classCallCheck(this, MapIterator);
	    _this12 = _super8.call(this);
	    _this12.upstream = upstream;
	    _this12.transform = transform;
	    return _this12;
	  }
	  _createClass(MapIterator, [{
	    key: "summary",
	    value: function summary() {
	      return "".concat(this.upstream.summary(), " -> Map");
	    }
	  }, {
	    key: "next",
	    value: function () {
	      var _next8 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee18() {
	        var item, inputTensors, mapped, outputTensors, _iterator, _step, t;
	        return _regeneratorRuntime().wrap(function _callee18$(_context18) {
	          while (1) switch (_context18.prev = _context18.next) {
	            case 0:
	              _context18.next = 2;
	              return this.upstream.next();
	            case 2:
	              item = _context18.sent;
	              if (!item.done) {
	                _context18.next = 5;
	                break;
	              }
	              return _context18.abrupt("return", {
	                value: null,
	                done: true
	              });
	            case 5:
	              inputTensors = getTensorsInContainer(item.value); // Careful: the transform may mutate the item in place.
	              // That's why we have to remember the input Tensors above, and then
	              // below dispose only those that were not passed through to the output.
	              // Note too that the transform function is responsible for tidying
	              // any intermediate Tensors.  Here we are concerned only about the
	              // inputs.
	              mapped = this.transform(item.value);
	              outputTensors = getTensorsInContainer(mapped); // TODO(soergel) faster intersection
	              // TODO(soergel) move to tf.disposeExcept(in, out)?
	              _iterator = _createForOfIteratorHelper(inputTensors);
	              try {
	                for (_iterator.s(); !(_step = _iterator.n()).done;) {
	                  t = _step.value;
	                  if (!isTensorInList(t, outputTensors)) {
	                    t.dispose();
	                  }
	                }
	              } catch (err) {
	                _iterator.e(err);
	              } finally {
	                _iterator.f();
	              }
	              return _context18.abrupt("return", {
	                value: mapped,
	                done: false
	              });
	            case 11:
	            case "end":
	              return _context18.stop();
	          }
	        }, _callee18, this);
	      }));
	      function next() {
	        return _next8.apply(this, arguments);
	      }
	      return next;
	    }()
	  }]);
	  return MapIterator;
	}(LazyIterator);
	var ErrorHandlingLazyIterator = /*#__PURE__*/function (_LazyIterator9) {
	  _inherits(ErrorHandlingLazyIterator, _LazyIterator9);
	  var _super9 = _createSuper(ErrorHandlingLazyIterator);
	  function ErrorHandlingLazyIterator(upstream, handler) {
	    var _this13;
	    _classCallCheck(this, ErrorHandlingLazyIterator);
	    _this13 = _super9.call(this);
	    _this13.upstream = upstream;
	    _this13.handler = handler;
	    _this13.count = 0;
	    _this13.lastRead = Promise.resolve({
	      value: null,
	      done: false
	    });
	    return _this13;
	  }
	  _createClass(ErrorHandlingLazyIterator, [{
	    key: "summary",
	    value: function summary() {
	      return "".concat(this.upstream.summary(), " -> handleErrors");
	    }
	  }, {
	    key: "next",
	    value: function () {
	      var _next9 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee19() {
	        var _this14 = this;
	        return _regeneratorRuntime().wrap(function _callee19$(_context19) {
	          while (1) switch (_context19.prev = _context19.next) {
	            case 0:
	              // This sets this.lastRead to a new Promise right away, as opposed to
	              // saying `await this.lastRead; this.lastRead = this.serialNext();` which
	              // would not work because this.nextRead would be updated only after the
	              // promise resolves.
	              this.lastRead = this.lastRead.then(function () {
	                return _this14.serialNext();
	              });
	              return _context19.abrupt("return", this.lastRead);
	            case 2:
	            case "end":
	              return _context19.stop();
	          }
	        }, _callee19, this);
	      }));
	      function next() {
	        return _next9.apply(this, arguments);
	      }
	      return next;
	    }()
	  }, {
	    key: "serialNext",
	    value: function () {
	      var _serialNext5 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee20() {
	        return _regeneratorRuntime().wrap(function _callee20$(_context20) {
	          while (1) switch (_context20.prev = _context20.next) {
	            case 0:
	              if (!true) {
	                _context20.next = 13;
	                break;
	              }
	              _context20.prev = 1;
	              _context20.next = 4;
	              return this.upstream.next();
	            case 4:
	              return _context20.abrupt("return", _context20.sent);
	            case 7:
	              _context20.prev = 7;
	              _context20.t0 = _context20["catch"](1);
	              if (this.handler(_context20.t0)) {
	                _context20.next = 11;
	                break;
	              }
	              return _context20.abrupt("return", {
	                value: null,
	                done: true
	              });
	            case 11:
	              _context20.next = 0;
	              break;
	            case 13:
	            case "end":
	              return _context20.stop();
	          }
	        }, _callee20, this, [[1, 7]]);
	      }));
	      function serialNext() {
	        return _serialNext5.apply(this, arguments);
	      }
	      return serialNext;
	    }()
	  }]);
	  return ErrorHandlingLazyIterator;
	}(LazyIterator);
	var AsyncMapIterator = /*#__PURE__*/function (_LazyIterator10) {
	  _inherits(AsyncMapIterator, _LazyIterator10);
	  var _super10 = _createSuper(AsyncMapIterator);
	  function AsyncMapIterator(upstream, transform) {
	    var _this15;
	    _classCallCheck(this, AsyncMapIterator);
	    _this15 = _super10.call(this);
	    _this15.upstream = upstream;
	    _this15.transform = transform;
	    return _this15;
	  }
	  _createClass(AsyncMapIterator, [{
	    key: "summary",
	    value: function summary() {
	      return "".concat(this.upstream.summary(), " -> AsyncMap");
	    }
	  }, {
	    key: "next",
	    value: function () {
	      var _next10 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee21() {
	        var item, inputTensors, mapped, outputTensors, _iterator2, _step2, t;
	        return _regeneratorRuntime().wrap(function _callee21$(_context21) {
	          while (1) switch (_context21.prev = _context21.next) {
	            case 0:
	              _context21.next = 2;
	              return this.upstream.next();
	            case 2:
	              item = _context21.sent;
	              if (!item.done) {
	                _context21.next = 5;
	                break;
	              }
	              return _context21.abrupt("return", {
	                value: null,
	                done: true
	              });
	            case 5:
	              inputTensors = getTensorsInContainer(item.value); // Careful: the transform may mutate the item in place.
	              // That's why we have to remember the input Tensors above, and then
	              // below dispose only those that were not passed through to the output.
	              // Note too that the transform function is responsible for tidying
	              // any intermediate Tensors.  Here we are concerned only about the
	              // inputs.
	              _context21.next = 8;
	              return this.transform(item.value);
	            case 8:
	              mapped = _context21.sent;
	              outputTensors = getTensorsInContainer(mapped); // TODO(soergel) faster intersection
	              // TODO(soergel) move to tf.disposeExcept(in, out)?
	              _iterator2 = _createForOfIteratorHelper(inputTensors);
	              try {
	                for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	                  t = _step2.value;
	                  if (!isTensorInList(t, outputTensors)) {
	                    t.dispose();
	                  }
	                }
	              } catch (err) {
	                _iterator2.e(err);
	              } finally {
	                _iterator2.f();
	              }
	              return _context21.abrupt("return", {
	                value: mapped,
	                done: false
	              });
	            case 13:
	            case "end":
	              return _context21.stop();
	          }
	        }, _callee21, this);
	      }));
	      function next() {
	        return _next10.apply(this, arguments);
	      }
	      return next;
	    }()
	  }]);
	  return AsyncMapIterator;
	}(LazyIterator); // Iterators that maintain a queue of pending items
	// ============================================================================
	/**
	 * A base class for transforming streams that operate by maintaining an
	 * output queue of elements that are ready to return via next().  This is
	 * commonly required when the transformation is 1-to-many:  A call to next()
	 * may trigger a call to the underlying stream, which will produce many
	 * mapped elements of this stream-- of which we need to return only one, so
	 * we have to queue the rest.
	 */
	var OneToManyIterator = /*#__PURE__*/function (_LazyIterator11) {
	  _inherits(OneToManyIterator, _LazyIterator11);
	  var _super11 = _createSuper(OneToManyIterator);
	  function OneToManyIterator() {
	    var _this16;
	    _classCallCheck(this, OneToManyIterator);
	    _this16 = _super11.call(this);
	    _this16.outputQueue = new GrowingRingBuffer();
	    _this16.lastRead = Promise.resolve({
	      value: null,
	      done: false
	    });
	    return _this16;
	  }
	  _createClass(OneToManyIterator, [{
	    key: "next",
	    value: function () {
	      var _next11 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee22() {
	        var _this17 = this;
	        return _regeneratorRuntime().wrap(function _callee22$(_context22) {
	          while (1) switch (_context22.prev = _context22.next) {
	            case 0:
	              // This sets this.lastRead to a new Promise right away, as opposed to
	              // saying `await this.lastRead; this.lastRead = this.serialNext();` which
	              // would not work because this.nextRead would be updated only after the
	              // promise resolves.
	              this.lastRead = this.lastRead.then(function () {
	                return _this17.serialNext();
	              });
	              return _context22.abrupt("return", this.lastRead);
	            case 2:
	            case "end":
	              return _context22.stop();
	          }
	        }, _callee22, this);
	      }));
	      function next() {
	        return _next11.apply(this, arguments);
	      }
	      return next;
	    }()
	  }, {
	    key: "serialNext",
	    value: function () {
	      var _serialNext6 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee23() {
	        return _regeneratorRuntime().wrap(function _callee23$(_context23) {
	          while (1) switch (_context23.prev = _context23.next) {
	            case 0:
	              if (!(this.outputQueue.length() === 0)) {
	                _context23.next = 7;
	                break;
	              }
	              _context23.next = 3;
	              return this.pump();
	            case 3:
	              if (_context23.sent) {
	                _context23.next = 5;
	                break;
	              }
	              return _context23.abrupt("return", {
	                value: null,
	                done: true
	              });
	            case 5:
	              _context23.next = 0;
	              break;
	            case 7:
	              return _context23.abrupt("return", {
	                value: this.outputQueue.shift(),
	                done: false
	              });
	            case 8:
	            case "end":
	              return _context23.stop();
	          }
	        }, _callee23, this);
	      }));
	      function serialNext() {
	        return _serialNext6.apply(this, arguments);
	      }
	      return serialNext;
	    }()
	  }]);
	  return OneToManyIterator;
	}(LazyIterator);
	var FlatmapIterator = /*#__PURE__*/function (_OneToManyIterator) {
	  _inherits(FlatmapIterator, _OneToManyIterator);
	  var _super12 = _createSuper(FlatmapIterator);
	  function FlatmapIterator(upstream, transform) {
	    var _this18;
	    _classCallCheck(this, FlatmapIterator);
	    _this18 = _super12.call(this);
	    _this18.upstream = upstream;
	    _this18.transform = transform;
	    return _this18;
	  }
	  _createClass(FlatmapIterator, [{
	    key: "summary",
	    value: function summary() {
	      return "".concat(this.upstream.summary(), " -> Flatmap");
	    }
	  }, {
	    key: "pump",
	    value: function () {
	      var _pump = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee24() {
	        var item, inputTensors, mappedArray, outputTensors, _iterator3, _step3, t;
	        return _regeneratorRuntime().wrap(function _callee24$(_context24) {
	          while (1) switch (_context24.prev = _context24.next) {
	            case 0:
	              _context24.next = 2;
	              return this.upstream.next();
	            case 2:
	              item = _context24.sent;
	              if (!item.done) {
	                _context24.next = 5;
	                break;
	              }
	              return _context24.abrupt("return", false);
	            case 5:
	              inputTensors = getTensorsInContainer(item.value); // Careful: the transform may mutate the item in place.
	              // that's why we have to remember the input Tensors above, and then
	              // below dispose only those that were not passed through to the output.
	              // Note too that the transform function is responsible for tidying any
	              // intermediate Tensors.  Here we are concerned only about the inputs.
	              mappedArray = this.transform(item.value);
	              outputTensors = getTensorsInContainer(mappedArray);
	              this.outputQueue.pushAll(mappedArray);
	              // TODO(soergel) faster intersection, and deduplicate outputTensors
	              // TODO(soergel) move to tf.disposeExcept(in, out)?
	              _iterator3 = _createForOfIteratorHelper(inputTensors);
	              try {
	                for (_iterator3.s(); !(_step3 = _iterator3.n()).done;) {
	                  t = _step3.value;
	                  if (!isTensorInList(t, outputTensors)) {
	                    t.dispose();
	                  }
	                }
	              } catch (err) {
	                _iterator3.e(err);
	              } finally {
	                _iterator3.f();
	              }
	              return _context24.abrupt("return", true);
	            case 12:
	            case "end":
	              return _context24.stop();
	          }
	        }, _callee24, this);
	      }));
	      function pump() {
	        return _pump.apply(this, arguments);
	      }
	      return pump;
	    }()
	  }]);
	  return FlatmapIterator;
	}(OneToManyIterator);
	/**
	 * Provides a `LazyIterator` that concatenates a stream of underlying
	 * streams.
	 *
	 * Doing this in a concurrency-safe way requires some trickery.  In
	 * particular, we want this stream to return the elements from the
	 * underlying streams in the correct order according to when next() was
	 * called, even if the resulting Promises resolve in a different order.
	 */
	var ChainedIterator = /*#__PURE__*/function (_LazyIterator12) {
	  _inherits(ChainedIterator, _LazyIterator12);
	  var _super13 = _createSuper(ChainedIterator);
	  function ChainedIterator(iterators, baseErrorHandler) {
	    var _this19;
	    _classCallCheck(this, ChainedIterator);
	    _this19 = _super13.call(this);
	    _this19.baseErrorHandler = baseErrorHandler;
	    // Strict Promise execution order:
	    // a next() call may not even begin until the previous one completes.
	    _this19.lastRead = null;
	    // Local state that should not be clobbered by out-of-order execution.
	    _this19.iterator = null;
	    _this19.moreIterators = iterators;
	    return _this19;
	  }
	  _createClass(ChainedIterator, [{
	    key: "summary",
	    value: function summary() {
	      var upstreamSummaries = 'TODO: fill in upstream of chained summaries';
	      return "".concat(upstreamSummaries, " -> Chained");
	    }
	  }, {
	    key: "next",
	    value: function () {
	      var _next12 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee25() {
	        return _regeneratorRuntime().wrap(function _callee25$(_context25) {
	          while (1) switch (_context25.prev = _context25.next) {
	            case 0:
	              this.lastRead = this.readFromChain(this.lastRead);
	              return _context25.abrupt("return", this.lastRead);
	            case 2:
	            case "end":
	              return _context25.stop();
	          }
	        }, _callee25, this);
	      }));
	      function next() {
	        return _next12.apply(this, arguments);
	      }
	      return next;
	    }()
	  }, {
	    key: "readFromChain",
	    value: function () {
	      var _readFromChain = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee26(lastRead) {
	        var iteratorResult, itemResult;
	        return _regeneratorRuntime().wrap(function _callee26$(_context26) {
	          while (1) switch (_context26.prev = _context26.next) {
	            case 0:
	              _context26.next = 2;
	              return lastRead;
	            case 2:
	              if (!(this.iterator == null)) {
	                _context26.next = 10;
	                break;
	              }
	              _context26.next = 5;
	              return this.moreIterators.next();
	            case 5:
	              iteratorResult = _context26.sent;
	              if (!iteratorResult.done) {
	                _context26.next = 8;
	                break;
	              }
	              return _context26.abrupt("return", {
	                value: null,
	                done: true
	              });
	            case 8:
	              this.iterator = iteratorResult.value;
	              if (this.baseErrorHandler != null) {
	                this.iterator = this.iterator.handleErrors(this.baseErrorHandler);
	              }
	            case 10:
	              _context26.next = 12;
	              return this.iterator.next();
	            case 12:
	              itemResult = _context26.sent;
	              if (!itemResult.done) {
	                _context26.next = 16;
	                break;
	              }
	              this.iterator = null;
	              return _context26.abrupt("return", this.readFromChain(lastRead));
	            case 16:
	              return _context26.abrupt("return", itemResult);
	            case 17:
	            case "end":
	              return _context26.stop();
	          }
	        }, _callee26, this);
	      }));
	      function readFromChain(_x4) {
	        return _readFromChain.apply(this, arguments);
	      }
	      return readFromChain;
	    }()
	  }]);
	  return ChainedIterator;
	}(LazyIterator);
	var ZipMismatchMode;
	(function (ZipMismatchMode) {
	  ZipMismatchMode[ZipMismatchMode["FAIL"] = 0] = "FAIL";
	  ZipMismatchMode[ZipMismatchMode["SHORTEST"] = 1] = "SHORTEST";
	  ZipMismatchMode[ZipMismatchMode["LONGEST"] = 2] = "LONGEST"; // use nulls for exhausted streams; use up the longest stream.
	})(ZipMismatchMode || (ZipMismatchMode = {}));
	/**
	 * Provides a `LazyIterator` that zips together an array, dict, or nested
	 * structure of `LazyIterator`s (and perhaps additional constants).
	 *
	 * The underlying streams must provide elements in a consistent order such
	 * that they correspond.
	 *
	 * Typically, the underlying streams should have the same number of
	 * elements. If they do not, the behavior is determined by the
	 * `mismatchMode` argument.
	 *
	 * The nested structure of the `iterators` argument determines the
	 * structure of elements in the resulting iterator.
	 *
	 * Doing this in a concurrency-safe way requires some trickery.  In
	 * particular, we want this stream to return the elements from the
	 * underlying streams in the correct order according to when next() was
	 * called, even if the resulting Promises resolve in a different order.
	 *
	 * @param iterators: An array or object containing LazyIterators at the
	 * leaves.
	 * @param mismatchMode: Determines what to do when one underlying iterator
	 * is exhausted before the others.  `ZipMismatchMode.FAIL` (the default)
	 * causes an error to be thrown in this case.  `ZipMismatchMode.SHORTEST`
	 * causes the zipped iterator to terminate with the furst underlying
	 * streams, so elements remaining on the longer streams are ignored.
	 * `ZipMismatchMode.LONGEST` causes the zipped stream to continue, filling
	 * in nulls for the exhausted streams, until all streams are exhausted.
	 */
	var ZipIterator = /*#__PURE__*/function (_LazyIterator13) {
	  _inherits(ZipIterator, _LazyIterator13);
	  var _super14 = _createSuper(ZipIterator);
	  function ZipIterator(iterators) {
	    var _this20;
	    var mismatchMode = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : ZipMismatchMode.FAIL;
	    _classCallCheck(this, ZipIterator);
	    _this20 = _super14.call(this);
	    _this20.iterators = iterators;
	    _this20.mismatchMode = mismatchMode;
	    _this20.count = 0;
	    _this20.currentPromise = null;
	    return _this20;
	  }
	  _createClass(ZipIterator, [{
	    key: "summary",
	    value: function summary() {
	      var upstreamSummaries = 'TODO: fill in upstream of zip summaries';
	      return "{".concat(upstreamSummaries, "} -> Zip");
	    }
	  }, {
	    key: "nextState",
	    value: function () {
	      var _nextState = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee27(afterState) {
	        var numIterators, iteratorsDone, getNext, mapped;
	        return _regeneratorRuntime().wrap(function _callee27$(_context27) {
	          while (1) switch (_context27.prev = _context27.next) {
	            case 0:
	              getNext = function _getNext(container) {
	                if (container instanceof LazyIterator) {
	                  var result = container.next();
	                  return {
	                    value: result.then(function (x) {
	                      numIterators++;
	                      if (x.done) {
	                        iteratorsDone++;
	                      }
	                      return x.value;
	                    }),
	                    recurse: false
	                  };
	                } else {
	                  return {
	                    value: null,
	                    recurse: true
	                  };
	                }
	              };
	              _context27.next = 3;
	              return afterState;
	            case 3:
	              // Collect underlying iterator "done" signals as a side effect in
	              // getNext()
	              numIterators = 0;
	              iteratorsDone = 0;
	              _context27.next = 7;
	              return deepMapAndAwaitAll(this.iterators, getNext);
	            case 7:
	              mapped = _context27.sent;
	              if (!(numIterators === iteratorsDone)) {
	                _context27.next = 10;
	                break;
	              }
	              return _context27.abrupt("return", {
	                value: null,
	                done: true
	              });
	            case 10:
	              if (!(iteratorsDone > 0)) {
	                _context27.next = 16;
	                break;
	              }
	              _context27.t0 = this.mismatchMode;
	              _context27.next = _context27.t0 === ZipMismatchMode.FAIL ? 14 : _context27.t0 === ZipMismatchMode.SHORTEST ? 15 : _context27.t0 === ZipMismatchMode.LONGEST ? 16 : 16;
	              break;
	            case 14:
	              throw new Error('Zipped streams should have the same length. ' + "Mismatched at element ".concat(this.count, "."));
	            case 15:
	              return _context27.abrupt("return", {
	                value: null,
	                done: true
	              });
	            case 16:
	              this.count++;
	              return _context27.abrupt("return", {
	                value: mapped,
	                done: false
	              });
	            case 18:
	            case "end":
	              return _context27.stop();
	          }
	        }, _callee27, this);
	      }));
	      function nextState(_x5) {
	        return _nextState.apply(this, arguments);
	      }
	      return nextState;
	    }()
	  }, {
	    key: "next",
	    value: function () {
	      var _next13 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee28() {
	        return _regeneratorRuntime().wrap(function _callee28$(_context28) {
	          while (1) switch (_context28.prev = _context28.next) {
	            case 0:
	              this.currentPromise = this.nextState(this.currentPromise);
	              return _context28.abrupt("return", this.currentPromise);
	            case 2:
	            case "end":
	              return _context28.stop();
	          }
	        }, _callee28, this);
	      }));
	      function next() {
	        return _next13.apply(this, arguments);
	      }
	      return next;
	    }()
	  }]);
	  return ZipIterator;
	}(LazyIterator); // Iterators that maintain a ring buffer of pending promises
	// ============================================================================
	/**
	 * A stream that prefetches a given number of items from an upstream source,
	 * returning them in FIFO order.
	 *
	 * Note this prefetches Promises, but makes no guarantees about when those
	 * Promises resolve.
	 */
	var PrefetchIterator = /*#__PURE__*/function (_LazyIterator14) {
	  _inherits(PrefetchIterator, _LazyIterator14);
	  var _super15 = _createSuper(PrefetchIterator);
	  function PrefetchIterator(upstream, bufferSize) {
	    var _this21;
	    _classCallCheck(this, PrefetchIterator);
	    _this21 = _super15.call(this);
	    _this21.upstream = upstream;
	    _this21.bufferSize = bufferSize;
	    _this21.buffer = new RingBuffer(bufferSize);
	    return _this21;
	  }
	  _createClass(PrefetchIterator, [{
	    key: "summary",
	    value: function summary() {
	      return "".concat(this.upstream.summary(), " -> Prefetch");
	    }
	    /**
	     * Refill the prefetch buffer.  Returns only after the buffer is full, or
	     * the upstream source is exhausted.
	     */
	  }, {
	    key: "refill",
	    value: function refill() {
	      while (!this.buffer.isFull()) {
	        var v = this.upstream.next();
	        this.buffer.push(v);
	      }
	    }
	  }, {
	    key: "next",
	    value: function next() {
	      this.refill();
	      // This shift will never throw an error because the buffer is always
	      // full after a refill. If the stream is exhausted, the buffer will be
	      // full of Promises that will resolve to the end-of-stream signal.
	      return this.buffer.shift();
	    }
	  }]);
	  return PrefetchIterator;
	}(LazyIterator);
	/**
	 * A stream that performs a sliding-window random shuffle on an upstream
	 * source. This is like a `PrefetchIterator` except that the items are
	 * returned in randomized order.  Mixing naturally improves as the buffer
	 * size increases.
	 */
	var ShuffleIterator = /*#__PURE__*/function (_PrefetchIterator) {
	  _inherits(ShuffleIterator, _PrefetchIterator);
	  var _super16 = _createSuper(ShuffleIterator);
	  function ShuffleIterator(upstream, windowSize, seed) {
	    var _this22;
	    _classCallCheck(this, ShuffleIterator);
	    _this22 = _super16.call(this, upstream, windowSize);
	    _this22.upstream = upstream;
	    _this22.windowSize = windowSize;
	    // Local state that should not be clobbered by out-of-order execution.
	    _this22.upstreamExhausted = false;
	    _this22.random = seedrandom.alea(seed || now().toString());
	    _this22.lastRead = Promise.resolve({
	      value: null,
	      done: false
	    });
	    return _this22;
	  }
	  _createClass(ShuffleIterator, [{
	    key: "next",
	    value: function () {
	      var _next14 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee29() {
	        var _this23 = this;
	        return _regeneratorRuntime().wrap(function _callee29$(_context29) {
	          while (1) switch (_context29.prev = _context29.next) {
	            case 0:
	              // This sets this.lastRead to a new Promise right away, as opposed to
	              // saying `await this.lastRead; this.lastRead = this.serialNext();` which
	              // would not work because this.nextRead would be updated only after the
	              // promise resolves.
	              this.lastRead = this.lastRead.then(function () {
	                return _this23.serialNext();
	              });
	              return _context29.abrupt("return", this.lastRead);
	            case 2:
	            case "end":
	              return _context29.stop();
	          }
	        }, _callee29, this);
	      }));
	      function next() {
	        return _next14.apply(this, arguments);
	      }
	      return next;
	    }()
	  }, {
	    key: "randomInt",
	    value: function randomInt(max) {
	      return Math.floor(this.random() * max);
	    }
	  }, {
	    key: "chooseIndex",
	    value: function chooseIndex() {
	      return this.randomInt(this.buffer.length());
	    }
	  }, {
	    key: "serialNext",
	    value: function () {
	      var _serialNext7 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee30() {
	        var chosenIndex, result;
	        return _regeneratorRuntime().wrap(function _callee30$(_context30) {
	          while (1) switch (_context30.prev = _context30.next) {
	            case 0:
	              // TODO(soergel): consider performance
	              if (!this.upstreamExhausted) {
	                this.refill();
	              }
	            case 1:
	              if (this.buffer.isEmpty()) {
	                _context30.next = 14;
	                break;
	              }
	              chosenIndex = this.chooseIndex();
	              _context30.next = 5;
	              return this.buffer.shuffleExcise(chosenIndex);
	            case 5:
	              result = _context30.sent;
	              if (!result.done) {
	                _context30.next = 10;
	                break;
	              }
	              this.upstreamExhausted = true;
	              _context30.next = 12;
	              break;
	            case 10:
	              this.refill();
	              return _context30.abrupt("return", result);
	            case 12:
	              _context30.next = 1;
	              break;
	            case 14:
	              return _context30.abrupt("return", {
	                value: null,
	                done: true
	              });
	            case 15:
	            case "end":
	              return _context30.stop();
	          }
	        }, _callee30, this);
	      }));
	      function serialNext() {
	        return _serialNext7.apply(this, arguments);
	      }
	      return serialNext;
	    }()
	  }]);
	  return ShuffleIterator;
	}(PrefetchIterator);

	// TODO(soergel): consider vectorized operations within the pipeline.
	/**
	 * Represents a potentially large list of independent data elements (typically
	 * 'samples' or 'examples').
	 *
	 * A 'data example' may be a primitive, an array, a map from string keys to
	 * values, or any nested structure of these.
	 *
	 * A `Dataset` represents an ordered collection of elements, together with a
	 * chain of transformations to be performed on those elements. Each
	 * transformation is a method of `Dataset` that returns another `Dataset`, so
	 * these may be chained, e.g.
	 * `const processedDataset = rawDataset.filter(...).map(...).batch(...)`.
	 *
	 * Data loading and transformation is done in a lazy, streaming fashion.  The
	 * dataset may be iterated over multiple times; each iteration starts the data
	 * loading anew and recapitulates the transformations.
	 *
	 * A `Dataset` is typically processed as a stream of unbatched examples -- i.e.,
	 * its transformations are applied one example at a time. Batching produces a
	 * new `Dataset` where each element is a batch. Batching should usually come
	 * last in a pipeline, because data transformations are easier to express on a
	 * per-example basis than on a per-batch basis.
	 *
	 * The following code examples are calling `await dataset.forEachAsync(...)` to
	 * iterate once over the entire dataset in order to print out the data.
	 *
	 * @doc {heading: 'Data', subheading: 'Classes', namespace: 'data'}
	 */
	var Dataset = /*#__PURE__*/function () {
	  function Dataset() {
	    _classCallCheck(this, Dataset);
	    this.size = null;
	  }
	  // TODO(soergel): Make Datasets report whether repeated iterator() calls
	  // produce the same result (e.g., reading from a file) or different results
	  // (e.g., from the webcam).  Currently we don't make this distinction but it
	  // could be important for the user to know.
	  // abstract isDeterministic(): boolean;
	  /**
	   * Groups elements into batches.
	   *
	   * It is assumed that each of the incoming dataset elements has the same
	   * structure -- i.e. the same set of keys at each location in an object
	   * hierarchy.  For each key, the resulting `Dataset` provides a batched
	   * element collecting all of the incoming values for that key.
	   *
	   *  * Incoming primitives are grouped into a 1-D Tensor.
	   *  * Incoming Tensors are grouped into a new Tensor where the 0th axis is
	   *    the batch dimension.
	   *  * Incoming arrays are converted to Tensor and then batched.
	   *  * A nested array is interpreted as an n-D Tensor, so the batched result
	   *    has n+1 dimensions.
	   *  * An array that cannot be converted to Tensor produces an error.
	   *
	   * If an array should not be batched as a unit, it should first be converted
	   * to an object with integer keys.
	   *
	   * Here are a few examples:
	   *
	   * Batch a dataset of numbers:
	   * ```js
	   * const a = tf.data.array([1, 2, 3, 4, 5, 6, 7, 8]).batch(4);
	   * await a.forEachAsync(e => e.print());
	   * ```
	   *
	   * Batch a dataset of arrays:
	   * ```js
	   * const b = tf.data.array([[1], [2], [3], [4], [5], [6], [7], [8]]).batch(4);
	   * await b.forEachAsync(e => e.print());
	   * ```
	   *
	   * Batch a dataset of objects:
	   * ```js
	   * const c = tf.data.array([{a: 1, b: 11}, {a: 2, b: 12}, {a: 3, b: 13},
	   *   {a: 4, b: 14}, {a: 5, b: 15}, {a: 6, b: 16}, {a: 7, b: 17},
	   *   {a: 8, b: 18}]).batch(4);
	   * await c.forEachAsync(e => {
	   *   console.log('{');
	   *   for(var key in e) {
	   *     console.log(key+':');
	   *     e[key].print();
	   *   }
	   *   console.log('}');
	   * })
	   * ```
	   *
	   * @param batchSize The number of elements desired per batch.
	   * @param smallLastBatch Whether to emit the final batch when it has fewer
	   *   than batchSize elements. Default true.
	   * @returns A `Dataset`, from which a stream of batches can be obtained.
	   *
	   * @doc {heading: 'Data', subheading: 'Classes'}
	   */
	  _createClass(Dataset, [{
	    key: "batch",
	    value: function batch(batchSize) {
	      var smallLastBatch = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
	      var base = this;
	      assert$1(batchSize > 0, function () {
	        return "batchSize needs to be positive, but it is\n      ".concat(batchSize);
	      });
	      var size;
	      if (this.size === Infinity || this.size == null) {
	        // If the size of this dataset is infinity or null, the new size keeps the
	        // same.
	        size = this.size;
	      } else if (smallLastBatch) {
	        // If the size of this dataset is known and include small last batch, the
	        // new size is full batch count plus last batch.
	        size = Math.ceil(this.size / batchSize);
	      } else {
	        // If the size of this dataset is known and not include small last batch,
	        // the new size is full batch count.
	        size = Math.floor(this.size / batchSize);
	      }
	      return datasetFromIteratorFn( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              _context.next = 2;
	              return base.iterator();
	            case 2:
	              return _context.abrupt("return", _context.sent.columnMajorBatch(batchSize, smallLastBatch, deepBatchConcat));
	            case 3:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee);
	      })), size);
	    }
	    /**
	     * Concatenates this `Dataset` with another.
	     *
	     * ```js
	     * const a = tf.data.array([1, 2, 3]);
	     * const b = tf.data.array([4, 5, 6]);
	     * const c = a.concatenate(b);
	     * await c.forEachAsync(e => console.log(e));
	     * ```
	     *
	     * @param dataset A `Dataset` to be concatenated onto this one.
	     * @returns A `Dataset`.
	     *
	     * @doc {heading: 'Data', subheading: 'Classes'}
	     */
	  }, {
	    key: "concatenate",
	    value: function concatenate(dataset) {
	      var base = this;
	      var size;
	      if (this.size === Infinity || dataset.size === Infinity) {
	        // If the size of any of these two dataset is infinity, new size is
	        // infinity.
	        size = Infinity;
	      } else if (this.size != null && dataset.size != null) {
	        // If the size of both datasets are known and not infinity, new size is
	        // sum the size of these two datasets.
	        size = this.size + dataset.size;
	      } else {
	        // If neither of these two datasets has infinite size and any of these two
	        // datasets' size is null, the new size is null.
	        size = null;
	      }
	      return datasetFromIteratorFn( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2() {
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              _context2.next = 2;
	              return base.iterator();
	            case 2:
	              _context2.t0 = _context2.sent;
	              _context2.next = 5;
	              return dataset.iterator();
	            case 5:
	              _context2.t1 = _context2.sent;
	              return _context2.abrupt("return", _context2.t0.concatenate.call(_context2.t0, _context2.t1));
	            case 7:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2);
	      })), size);
	    }
	    /**
	     * Filters this dataset according to `predicate`.
	     *
	     * ```js
	     * const a = tf.data.array([1, 2, 3, 4, 5, 6, 7, 8, 9, 10])
	     *   .filter(x => x%2 === 0);
	     * await a.forEachAsync(e => console.log(e));
	     * ```
	     *
	     * @param predicate A function mapping a dataset element to a boolean or a
	     * `Promise` for one.
	     *
	     * @returns A `Dataset` of elements for which the predicate was true.
	     *
	     * @doc {heading: 'Data', subheading: 'Classes'}
	     */
	  }, {
	    key: "filter",
	    value: function filter(predicate) {
	      var base = this;
	      var size;
	      if (this.size === Infinity) {
	        // If the size of this dataset is infinity, new size is infinity
	        size = Infinity;
	      } else {
	        // If this dataset has limited elements, new size is null because it might
	        // exhausted randomly.
	        size = null;
	      }
	      return datasetFromIteratorFn( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3() {
	        return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	          while (1) switch (_context3.prev = _context3.next) {
	            case 0:
	              _context3.next = 2;
	              return base.iterator();
	            case 2:
	              return _context3.abrupt("return", _context3.sent.filter(function (x) {
	                return tidy(function () {
	                  return predicate(x);
	                });
	              }));
	            case 3:
	            case "end":
	              return _context3.stop();
	          }
	        }, _callee3);
	      })), size);
	    }
	    /**
	     * Apply a function to every element of the dataset.
	     *
	     * After the function is applied to a dataset element, any Tensors contained
	     * within that element are disposed.
	     *
	     * ```js
	     * const a = tf.data.array([1, 2, 3]);
	     * await a.forEachAsync(e => console.log(e));
	     * ```
	     *
	     * @param f A function to apply to each dataset element.
	     * @returns A `Promise` that resolves after all elements have been processed.
	     *
	     * @doc {heading: 'Data', subheading: 'Classes'}
	     */
	  }, {
	    key: "forEachAsync",
	    value: function () {
	      var _forEachAsync = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4(f) {
	        return _regeneratorRuntime().wrap(function _callee4$(_context4) {
	          while (1) switch (_context4.prev = _context4.next) {
	            case 0:
	              _context4.next = 2;
	              return this.iterator();
	            case 2:
	              return _context4.abrupt("return", _context4.sent.forEachAsync(f));
	            case 3:
	            case "end":
	              return _context4.stop();
	          }
	        }, _callee4, this);
	      }));
	      function forEachAsync(_x) {
	        return _forEachAsync.apply(this, arguments);
	      }
	      return forEachAsync;
	    }()
	    /**
	     * Maps this dataset through a 1-to-1 transform.
	     *
	     * ```js
	     * const a = tf.data.array([1, 2, 3]).map(x => x*x);
	     * await a.forEachAsync(e => console.log(e));
	     * ```
	     *
	     * @param transform A function mapping a dataset element to a transformed
	     *   dataset element.
	     *
	     * @returns A `Dataset` of transformed elements.
	     *
	     * @doc {heading: 'Data', subheading: 'Classes'}
	     */
	  }, {
	    key: "map",
	    value: function map(transform) {
	      var base = this;
	      return datasetFromIteratorFn( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee5() {
	        return _regeneratorRuntime().wrap(function _callee5$(_context5) {
	          while (1) switch (_context5.prev = _context5.next) {
	            case 0:
	              _context5.next = 2;
	              return base.iterator();
	            case 2:
	              return _context5.abrupt("return", _context5.sent.map(function (x) {
	                return tidy(function () {
	                  return transform(x);
	                });
	              }));
	            case 3:
	            case "end":
	              return _context5.stop();
	          }
	        }, _callee5);
	      })), this.size);
	    }
	    /**
	     * Maps this dataset through an async 1-to-1 transform.
	     *
	     * ```js
	     * const a =
	     *  tf.data.array([1, 2, 3]).mapAsync(x => new Promise(function(resolve){
	     *    setTimeout(() => {
	     *      resolve(x * x);
	     *    }, Math.random()*1000 + 500);
	     *  }));
	     * console.log(await a.toArray());
	     * ```
	     *
	     * @param transform A function mapping a dataset element to a `Promise` for a
	     *   transformed dataset element.  This transform is responsible for disposing
	     *   any intermediate `Tensor`s, i.e. by wrapping its computation in
	     *   `tf.tidy()`; that cannot be automated here (as it is in the synchronous
	     *   `map()` case).
	     *
	     * @returns A `Dataset` of transformed elements.
	     *
	     * @doc {heading: 'Data', subheading: 'Classes'}
	     */
	  }, {
	    key: "mapAsync",
	    value: function mapAsync(transform) {
	      var base = this;
	      return datasetFromIteratorFn( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee6() {
	        return _regeneratorRuntime().wrap(function _callee6$(_context6) {
	          while (1) switch (_context6.prev = _context6.next) {
	            case 0:
	              _context6.next = 2;
	              return base.iterator();
	            case 2:
	              return _context6.abrupt("return", _context6.sent.mapAsync(transform));
	            case 3:
	            case "end":
	              return _context6.stop();
	          }
	        }, _callee6);
	      })), this.size);
	    }
	    /**
	     *  Creates a `Dataset` that prefetches elements from this dataset.
	     *
	     * @param bufferSize: An integer specifying the number of elements to be
	     *   prefetched.
	     * @returns A `Dataset`.
	     *
	     * @doc {heading: 'Data', subheading: 'Classes'}
	     */
	  }, {
	    key: "prefetch",
	    value: function prefetch(bufferSize) {
	      if (bufferSize == null) {
	        throw new RangeError('`Dataset.prefetch()` requires bufferSize to be specified.');
	      }
	      var base = this;
	      return datasetFromIteratorFn( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee7() {
	        return _regeneratorRuntime().wrap(function _callee7$(_context7) {
	          while (1) switch (_context7.prev = _context7.next) {
	            case 0:
	              _context7.next = 2;
	              return base.iterator();
	            case 2:
	              return _context7.abrupt("return", _context7.sent.prefetch(bufferSize));
	            case 3:
	            case "end":
	              return _context7.stop();
	          }
	        }, _callee7);
	      })), this.size);
	    }
	    /**
	     * Repeats this dataset `count` times.
	     *
	     * NOTE: If this dataset is a function of global state (e.g. a random number
	     * generator), then different repetitions may produce different elements.
	     *
	     * ```js
	     * const a = tf.data.array([1, 2, 3]).repeat(3);
	     * await a.forEachAsync(e => console.log(e));
	     * ```
	     *
	     * @param count: (Optional) An integer, representing the number of times
	     *   the dataset should be repeated. The default behavior (if `count` is
	     *   `undefined` or negative) is for the dataset be repeated indefinitely.
	     * @returns A `Dataset`.
	     *
	     * @doc {heading: 'Data', subheading: 'Classes'}
	     */
	  }, {
	    key: "repeat",
	    value: function repeat(count) {
	      var base = this;
	      var size;
	      if (this.size != null && count > 0) {
	        // If this dataset has size and count is positive, new size is current
	        // size multiply count. This also covers the case that current size is
	        // infinity.
	        size = this.size * count;
	      } else if (count === 0) {
	        // If count is 0, new size is 0.
	        size = 0;
	      } else if (this.size != null && (count === undefined || count < 0)) {
	        // If this dataset has size and count is undefined or negative, the
	        // dataset will be repeated indefinitely and new size is infinity.
	        size = Infinity;
	      } else {
	        // If the size of this dataset is null, the new dataset's size is null.
	        size = null;
	      }
	      return datasetFromIteratorFn( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee9() {
	        var iteratorIterator;
	        return _regeneratorRuntime().wrap(function _callee9$(_context9) {
	          while (1) switch (_context9.prev = _context9.next) {
	            case 0:
	              iteratorIterator = iteratorFromFunction( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee8() {
	                return _regeneratorRuntime().wrap(function _callee8$(_context8) {
	                  while (1) switch (_context8.prev = _context8.next) {
	                    case 0:
	                      _context8.next = 2;
	                      return base.iterator();
	                    case 2:
	                      _context8.t0 = _context8.sent;
	                      return _context8.abrupt("return", {
	                        value: _context8.t0,
	                        done: false
	                      });
	                    case 4:
	                    case "end":
	                      return _context8.stop();
	                  }
	                }, _callee8);
	              })));
	              return _context9.abrupt("return", iteratorFromConcatenated(iteratorIterator.take(count)));
	            case 2:
	            case "end":
	              return _context9.stop();
	          }
	        }, _callee9);
	      })), size);
	    }
	    /**
	     * Creates a `Dataset` that skips `count` initial elements from this dataset.
	     *
	     * ```js
	     * const a = tf.data.array([1, 2, 3, 4, 5, 6]).skip(3);
	     * await a.forEachAsync(e => console.log(e));
	     * ```
	     *
	     * @param count: The number of elements of this dataset that should be skipped
	     *   to form the new dataset.  If `count` is greater than the size of this
	     *   dataset, the new dataset will contain no elements.  If `count`
	     *   is `undefined` or negative, skips the entire dataset.
	     *
	     * @returns A `Dataset`.
	     *
	     * @doc {heading: 'Data', subheading: 'Classes'}
	     */
	  }, {
	    key: "skip",
	    value: function skip(count) {
	      var base = this;
	      var size;
	      if (this.size != null && count >= 0 && this.size >= count) {
	        // If the size of this dataset is greater than count, the new dataset's
	        // size is current size minus skipped size.This also covers the case that
	        // current size is infinity.
	        size = this.size - count;
	      } else if (this.size != null && (this.size < count || count === undefined || count < 0)) {
	        // If the size of this dataset is smaller than count, or count is
	        // undefined or negative, skips the entire dataset and the new size is 0.
	        size = 0;
	      } else {
	        // If the size of this dataset is null, the new dataset's size is null.
	        size = null;
	      }
	      return datasetFromIteratorFn( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee10() {
	        return _regeneratorRuntime().wrap(function _callee10$(_context10) {
	          while (1) switch (_context10.prev = _context10.next) {
	            case 0:
	              _context10.next = 2;
	              return base.iterator();
	            case 2:
	              return _context10.abrupt("return", _context10.sent.skip(count));
	            case 3:
	            case "end":
	              return _context10.stop();
	          }
	        }, _callee10);
	      })), size);
	    }
	    /**
	     * Pseudorandomly shuffles the elements of this dataset. This is done in a
	     * streaming manner, by sampling from a given number of prefetched elements.
	     *
	     * ```js
	     * const a = tf.data.array([1, 2, 3, 4, 5, 6]).shuffle(3);
	     * await a.forEachAsync(e => console.log(e));
	     * ```
	     *
	     * @param bufferSize: An integer specifying the number of elements from this
	     *   dataset from which the new dataset will sample.
	     * @param seed: (Optional) An integer specifying the random seed that will
	     *   be used to create the distribution.
	     * @param reshuffleEachIteration: (Optional) A boolean, which if true
	     *   indicates that the dataset should be pseudorandomly reshuffled each time
	     *   it is iterated over. If false, elements will be returned in the same
	     *   shuffled order on each iteration. (Defaults to `true`.)
	     * @returns A `Dataset`.
	     *
	     * @doc {heading: 'Data', subheading: 'Classes'}
	     */
	  }, {
	    key: "shuffle",
	    value: function shuffle(bufferSize, seed) {
	      var reshuffleEachIteration = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
	      if (bufferSize == null || bufferSize < 0) {
	        if (this.size == null) {
	          throw new RangeError('`Dataset.shuffle()` requires bufferSize to be specified.');
	        } else {
	          throw new RangeError('`Dataset.shuffle()` requires bufferSize to be specified.  ' + 'If your data fits in main memory (for regular JS objects), ' + 'and/or GPU memory (for `tf.Tensor`s), consider setting ' + "bufferSize to the dataset size (".concat(this.size, " elements)"));
	        }
	      }
	      var base = this;
	      var random = seedrandom.alea(seed || now().toString());
	      return datasetFromIteratorFn( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee11() {
	        var seed2;
	        return _regeneratorRuntime().wrap(function _callee11$(_context11) {
	          while (1) switch (_context11.prev = _context11.next) {
	            case 0:
	              seed2 = random.int32();
	              if (reshuffleEachIteration) {
	                seed2 += random.int32();
	              }
	              _context11.next = 4;
	              return base.iterator();
	            case 4:
	              return _context11.abrupt("return", _context11.sent.shuffle(bufferSize, seed2.toString()));
	            case 5:
	            case "end":
	              return _context11.stop();
	          }
	        }, _callee11);
	      })), this.size);
	    }
	    /**
	     * Creates a `Dataset` with at most `count` initial elements from this
	     * dataset.
	     *
	     * ```js
	     * const a = tf.data.array([1, 2, 3, 4, 5, 6]).take(3);
	     * await a.forEachAsync(e => console.log(e));
	     * ```
	     *
	     * @param count: The number of elements of this dataset that should be taken
	     *   to form the new dataset.  If `count` is `undefined` or negative, or if
	     *   `count` is greater than the size of this dataset, the new dataset will
	     *   contain all elements of this dataset.
	     * @returns A `Dataset`.
	     *
	     * @doc {heading: 'Data', subheading: 'Classes'}
	     */
	  }, {
	    key: "take",
	    value: function take(count) {
	      var base = this;
	      var size;
	      if (this.size != null && this.size > count) {
	        // If the size of this dataset is greater than count, the new dataset's
	        // size is count.
	        size = count;
	      } else if (this.size != null && this.size <= count) {
	        // If the size of this dataset is equal or smaller than count, the new
	        // dataset's size is the size of this dataset.
	        size = this.size;
	      } else {
	        // If the size of this dataset is null, the new dataset's size is null.
	        size = null;
	      }
	      return datasetFromIteratorFn( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee12() {
	        return _regeneratorRuntime().wrap(function _callee12$(_context12) {
	          while (1) switch (_context12.prev = _context12.next) {
	            case 0:
	              _context12.next = 2;
	              return base.iterator();
	            case 2:
	              return _context12.abrupt("return", _context12.sent.take(count));
	            case 3:
	            case "end":
	              return _context12.stop();
	          }
	        }, _callee12);
	      })), size);
	    }
	    /**
	     * Collect all elements of this dataset into an array.
	     *
	     * Obviously this will succeed only for small datasets that fit in memory.
	     * Useful for testing and generally should be avoided if possible.
	     *
	     * ```js
	     * const a = tf.data.array([1, 2, 3, 4, 5, 6]);
	     * console.log(await a.toArray());
	     * ```
	     *
	     * @returns A Promise for an array of elements, which will resolve
	     *   when a new stream has been obtained and fully consumed.
	     *
	     * @doc {heading: 'Data', subheading: 'Classes'}
	     */
	  }, {
	    key: "toArray",
	    value: function () {
	      var _toArray = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee13() {
	        return _regeneratorRuntime().wrap(function _callee13$(_context13) {
	          while (1) switch (_context13.prev = _context13.next) {
	            case 0:
	              if (!(this.size === Infinity)) {
	                _context13.next = 2;
	                break;
	              }
	              throw new Error('Can not convert infinite data stream to array.');
	            case 2:
	              _context13.next = 4;
	              return this.iterator();
	            case 4:
	              return _context13.abrupt("return", _context13.sent.toArray());
	            case 5:
	            case "end":
	              return _context13.stop();
	          }
	        }, _callee13, this);
	      }));
	      function toArray() {
	        return _toArray.apply(this, arguments);
	      }
	      return toArray;
	    }()
	    /**
	     * Collect all elements of this dataset into an array with prefetching 100
	     * elements. This is useful for testing, because the prefetch changes the
	     * order in which the Promises are resolved along the processing pipeline.
	     * This may help expose bugs where results are dependent on the order of
	     * Promise resolution rather than on the logical order of the stream (i.e.,
	     * due to hidden mutable state).
	     *
	     * @returns A Promise for an array of elements, which will resolve
	     *   when a new stream has been obtained and fully consumed.
	     */
	  }, {
	    key: "toArrayForTest",
	    value: function () {
	      var _toArrayForTest = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee14() {
	        return _regeneratorRuntime().wrap(function _callee14$(_context14) {
	          while (1) switch (_context14.prev = _context14.next) {
	            case 0:
	              if (!(this.size === Infinity)) {
	                _context14.next = 2;
	                break;
	              }
	              throw new Error('Can not convert infinite data stream to array.');
	            case 2:
	              _context14.next = 4;
	              return this.iterator();
	            case 4:
	              return _context14.abrupt("return", _context14.sent.toArrayForTest());
	            case 5:
	            case "end":
	              return _context14.stop();
	          }
	        }, _callee14, this);
	      }));
	      function toArrayForTest() {
	        return _toArrayForTest.apply(this, arguments);
	      }
	      return toArrayForTest;
	    }()
	  }]);
	  return Dataset;
	}(); // TODO(soergel): deep sharded shuffle, where supported
	Dataset.MAX_BUFFER_SIZE = 10000;
	/**
	 * Create a `Dataset` defined by a provided iterator() function.
	 *
	 * ```js
	 * let i = -1;
	 * const func = () =>
	 *    ++i < 5 ? {value: i, done: false} : {value: null, done: true};
	 * const iter = tf.data.iteratorFromFunction(func);
	 * const ds = tf.data.datasetFromIteratorFn(iter);
	 * await ds.forEachAsync(e => console.log(e));
	 * ```
	 */
	function datasetFromIteratorFn(iteratorFn) {
	  var size = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
	  return new ( /*#__PURE__*/function (_Dataset) {
	    _inherits(_class, _Dataset);
	    var _super = _createSuper(_class);
	    function _class() {
	      var _this;
	      _classCallCheck(this, _class);
	      _this = _super.apply(this, arguments);
	      _this.size = size;
	      return _this;
	    }
	    /*
	     * Provide a new stream of elements.  Note this will also start new streams
	     * from any underlying `Dataset`s.
	     */
	    _createClass(_class, [{
	      key: "iterator",
	      value: function () {
	        var _iterator = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee15() {
	          return _regeneratorRuntime().wrap(function _callee15$(_context15) {
	            while (1) switch (_context15.prev = _context15.next) {
	              case 0:
	                return _context15.abrupt("return", iteratorFn());
	              case 1:
	              case "end":
	                return _context15.stop();
	            }
	          }, _callee15);
	        }));
	        function iterator() {
	          return _iterator.apply(this, arguments);
	        }
	        return iterator;
	      }()
	    }]);
	    return _class;
	  }(Dataset))();
	}
	/**
	 * Create a `Dataset` from an array of elements.
	 *
	 * Create a Dataset from an array of objects:
	 * ```js
	 * const a = tf.data.array([{'item': 1}, {'item': 2}, {'item': 3}]);
	 * await a.forEachAsync(e => console.log(e));
	 * ```
	 *
	 * Create a Dataset from an array of numbers:
	 * ```js
	 * const a = tf.data.array([4, 5, 6]);
	 * await a.forEachAsync(e => console.log(e));
	 * ```
	 * @param items An array of elements that will be parsed as items in a dataset.
	 *
	 * @doc {heading: 'Data', subheading: 'Creation', namespace: 'data'}
	 */
	function array(items) {
	  return datasetFromIteratorFn( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee16() {
	    return _regeneratorRuntime().wrap(function _callee16$(_context16) {
	      while (1) switch (_context16.prev = _context16.next) {
	        case 0:
	          return _context16.abrupt("return", iteratorFromItems(items));
	        case 1:
	        case "end":
	          return _context16.stop();
	      }
	    }, _callee16);
	  })), items.length);
	}
	/**
	 * Create a `Dataset` by zipping together an array, dict, or nested
	 * structure of `Dataset`s (and perhaps additional constants).
	 * The underlying datasets must provide elements in a consistent order such that
	 * they correspond.
	 *
	 * The number of elements in the resulting dataset is the same as the size of
	 * the smallest dataset in datasets.
	 *
	 * The nested structure of the `datasets` argument determines the
	 * structure of elements in the resulting iterator.
	 *
	 * Note this means that, given an array of two datasets that produce dict
	 * elements, the result is a dataset that produces elements that are arrays
	 * of two dicts:
	 *
	 * Zip an array of datasets:
	 * ```js
	 * console.log('Zip two datasets of objects:');
	 * const ds1 = tf.data.array([{a: 1}, {a: 2}, {a: 3}]);
	 * const ds2 = tf.data.array([{b: 4}, {b: 5}, {b: 6}]);
	 * const ds3 = tf.data.zip([ds1, ds2]);
	 * await ds3.forEachAsync(e => console.log(JSON.stringify(e)));
	 *
	 * // If the goal is to merge the dicts in order to produce elements like
	 * // {a: ..., b: ...}, this requires a second step such as:
	 * console.log('Merge the objects:');
	 * const ds4 = ds3.map(x => {return {a: x[0].a, b: x[1].b}});
	 * await ds4.forEachAsync(e => console.log(e));
	 * ```
	 *
	 * Zip a dict of datasets:
	 * ```js
	 * const a = tf.data.array([{a: 1}, {a: 2}, {a: 3}]);
	 * const b = tf.data.array([{b: 4}, {b: 5}, {b: 6}]);
	 * const c = tf.data.zip({c: a, d: b});
	 * await c.forEachAsync(e => console.log(JSON.stringify(e)));
	 * ```
	 *
	 * @doc {heading: 'Data', subheading: 'Operations', namespace: 'data'}
	 */
	function zip(datasets) {
	  // manually type-check the argument for JS users
	  if (!isIterable(datasets)) {
	    throw new Error('The argument to zip() must be an object or array.');
	  }
	  var size;
	  if (Array.isArray(datasets)) {
	    for (var i = 0; i < datasets.length; i++) {
	      size = size == null ? datasets[i].size : Math.min(size, datasets[i].size);
	    }
	  } else if (datasets instanceof Object) {
	    for (var ds in datasets) {
	      size = size == null ? datasets[ds].size : Math.min(size, datasets[ds].size);
	    }
	  }
	  return datasetFromIteratorFn( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee17() {
	    var streams;
	    return _regeneratorRuntime().wrap(function _callee17$(_context17) {
	      while (1) switch (_context17.prev = _context17.next) {
	        case 0:
	          _context17.next = 2;
	          return deepMapAndAwaitAll(datasets, function (d) {
	            if (d instanceof Dataset) {
	              return {
	                value: d.iterator(),
	                recurse: false
	              };
	            } else if (isIterable(d)) {
	              return {
	                value: null,
	                recurse: true
	              };
	            } else {
	              throw new Error('Leaves of the structure passed to zip() must be Datasets, ' + 'not primitives.');
	            }
	          });
	        case 2:
	          streams = _context17.sent;
	          return _context17.abrupt("return", iteratorFromZipped(streams, ZipMismatchMode.SHORTEST));
	        case 4:
	        case "end":
	          return _context17.stop();
	      }
	    }, _callee17);
	  })), size);
	}
	/**
	 * A zip function for use with deepZip, passed via the columnMajorBatch call.
	 *
	 * Accepts an array of identically-structured nested elements and either batches
	 * them (if they are primitives, numeric arrays, or Tensors) or requests
	 * recursion (if not).
	 */
	// tslint:disable-next-line:no-any
	function deepBatchConcat(rows) {
	  if (rows === null) {
	    return null;
	  }
	  // use the first item to decide whether to recurse or batch here.
	  var exampleRow = rows[0];
	  if (canTensorify(exampleRow)) {
	    // rows is an array of primitives, Tensors, or arrays.  Batch them.
	    var value = batchConcat(rows);
	    return {
	      value: value,
	      recurse: false
	    };
	  }
	  // the example row is an object, so recurse into it.
	  return {
	    value: null,
	    recurse: true
	  };
	}
	/**
	 * Assembles a list of same-shaped numbers, number arrays, or Tensors
	 * into a single new Tensor where axis 0 is the batch dimension.
	 */
	function batchConcat(arrays) {
	  if (arrays.length === 0) {
	    // We can't return an empty Tensor because we don't know the element shape.
	    throw new Error('Can\'t make a batch of zero elements.');
	  }
	  if (arrays[0] instanceof Tensor) {
	    // Input is an array of Tensors
	    return stack(arrays);
	  } else {
	    // Input is a possibly-nested array of numbers.
	    return tensor(arrays);
	  }
	}

	/**
	 * Represents a potentially large collection of text lines.
	 *
	 * The results are not batched.
	 */
	var TextLineDataset = /*#__PURE__*/function (_Dataset) {
	  _inherits(TextLineDataset, _Dataset);
	  var _super = _createSuper(TextLineDataset);
	  /**
	   * Create a `TextLineDataset`.
	   *
	   * @param input A `DataSource` providing a chunked, UTF8-encoded byte stream.
	   */
	  function TextLineDataset(input) {
	    var _this;
	    _classCallCheck(this, TextLineDataset);
	    _this = _super.call(this);
	    _this.input = input;
	    return _this;
	  }
	  _createClass(TextLineDataset, [{
	    key: "iterator",
	    value: function () {
	      var _iterator = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        var inputIterator, utf8Iterator, lineIterator;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              _context.next = 2;
	              return this.input.iterator();
	            case 2:
	              inputIterator = _context.sent;
	              utf8Iterator = inputIterator.decodeUTF8();
	              lineIterator = utf8Iterator.split('\n').map(function (line) {
	                // Windows/DOS format text file has extra line breaker at the end of line.
	                if (line.endsWith('\r')) {
	                  line = line.slice(0, -1);
	                }
	                return line;
	              });
	              return _context.abrupt("return", lineIterator);
	            case 6:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function iterator() {
	        return _iterator.apply(this, arguments);
	      }
	      return iterator;
	    }()
	  }]);
	  return TextLineDataset;
	}(Dataset);

	var CODE_QUOTE = '"';
	var STATE_OUT = Symbol('out');
	var STATE_FIELD = Symbol('field');
	var STATE_QUOTE = Symbol('quote');
	var STATE_QUOTE_AFTER_QUOTE = Symbol('quoteafterquote');
	var STATE_WITHIN_QUOTE_IN_QUOTE = Symbol('quoteinquote');
	/**
	 * Represents a potentially large collection of delimited text records.
	 *
	 * The produced `TensorContainer`s each contain one key-value pair for
	 * every column of the table.  When a field is empty in the incoming data, the
	 * resulting value is `undefined`, or throw error if it is required.  Values
	 * that can be parsed as numbers are emitted as type `number`, other values
	 * are parsed as `string`.
	 *
	 * The results are not batched.
	 *
	 * @doc {heading: 'Data', subheading: 'Classes', namespace: 'data'}
	 */
	var CSVDataset = /*#__PURE__*/function (_Dataset) {
	  _inherits(CSVDataset, _Dataset);
	  var _super = _createSuper(CSVDataset);
	  /**
	   * Create a `CSVDataset`.
	   *
	   * @param input A `DataSource` providing a chunked, UTF8-encoded byte stream.
	   * @param csvConfig (Optional) A CSVConfig object that contains configurations
	   *     of reading and decoding from CSV file(s).
	   *
	   *     hasHeader: (Optional) A boolean value that indicates whether the first
	   *     row of provided CSV file is a header line with column names, and should
	   *     not be included in the data. Defaults to `true`.
	   *
	   *     columnNames: (Optional) A list of strings that corresponds to
	   *     the CSV column names, in order. If provided, it ignores the column
	   *     names inferred from the header row. If not provided, infers the column
	   *     names from the first row of the records. If hasHeader is false and
	   *     columnNames is not provided, this method throws an error.
	   *
	   *     columnConfigs: (Optional) A dictionary whose key is column names, value
	   *     is an object stating if this column is required, column's data type,
	   *     default value, and if this column is label. If provided, keys must
	   *     correspond to names provided in columnNames or inferred from the file
	   *     header lines. If isLabel is true any column, returns an array of two
	   *     items: the first item is a dict of features key/value pairs, the second
	   *     item is a dict of labels key/value pairs. If no feature is marked as
	   *     label, returns a dict of features only.
	   *
	   *     configuredColumnsOnly (Optional) If true, only columns provided in
	   *     columnConfigs will be parsed and provided during iteration.
	   *
	   *     delimiter (Optional) The string used to parse each line of the input
	   *     file. Defaults to `,`.
	   */
	  function CSVDataset(input, csvConfig) {
	    var _this;
	    _classCallCheck(this, CSVDataset);
	    _this = _super.call(this);
	    _this.input = input;
	    _this.hasHeader = true;
	    _this.fullColumnNames = null;
	    _this.columnNamesValidated = false;
	    _this.columnConfigs = null;
	    _this.configuredColumnsOnly = false;
	    _this.delimiter = ',';
	    _this.delimWhitespace = false;
	    _this.base = new TextLineDataset(input);
	    if (!csvConfig) {
	      csvConfig = {};
	    }
	    _this.hasHeader = csvConfig.hasHeader === false ? false : true;
	    _this.fullColumnNames = csvConfig.columnNames;
	    _this.columnConfigs = csvConfig.columnConfigs;
	    _this.configuredColumnsOnly = csvConfig.configuredColumnsOnly;
	    if (csvConfig.delimWhitespace) {
	      assert$1(csvConfig.delimiter == null, function () {
	        return 'Delimiter should not be provided when delimWhitespace is true.';
	      });
	      _this.delimWhitespace = true;
	      _this.delimiter = ' ';
	    } else {
	      _this.delimiter = csvConfig.delimiter ? csvConfig.delimiter : ',';
	    }
	    return _this;
	  }
	  _createClass(CSVDataset, [{
	    key: "columnNames",
	    value:
	    /**
	     * Returns column names of the csv dataset. If `configuredColumnsOnly` is
	     * true, return column names in `columnConfigs`. If `configuredColumnsOnly` is
	     * false and `columnNames` is provided, `columnNames`. If
	     * `configuredColumnsOnly` is false and `columnNames` is not provided, return
	     * all column names parsed from the csv file. For example usage please go to
	     * `tf.data.csv`.
	     *
	     * @doc {heading: 'Data', subheading: 'Classes'}
	     */
	    function () {
	      var _columnNames = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              if (this.columnNamesValidated) {
	                _context.next = 3;
	                break;
	              }
	              _context.next = 3;
	              return this.setColumnNames();
	            case 3:
	              return _context.abrupt("return", this.configuredColumnsOnly ? Object.keys(this.columnConfigs) : this.fullColumnNames);
	            case 4:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function columnNames() {
	        return _columnNames.apply(this, arguments);
	      }
	      return columnNames;
	    }()
	    /* 1) If `columnNames` is provided as string[], use this string[] as output
	     * keys in corresponding order. The length must match the number of inferred
	     * columns if `hasHeader` is true .
	     * 2) If `columnNames` is not provided, parse header line as `columnNames` if
	     * hasHeader is true. If `hasHeader` is false, throw an error.
	     * 3) If `columnConfigs` is provided, all the keys in `columnConfigs` must
	     * exist in parsed `columnNames`.
	     */
	  }, {
	    key: "setColumnNames",
	    value: function () {
	      var _setColumnNames = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2() {
	        var _this2 = this;
	        var columnNamesFromFile, counts, duplicateNames, _i, _Object$keys, key, index;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              _context2.next = 2;
	              return this.maybeReadHeaderLine();
	            case 2:
	              columnNamesFromFile = _context2.sent;
	              if (!(!this.fullColumnNames && !columnNamesFromFile)) {
	                _context2.next = 7;
	                break;
	              }
	              throw new Error('Column names must be provided if there is no header line.');
	            case 7:
	              if (this.fullColumnNames && columnNamesFromFile) {
	                // Check provided columnNames match header line.
	                assert$1(columnNamesFromFile.length === this.fullColumnNames.length, function () {
	                  return 'The length of provided columnNames (' + _this2.fullColumnNames.length.toString() + ') does not match the length of the header line read from ' + 'file (' + columnNamesFromFile.length.toString() + ').';
	                });
	              }
	            case 8:
	              if (!this.fullColumnNames) {
	                this.fullColumnNames = columnNamesFromFile;
	              }
	              // Check if there are duplicate column names.
	              counts = this.fullColumnNames.reduce(function (countAcc, name) {
	                countAcc[name] = countAcc[name] + 1 || 1;
	                return countAcc;
	              }, {});
	              duplicateNames = Object.keys(counts).filter(function (name) {
	                return counts[name] > 1;
	              });
	              assert$1(duplicateNames.length === 0, function () {
	                return 'Duplicate column names found: ' + duplicateNames.toString();
	              });
	              // Check if keys in columnConfigs match columnNames.
	              if (!this.columnConfigs) {
	                _context2.next = 22;
	                break;
	              }
	              _i = 0, _Object$keys = Object.keys(this.columnConfigs);
	            case 14:
	              if (!(_i < _Object$keys.length)) {
	                _context2.next = 22;
	                break;
	              }
	              key = _Object$keys[_i];
	              index = this.fullColumnNames.indexOf(key);
	              if (!(index === -1)) {
	                _context2.next = 19;
	                break;
	              }
	              throw new Error('The key "' + key + '" provided in columnConfigs does not match any of the column ' + 'names (' + this.fullColumnNames.toString() + ').');
	            case 19:
	              _i++;
	              _context2.next = 14;
	              break;
	            case 22:
	              this.columnNamesValidated = true;
	            case 23:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function setColumnNames() {
	        return _setColumnNames.apply(this, arguments);
	      }
	      return setColumnNames;
	    }()
	  }, {
	    key: "maybeReadHeaderLine",
	    value: function () {
	      var _maybeReadHeaderLine = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3() {
	        var iter, firstElement, firstLine, headers;
	        return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	          while (1) switch (_context3.prev = _context3.next) {
	            case 0:
	              if (!this.hasHeader) {
	                _context3.next = 14;
	                break;
	              }
	              _context3.next = 3;
	              return this.base.iterator();
	            case 3:
	              iter = _context3.sent;
	              _context3.next = 6;
	              return iter.next();
	            case 6:
	              firstElement = _context3.sent;
	              if (!firstElement.done) {
	                _context3.next = 9;
	                break;
	              }
	              throw new Error('No data was found for CSV parsing.');
	            case 9:
	              firstLine = firstElement.value;
	              headers = this.parseRow(firstLine, false);
	              return _context3.abrupt("return", headers);
	            case 14:
	              return _context3.abrupt("return", null);
	            case 15:
	            case "end":
	              return _context3.stop();
	          }
	        }, _callee3, this);
	      }));
	      function maybeReadHeaderLine() {
	        return _maybeReadHeaderLine.apply(this, arguments);
	      }
	      return maybeReadHeaderLine;
	    }()
	  }, {
	    key: "iterator",
	    value: function () {
	      var _iterator = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4() {
	        var _this3 = this;
	        var lines;
	        return _regeneratorRuntime().wrap(function _callee4$(_context4) {
	          while (1) switch (_context4.prev = _context4.next) {
	            case 0:
	              if (this.columnNamesValidated) {
	                _context4.next = 3;
	                break;
	              }
	              _context4.next = 3;
	              return this.setColumnNames();
	            case 3:
	              _context4.next = 5;
	              return this.base.iterator();
	            case 5:
	              lines = _context4.sent;
	              if (this.hasHeader) {
	                // We previously read the first line to get the columnNames.
	                // Now that we're providing data, skip it.
	                lines = lines.skip(1);
	              }
	              return _context4.abrupt("return", lines.map(function (x) {
	                return _this3.makeDataElement(x);
	              }));
	            case 8:
	            case "end":
	              return _context4.stop();
	          }
	        }, _callee4, this);
	      }));
	      function iterator() {
	        return _iterator.apply(this, arguments);
	      }
	      return iterator;
	    }()
	  }, {
	    key: "makeDataElement",
	    value: function makeDataElement(line) {
	      var values = this.parseRow(line);
	      var features = {};
	      var labels = {};
	      for (var i = 0; i < this.fullColumnNames.length; i++) {
	        var key = this.fullColumnNames[i];
	        var config = this.columnConfigs ? this.columnConfigs[key] : null;
	        if (this.configuredColumnsOnly && !config) {
	          // This column is not selected.
	          continue;
	        } else {
	          var value = values[i];
	          var parsedValue = null;
	          if (value === '') {
	            // If default value is provided, use it. If default value is not
	            // provided, set as undefined.
	            if (config && config.default !== undefined) {
	              parsedValue = config.default;
	            } else if (config && (config.required || config.isLabel)) {
	              throw new Error("Required column ".concat(key, " is empty in this line: ").concat(line));
	            } else {
	              parsedValue = undefined;
	            }
	          } else {
	            // A value is present, so parse it based on type
	            var valueAsNum = Number(value);
	            if (isNaN(valueAsNum)) {
	              // The value is a string and this column is declared as boolean
	              // in config, parse it as boolean.
	              if (config && config.dtype === 'bool') {
	                parsedValue = this.getBoolean(value);
	              } else {
	                // Set value as string
	                parsedValue = value;
	              }
	            } else if (!config || !config.dtype) {
	              // If this value is a number and no type config is provided, return
	              // it as number.
	              parsedValue = valueAsNum;
	            } else {
	              // If this value is a number and data type is provided, parse it
	              // according to provided data type.
	              switch (config.dtype) {
	                case 'float32':
	                  parsedValue = valueAsNum;
	                  break;
	                case 'int32':
	                  parsedValue = Math.floor(valueAsNum);
	                  break;
	                case 'bool':
	                  parsedValue = this.getBoolean(value);
	                  break;
	                default:
	                  parsedValue = valueAsNum;
	              }
	            }
	          }
	          // Check if this column is label.
	          config && config.isLabel ? labels[key] = parsedValue : features[key] = parsedValue;
	        }
	      }
	      // If label exists, return an object of features and labels as {xs:features,
	      // ys:labels}, otherwise return features only.
	      if (Object.keys(labels).length === 0) {
	        return features;
	      } else {
	        return {
	          xs: features,
	          ys: labels
	        };
	      }
	    }
	  }, {
	    key: "getBoolean",
	    value: function getBoolean(value) {
	      if (value === '1' || value.toLowerCase() === 'true') {
	        return 1;
	      } else {
	        return 0;
	      }
	    }
	    // adapted from https://beta.observablehq.com/@mbostock/streaming-csv
	  }, {
	    key: "parseRow",
	    value: function parseRow(line) {
	      var validateElementCount = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
	      var result = [];
	      var readOffset = 0;
	      var readLength = line.length;
	      var currentState = STATE_OUT;
	      // Goes through the line to parse quote.
	      for (var i = 0; i < readLength; i++) {
	        switch (currentState) {
	          // Before enter a new field
	          case STATE_OUT:
	            switch (line.charAt(i)) {
	              // Enter a quoted field
	              case CODE_QUOTE:
	                readOffset = i + 1;
	                currentState = STATE_QUOTE;
	                break;
	              // Read an empty field
	              case this.delimiter:
	                readOffset = i + 1;
	                // If delimiter is white space and configured to collapse
	                // multiple white spaces, ignore this white space.
	                if (this.delimiter === ' ' && this.delimWhitespace) {
	                  break;
	                }
	                result.push('');
	                currentState = STATE_OUT;
	                break;
	              // Enter an unquoted field
	              default:
	                currentState = STATE_FIELD;
	                readOffset = i;
	                break;
	            }
	            break;
	          // In an unquoted field
	          case STATE_FIELD:
	            switch (line.charAt(i)) {
	              // Exit an unquoted field, add it to result
	              case this.delimiter:
	                result.push(line.substring(readOffset, i));
	                currentState = STATE_OUT;
	                readOffset = i + 1;
	                break;
	              default:
	            }
	            break;
	          // In a quoted field
	          case STATE_QUOTE:
	            switch (line.charAt(i)) {
	              // Read a quote after a quote
	              case CODE_QUOTE:
	                currentState = STATE_QUOTE_AFTER_QUOTE;
	                break;
	              default:
	            }
	            break;
	          // This state means it's right after a second quote in a field
	          case STATE_QUOTE_AFTER_QUOTE:
	            switch (line.charAt(i)) {
	              // Finished a quoted field
	              case this.delimiter:
	                result.push(line.substring(readOffset, i - 1));
	                currentState = STATE_OUT;
	                readOffset = i + 1;
	                break;
	              // Finished a quoted part in a quoted field
	              case CODE_QUOTE:
	                currentState = STATE_QUOTE;
	                break;
	              // In a quoted part in a quoted field
	              default:
	                currentState = STATE_WITHIN_QUOTE_IN_QUOTE;
	                break;
	            }
	            break;
	          case STATE_WITHIN_QUOTE_IN_QUOTE:
	            switch (line.charAt(i)) {
	              // Exit a quoted part in a quoted field
	              case CODE_QUOTE:
	                currentState = STATE_QUOTE;
	                break;
	              default:
	            }
	            break;
	          default:
	        }
	      }
	      // Adds last item based on if it is quoted.
	      if (currentState === STATE_QUOTE_AFTER_QUOTE) {
	        result.push(line.substring(readOffset, readLength - 1));
	      } else {
	        result.push(line.substring(readOffset));
	      }
	      // Check if each row has the same number of elements as column names.
	      if (validateElementCount && result.length !== this.fullColumnNames.length) {
	        throw new Error("Invalid row in csv file. Should have ".concat(this.fullColumnNames.length, " elements in a row, but got ").concat(result));
	      }
	      return result;
	    }
	  }]);
	  return CSVDataset;
	}(Dataset);
	// TODO(soergel): add more basic datasets for parity with tf.data
	// tf.data.FixedLengthRecordDataset()
	// tf.data.TFRecordDataset()

	/**
	 * Provide a stream of tensors from microphone audio stream. The tensors are
	 * representing audio data as frequency-domain spectrogram generated with
	 * browser's native FFT. Tensors representing time-domain waveform is available
	 * based on configuration. Only works in browser environment.
	 */
	var MicrophoneIterator = /*#__PURE__*/function (_LazyIterator) {
	  _inherits(MicrophoneIterator, _LazyIterator);
	  var _super = _createSuper(MicrophoneIterator);
	  function MicrophoneIterator(microphoneConfig) {
	    var _this;
	    _classCallCheck(this, MicrophoneIterator);
	    _this = _super.call(this);
	    _this.microphoneConfig = microphoneConfig;
	    _this.isClosed = false;
	    _this.fftSize = microphoneConfig.fftSize || 1024;
	    var fftSizeLog2 = Math.log2(_this.fftSize);
	    if (_this.fftSize < 0 || fftSizeLog2 < 4 || fftSizeLog2 > 14 || !Number.isInteger(fftSizeLog2)) {
	      throw new Error("Invalid fftSize: it must be a power of 2 between " + "2 to 4 and 2 to 14, but got ".concat(_this.fftSize));
	    }
	    _this.numFrames = microphoneConfig.numFramesPerSpectrogram || 43;
	    _this.sampleRateHz = microphoneConfig.sampleRateHz;
	    _this.columnTruncateLength = microphoneConfig.columnTruncateLength || _this.fftSize;
	    _this.audioTrackConstraints = microphoneConfig.audioTrackConstraints;
	    _this.smoothingTimeConstant = microphoneConfig.smoothingTimeConstant || 0;
	    _this.includeSpectrogram = microphoneConfig.includeSpectrogram === false ? false : true;
	    _this.includeWaveform = microphoneConfig.includeWaveform === true ? true : false;
	    if (!_this.includeSpectrogram && !_this.includeWaveform) {
	      throw new Error('Both includeSpectrogram and includeWaveform are false. ' + 'At least one type of data should be returned.');
	    }
	    return _this;
	  }
	  _createClass(MicrophoneIterator, [{
	    key: "summary",
	    value: function summary() {
	      return "microphone";
	    }
	    // Construct a MicrophoneIterator and start the audio stream.
	  }, {
	    key: "start",
	    value: // Start the audio stream and FFT.
	    function () {
	      var _start = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        var ctxConstructor, streamSource;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              _context.prev = 0;
	              _context.next = 3;
	              return navigator.mediaDevices.getUserMedia({
	                audio: this.audioTrackConstraints == null ? true : this.audioTrackConstraints,
	                video: false
	              });
	            case 3:
	              this.stream = _context.sent;
	              _context.next = 9;
	              break;
	            case 6:
	              _context.prev = 6;
	              _context.t0 = _context["catch"](0);
	              throw new Error("Error thrown while initializing video stream: ".concat(_context.t0.message));
	            case 9:
	              if (this.stream) {
	                _context.next = 11;
	                break;
	              }
	              throw new Error('Could not obtain audio from microphone.');
	            case 11:
	              ctxConstructor =
	              // tslint:disable-next-line:no-any
	              window.AudioContext || window.webkitAudioContext;
	              this.audioContext = new ctxConstructor();
	              if (this.sampleRateHz) {
	                _context.next = 17;
	                break;
	              }
	              // If sample rate is not provided, use the available sample rate on
	              // device.
	              this.sampleRateHz = this.audioContext.sampleRate;
	              _context.next = 19;
	              break;
	            case 17:
	              if (!(this.audioContext.sampleRate !== this.sampleRateHz)) {
	                _context.next = 19;
	                break;
	              }
	              throw new Error("Mismatch in sampling rate: " + "Expected: ".concat(this.sampleRateHz, "; ") + "Actual: ".concat(this.audioContext.sampleRate));
	            case 19:
	              streamSource = this.audioContext.createMediaStreamSource(this.stream);
	              this.analyser = this.audioContext.createAnalyser();
	              this.analyser.fftSize = this.fftSize * 2;
	              this.analyser.smoothingTimeConstant = this.smoothingTimeConstant;
	              streamSource.connect(this.analyser);
	              this.freqData = new Float32Array(this.fftSize);
	              this.timeData = new Float32Array(this.fftSize);
	              return _context.abrupt("return");
	            case 27:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this, [[0, 6]]);
	      }));
	      function start() {
	        return _start.apply(this, arguments);
	      }
	      return start;
	    }()
	  }, {
	    key: "next",
	    value: function () {
	      var _next = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2() {
	        var spectrogramTensor, waveformTensor, audioDataQueue, freqData, timeData;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              if (!this.isClosed) {
	                _context2.next = 2;
	                break;
	              }
	              return _context2.abrupt("return", {
	                value: null,
	                done: true
	              });
	            case 2:
	              _context2.next = 4;
	              return this.getAudioData();
	            case 4:
	              audioDataQueue = _context2.sent;
	              if (this.includeSpectrogram) {
	                freqData = this.flattenQueue(audioDataQueue.freqDataQueue);
	                spectrogramTensor = this.getTensorFromAudioDataArray(freqData, [this.numFrames, this.columnTruncateLength, 1]);
	              }
	              if (this.includeWaveform) {
	                timeData = this.flattenQueue(audioDataQueue.timeDataQueue);
	                waveformTensor = this.getTensorFromAudioDataArray(timeData, [this.numFrames * this.fftSize, 1]);
	              }
	              return _context2.abrupt("return", {
	                value: {
	                  'spectrogram': spectrogramTensor,
	                  'waveform': waveformTensor
	                },
	                done: false
	              });
	            case 8:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function next() {
	        return _next.apply(this, arguments);
	      }
	      return next;
	    }() // Capture one result from the audio stream, and extract the value from
	    // iterator.next() result.
	  }, {
	    key: "capture",
	    value: function () {
	      var _capture = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3() {
	        return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	          while (1) switch (_context3.prev = _context3.next) {
	            case 0:
	              _context3.next = 2;
	              return this.next();
	            case 2:
	              return _context3.abrupt("return", _context3.sent.value);
	            case 3:
	            case "end":
	              return _context3.stop();
	          }
	        }, _callee3, this);
	      }));
	      function capture() {
	        return _capture.apply(this, arguments);
	      }
	      return capture;
	    }()
	  }, {
	    key: "getAudioData",
	    value: function () {
	      var _getAudioData = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4() {
	        var _this2 = this;
	        var freqDataQueue, timeDataQueue, currentFrames;
	        return _regeneratorRuntime().wrap(function _callee4$(_context4) {
	          while (1) switch (_context4.prev = _context4.next) {
	            case 0:
	              freqDataQueue = [];
	              timeDataQueue = [];
	              currentFrames = 0;
	              return _context4.abrupt("return", new Promise(function (resolve) {
	                var intervalID = setInterval(function () {
	                  if (_this2.includeSpectrogram) {
	                    _this2.analyser.getFloatFrequencyData(_this2.freqData);
	                    // If the audio stream is initializing, return empty queue.
	                    if (_this2.freqData[0] === -Infinity) {
	                      resolve({
	                        freqDataQueue: freqDataQueue,
	                        timeDataQueue: timeDataQueue
	                      });
	                    }
	                    freqDataQueue.push(_this2.freqData.slice(0, _this2.columnTruncateLength));
	                  }
	                  if (_this2.includeWaveform) {
	                    _this2.analyser.getFloatTimeDomainData(_this2.timeData);
	                    timeDataQueue.push(_this2.timeData.slice());
	                  }
	                  // Clean interval and return when all frames have been collected
	                  if (++currentFrames === _this2.numFrames) {
	                    clearInterval(intervalID);
	                    resolve({
	                      freqDataQueue: freqDataQueue,
	                      timeDataQueue: timeDataQueue
	                    });
	                  }
	                }, _this2.fftSize / _this2.sampleRateHz * 1e3);
	              }));
	            case 4:
	            case "end":
	              return _context4.stop();
	          }
	        }, _callee4);
	      }));
	      function getAudioData() {
	        return _getAudioData.apply(this, arguments);
	      }
	      return getAudioData;
	    }() // Stop the audio stream and pause the iterator.
	  }, {
	    key: "stop",
	    value: function stop() {
	      if (!this.isClosed) {
	        this.isClosed = true;
	        this.analyser.disconnect();
	        this.audioContext.close();
	        if (this.stream != null && this.stream.getTracks().length > 0) {
	          this.stream.getTracks()[0].stop();
	        }
	      }
	    }
	    // Override toArray() function to prevent collecting.
	  }, {
	    key: "toArray",
	    value: function toArray() {
	      throw new Error('Can not convert infinite audio stream to array.');
	    }
	    // Return audio sampling rate in Hz
	  }, {
	    key: "getSampleRate",
	    value: function getSampleRate() {
	      return this.sampleRateHz;
	    }
	  }, {
	    key: "flattenQueue",
	    value: function flattenQueue(queue) {
	      var frameSize = queue[0].length;
	      var freqData = new Float32Array(queue.length * frameSize);
	      queue.forEach(function (data, i) {
	        return freqData.set(data, i * frameSize);
	      });
	      return freqData;
	    }
	  }, {
	    key: "getTensorFromAudioDataArray",
	    value: function getTensorFromAudioDataArray(freqData, shape) {
	      var vals = new Float32Array(sizeFromShape(shape));
	      // If the data is less than the output shape, the rest is padded with zeros.
	      vals.set(freqData, vals.length - freqData.length);
	      return tensor(vals, shape);
	    }
	  }], [{
	    key: "create",
	    value: function () {
	      var _create = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee5() {
	        var microphoneConfig,
	          microphoneIterator,
	          _args5 = arguments;
	        return _regeneratorRuntime().wrap(function _callee5$(_context5) {
	          while (1) switch (_context5.prev = _context5.next) {
	            case 0:
	              microphoneConfig = _args5.length > 0 && _args5[0] !== undefined ? _args5[0] : {};
	              if (env().get('IS_BROWSER')) {
	                _context5.next = 3;
	                break;
	              }
	              throw new Error('microphone API is only supported in browser environment.');
	            case 3:
	              microphoneIterator = new MicrophoneIterator(microphoneConfig); // Call async function start() to initialize the audio stream.
	              _context5.next = 6;
	              return microphoneIterator.start();
	            case 6:
	              return _context5.abrupt("return", microphoneIterator);
	            case 7:
	            case "end":
	              return _context5.stop();
	          }
	        }, _callee5);
	      }));
	      function create() {
	        return _create.apply(this, arguments);
	      }
	      return create;
	    }()
	  }]);
	  return MicrophoneIterator;
	}(LazyIterator);

	/**
	 * Provide a stream of image tensors from webcam video stream. Only works in
	 * browser environment.
	 */
	var WebcamIterator = /*#__PURE__*/function (_LazyIterator) {
	  _inherits(WebcamIterator, _LazyIterator);
	  var _super = _createSuper(WebcamIterator);
	  function WebcamIterator(webcamVideoElement, webcamConfig) {
	    var _this;
	    _classCallCheck(this, WebcamIterator);
	    _this = _super.call(this);
	    _this.webcamVideoElement = webcamVideoElement;
	    _this.webcamConfig = webcamConfig;
	    _this.isClosed = true;
	    _this.resize = false;
	    if (_this.needToResize()) {
	      _this.resize = true;
	      _this.cropSize = [_this.webcamConfig.resizeHeight, _this.webcamConfig.resizeWidth];
	      _this.cropBoxInd = tensor1d([0], 'int32');
	      if (_this.webcamConfig.centerCrop) {
	        // Calculate the box based on resizing shape.
	        var widthCroppingRatio = _this.webcamConfig.resizeWidth * 1.0 / _this.webcamVideoElement.width;
	        var heightCroppingRatio = _this.webcamConfig.resizeHeight * 1.0 / _this.webcamVideoElement.height;
	        var widthCropStart = (1 - widthCroppingRatio) / 2;
	        var heightCropStart = (1 - heightCroppingRatio) / 2;
	        var widthCropEnd = widthCropStart + widthCroppingRatio;
	        var heightCropEnd = heightCroppingRatio + heightCropStart;
	        _this.cropBox = tensor2d([heightCropStart, widthCropStart, heightCropEnd, widthCropEnd], [1, 4]);
	      } else {
	        _this.cropBox = tensor2d([0, 0, 1, 1], [1, 4]);
	      }
	    }
	    return _this;
	  }
	  _createClass(WebcamIterator, [{
	    key: "summary",
	    value: function summary() {
	      return "webcam";
	    }
	    // Construct a WebcamIterator and start it's video stream.
	  }, {
	    key: "start",
	    value: // Async function to start video stream.
	    function () {
	      var _start = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        var _this2 = this;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              if (this.webcamConfig.facingMode) {
	                assert$1(this.webcamConfig.facingMode === 'user' || this.webcamConfig.facingMode === 'environment', function () {
	                  return "Invalid webcam facing mode: ".concat(_this2.webcamConfig.facingMode, ". ") + "Please provide 'user' or 'environment'";
	                });
	              }
	              _context.prev = 1;
	              _context.next = 4;
	              return navigator.mediaDevices.getUserMedia({
	                video: {
	                  deviceId: this.webcamConfig.deviceId,
	                  facingMode: this.webcamConfig.facingMode ? this.webcamConfig.facingMode : 'user',
	                  width: this.webcamVideoElement.width,
	                  height: this.webcamVideoElement.height
	                }
	              });
	            case 4:
	              this.stream = _context.sent;
	              _context.next = 11;
	              break;
	            case 7:
	              _context.prev = 7;
	              _context.t0 = _context["catch"](1);
	              // Modify the error message but leave the stack trace intact
	              _context.t0.message = "Error thrown while initializing video stream: ".concat(_context.t0.message);
	              throw _context.t0;
	            case 11:
	              if (this.stream) {
	                _context.next = 13;
	                break;
	              }
	              throw new Error('Could not obtain video from webcam.');
	            case 13:
	              // Older browsers may not have srcObject
	              try {
	                this.webcamVideoElement.srcObject = this.stream;
	              } catch (error) {
	                console.log(error);
	                this.webcamVideoElement.src = window.URL.createObjectURL(this.stream);
	              }
	              // Start the webcam video stream
	              this.webcamVideoElement.play();
	              this.isClosed = false;
	              return _context.abrupt("return", new Promise(function (resolve) {
	                // Add event listener to make sure the webcam has been fully initialized.
	                _this2.webcamVideoElement.onloadedmetadata = function () {
	                  resolve();
	                };
	              }));
	            case 17:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this, [[1, 7]]);
	      }));
	      function start() {
	        return _start.apply(this, arguments);
	      }
	      return start;
	    }()
	  }, {
	    key: "next",
	    value: function () {
	      var _next = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2() {
	        var img;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              if (!this.isClosed) {
	                _context2.next = 2;
	                break;
	              }
	              return _context2.abrupt("return", {
	                value: null,
	                done: true
	              });
	            case 2:
	              _context2.prev = 2;
	              img = fromPixels$1(this.webcamVideoElement);
	              _context2.next = 9;
	              break;
	            case 6:
	              _context2.prev = 6;
	              _context2.t0 = _context2["catch"](2);
	              throw new Error("Error thrown converting video to pixels: ".concat(JSON.stringify(_context2.t0)));
	            case 9:
	              if (!this.resize) {
	                _context2.next = 22;
	                break;
	              }
	              _context2.prev = 10;
	              return _context2.abrupt("return", {
	                value: this.cropAndResizeFrame(img),
	                done: false
	              });
	            case 14:
	              _context2.prev = 14;
	              _context2.t1 = _context2["catch"](10);
	              throw new Error("Error thrown cropping the video: ".concat(_context2.t1.message));
	            case 17:
	              _context2.prev = 17;
	              img.dispose();
	              return _context2.finish(17);
	            case 20:
	              _context2.next = 23;
	              break;
	            case 22:
	              return _context2.abrupt("return", {
	                value: img,
	                done: false
	              });
	            case 23:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this, [[2, 6], [10, 14, 17, 20]]);
	      }));
	      function next() {
	        return _next.apply(this, arguments);
	      }
	      return next;
	    }()
	  }, {
	    key: "needToResize",
	    value: function needToResize() {
	      // If resizeWidth and resizeHeight are provided, and different from the
	      // width and height of original HTMLVideoElement, then resizing and cropping
	      // is required.
	      if (this.webcamConfig.resizeWidth && this.webcamConfig.resizeHeight && (this.webcamVideoElement.width !== this.webcamConfig.resizeWidth || this.webcamVideoElement.height !== this.webcamConfig.resizeHeight)) {
	        return true;
	      }
	      return false;
	    }
	    // Cropping and resizing each frame based on config
	  }, {
	    key: "cropAndResizeFrame",
	    value: function cropAndResizeFrame(img) {
	      var _this3 = this;
	      return tidy(function () {
	        var expandedImage = expandDims$3(cast$3(img, 'float32'), 0);
	        var resizedImage;
	        resizedImage = image$1.cropAndResize(expandedImage, _this3.cropBox, _this3.cropBoxInd, _this3.cropSize, 'bilinear');
	        // Extract image from batch cropping.
	        var shape = resizedImage.shape;
	        return reshape$3(resizedImage, shape.slice(1));
	      });
	    }
	    // Capture one frame from the video stream, and extract the value from
	    // iterator.next() result.
	  }, {
	    key: "capture",
	    value: function () {
	      var _capture = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3() {
	        return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	          while (1) switch (_context3.prev = _context3.next) {
	            case 0:
	              _context3.next = 2;
	              return this.next();
	            case 2:
	              return _context3.abrupt("return", _context3.sent.value);
	            case 3:
	            case "end":
	              return _context3.stop();
	          }
	        }, _callee3, this);
	      }));
	      function capture() {
	        return _capture.apply(this, arguments);
	      }
	      return capture;
	    }() // Stop the video stream and pause webcam iterator.
	  }, {
	    key: "stop",
	    value: function stop() {
	      var tracks = this.stream.getTracks();
	      tracks.forEach(function (track) {
	        return track.stop();
	      });
	      try {
	        this.webcamVideoElement.srcObject = null;
	      } catch (error) {
	        console.log(error);
	        this.webcamVideoElement.src = null;
	      }
	      this.isClosed = true;
	    }
	    // Override toArray() function to prevent collecting.
	  }, {
	    key: "toArray",
	    value: function toArray() {
	      throw new Error('Can not convert infinite video stream to array.');
	    }
	  }], [{
	    key: "create",
	    value: function () {
	      var _create = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4(webcamVideoElement) {
	        var webcamConfig,
	          webcamIterator,
	          _args4 = arguments;
	        return _regeneratorRuntime().wrap(function _callee4$(_context4) {
	          while (1) switch (_context4.prev = _context4.next) {
	            case 0:
	              webcamConfig = _args4.length > 1 && _args4[1] !== undefined ? _args4[1] : {};
	              if (env().get('IS_BROWSER')) {
	                _context4.next = 3;
	                break;
	              }
	              throw new Error('tf.data.webcam is only supported in browser environment.');
	            case 3:
	              if (webcamVideoElement) {
	                _context4.next = 9;
	                break;
	              }
	              // If webcam video element is not provided, create a hidden video element
	              // with provided width and height.
	              webcamVideoElement = document.createElement('video');
	              if (!(!webcamConfig.resizeWidth || !webcamConfig.resizeHeight)) {
	                _context4.next = 7;
	                break;
	              }
	              throw new Error('Please provide webcam video element, or resizeWidth and ' + 'resizeHeight to create a hidden video element.');
	            case 7:
	              webcamVideoElement.width = webcamConfig.resizeWidth;
	              webcamVideoElement.height = webcamConfig.resizeHeight;
	            case 9:
	              webcamIterator = new WebcamIterator(webcamVideoElement, webcamConfig); // Call async function to initialize the video stream.
	              _context4.next = 12;
	              return webcamIterator.start();
	            case 12:
	              return _context4.abrupt("return", webcamIterator);
	            case 13:
	            case "end":
	              return _context4.stop();
	          }
	        }, _callee4);
	      }));
	      function create(_x) {
	        return _create.apply(this, arguments);
	      }
	      return create;
	    }()
	  }]);
	  return WebcamIterator;
	}(LazyIterator);

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 *
	 * =============================================================================
	 */
	/**
	 * Represents a data source readable as a stream of binary data chunks.
	 *
	 * Because `Dataset`s can be read repeatedly (via `Dataset.iterator()`), this
	 * provides a means to repeatedly create streams from the underlying data
	 * sources.
	 */
	var DataSource = /*#__PURE__*/_createClass(function DataSource() {
	  _classCallCheck(this, DataSource);
	});
	// TODO(soergel): consider convenience factory functions here
	// in combination with chainable source->dataset above, e.g.:
	// tf.data.url(...).asCsvDataset().shuffle().batch()

	var StringIterator = /*#__PURE__*/function (_LazyIterator) {
	  _inherits(StringIterator, _LazyIterator);
	  var _super = _createSuper(StringIterator);
	  function StringIterator() {
	    _classCallCheck(this, StringIterator);
	    return _super.apply(this, arguments);
	  }
	  _createClass(StringIterator, [{
	    key: "split",
	    value:
	    /**
	     * Splits a string stream on a given separator.
	     *
	     * It is assumed that the incoming chunk boundaries have no semantic meaning,
	     * so conceptually the incoming stream is treated simply as the concatenation
	     * of its elements.
	     *
	     * The outgoing stream provides chunks corresponding to the results of the
	     * standard string split() operation (even if such a chunk spanned incoming
	     * chunks).  The separators are not included.
	     *
	     * A typical usage is to split a text file (represented as a stream with
	     * arbitrary chunk boundaries) into lines.
	     *
	     * @param upstream A readable stream of strings that can be treated as
	     *   concatenated.
	     * @param separator A character to split on.
	     */
	    function split(separator) {
	      return new SplitIterator(this, separator);
	    }
	  }]);
	  return StringIterator;
	}(LazyIterator);
	// ============================================================================
	// The following private classes serve to implement the chainable methods
	// on StringIterator.  Unfortunately they can't be placed in separate files, due
	// to resulting trouble with circular imports.
	// ============================================================================
	// We wanted multiple inheritance, e.g.
	//   class SplitIterator extends QueueIterator<string>, StringIterator
	// but the TypeScript mixin approach is a bit hacky, so we take this adapter
	// approach instead.
	var SplitIterator = /*#__PURE__*/function (_StringIterator) {
	  _inherits(SplitIterator, _StringIterator);
	  var _super2 = _createSuper(SplitIterator);
	  function SplitIterator(upstream, separator) {
	    var _this;
	    _classCallCheck(this, SplitIterator);
	    _this = _super2.call(this);
	    _this.upstream = upstream;
	    _this.impl = new SplitIteratorImpl(upstream, separator);
	    return _this;
	  }
	  _createClass(SplitIterator, [{
	    key: "summary",
	    value: function summary() {
	      return this.impl.summary();
	    }
	  }, {
	    key: "next",
	    value: function () {
	      var _next = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              return _context.abrupt("return", this.impl.next());
	            case 1:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function next() {
	        return _next.apply(this, arguments);
	      }
	      return next;
	    }()
	  }]);
	  return SplitIterator;
	}(StringIterator);
	var SplitIteratorImpl = /*#__PURE__*/function (_OneToManyIterator) {
	  _inherits(SplitIteratorImpl, _OneToManyIterator);
	  var _super3 = _createSuper(SplitIteratorImpl);
	  function SplitIteratorImpl(upstream, separator) {
	    var _this2;
	    _classCallCheck(this, SplitIteratorImpl);
	    _this2 = _super3.call(this);
	    _this2.upstream = upstream;
	    _this2.separator = separator;
	    // A partial string at the end of an upstream chunk
	    _this2.carryover = '';
	    return _this2;
	  }
	  _createClass(SplitIteratorImpl, [{
	    key: "summary",
	    value: function summary() {
	      return "".concat(this.upstream.summary(), " -> Split('").concat(this.separator, "')");
	    }
	  }, {
	    key: "pump",
	    value: function () {
	      var _pump = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2() {
	        var chunkResult, lines, _iterator, _step, line;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              _context2.next = 2;
	              return this.upstream.next();
	            case 2:
	              chunkResult = _context2.sent;
	              if (!chunkResult.done) {
	                _context2.next = 9;
	                break;
	              }
	              if (!(this.carryover === '')) {
	                _context2.next = 6;
	                break;
	              }
	              return _context2.abrupt("return", false);
	            case 6:
	              // Pretend that the pump succeeded in order to emit the small last batch.
	              // The next pump() call will actually fail.
	              this.outputQueue.push(this.carryover);
	              this.carryover = '';
	              return _context2.abrupt("return", true);
	            case 9:
	              lines = chunkResult.value.split(this.separator); // Note the behavior: " ab ".split(' ') === ['', 'ab', '']
	              // Thus the carryover may be '' if the separator falls on a chunk
	              // boundary; this produces the correct result.
	              lines[0] = this.carryover + lines[0];
	              _iterator = _createForOfIteratorHelper(lines.slice(0, -1));
	              try {
	                for (_iterator.s(); !(_step = _iterator.n()).done;) {
	                  line = _step.value;
	                  this.outputQueue.push(line);
	                }
	              } catch (err) {
	                _iterator.e(err);
	              } finally {
	                _iterator.f();
	              }
	              this.carryover = lines[lines.length - 1];
	              return _context2.abrupt("return", true);
	            case 15:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function pump() {
	        return _pump.apply(this, arguments);
	      }
	      return pump;
	    }()
	  }]);
	  return SplitIteratorImpl;
	}(OneToManyIterator);

	var ByteChunkIterator = /*#__PURE__*/function (_LazyIterator) {
	  _inherits(ByteChunkIterator, _LazyIterator);
	  var _super = _createSuper(ByteChunkIterator);
	  function ByteChunkIterator() {
	    _classCallCheck(this, ByteChunkIterator);
	    return _super.apply(this, arguments);
	  }
	  _createClass(ByteChunkIterator, [{
	    key: "decodeUTF8",
	    value:
	    /**
	     * Decode a stream of UTF8-encoded byte arrays to a stream of strings.
	     *
	     * The byte arrays producetd from the ByteChunkIterator on which this is
	     * called will be interpreted as concatenated.  No assumptions are made about
	     * the boundaries of the incoming chunks, so a multi-byte UTF8 encoding of a
	     * character may span the boundary between chunks.  This naturally happens,
	     * for instance, when reading fixed-size byte arrays from a file.
	     */
	    function decodeUTF8() {
	      return new Utf8Iterator(this);
	    }
	  }]);
	  return ByteChunkIterator;
	}(LazyIterator);
	// ============================================================================
	// The following private classes serve to implement the chainable methods
	// on ByteChunkIterator.  Unfortunately they can't be placed in separate files,
	// due to resulting trouble with circular imports.
	// ============================================================================
	// We wanted multiple inheritance, e.g.
	//   class Utf8Iterator extends QueueIterator<string>, StringIterator
	// but the TypeScript mixin approach is a bit hacky, so we take this adapter
	// approach instead.
	var Utf8Iterator = /*#__PURE__*/function (_StringIterator) {
	  _inherits(Utf8Iterator, _StringIterator);
	  var _super2 = _createSuper(Utf8Iterator);
	  function Utf8Iterator(upstream) {
	    var _this;
	    _classCallCheck(this, Utf8Iterator);
	    _this = _super2.call(this);
	    _this.upstream = upstream;
	    _this.impl = new Utf8IteratorImpl(upstream);
	    return _this;
	  }
	  _createClass(Utf8Iterator, [{
	    key: "summary",
	    value: function summary() {
	      return this.impl.summary();
	    }
	  }, {
	    key: "next",
	    value: function () {
	      var _next = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              return _context.abrupt("return", this.impl.next());
	            case 1:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function next() {
	        return _next.apply(this, arguments);
	      }
	      return next;
	    }()
	  }]);
	  return Utf8Iterator;
	}(StringIterator);
	/**
	 * Decode a stream of UTF8-encoded byte arrays to a stream of strings.
	 *
	 * This is tricky because the incoming byte array boundaries may disrupt a
	 * multi-byte UTF8 character. Thus any incomplete character data at the end of
	 * a chunk must be carried over and prepended to the next chunk before
	 * decoding. Luckily with native decoder, TextDecoder in browser and
	 * string_decoder in node, byte array boundaries are handled automatically.
	 *
	 * In the context of an input pipeline for machine learning, UTF8 decoding is
	 * needed to parse text files containing training examples or prediction
	 * requests (e.g., formatted as CSV or JSON). We cannot use the built-in
	 * decoding provided by FileReader.readAsText() because here we are in a
	 * streaming context, which FileReader does not support.
	 *
	 * @param upstream A `LazyIterator` of `Uint8Arrays` containing UTF8-encoded
	 *   text, which should be interpreted as concatenated.  No assumptions are
	 *   made about the boundaries of the incoming chunks, so a multi-byte UTF8
	 *   encoding of a character may span the boundary between chunks.  This
	 *   naturally happens, for instance, when reading fixed-size byte arrays from a
	 *   file.
	 */
	var Utf8IteratorImpl = /*#__PURE__*/function (_OneToManyIterator) {
	  _inherits(Utf8IteratorImpl, _OneToManyIterator);
	  var _super3 = _createSuper(Utf8IteratorImpl);
	  function Utf8IteratorImpl(upstream) {
	    var _this2;
	    _classCallCheck(this, Utf8IteratorImpl);
	    _this2 = _super3.call(this);
	    _this2.upstream = upstream;
	    if (env().get('IS_BROWSER')) {
	      _this2.decoder = new TextDecoder('utf-8');
	    } else {
	      // tslint:disable-next-line:no-require-imports
	      var _require = require('string_decoder'),
	        StringDecoder = _require.StringDecoder;
	      _this2.decoder = new StringDecoder('utf8');
	    }
	    return _this2;
	  }
	  _createClass(Utf8IteratorImpl, [{
	    key: "summary",
	    value: function summary() {
	      return "".concat(this.upstream.summary(), " -> Utf8");
	    }
	  }, {
	    key: "pump",
	    value: function () {
	      var _pump = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2() {
	        var chunkResult, chunk, text;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              _context2.next = 2;
	              return this.upstream.next();
	            case 2:
	              chunkResult = _context2.sent;
	              if (!chunkResult.done) {
	                _context2.next = 7;
	                break;
	              }
	              return _context2.abrupt("return", false);
	            case 7:
	              chunk = chunkResult.value;
	            case 8:
	              if (env().get('IS_BROWSER')) {
	                text = this.decoder.decode(chunk, {
	                  stream: true
	                });
	              } else {
	                text = this.decoder.write(Buffer.from(chunk.buffer));
	              }
	              this.outputQueue.push(text);
	              return _context2.abrupt("return", true);
	            case 11:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2, this);
	      }));
	      function pump() {
	        return _pump.apply(this, arguments);
	      }
	      return pump;
	    }()
	  }]);
	  return Utf8IteratorImpl;
	}(OneToManyIterator);

	/**
	 * Provide a stream of chunks from a File, Blob, or Uint8Array.
	 * @param file The source File, Blob or Uint8Array.
	 * @param options Optional settings controlling file reading.
	 * @returns a lazy Iterator of Uint8Arrays containing sequential chunks of the
	 *   input File, Blob or Uint8Array.
	 */
	var FileChunkIterator = /*#__PURE__*/function (_ByteChunkIterator) {
	  _inherits(FileChunkIterator, _ByteChunkIterator);
	  var _super = _createSuper(FileChunkIterator);
	  function FileChunkIterator(file) {
	    var _this;
	    var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	    _classCallCheck(this, FileChunkIterator);
	    _this = _super.call(this);
	    _this.file = file;
	    _this.options = options;
	    assert$1(file instanceof Uint8Array || (env().get('IS_BROWSER') ? file instanceof File || file instanceof Blob : false), function () {
	      return 'FileChunkIterator only supports File, Blob and Uint8Array ' + 'right now.';
	    });
	    _this.offset = options.offset || 0;
	    // default 1MB chunk has tolerable perf on large files
	    _this.chunkSize = options.chunkSize || 1024 * 1024;
	    return _this;
	  }
	  _createClass(FileChunkIterator, [{
	    key: "summary",
	    value: function summary() {
	      return "FileChunks ".concat(this.file);
	    }
	  }, {
	    key: "next",
	    value: function () {
	      var _next = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        var _this2 = this;
	        var chunk;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              if (!(this.offset >= (this.file instanceof Uint8Array ? this.file.byteLength : this.file.size))) {
	                _context.next = 2;
	                break;
	              }
	              return _context.abrupt("return", {
	                value: null,
	                done: true
	              });
	            case 2:
	              chunk = new Promise(function (resolve, reject) {
	                var end = _this2.offset + _this2.chunkSize;
	                if (_this2.file instanceof Uint8Array) {
	                  // Note if end > this.uint8Array.byteLength, we just get a small last
	                  // chunk.
	                  resolve(new Uint8Array(_this2.file.slice(_this2.offset, end)));
	                } else {
	                  // This branch assumes that this.file type is File or Blob, which
	                  // means it is in the browser environment.
	                  // TODO(soergel): is this a performance issue?
	                  var fileReader = new FileReader();
	                  fileReader.onload = function (event) {
	                    var data = fileReader.result;
	                    // Not sure we can trust the return type of
	                    // FileReader.readAsArrayBuffer See e.g.
	                    // https://github.com/node-file-api/FileReader/issues/2
	                    if (data instanceof ArrayBuffer) {
	                      data = new Uint8Array(data);
	                    }
	                    if (!(data instanceof Uint8Array)) {
	                      return reject(new TypeError('FileReader returned unknown type.'));
	                    }
	                    resolve(data);
	                  };
	                  fileReader.onabort = function (event) {
	                    return reject(new Error('Aborted'));
	                  };
	                  fileReader.onerror = function (event) {
	                    return reject(new Error(event.type));
	                  };
	                  // TODO(soergel): better handle onabort, onerror
	                  // Note if end > this.file.size, we just get a small last chunk.
	                  var slice = _this2.file.slice(_this2.offset, end);
	                  // We can't use readAsText here (even if we know the file is text)
	                  // because the slice boundary may fall within a multi-byte character.
	                  fileReader.readAsArrayBuffer(slice);
	                }
	                _this2.offset = end;
	              });
	              _context.next = 5;
	              return chunk;
	            case 5:
	              _context.t0 = _context.sent;
	              return _context.abrupt("return", {
	                value: _context.t0,
	                done: false
	              });
	            case 7:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function next() {
	        return _next.apply(this, arguments);
	      }
	      return next;
	    }()
	  }]);
	  return FileChunkIterator;
	}(ByteChunkIterator);

	/**
	 * Provide a stream of chunks from a URL.
	 *
	 * Note this class first downloads the entire file into memory before providing
	 * the first element from the stream.  This is because the Fetch API does not
	 * yet reliably provide a reader stream for the response body.
	 */
	function urlChunkIterator(_x) {
	  return _urlChunkIterator.apply(this, arguments);
	}
	// Generate RequestInit from Request to match tf.util.fetch signature.
	function _urlChunkIterator() {
	  _urlChunkIterator = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(url) {
	    var options,
	      fetchFunc,
	      urlString,
	      requestInit,
	      response,
	      uint8Array,
	      _args = arguments;
	    return _regeneratorRuntime().wrap(function _callee$(_context) {
	      while (1) switch (_context.prev = _context.next) {
	        case 0:
	          options = _args.length > 1 && _args[1] !== undefined ? _args[1] : {};
	          fetchFunc = _args.length > 2 ? _args[2] : undefined;
	          if (typeof url === 'string') {
	            urlString = url;
	          } else {
	            urlString = url.url;
	            requestInit = getRequestInitFromRequest(url);
	          }
	          _context.next = 5;
	          return (fetchFunc || fetch$1)(urlString, requestInit);
	        case 5:
	          response = _context.sent;
	          if (!response.ok) {
	            _context.next = 15;
	            break;
	          }
	          _context.t0 = Uint8Array;
	          _context.next = 10;
	          return response.arrayBuffer();
	        case 10:
	          _context.t1 = _context.sent;
	          uint8Array = new _context.t0(_context.t1);
	          return _context.abrupt("return", new FileChunkIterator(uint8Array, options));
	        case 15:
	          throw new Error(response.statusText);
	        case 16:
	        case "end":
	          return _context.stop();
	      }
	    }, _callee);
	  }));
	  return _urlChunkIterator.apply(this, arguments);
	}
	var getRequestInitFromRequest = function getRequestInitFromRequest(request) {
	  var init = {
	    method: request.method,
	    headers: request.headers,
	    body: request.body,
	    mode: request.mode,
	    credentials: request.credentials,
	    cache: request.cache,
	    redirect: request.redirect,
	    referrer: request.referrer,
	    integrity: request.integrity
	  };
	  return init;
	};

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 *
	 * =============================================================================
	 */
	// Skip tslint any type check cause this method is aiming to check type of
	// input.
	// tslint:disable-next-line:no-any
	function isLocalPath(source) {
	  return typeof source === 'string' && source.slice(0, 7) === 'file://';
	}

	/**
	 * Represents a file, blob, or Uint8Array readable as a stream of binary data
	 * chunks.
	 */
	var FileDataSource = /*#__PURE__*/function (_DataSource) {
	  _inherits(FileDataSource, _DataSource);
	  var _super = _createSuper(FileDataSource);
	  /**
	   * Create a `FileDataSource`.
	   *
	   * @param input Local file path, or `File`/`Blob`/`Uint8Array` object to
	   *     read. Local file only works in node environment.
	   * @param options Options passed to the underlying `FileChunkIterator`s,
	   *   such as {chunksize: 1024}.
	   */
	  function FileDataSource(input) {
	    var _this;
	    var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	    _classCallCheck(this, FileDataSource);
	    _this = _super.call(this);
	    _this.input = input;
	    _this.options = options;
	    return _this;
	  }
	  _createClass(FileDataSource, [{
	    key: "iterator",
	    value: function () {
	      var _iterator = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        var fs;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              if (isLocalPath(this.input) && env().get('IS_NODE')) {
	                // tslint:disable-next-line:no-require-imports
	                fs = require('fs');
	                this.input = fs.readFileSync(this.input.slice(7));
	              }
	              // TODO(kangyizhang): Add LocalFileChunkIterator to split local streaming
	              // with file in browser.
	              return _context.abrupt("return", new FileChunkIterator(this.input, this.options));
	            case 2:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function iterator() {
	        return _iterator.apply(this, arguments);
	      }
	      return iterator;
	    }()
	  }]);
	  return FileDataSource;
	}(DataSource);

	/*
	 * Represents a URL readable as a stream of binary data chunks.
	 */
	var URLDataSource = /*#__PURE__*/function (_DataSource) {
	  _inherits(URLDataSource, _DataSource);
	  var _super = _createSuper(URLDataSource);
	  /**
	   * Create a `URLDataSource`.
	   *
	   * @param url A source URL string, or a `Request` object.
	   * @param options Options passed to the underlying `FileChunkIterator`s,
	   *   such as {chunksize: 1024}.
	   */
	  function URLDataSource(url) {
	    var _this;
	    var fileOptions = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	    _classCallCheck(this, URLDataSource);
	    _this = _super.call(this);
	    _this.url = url;
	    _this.fileOptions = fileOptions;
	    return _this;
	  }
	  // TODO(soergel): provide appropriate caching options.  Currently this
	  // will download the URL anew for each call to iterator().  Since we have
	  // to treat the downloaded file as a blob/buffer anyway, we may as well retain
	  // it-- but that raises GC issues.  Also we may want a persistent disk cache.
	  _createClass(URLDataSource, [{
	    key: "iterator",
	    value: function () {
	      var _iterator = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              if (!isLocalPath(this.url)) {
	                _context.next = 4;
	                break;
	              }
	              return _context.abrupt("return", new FileDataSource(this.url, this.fileOptions).iterator());
	            case 4:
	              return _context.abrupt("return", urlChunkIterator(this.url, this.fileOptions));
	            case 5:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function iterator() {
	        return _iterator.apply(this, arguments);
	      }
	      return iterator;
	    }()
	  }]);
	  return URLDataSource;
	}(DataSource);

	/**
	 * Create a `CSVDataset` by reading and decoding CSV file(s) from provided URL
	 * or local path if it's in Node environment.
	 *
	 * Note: If isLabel in columnConfigs is `true` for at least one column, the
	 * element in returned `CSVDataset` will be an object of
	 * `{xs:features, ys:labels}`: xs is a dict of features key/value pairs, ys
	 * is a dict of labels key/value pairs. If no column is marked as label,
	 * returns a dict of features only.
	 *
	 * ```js
	 * const csvUrl =
	 * 'https://storage.googleapis.com/tfjs-examples/multivariate-linear-regression/data/boston-housing-train.csv';
	 *
	 * async function run() {
	 *   // We want to predict the column "medv", which represents a median value of
	 *   // a home (in $1000s), so we mark it as a label.
	 *   const csvDataset = tf.data.csv(
	 *     csvUrl, {
	 *       columnConfigs: {
	 *         medv: {
	 *           isLabel: true
	 *         }
	 *       }
	 *     });
	 *
	 *   // Number of features is the number of column names minus one for the label
	 *   // column.
	 *   const numOfFeatures = (await csvDataset.columnNames()).length - 1;
	 *
	 *   // Prepare the Dataset for training.
	 *   const flattenedDataset =
	 *     csvDataset
	 *     .map(({xs, ys}) =>
	 *       {
	 *         // Convert xs(features) and ys(labels) from object form (keyed by
	 *         // column name) to array form.
	 *         return {xs:Object.values(xs), ys:Object.values(ys)};
	 *       })
	 *     .batch(10);
	 *
	 *   // Define the model.
	 *   const model = tf.sequential();
	 *   model.add(tf.layers.dense({
	 *     inputShape: [numOfFeatures],
	 *     units: 1
	 *   }));
	 *   model.compile({
	 *     optimizer: tf.train.sgd(0.000001),
	 *     loss: 'meanSquaredError'
	 *   });
	 *
	 *   // Fit the model using the prepared Dataset
	 *   return model.fitDataset(flattenedDataset, {
	 *     epochs: 10,
	 *     callbacks: {
	 *       onEpochEnd: async (epoch, logs) => {
	 *         console.log(epoch + ':' + logs.loss);
	 *       }
	 *     }
	 *   });
	 * }
	 *
	 * await run();
	 * ```
	 *
	 * @param source URL or local path to get CSV file. If it's a local path, it
	 * must have prefix `file://` and it only works in node environment.
	 * @param csvConfig (Optional) A CSVConfig object that contains configurations
	 *     of reading and decoding from CSV file(s).
	 *
	 * @doc {
	 *   heading: 'Data',
	 *   subheading: 'Creation',
	 *   namespace: 'data',
	 *   configParamIndices: [1]
	 *  }
	 */
	function csv(source) {
	  var csvConfig = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	  return new CSVDataset(new URLDataSource(source), csvConfig);
	}
	/**
	 * Create a `Dataset` that produces each element by calling a provided function.
	 *
	 * Note that repeated iterations over this `Dataset` may produce different
	 * results, because the function will be called anew for each element of each
	 * iteration.
	 *
	 * Also, beware that the sequence of calls to this function may be out of order
	 * in time with respect to the logical order of the Dataset. This is due to the
	 * asynchronous lazy nature of stream processing, and depends on downstream
	 * transformations (e.g. .shuffle()). If the provided function is pure, this is
	 * no problem, but if it is a closure over a mutable state (e.g., a traversal
	 * pointer), then the order of the produced elements may be scrambled.
	 *
	 * ```js
	 * let i = -1;
	 * const func = () =>
	 *    ++i < 5 ? {value: i, done: false} : {value: null, done: true};
	 * const ds = tf.data.func(func);
	 * await ds.forEachAsync(e => console.log(e));
	 * ```
	 *
	 * @param f A function that produces one data element on each call.
	 */
	function func(f) {
	  var iter = iteratorFromFunction(f);
	  return datasetFromIteratorFn( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee() {
	    return _regeneratorRuntime().wrap(function _callee$(_context) {
	      while (1) switch (_context.prev = _context.next) {
	        case 0:
	          return _context.abrupt("return", iter);
	        case 1:
	        case "end":
	          return _context.stop();
	      }
	    }, _callee);
	  })));
	}
	/**
	 * Create a `Dataset` that produces each element from provided JavaScript
	 * generator, which is a function that returns a (potentially async) iterator.
	 *
	 * For more information on iterators and generators, see
	 * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Iterators_and_Generators .
	 * For the iterator protocol, see
	 * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Iteration_protocols .
	 *
	 * Example of creating a dataset from an iterator factory:
	 * ```js
	 * function makeIterator() {
	 *   const numElements = 10;
	 *   let index = 0;
	 *
	 *   const iterator = {
	 *     next: () => {
	 *       let result;
	 *       if (index < numElements) {
	 *         result = {value: index, done: false};
	 *         index++;
	 *         return result;
	 *       }
	 *       return {value: index, done: true};
	 *     }
	 *   };
	 *   return iterator;
	 * }
	 * const ds = tf.data.generator(makeIterator);
	 * await ds.forEachAsync(e => console.log(e));
	 * ```
	 *
	 * Example of creating a dataset from a generator:
	 * ```js
	 * function* dataGenerator() {
	 *   const numElements = 10;
	 *   let index = 0;
	 *   while (index < numElements) {
	 *     const x = index;
	 *     index++;
	 *     yield x;
	 *   }
	 * }
	 *
	 * const ds = tf.data.generator(dataGenerator);
	 * await ds.forEachAsync(e => console.log(e));
	 * ```
	 *
	 * @param generator A JavaScript function that returns
	 *     a (potentially async) JavaScript iterator.
	 *
	 * @doc {
	 *   heading: 'Data',
	 *   subheading: 'Creation',
	 *   namespace: 'data',
	 *   configParamIndices: [1]
	 *  }
	 */
	function generator(generator) {
	  return datasetFromIteratorFn( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2() {
	    var gen;
	    return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	      while (1) switch (_context2.prev = _context2.next) {
	        case 0:
	          _context2.next = 2;
	          return generator();
	        case 2:
	          gen = _context2.sent;
	          return _context2.abrupt("return", iteratorFromFunction(function () {
	            return gen.next();
	          }));
	        case 4:
	        case "end":
	          return _context2.stop();
	      }
	    }, _callee2);
	  })));
	}
	/**
	 * Create an iterator that generates `Tensor`s from webcam video stream. This
	 * API only works in Browser environment when the device has webcam.
	 *
	 * Note: this code snippet only works when the device has a webcam. It will
	 * request permission to open the webcam when running.
	 * ```js
	 * const videoElement = document.createElement('video');
	 * videoElement.width = 100;
	 * videoElement.height = 100;
	 * const cam = await tf.data.webcam(videoElement);
	 * const img = await cam.capture();
	 * img.print();
	 * cam.stop();
	 * ```
	 *
	 * @param webcamVideoElement A `HTMLVideoElement` used to play video from
	 *     webcam. If this element is not provided, a hidden `HTMLVideoElement` will
	 *     be created. In that case, `resizeWidth` and `resizeHeight` must be
	 *     provided to set the generated tensor shape.
	 * @param webcamConfig A `WebcamConfig` object that contains configurations of
	 *     reading and manipulating data from webcam video stream.
	 *
	 * @doc {
	 *   heading: 'Data',
	 *   subheading: 'Creation',
	 *   namespace: 'data',
	 *   ignoreCI: true
	 *  }
	 */
	function webcam(_x, _x2) {
	  return _webcam.apply(this, arguments);
	}
	/**
	 * Create an iterator that generates frequency-domain spectrogram `Tensor`s from
	 * microphone audio stream with browser's native FFT. This API only works in
	 * browser environment when the device has microphone.
	 *
	 * Note: this code snippet only works when the device has a microphone. It will
	 * request permission to open the microphone when running.
	 * ```js
	 * const mic = await tf.data.microphone({
	 *   fftSize: 1024,
	 *   columnTruncateLength: 232,
	 *   numFramesPerSpectrogram: 43,
	 *   sampleRateHz:44100,
	 *   includeSpectrogram: true,
	 *   includeWaveform: true
	 * });
	 * const audioData = await mic.capture();
	 * const spectrogramTensor = audioData.spectrogram;
	 * spectrogramTensor.print();
	 * const waveformTensor = audioData.waveform;
	 * waveformTensor.print();
	 * mic.stop();
	 * ```
	 *
	 * @param microphoneConfig A `MicrophoneConfig` object that contains
	 *     configurations of reading audio data from microphone.
	 *
	 * @doc {
	 *   heading: 'Data',
	 *   subheading: 'Creation',
	 *   namespace: 'data',
	 *   ignoreCI: true
	 *  }
	 */
	function _webcam() {
	  _webcam = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3(webcamVideoElement, webcamConfig) {
	    return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	      while (1) switch (_context3.prev = _context3.next) {
	        case 0:
	          return _context3.abrupt("return", WebcamIterator.create(webcamVideoElement, webcamConfig));
	        case 1:
	        case "end":
	          return _context3.stop();
	      }
	    }, _callee3);
	  }));
	  return _webcam.apply(this, arguments);
	}
	function microphone(_x3) {
	  return _microphone.apply(this, arguments);
	}
	function _microphone() {
	  _microphone = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4(microphoneConfig) {
	    return _regeneratorRuntime().wrap(function _callee4$(_context4) {
	      while (1) switch (_context4.prev = _context4.next) {
	        case 0:
	          return _context4.abrupt("return", MicrophoneIterator.create(microphoneConfig));
	        case 1:
	        case "end":
	          return _context4.stop();
	      }
	    }, _callee4);
	  }));
	  return _microphone.apply(this, arguments);
	}

	/** @license See the LICENSE file. */
	// This code is auto-generated, do not modify this file!
	var version$4 = '4.22.0';

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */

	var index = {
		__proto__: null,
		CSVDataset: CSVDataset,
		Dataset: Dataset,
		FileDataSource: FileDataSource,
		TextLineDataset: TextLineDataset,
		URLDataSource: URLDataSource,
		array: array,
		csv: csv,
		func: func,
		generator: generator,
		microphone: microphone,
		version_data: version$4,
		webcam: webcam,
		zip: zip
	};

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function assertNotComplex$1(tensor, opName) {
	  if (!Array.isArray(tensor)) {
	    tensor = [tensor];
	  }
	  tensor.forEach(function (t) {
	    if (t != null) {
	      assert$1(t.dtype !== 'complex64', function () {
	        return "".concat(opName, " does not support complex64 tensors in the CPU backend.");
	      });
	    }
	  });
	}

	var whereImpl$1 = whereImpl$2;
	var MathBackendCPU = /*#__PURE__*/function (_KernelBackend) {
	  _inherits(MathBackendCPU, _KernelBackend);
	  var _super = _createSuper(MathBackendCPU);
	  function MathBackendCPU() {
	    var _this;
	    _classCallCheck(this, MathBackendCPU);
	    _this = _super.call(this);
	    _this.blockSize = 48;
	    _this.firstUse = true;
	    _this.data = new DataStorage(_assertThisInitialized(_this), engine());
	    return _this;
	  }
	  _createClass(MathBackendCPU, [{
	    key: "nextDataId",
	    value: function nextDataId() {
	      return MathBackendCPU.nextDataId++;
	    }
	  }, {
	    key: "write",
	    value: function write(values, shape, dtype) {
	      if (this.firstUse) {
	        this.firstUse = false;
	        if (env().get('IS_NODE')) {
	          warn('\n============================\n' + 'Hi, looks like you are running TensorFlow.js in ' + 'Node.js. To speed things up dramatically, install our node ' + 'backend, visit https://github.com/tensorflow/tfjs-node for more details. ' + '\n============================');
	        }
	      }
	      var dataId = {
	        id: this.nextDataId()
	      };
	      this.data.set(dataId, {
	        values: values,
	        dtype: dtype,
	        refCount: 1
	      });
	      return dataId;
	    }
	    /**
	     * Create a data bucket in cpu backend.
	     * @param shape Shape of the `TensorInfo`.
	     * @param dtype DType of the `TensorInfo`.
	     * @param values The value of the `TensorInfo` stored as a flattened array.
	     */
	  }, {
	    key: "makeTensorInfo",
	    value: function makeTensorInfo(shape, dtype, values) {
	      var outId;
	      if (dtype === 'string' && values != null && values.length > 0 && isString(values[0])) {
	        var encodedValues = values.map(function (d) {
	          return encodeString(d);
	        });
	        outId = this.write(encodedValues, shape, dtype);
	      } else {
	        outId = this.write(values, shape, dtype);
	      }
	      return {
	        dataId: outId,
	        shape: shape,
	        dtype: dtype
	      };
	    }
	    /** Return refCount of a `TensorData`. */
	  }, {
	    key: "refCount",
	    value: function refCount(dataId) {
	      if (this.data.has(dataId)) {
	        var tensorData = this.data.get(dataId);
	        return tensorData.refCount;
	      }
	      return 0;
	    }
	    /** Increase refCount of a `TensorData`. */
	  }, {
	    key: "incRef",
	    value: function incRef(dataId) {
	      var tensorData = this.data.get(dataId);
	      tensorData.refCount++;
	    }
	    /** Decrease refCount of a `TensorData`. */
	  }, {
	    key: "decRef",
	    value: function decRef(dataId) {
	      if (this.data.has(dataId)) {
	        var tensorData = this.data.get(dataId);
	        tensorData.refCount--;
	      }
	    }
	  }, {
	    key: "move",
	    value: function move(dataId, values, shape, dtype, refCount) {
	      this.data.set(dataId, {
	        values: values,
	        dtype: dtype,
	        refCount: refCount
	      });
	    }
	  }, {
	    key: "numDataIds",
	    value: function numDataIds() {
	      return this.data.numDataIds();
	    }
	  }, {
	    key: "read",
	    value: function () {
	      var _read = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(dataId) {
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              return _context.abrupt("return", this.readSync(dataId));
	            case 1:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function read(_x) {
	        return _read.apply(this, arguments);
	      }
	      return read;
	    }()
	  }, {
	    key: "readSync",
	    value: function readSync(dataId) {
	      var _this$data$get = this.data.get(dataId),
	        dtype = _this$data$get.dtype,
	        complexTensorInfos = _this$data$get.complexTensorInfos;
	      if (dtype === 'complex64') {
	        var realValues = this.readSync(complexTensorInfos.real.dataId);
	        var imagValues = this.readSync(complexTensorInfos.imag.dataId);
	        return mergeRealAndImagArrays(realValues, imagValues);
	      }
	      return convertBackendValuesAndArrayBuffer(this.data.get(dataId).values, dtype);
	    }
	  }, {
	    key: "bufferSync",
	    value: function bufferSync(t) {
	      var data = this.readSync(t.dataId);
	      if (t.dtype === 'string') {
	        try {
	          // Decode the bytes into string.
	          var strings = data.map(function (d) {
	            return decodeString(d);
	          });
	          return buffer(t.shape, t.dtype, strings);
	        } catch (_a) {
	          throw new Error('Failed to decode encoded string bytes into utf-8');
	        }
	      }
	      return buffer(t.shape, t.dtype, data);
	    }
	  }, {
	    key: "makeOutput",
	    value: function makeOutput(values, shape, dtype) {
	      return engine().makeTensorFromTensorInfo(this.makeTensorInfo(shape, dtype, values), this);
	    }
	    /**
	     * Dispose the memory if the dataId has 0 refCount. Return true if the memory
	     * is released or memory is not managed in this backend, false if memory is
	     * not cleared.
	     * @param dataId
	     * @oaram force Optional, remove the data regardless of refCount
	     */
	  }, {
	    key: "disposeData",
	    value: function disposeData(dataId) {
	      var force = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
	      if (this.data.has(dataId)) {
	        this.data.get(dataId).refCount--;
	        if (!force && this.data.get(dataId).refCount > 0) {
	          return false;
	        }
	        var _this$data$get2 = this.data.get(dataId),
	          complexTensorInfos = _this$data$get2.complexTensorInfos;
	        if (complexTensorInfos != null) {
	          this.disposeData(complexTensorInfos.real.dataId, true);
	          this.disposeData(complexTensorInfos.imag.dataId, true);
	        }
	        this.data.delete(dataId);
	      }
	      return true;
	    }
	  }, {
	    key: "disposeIntermediateTensorInfo",
	    value: function disposeIntermediateTensorInfo(tensorInfo) {
	      this.disposeData(tensorInfo.dataId);
	    }
	  }, {
	    key: "time",
	    value: function () {
	      var _time = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2(f) {
	        var start, kernelMs;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              start = now();
	              f();
	              kernelMs = now() - start;
	              return _context2.abrupt("return", {
	                kernelMs: kernelMs
	              });
	            case 4:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2);
	      }));
	      function time(_x2) {
	        return _time.apply(this, arguments);
	      }
	      return time;
	    }()
	  }, {
	    key: "memory",
	    value: function memory() {
	      return {
	        // Unreliable due to automatic gc. The numbers above are cumulative.
	        unreliable: true,
	        reasons: ['The reported memory is an upper bound. Due to automatic garbage ' + 'collection, the true allocated memory may be less.']
	      };
	    }
	  }, {
	    key: "where",
	    value: function where(condition) {
	      assertNotComplex$1([condition], 'where');
	      var condVals = this.readSync(condition.dataId);
	      return whereImpl$1(condition.shape, condVals);
	    }
	  }, {
	    key: "dispose",
	    value: function dispose() {}
	  }, {
	    key: "floatPrecision",
	    value: function floatPrecision() {
	      return 32;
	    }
	    /** Returns the smallest representable number.  */
	  }, {
	    key: "epsilon",
	    value: function epsilon() {
	      return _get(_getPrototypeOf(MathBackendCPU.prototype), "epsilon", this).call(this);
	    }
	  }]);
	  return MathBackendCPU;
	}(KernelBackend);
	MathBackendCPU.nextDataId = 0;

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function simpleAbsImpl(vals) {
	  var resultValues = new Float32Array(vals.length);
	  for (var i = 0; i < vals.length; ++i) {
	    resultValues[i] = Math.abs(vals[i]);
	  }
	  return resultValues;
	}
	var abs$1 = function abs(args) {
	  var x = args.inputs.x;
	  var cpuBackend = args.backend;
	  assertNotComplex$1(x, 'abs');
	  var resultValues = new Float32Array(sizeFromShape(x.shape));
	  var values = cpuBackend.data.get(x.dataId).values;
	  resultValues = simpleAbsImpl(values);
	  return cpuBackend.makeOutput(resultValues, x.shape, x.dtype);
	};
	var absConfig$1 = {
	  kernelName: Abs,
	  backendName: 'cpu',
	  kernelFunc: abs$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Template that creates implementation for binary ops. Supports broadcast.
	 */
	function createSimpleBinaryKernelImpl(op) {
	  return function (aShape, bShape, aVals, bVals, dtype) {
	    var newShape = assertAndGetBroadcastShape(aShape, bShape);
	    var resultRank = newShape.length;
	    var resultStrides = computeStrides(newShape);
	    var resultSize = sizeFromShape(newShape);
	    var result = getTypedArrayFromDType(dtype, resultSize);
	    var aRank = aShape.length;
	    var bRank = bShape.length;
	    var aStrides = computeStrides(aShape);
	    var bStrides = computeStrides(bShape);
	    var aBroadcastDims = getBroadcastDims$1(aShape, newShape);
	    var bBroadcastDims = getBroadcastDims$1(bShape, newShape);
	    if (aBroadcastDims.length + bBroadcastDims.length === 0) {
	      for (var i = 0; i < result.length; ++i) {
	        result[i] = op(aVals[i % aVals.length], bVals[i % bVals.length]);
	      }
	    } else {
	      var _loop = function _loop() {
	        var loc = indexToLoc(_i, resultRank, resultStrides);
	        var aLoc = loc.slice(-aRank);
	        aBroadcastDims.forEach(function (d) {
	          return aLoc[d] = 0;
	        });
	        var aIndex = locToIndex(aLoc, aRank, aStrides);
	        var bLoc = loc.slice(-bRank);
	        bBroadcastDims.forEach(function (d) {
	          return bLoc[d] = 0;
	        });
	        var bIndex = locToIndex(bLoc, bRank, bStrides);
	        result[_i] = op(aVals[aIndex], bVals[bIndex]);
	      };
	      for (var _i = 0; _i < result.length; ++_i) {
	        _loop();
	      }
	    }
	    return [result, newShape];
	  };
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function complex$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var real = inputs.real,
	    imag = inputs.imag;
	  var realVals = backend.data.get(real.dataId).values;
	  var imagVals = backend.data.get(imag.dataId).values;
	  var complexInfo = backend.makeTensorInfo(real.shape, 'complex64');
	  var complex = backend.data.get(complexInfo.dataId);
	  // The complex tensor owns the underlying real and imag tensorInfos, only the
	  // complex tensor tracks refCount, when complexData is disposed the
	  // underlying tensorData will be disposed.
	  complex.complexTensorInfos = {
	    real: backend.makeTensorInfo(real.shape, 'float32', realVals),
	    imag: backend.makeTensorInfo(imag.shape, 'float32', imagVals)
	  };
	  return complexInfo;
	}
	var complexConfig$1 = {
	  kernelName: Complex,
	  backendName: 'cpu',
	  kernelFunc: complex$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Generates a tensorInfo with all zeros value.
	 * @param backend cpu backend.
	 * @param shape Shape for the zeros tensor.
	 * @param dtype Optional. If set, the result has this dtype.
	 */
	function zeros(backend, shape) {
	  var dtype = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'float32';
	  if (dtype === 'complex64') {
	    var real = zeros(backend, shape, 'float32');
	    var imag = zeros(backend, shape, 'float32');
	    return complex$1({
	      inputs: {
	        real: real,
	        imag: imag
	      },
	      backend: backend
	    });
	  }
	  var values = makeZerosTypedArray(sizeFromShape(shape), dtype);
	  return backend.makeTensorInfo(shape, dtype, values);
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function identity$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var x = inputs.x;
	  backend.incRef(x.dataId);
	  return {
	    dataId: x.dataId,
	    shape: x.shape,
	    dtype: x.dtype
	  };
	}
	var identityConfig$1 = {
	  kernelName: Identity$1,
	  backendName: 'cpu',
	  kernelFunc: identity$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function real$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var input = inputs.input;
	  var real = backend.data.get(input.dataId).complexTensorInfos.real;
	  var realVal = backend.data.get(real.dataId).values;
	  // When complex tensor is disposed, its underlying parts will be disposed too.
	  // Make new tensor out of the real value of the complex. This makes sure the
	  // value is still accessible even if complex tensor is disposed.
	  return backend.makeTensorInfo(real.shape, real.dtype, realVal);
	}
	var realConfig$1 = {
	  kernelName: Real,
	  backendName: 'cpu',
	  kernelFunc: real$1
	};

	function castImpl(values, shape, inputType, dtype) {
	  if (dtype === 'int32') {
	    var resultValues = Int32Array.from(values);
	    return [shape, 'int32', resultValues];
	  }
	  if (dtype === 'bool') {
	    // This is essentially the result of notEqual(x, 0). We avoid using
	    // kernel notEqual to avoid circular dependency, i.e. binary_utils ->
	    // cast -> notEqual -> binary_utils.
	    var zero = toTypedArray([0], inputType);
	    var _createSimpleBinaryKe = createSimpleBinaryKernelImpl(function (a, b) {
	        return a !== b ? 1 : 0;
	      })(shape, [], values, zero, 'bool'),
	      _createSimpleBinaryKe2 = _slicedToArray(_createSimpleBinaryKe, 2),
	      resultData = _createSimpleBinaryKe2[0],
	      resultShape = _createSimpleBinaryKe2[1];
	    return [resultShape, 'bool', resultData];
	  }
	  throw new Error("Error in Cast: failed to cast ".concat(inputType, " to ").concat(dtype));
	}
	function cast$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var dtype = attrs.dtype;
	  // Casting to complex64.
	  if (dtype === 'complex64') {
	    if (x.dtype === 'complex64') {
	      return identity$1({
	        inputs: {
	          x: x
	        },
	        backend: backend
	      });
	    }
	    var zerosTensorInfo = zeros(backend, x.shape, x.dtype);
	    var floatX = cast$1({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        dtype: 'float32'
	      }
	    });
	    var result = complex$1({
	      inputs: {
	        real: floatX,
	        imag: zerosTensorInfo
	      },
	      backend: backend
	    });
	    backend.disposeIntermediateTensorInfo(zerosTensorInfo);
	    backend.disposeIntermediateTensorInfo(floatX);
	    return result;
	  }
	  // Casting from complex64
	  if (x.dtype === 'complex64') {
	    var realPart = real$1({
	      inputs: {
	        input: x
	      },
	      backend: backend
	    });
	    var _result = cast$1({
	      inputs: {
	        x: realPart
	      },
	      backend: backend,
	      attrs: {
	        dtype: dtype
	      }
	    });
	    backend.disposeIntermediateTensorInfo(realPart);
	    return _result;
	  }
	  if (!hasEncodingLoss(x.dtype, dtype)) {
	    // We don't change the underlying data, since we cast to higher
	    // precision.
	    var _result2 = identity$1({
	      inputs: {
	        x: x
	      },
	      backend: backend
	    });
	    return {
	      dataId: _result2.dataId,
	      shape: _result2.shape,
	      dtype: dtype
	    };
	  }
	  var values = backend.data.get(x.dataId).values;
	  var _castImpl = castImpl(values, x.shape, x.dtype, dtype),
	    _castImpl2 = _slicedToArray(_castImpl, 3),
	    resultShape = _castImpl2[0],
	    resultType = _castImpl2[1],
	    resultData = _castImpl2[2];
	  return backend.makeTensorInfo(resultShape, resultType, resultData);
	}
	var castConfig$1 = {
	  kernelName: Cast,
	  backendName: 'cpu',
	  kernelFunc: cast$1
	};

	/**
	 * Template that creates a `KernelFunc` for binary ops.
	 * @param name Kernel name.
	 * @param binaryKernelImpl A `SimpleBinaryKernelImpl` for the kernel.
	 * @param binaryKernelComplexImpl Optional. If exists, represents a
	 *     `ComplexBinaryKernelImpl` for the kernel, will be used when input dtype
	 *     is `complex64`.
	 * @param dtype Optional. If set, the result has this dtype. Otherwise, the
	 *     result has the same dtype as the first input. This is mainly used in
	 *     comparison kernels, such as Equal, Less, Greater, etc.
	 */
	function binaryKernelFunc$1(name, simpleImpl, complexImpl, dtype) {
	  if (complexImpl == null) {
	    return function (_ref) {
	      var inputs = _ref.inputs,
	        backend = _ref.backend;
	      var a = inputs.a,
	        b = inputs.b;
	      var cpuBackend = backend;
	      assertNotComplex$1([a, b], name);
	      var aVals = cpuBackend.data.get(a.dataId).values;
	      var bVals = cpuBackend.data.get(b.dataId).values;
	      var decodedAVals = a.dtype === 'string' ?
	      // tslint:disable-next-line: no-any
	      fromUint8ToStringArray(aVals) : aVals;
	      var decodedBVals = a.dtype === 'string' ?
	      // tslint:disable-next-line: no-any
	      fromUint8ToStringArray(bVals) : bVals;
	      var $dtype = dtype || a.dtype;
	      var _simpleImpl = simpleImpl(a.shape, b.shape, decodedAVals, decodedBVals, $dtype),
	        _simpleImpl2 = _slicedToArray(_simpleImpl, 2),
	        resultData = _simpleImpl2[0],
	        resultShape = _simpleImpl2[1];
	      return cpuBackend.makeTensorInfo(resultShape, $dtype, resultData);
	    };
	  }
	  return function (_ref2) {
	    var inputs = _ref2.inputs,
	      backend = _ref2.backend;
	    var a = inputs.a,
	      b = inputs.b;
	    var cpuBackend = backend;
	    if (a.dtype === 'complex64' || b.dtype === 'complex64') {
	      var $aComplex = cast$1({
	        inputs: {
	          x: a
	        },
	        backend: cpuBackend,
	        attrs: {
	          dtype: 'complex64'
	        }
	      });
	      var $aComplexVals = cpuBackend.data.get($aComplex.dataId);
	      var aReal = $aComplexVals.complexTensorInfos.real;
	      var aImag = $aComplexVals.complexTensorInfos.imag;
	      var aRealVals = cpuBackend.data.get(aReal.dataId).values;
	      var aImagVals = cpuBackend.data.get(aImag.dataId).values;
	      var $bComplex = cast$1({
	        inputs: {
	          x: b
	        },
	        backend: cpuBackend,
	        attrs: {
	          dtype: 'complex64'
	        }
	      });
	      var $bComplexVals = cpuBackend.data.get($bComplex.dataId);
	      var bReal = $bComplexVals.complexTensorInfos.real;
	      var bImag = $bComplexVals.complexTensorInfos.imag;
	      var bRealVals = cpuBackend.data.get(bReal.dataId).values;
	      var bImagVals = cpuBackend.data.get(bImag.dataId).values;
	      var _complexImpl = complexImpl(a.shape, b.shape, aRealVals, aImagVals, bRealVals, bImagVals),
	        _complexImpl2 = _slicedToArray(_complexImpl, 3),
	        resultRealData = _complexImpl2[0],
	        resultImagData = _complexImpl2[1],
	        resultShape = _complexImpl2[2];
	      var resultReal = cpuBackend.makeTensorInfo(resultShape, 'float32', resultRealData);
	      var resultImag = cpuBackend.makeTensorInfo(resultShape, 'float32', resultImagData);
	      var result = complex$1({
	        inputs: {
	          real: resultReal,
	          imag: resultImag
	        },
	        backend: cpuBackend
	      });
	      cpuBackend.disposeIntermediateTensorInfo($aComplex);
	      cpuBackend.disposeIntermediateTensorInfo($bComplex);
	      cpuBackend.disposeIntermediateTensorInfo(resultReal);
	      cpuBackend.disposeIntermediateTensorInfo(resultImag);
	      return result;
	    } else {
	      var aVals = cpuBackend.data.get(a.dataId).values;
	      var bVals = cpuBackend.data.get(b.dataId).values;
	      var $dtype = dtype || a.dtype;
	      var _simpleImpl3 = simpleImpl(a.shape, b.shape, aVals, bVals, $dtype),
	        _simpleImpl4 = _slicedToArray(_simpleImpl3, 2),
	        resultData = _simpleImpl4[0],
	        _resultShape = _simpleImpl4[1];
	      return cpuBackend.makeTensorInfo(_resultShape, $dtype, resultData);
	    }
	  };
	}
	/**
	 * Template that creates the complex type implementation for binary ops.
	 * Supports broadcast.
	 */
	function createComplexBinaryKernelImpl(op) {
	  return function (aShape, bShape, aRealVals, aImagVals, bRealVals, bImagVals) {
	    var resultShape = assertAndGetBroadcastShape(aShape, bShape);
	    var resultSize = sizeFromShape(resultShape);
	    var resultRank = resultShape.length;
	    var resultStrides = computeStrides(resultShape);
	    var resultRealVals = getTypedArrayFromDType('float32', resultSize);
	    var resultImagVals = getTypedArrayFromDType('float32', resultSize);
	    var aBroadcastDims = getBroadcastDims$1(aShape, resultShape);
	    var bBroadcastDims = getBroadcastDims$1(bShape, resultShape);
	    var aVals = mergeRealAndImagArrays(aRealVals, aImagVals);
	    var bVals = mergeRealAndImagArrays(bRealVals, bImagVals);
	    var aRank = aShape.length;
	    var aStrides = computeStrides(aShape);
	    var bRank = bShape.length;
	    var bStrides = computeStrides(bShape);
	    if (aBroadcastDims.length + bBroadcastDims.length === 0) {
	      for (var i = 0; i < resultRealVals.length; i++) {
	        var aIdx = i % aVals.length;
	        var bIdx = i % bVals.length;
	        var result = op(aVals[aIdx * 2], aVals[aIdx * 2 + 1], bVals[bIdx * 2], bVals[bIdx * 2 + 1]);
	        resultRealVals[i] = result.real;
	        resultImagVals[i] = result.imag;
	      }
	    } else {
	      var _loop = function _loop() {
	        var loc = indexToLoc(_i, resultRank, resultStrides);
	        var aLoc = loc.slice(-aRank);
	        aBroadcastDims.forEach(function (d) {
	          return aLoc[d] = 0;
	        });
	        var aIndex = locToIndex(aLoc, aRank, aStrides);
	        var bLoc = loc.slice(-bRank);
	        bBroadcastDims.forEach(function (d) {
	          return bLoc[d] = 0;
	        });
	        var bIndex = locToIndex(bLoc, bRank, bStrides);
	        var opResult = op(aVals[aIndex * 2], aVals[aIndex * 2 + 1], bVals[bIndex * 2], bVals[bIndex * 2 + 1]);
	        resultRealVals[_i] = opResult.real;
	        resultImagVals[_i] = opResult.imag;
	      };
	      for (var _i = 0; _i < resultRealVals.length; _i++) {
	        _loop();
	      }
	    }
	    return [resultRealVals, resultImagVals, resultShape];
	  };
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var addImpl = createSimpleBinaryKernelImpl(function (a, b) {
	  return a + b;
	});
	var addComplexImpl = createComplexBinaryKernelImpl(function (aReal, aImag, bReal, bImag) {
	  return {
	    real: aReal + bReal,
	    imag: aImag + bImag
	  };
	});
	var add = binaryKernelFunc$1(Add$1, addImpl, addComplexImpl);
	var addConfig$1 = {
	  kernelName: Add$1,
	  backendName: 'cpu',
	  kernelFunc: add
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function bincountImpl(xVals, weightsVals, weightsDtype, weightsShape, size) {
	  var weightsSize = sizeFromShape(weightsShape);
	  var outVals = makeZerosTypedArray(size, weightsDtype);
	  for (var i = 0; i < xVals.length; i++) {
	    var value = xVals[i];
	    if (value < 0) {
	      throw new Error('Input x must be non-negative!');
	    }
	    if (value >= size) {
	      continue;
	    }
	    if (weightsSize > 0) {
	      outVals[value] += weightsVals[i];
	    } else {
	      outVals[value] += 1;
	    }
	  }
	  return outVals;
	}
	function bincountReduceImpl(xBuf, weightsBuf, size) {
	  var binaryOutput = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var numRows = xBuf.shape[0];
	  var numCols = xBuf.shape[1];
	  var outBuf = buffer([numRows, size], weightsBuf.dtype);
	  for (var i = 0; i < numRows; i++) {
	    for (var j = 0; j < numCols; j++) {
	      var value = xBuf.get(i, j);
	      if (value < 0) {
	        throw new Error('Input x must be non-negative!');
	      }
	      if (value >= size) {
	        continue;
	      }
	      if (binaryOutput) {
	        outBuf.set(1, i, value);
	      } else {
	        if (weightsBuf.size > 0) {
	          outBuf.set(outBuf.get(i, value) + weightsBuf.get(i, j), i, value);
	        } else {
	          outBuf.set(outBuf.get(i, value) + 1, i, value);
	        }
	      }
	    }
	  }
	  return outBuf;
	}

	/**
	 * @license
	 * Copyright 2023 Google LLC.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var bitwiseAndImpl = createSimpleBinaryKernelImpl(function (a, b) {
	  return a & b;
	});
	var bitwiseAnd$1 = binaryKernelFunc$1(BitwiseAnd, bitwiseAndImpl);
	var bitwiseAndConfig$1 = {
	  kernelName: BitwiseAnd,
	  backendName: 'cpu',
	  kernelFunc: bitwiseAnd$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Template that creates implementation for unary op.
	 */
	function createSimpleUnaryImpl(op) {
	  return function (values, dtype, attrs) {
	    var newValues = getArrayFromDType(dtype, values.length);
	    for (var i = 0; i < values.length; ++i) {
	      newValues[i] = op(values[i], attrs);
	    }
	    return newValues;
	  };
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Template that creates a `KernelFunc` for unary ops.
	 * @param name Kernel name.
	 * @param op A `SimpleUnaryOperation` for the kernel.
	 * @param dtype Optional. If set, the result has this dtype. Otherwise, the
	 *     result has the same dtype as the input. This is mainly used in certain
	 *     kernels that return bool type, such as isFinite, isInf, etc.
	 */
	function unaryKernelFunc$1(name, op, dtype) {
	  var impl = createSimpleUnaryImpl(op);
	  return unaryKernelFuncFromImpl(name, impl, dtype);
	}
	/**
	 * Template that creates a `KernelFunc` for unary ops from the given
	 * `SimpleUnaryImpl`..
	 * @param name Kernel name.
	 * @param unaryImpl A `SimpleUnaryImpl` that implements the op.
	 * @param dtype Optional. If set, the result has this dtype. Otherwise, the
	 *     result has the same dtype as the input. This is mainly used in certain
	 *     kernels that return bool type, such as isFinite, isInf, etc.
	 */
	function unaryKernelFuncFromImpl(name, unaryImpl, dtype) {
	  return function (_ref) {
	    var inputs = _ref.inputs,
	      attrs = _ref.attrs,
	      backend = _ref.backend;
	    var x = inputs.x;
	    assertNotComplex$1(x, name);
	    var cpuBackend = backend;
	    var values = cpuBackend.data.get(x.dataId).values;
	    var decoded;
	    if (x.dtype === 'string') {
	      if (!Array.isArray(values)) {
	        throw new Error('String tensor\'s value was not an instance of Array');
	      }
	      decoded = fromUint8ToStringArray(values);
	    } else {
	      decoded = values;
	    }
	    var $dtype = dtype || x.dtype;
	    var newValues = unaryImpl(decoded, $dtype, attrs);
	    return cpuBackend.makeTensorInfo(x.shape, $dtype, newValues);
	  };
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ceilImpl = createSimpleUnaryImpl(function (xi) {
	  return Math.ceil(xi);
	});
	var ceil$1 = unaryKernelFuncFromImpl(Ceil, ceilImpl);
	var ceilConfig$1 = {
	  kernelName: Ceil,
	  backendName: 'cpu',
	  kernelFunc: ceil$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function concatImpl$1(inputs, outShape, dtype, simplyConcat) {
	  var outVals = getArrayFromDType(dtype, sizeFromShape(outShape));
	  if (simplyConcat && dtype !== 'string') {
	    // Use built-in TypedArray.set() method for speed.
	    var offset = 0;
	    inputs.forEach(function (input) {
	      var size = sizeFromShape(input.shape);
	      outVals.set(input.vals, offset);
	      offset += size;
	    });
	  } else {
	    var colOffset = 0;
	    inputs.forEach(function (input) {
	      var decodedData = dtype === 'string' ? fromUint8ToStringArray(input.vals) : input.vals;
	      var tIdx = 0;
	      for (var row = 0; row < input.shape[0]; ++row) {
	        var resIdx = row * outShape[1] + colOffset;
	        for (var col = 0; col < input.shape[1]; ++col) {
	          outVals[resIdx + col] = decodedData[tIdx++];
	        }
	      }
	      colOffset += input.shape[1];
	    });
	  }
	  return outVals;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var equalImpl = createSimpleBinaryKernelImpl(function (a, b) {
	  return a === b ? 1 : 0;
	});
	var equal$1 = binaryKernelFunc$1(Equal, equalImpl, null /* complexImpl */, 'bool');
	var equalConfig$1 = {
	  kernelName: Equal,
	  backendName: 'cpu',
	  kernelFunc: equal$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var expImpl = createSimpleUnaryImpl(function (xi) {
	  return Math.exp(xi);
	});
	var exp$1 = unaryKernelFuncFromImpl(Exp, expImpl, 'float32');
	var expConfig$1 = {
	  kernelName: Exp,
	  backendName: 'cpu',
	  kernelFunc: exp$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var expm1Impl = createSimpleUnaryImpl(function (xi) {
	  return Math.expm1(xi);
	});
	var expm1$1 = unaryKernelFuncFromImpl(Expm1, expm1Impl);
	var expm1Config$1 = {
	  kernelName: Expm1,
	  backendName: 'cpu',
	  kernelFunc: expm1$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var floorImpl = createSimpleUnaryImpl(function (xi) {
	  return Math.floor(xi);
	});
	var floor$1 = unaryKernelFuncFromImpl(Floor, floorImpl);
	var floorConfig$1 = {
	  kernelName: Floor,
	  backendName: 'cpu',
	  kernelFunc: floor$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var floorDivImpl = createSimpleBinaryKernelImpl(function (a, b) {
	  return Math.floor(a / b);
	});
	var floorDiv$1 = binaryKernelFunc$1(FloorDiv, floorDivImpl, null /* complexImpl */, 'int32');
	var floorDivConfig$1 = {
	  kernelName: FloorDiv,
	  backendName: 'cpu',
	  kernelFunc: floorDiv$1
	};

	function gatherNdImpl(indicesData, paramsBuf, dtype, numSlices, sliceRank, sliceSize, strides, paramsShape, paramsSize) {
	  var outBuf = buffer([numSlices, sliceSize], dtype);
	  for (var i = 0; i < numSlices; i++) {
	    var index = [];
	    var flattenIndex = 0;
	    for (var j = 0; j < sliceRank; j++) {
	      var dim = indicesData[i * sliceRank + j];
	      flattenIndex += dim * strides[j];
	      index.push(dim);
	    }
	    if (flattenIndex < 0 || flattenIndex >= paramsSize / sliceSize) {
	      throw new Error("Invalid indices: ".concat(index, " does not index into ").concat(paramsShape));
	    }
	    for (var k = 0; k < sliceSize; k++) {
	      outBuf.values[i * sliceSize + k] = paramsBuf.get.apply(paramsBuf, _toConsumableArray(paramsBuf.indexToLoc(flattenIndex * sliceSize + k)));
	    }
	  }
	  return outBuf;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function gatherV2Impl(xBuf, indicesBuf, flattenOutputShape) {
	  var outBuf = buffer(flattenOutputShape, xBuf.dtype);
	  for (var i = 0; i < outBuf.size; ++i) {
	    var newLoc = outBuf.indexToLoc(i);
	    var originalLoc = newLoc.slice();
	    var batchIdx = originalLoc[0];
	    var indicesIdx = originalLoc[2];
	    var indicesIndex = indicesBuf.locToIndex([batchIdx, indicesIdx]);
	    originalLoc[2] = indicesBuf.values[indicesIndex];
	    var originalIndex = xBuf.locToIndex(originalLoc);
	    if (0 <= originalIndex && originalIndex < xBuf.values.length) {
	      outBuf.values[i] = xBuf.values[originalIndex];
	    } // Else, index is out of bounds, so leave the default zero val in outBuf.
	  }

	  return outBuf;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var greaterImpl = createSimpleBinaryKernelImpl(function (a, b) {
	  return a > b ? 1 : 0;
	});
	var greater$1 = binaryKernelFunc$1(Greater, greaterImpl, null /* complexImpl */, 'bool');
	var greaterConfig$1 = {
	  kernelName: Greater,
	  backendName: 'cpu',
	  kernelFunc: greater$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var greaterEqualImpl = createSimpleBinaryKernelImpl(function (a, b) {
	  return a >= b ? 1 : 0;
	});
	var greaterEqual$1 = binaryKernelFunc$1(GreaterEqual, greaterEqualImpl, null /* complexImpl */, 'bool');
	var greaterEqualConfig$1 = {
	  kernelName: GreaterEqual,
	  backendName: 'cpu',
	  kernelFunc: greaterEqual$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var lessImpl = createSimpleBinaryKernelImpl(function (a, b) {
	  return a < b ? 1 : 0;
	});
	var less$1 = binaryKernelFunc$1(Less, lessImpl, null /* complexImpl */, 'bool');
	var lessConfig$1 = {
	  kernelName: Less,
	  backendName: 'cpu',
	  kernelFunc: less$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var lessEqualImpl = createSimpleBinaryKernelImpl(function (a, b) {
	  return a <= b ? 1 : 0;
	});
	var lessEqual$1 = binaryKernelFunc$1(LessEqual, lessEqualImpl, null /* complexImpl */, 'bool');
	var lessEqualConfig$1 = {
	  kernelName: LessEqual,
	  backendName: 'cpu',
	  kernelFunc: lessEqual$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function linSpaceImpl(start, stop, num) {
	  var step = (stop - start) / (num - 1);
	  var values = makeZerosTypedArray(num, 'float32');
	  values[0] = start;
	  for (var i = 1; i < values.length; i++) {
	    values[i] = values[i - 1] + step;
	  }
	  return values;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var logImpl = createSimpleUnaryImpl(function (xi) {
	  return Math.log(xi);
	});
	var log$1 = unaryKernelFuncFromImpl(Log, logImpl);
	var logConfig$1 = {
	  kernelName: Log,
	  backendName: 'cpu',
	  kernelFunc: log$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function maxImpl$1(aVals, reduceSize, outShape, dtype) {
	  var vals = getTypedArrayFromDType(dtype, sizeFromShape(outShape));
	  for (var i = 0; i < vals.length; ++i) {
	    var offset = i * reduceSize;
	    var max = aVals[offset];
	    for (var j = 0; j < reduceSize; ++j) {
	      var value = aVals[offset + j];
	      if (Number.isNaN(value) || value > max) {
	        // comparison with NaN always return false
	        max = value;
	      }
	    }
	    vals[i] = max;
	  }
	  return vals;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var maximumImpl = createSimpleBinaryKernelImpl(function (aValue, bValue) {
	  return Math.max(aValue, bValue);
	});
	var maximum$1 = binaryKernelFunc$1(Maximum$1, maximumImpl);
	var maximumConfig$1 = {
	  kernelName: Maximum$1,
	  backendName: 'cpu',
	  kernelFunc: maximum$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var minimumImpl = createSimpleBinaryKernelImpl(function (aValue, bValue) {
	  return Math.min(aValue, bValue);
	});
	var minimum$1 = binaryKernelFunc$1(Minimum$1, minimumImpl);
	var minimumConfig$1 = {
	  kernelName: Minimum$1,
	  backendName: 'cpu',
	  kernelFunc: minimum$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var multiplyImpl = createSimpleBinaryKernelImpl(function (aValue, bValue) {
	  return aValue * bValue;
	});
	var multiplyComplexImpl = createComplexBinaryKernelImpl(function (aReal, aImag, bReal, bImag) {
	  return {
	    real: aReal * bReal - aImag * bImag,
	    imag: aReal * bImag + aImag * bReal
	  };
	});
	var multiply$1 = binaryKernelFunc$1(Multiply$1, multiplyImpl, multiplyComplexImpl);
	var multiplyConfig$1 = {
	  kernelName: Multiply$1,
	  backendName: 'cpu',
	  kernelFunc: multiply$1
	};

	function negImpl(xVals, xShape, xDtype) {
	  var minusOne = createScalarValue(-1, xDtype);
	  return multiplyImpl([], xShape, minusOne, xVals, xDtype);
	}
	function neg$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var x = inputs.x;
	  assertNotComplex$1(x, 'neg');
	  var xVals = backend.data.get(x.dataId).values;
	  var _negImpl = negImpl(xVals, x.shape, x.dtype),
	    _negImpl2 = _slicedToArray(_negImpl, 2),
	    res = _negImpl2[0],
	    newShape = _negImpl2[1];
	  return backend.makeTensorInfo(newShape, x.dtype, res);
	}
	var negConfig$1 = {
	  kernelName: Neg,
	  backendName: 'cpu',
	  kernelFunc: neg$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var notEqualImpl = createSimpleBinaryKernelImpl(function (a, b) {
	  return a !== b ? 1 : 0;
	});
	var notEqual$1 = binaryKernelFunc$1(NotEqual, notEqualImpl, null /* complexOp */, 'bool');
	var notEqualConfig$1 = {
	  kernelName: NotEqual,
	  backendName: 'cpu',
	  kernelFunc: notEqual$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function transposeImpl$1(xVals, xShape, dtype, perm, newShape) {
	  var xRank = xShape.length;
	  var xSize = sizeFromShape(xShape);
	  var xStrides = computeStrides(xShape);
	  var newStrides = computeStrides(newShape);
	  var result = getTypedArrayFromDType(dtype, sizeFromShape(newShape));
	  for (var i = 0; i < xSize; ++i) {
	    var loc = indexToLoc(i, xRank, xStrides);
	    // Permute location.
	    var newLoc = new Array(loc.length);
	    for (var _i = 0; _i < newLoc.length; _i++) {
	      newLoc[_i] = loc[perm[_i]];
	    }
	    var newIndex = locToIndex(newLoc, xRank, newStrides);
	    result[newIndex] = xVals[i];
	  }
	  return result;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function transpose$1(args) {
	  var inputs = args.inputs,
	    attrs = args.attrs,
	    backend = args.backend;
	  var x = inputs.x;
	  var perm = attrs.perm;
	  assertNotComplex$1(x, 'transpose');
	  var xRank = x.shape.length;
	  var newShape = new Array(xRank);
	  for (var i = 0; i < newShape.length; i++) {
	    newShape[i] = x.shape[perm[i]];
	  }
	  var values = backend.data.get(x.dataId).values;
	  var result = transposeImpl$1(values, x.shape, x.dtype, perm, newShape);
	  var dataId = backend.write(result, newShape, x.dtype);
	  return {
	    dataId: dataId,
	    shape: newShape,
	    dtype: x.dtype
	  };
	}
	var transposeConfig$1 = {
	  kernelName: Transpose,
	  backendName: 'cpu',
	  kernelFunc: transpose$1
	};

	function prodImpl(xShape, xDtype, xVals, reductionAxes) {
	  var _backend_util$compute = computeOutAndReduceShapes(xShape, reductionAxes),
	    _backend_util$compute2 = _slicedToArray(_backend_util$compute, 2),
	    outShape = _backend_util$compute2[0],
	    reduceShape = _backend_util$compute2[1];
	  var outDtype = upcastType(xDtype, 'int32');
	  var outVals = makeZerosTypedArray(sizeFromShape(outShape), outDtype);
	  var reduceSize = sizeFromShape(reduceShape);
	  for (var i = 0; i < outVals.length; ++i) {
	    var offset = i * reduceSize;
	    var _prod = 1;
	    for (var j = 0; j < reduceSize; ++j) {
	      _prod *= xVals[offset + j];
	    }
	    outVals[i] = _prod;
	  }
	  return {
	    outVals: outVals,
	    outShape: outShape,
	    outDtype: outDtype
	  };
	}
	function prod$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis,
	    keepDims = attrs.keepDims;
	  assertNotComplex$1(x, 'prod');
	  var xRank = x.shape.length;
	  var axes = parseAxisParam(axis, x.shape);
	  var permutation = getAxesPermutation(axes, xRank);
	  var reductionAxes = axes;
	  var permutedX = x;
	  var intermediateTensorInfos = [];
	  if (permutation != null) {
	    permutedX = transpose$1({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        perm: permutation
	      }
	    });
	    intermediateTensorInfos.push(permutedX);
	    reductionAxes = getInnerMostAxes(reductionAxes.length, xRank);
	  }
	  var xVals = backend.data.get(permutedX.dataId).values;
	  var _prodImpl = prodImpl(permutedX.shape, permutedX.dtype, xVals, reductionAxes),
	    outVals = _prodImpl.outVals,
	    outShape = _prodImpl.outShape,
	    outDtype = _prodImpl.outDtype;
	  var resultShape = outShape;
	  if (keepDims) {
	    resultShape = expandShapeToKeepDim(outShape, axes);
	  }
	  intermediateTensorInfos.forEach(function (t) {
	    return backend.disposeIntermediateTensorInfo(t);
	  });
	  return backend.makeTensorInfo(resultShape, outDtype, outVals);
	}
	var prodConfig$1 = {
	  kernelName: Prod,
	  backendName: 'cpu',
	  kernelFunc: prod$1
	};

	function validateIndices(indices, indicesShape, numParams) {
	  indices.forEach(function (index, i) {
	    if (index < 0 || index >= numParams) {
	      var locString = indexToLoc(i, indicesShape.length, computeStrides(indicesShape)).join(',');
	      throw new Error("indices[".concat(locString, "] = ").concat(index, " is not in [0, ").concat(numParams, ")"));
	    }
	  });
	}
	function validateSplits(paramsNestedSplits, numParamsDenseValues) {
	  // Validate
	  for (var dim = 0; dim < paramsNestedSplits.length; ++dim) {
	    var splits = paramsNestedSplits[dim];
	    var lastSplit = dim === paramsNestedSplits.length - 1 ? numParamsDenseValues : paramsNestedSplits[dim + 1].length;
	    if (splits.length === 0) {
	      throw new Error('Ragged splits may not be empty');
	    }
	    if (splits[0] < 0) {
	      throw new Error('Ragged splits must be non-negative');
	    }
	    if (splits[splits.length - 1] > lastSplit) {
	      throw new Error('Ragged splits must not point past values');
	    }
	    for (var i = 1; i < splits.length; ++i) {
	      if (splits[i - 1] > splits[i]) {
	        throw new Error('Ragged splits must be sorted in ascending order');
	      }
	    }
	  }
	}
	// Construct the `splits` output tensors, encoded using a nested vector.
	// Also find the slices of values that need to be copied, and store them
	// in `valueSlices`.  The total number of values that will be copied (which
	// we need for allocating the output values tensor) is stored in `numValues`.
	function makeSplits(indices, indicesShape, paramsNestedSplits, numParamsDenseValues) {
	  var valueSlices = [];
	  var numValues = 0;
	  var numSplits = indicesShape.length - 1 + paramsNestedSplits.length;
	  var outSplits = new Array(numSplits).fill(null).map(function () {
	    return [0];
	  });
	  validateSplits(paramsNestedSplits, numParamsDenseValues);
	  // Add `splits` that come from all but the last dimension of the dense
	  // Tensor `indices`.  In particular, for each dimension D, we add a
	  // splits tensor whose values are:
	  //   range(reduceProd(splits.shape[:D]) + 1) * splits.shape[D+1]
	  // E.g., if indices.shape=[2, 3, 4] then we will add splits tensors:
	  //   [0, 3, 6]                    # length=2+1, stride=3
	  //   [0, 4, 8, 12, 16, 20, 24]    # length=2*3+1, stride=4
	  var nrows = 1;
	  for (var dim = 0; dim < indicesShape.length - 1; ++dim) {
	    nrows *= indicesShape[dim];
	    var rowLength = indicesShape[dim + 1];
	    for (var i = 1; i < nrows + 1; ++i) {
	      outSplits[dim].push(i * rowLength);
	    }
	  }
	  // Add `splits` that come from `paramsNestedSplits`.  Starting with the
	  // outermost ragged dimension (i.e., the first `splits` tensor), we work
	  // our way in, finding the range of values that should be copied.  As we
	  // go, we update the output `splits` for each dimension with the appropriate
	  // values.  In particular, the *lengths* of the slices from `param_splits`
	  // should be copied to generate corresponding slice lengths in the output
	  // splits.  E.g., if we are copying a ragged row with length 4, then we
	  // should add a new split point to outSplits that is 4 greater than the
	  // previous split point in outSplits.
	  for (var _i = 0; _i < indices.length; ++_i) {
	    var start = indices[_i];
	    var limit = indices[_i] + 1;
	    // Copy splits.
	    for (var _dim = 0; _dim < paramsNestedSplits.length; ++_dim) {
	      var splits = paramsNestedSplits[_dim];
	      var outDim = _dim + indicesShape.length - 1;
	      if (outDim >= 0) {
	        var outSplitsOutDim = outSplits[outDim];
	        var delta = outSplitsOutDim[outSplitsOutDim.length - 1] - splits[start];
	        for (var j = start; j < limit; ++j) {
	          outSplits[outDim].push(splits[j + 1] + delta);
	        }
	      }
	      start = splits[start];
	      limit = splits[limit];
	    }
	    if (limit !== start) {
	      valueSlices.push([start, limit]);
	      numValues += limit - start;
	    }
	  }
	  return {
	    outSplits: outSplits,
	    valueSlices: valueSlices,
	    numValues: numValues
	  };
	}
	function getSplits(outSplits) {
	  var splitsOut = [];
	  var _loop = function _loop() {
	    var numSplits = outSplits[i].length;
	    var splits = getArrayFromDType('int32', numSplits);
	    splitsOut.push(splits);
	    outSplits[i].forEach(function (value, j) {
	      return splits[j] = value;
	    });
	  };
	  for (var i = 0; i < outSplits.length; ++i) {
	    _loop();
	  }
	  return splitsOut;
	}
	function computeFlatOuterDims(orig, numOutDims) {
	  var outDims = orig.slice(0, numOutDims);
	  while (outDims.length < numOutDims) {
	    outDims.push(1);
	  }
	  for (var inDim = numOutDims; inDim < orig.length; inDim++) {
	    outDims[numOutDims - 1] *= orig[inDim];
	  }
	  return outDims;
	}
	// For each slice in `(start, limit)` in `valueSlices`, append
	// `paramsDenseValues[start,...,limit] to `values`.  `valueSize` indicates
	// the number of scalars contained in each value paramsDenseValues[i].
	function writeValueSlices(paramsDenseValues, paramsDenseValuesShape, valueSlices, valueSize, values, valuesShape) {
	  var denseM = computeFlatOuterDims(paramsDenseValuesShape, 2)[1];
	  var valuesM = computeFlatOuterDims(valuesShape, 2)[1];
	  var outPos = 0;
	  var _iterator = _createForOfIteratorHelper(valueSlices),
	    _step;
	  try {
	    for (_iterator.s(); !(_step = _iterator.n()).done;) {
	      var slice = _step.value;
	      for (var i = slice[0]; i < slice[1]; ++i) {
	        for (var j = 0; j < valueSize; ++j) {
	          values[outPos * valuesM + j] = paramsDenseValues[i * denseM + j];
	        }
	        ++outPos;
	      }
	    }
	  } catch (err) {
	    _iterator.e(err);
	  } finally {
	    _iterator.f();
	  }
	}
	function getValues(paramsDenseValues, paramsDenseValuesShape, paramsDenseValuesDType, valueSlices, numValues) {
	  var valuesShape = paramsDenseValuesShape.slice();
	  valuesShape[0] = numValues;
	  var valuesOut = getArrayFromDType(paramsDenseValuesDType, sizeFromShape(valuesShape));
	  var numElements = paramsDenseValues.length;
	  var valueSize = numElements === 0 ? 0 : numElements / paramsDenseValuesShape[0];
	  writeValueSlices(paramsDenseValues, paramsDenseValuesShape, valueSlices, valueSize, valuesOut, valuesShape);
	  return [valuesOut, valuesShape];
	}
	function raggedGatherImpl(paramsNestedSplits, paramsNestedSplitsShapes, paramsDenseValues, paramsDenseValuesShape, paramsDenseValuesDType, indices, indicesShape, outputRaggedRank) {
	  if (paramsNestedSplits.length === 0) {
	    throw new Error('paramsNestedSplits must be non empty');
	  }
	  if (paramsNestedSplitsShapes[0].length === 0) {
	    throw new Error('Split tensors must not be scalars');
	  }
	  var numParams = paramsNestedSplitsShapes[0][0] - 1;
	  validateIndices(indices, indicesShape, numParams);
	  if (paramsDenseValuesShape.length === 0) {
	    throw new Error('params.rank must be nonzero');
	  }
	  var numParamsDenseValues = paramsDenseValuesShape[0];
	  // Calculate the `splits`, and store the value slices that we need to
	  // copy in `valueSlices`.
	  var _makeSplits = makeSplits(indices, indicesShape, paramsNestedSplits, numParamsDenseValues),
	    outSplits = _makeSplits.outSplits,
	    valueSlices = _makeSplits.valueSlices,
	    numValues = _makeSplits.numValues;
	  // Write the output tensors.
	  var outputNestedSplits = getSplits(outSplits);
	  var outputDenseValues = getValues(paramsDenseValues, paramsDenseValuesShape, paramsDenseValuesDType, valueSlices, numValues);
	  return [outputNestedSplits, outputDenseValues[0], outputDenseValues[1]];
	}

	/**
	 * @license
	 * Copyright 2022 Google LLC.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var INT32_MAX = 2147483647;
	function raggedRangeImpl(starts, startsShape, startsDType, limits, limitsShape, deltas, deltasShape) {
	  // Check input tensor shapes.
	  if (startsShape.length > 1) {
	    throw new Error('starts must be a scalar or vector');
	  }
	  if (limitsShape.length > 1) {
	    throw new Error('limits must be a scalar or vector');
	  }
	  if (deltasShape.length > 1) {
	    throw new Error('deltas must be a scalar or vector');
	  }
	  // Determine which tensors we need to broadcast.
	  var broadcastStarts = startsShape.length === 0;
	  var broadcastLimits = limitsShape.length === 0;
	  var broadcastDeltas = deltasShape.length === 0;
	  // nRows (number of output rows) is the size of the non-broadcast inputs,
	  // or 1 if all inputs are scalars.
	  var inSizes = [];
	  if (!broadcastStarts) {
	    inSizes.push(startsShape[0]);
	  }
	  if (!broadcastLimits) {
	    inSizes.push(limitsShape[0]);
	  }
	  if (!broadcastDeltas) {
	    inSizes.push(deltasShape[0]);
	  }
	  for (var i = 1; i < inSizes.length; ++i) {
	    if (inSizes[i] !== inSizes[i - 1]) {
	      throw new Error('starts, limits, and deltas must have the same shape');
	    }
	  }
	  var nRows = inSizes.length === 0 ? 1 : inSizes[0];
	  // Construct the rtNestedSplits tensor.
	  var rtNestedSplits = getArrayFromDType('int32', nRows + 1);
	  rtNestedSplits[0] = 0;
	  for (var row = 0; row < nRows; ++row) {
	    var start = broadcastStarts ? starts[0] : starts[row];
	    var limit = broadcastLimits ? limits[0] : limits[row];
	    var delta = broadcastDeltas ? deltas[0] : deltas[row];
	    if (delta === 0) {
	      throw new Error('Requires delta != 0');
	    }
	    var size = void 0; // The number of elements in the specified range.
	    if (delta > 0 && limit < start || delta < 0 && limit > start) {
	      size = 0;
	    } else {
	      size = Math.ceil(Math.abs((limit - start) / delta));
	      if (size > INT32_MAX) {
	        throw new Error("Requires ((limit - start) / delta) <= ".concat(INT32_MAX));
	      }
	    }
	    rtNestedSplits[row + 1] = rtNestedSplits[row] + size;
	  }
	  var nVals = rtNestedSplits[nRows];
	  // Construct the rtDenseValues tensor.
	  var rtDenseValues = getArrayFromDType(startsDType, nVals);
	  var valueIndex = 0;
	  for (var _row = 0; _row < nRows; ++_row) {
	    var rowSize = rtNestedSplits[_row + 1] - rtNestedSplits[_row];
	    var value = broadcastStarts ? starts[0] : starts[_row];
	    var _delta = broadcastDeltas ? deltas[0] : deltas[_row];
	    for (var _i = 0; _i < rowSize; ++_i) {
	      rtDenseValues[valueIndex++] = value;
	      value += _delta;
	    }
	  }
	  return [rtNestedSplits, rtDenseValues];
	}

	var RowPartitionType = RowPartitionType$1;
	// Based on
	// https://github.com/tensorflow/tensorflow/blob/master/tensorflow/core/kernels/ragged_tensor_to_tensor_op.cc
	var RaggedTensorToTensorOp = /*#__PURE__*/function () {
	  function RaggedTensorToTensorOp(shape, shapeShape, values, valuesShape, valuesDType, defaultValue, defaultValueShape, rowPartitionValues, rowPartitionValuesShapes, rowPartitionTypeStrings) {
	    _classCallCheck(this, RaggedTensorToTensorOp);
	    this.shape = shape;
	    this.shapeShape = shapeShape;
	    this.values = values;
	    this.valuesShape = valuesShape;
	    this.valuesDType = valuesDType;
	    this.defaultValue = defaultValue;
	    this.defaultValueShape = defaultValueShape;
	    this.rowPartitionValues = rowPartitionValues;
	    this.rowPartitionValuesShapes = rowPartitionValuesShapes;
	    this.rowPartitionTypes = getRowPartitionTypesHelper(rowPartitionTypeStrings);
	    this.raggedRank = getRaggedRank(this.rowPartitionTypes);
	  }
	  _createClass(RaggedTensorToTensorOp, [{
	    key: "getRowPartitionTypeByDimension",
	    value: function getRowPartitionTypeByDimension(dimension) {
	      if (this.rowPartitionTypes[0] === RowPartitionType.FIRST_DIM_SIZE) {
	        return this.rowPartitionTypes[dimension + 1];
	      } else {
	        return this.rowPartitionTypes[dimension];
	      }
	    }
	    // Returns the relationship between dimension and dimension + 1.
	  }, {
	    key: "getRowPartitionTensor",
	    value: function getRowPartitionTensor(dimension) {
	      if (this.rowPartitionTypes[0] === RowPartitionType.FIRST_DIM_SIZE) {
	        return this.rowPartitionValues[dimension + 1];
	      } else {
	        return this.rowPartitionValues[dimension];
	      }
	    }
	  }, {
	    key: "getMaxWidth",
	    value: function getMaxWidth(dimension) {
	      var rowPartitionTensor = this.getRowPartitionTensor(dimension - 1);
	      switch (this.getRowPartitionTypeByDimension(dimension - 1)) {
	        case RowPartitionType.VALUE_ROWIDS:
	          return RaggedTensorToTensorOp.getMaxWidthValueRowID(rowPartitionTensor);
	        case RowPartitionType.ROW_SPLITS:
	          return RaggedTensorToTensorOp.getMaxWidthRowSplit(rowPartitionTensor);
	        default:
	          throw new Error("Cannot handle partition type ".concat(RowPartitionType[this.getRowPartitionTypeByDimension(dimension - 1)]));
	      }
	    }
	  }, {
	    key: "tensorShapeFromTensor",
	    value: function tensorShapeFromTensor(t, tShape) {
	      var isPartial = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
	      if (tShape.length === 0) {
	        if (t[0] === -1) {
	          return [];
	        }
	        throw new Error("The only valid scalar shape tensor is the fully unknown shape specified as -1.");
	      }
	      // MakePartialShape/MakeShapeHelper.
	      return makeShape(t, isPartial);
	    }
	  }, {
	    key: "calculateOutputSize",
	    value: function calculateOutputSize(firstDim) {
	      var valueShape = this.valuesShape;
	      var defaultValueShape = this.defaultValueShape;
	      validateDefaultValueShape(defaultValueShape, valueShape);
	      var shape = this.tensorShapeFromTensor(this.shape, this.shapeShape);
	      var outputShape = combineRaggedTensorToTensorShapes(this.raggedRank, shape, valueShape);
	      var result = outputShape;
	      if (result[0] < 0) {
	        result[0] = firstDim;
	      }
	      for (var i = 1; i <= this.raggedRank; ++i) {
	        if (result[i] < 0) {
	          result[i] = this.getMaxWidth(i);
	        }
	      }
	      return result;
	    }
	    /**
	     * The outputIndex represents the index in the output tensor
	     * where the first element of a particular dimension would be written.
	     * If it is -1, it indicates that the index is out of scope.
	     * Example, given firstDimension = 10, firstDimensionOutput = 6,
	     * and outputIndexMultiplier = 100:
	     * result = [0 100 200 300 400 500 -1 -1 -1 -1]
	     * If firstDimensionOutput = 11 instead, then:
	     * result = [0 100 200 300 400 500 600 700 800 900]
	     */
	  }, {
	    key: "calculateFirstParentOutputIndex",
	    value: function calculateFirstParentOutputIndex(firstDimension, outputIndexMultiplier, firstDimensionOutput) {
	      var minDimension = Math.min(firstDimension, firstDimensionOutput);
	      var result = [];
	      var currentOutputIndex = 0;
	      for (var i = 0; i < minDimension; ++i, currentOutputIndex += outputIndexMultiplier) {
	        result.push(currentOutputIndex);
	      }
	      for (var _i = minDimension; _i < firstDimension; ++_i) {
	        result.push(-1);
	      }
	      assert$1(result.length === firstDimension, function () {
	        return 'Final length of result must be equal to firstDimension.';
	      });
	      return result;
	    }
	  }, {
	    key: "calculateOutputIndexRowSplit",
	    value: function calculateOutputIndexRowSplit(rowSplit, parentOutputIndex, outputIndexMultiplier, outputSize) {
	      var rowSplitSize = rowSplit.length;
	      var result = [];
	      for (var i = 0; i < rowSplitSize - 1; ++i) {
	        var rowLength = rowSplit[i + 1] - rowSplit[i];
	        var realLength = Math.min(outputSize, rowLength);
	        var parentOutputIndexCurrent = parentOutputIndex[i];
	        if (parentOutputIndexCurrent === -1) {
	          realLength = 0;
	        }
	        for (var j = 0; j < realLength; ++j) {
	          result.push(parentOutputIndexCurrent);
	          parentOutputIndexCurrent += outputIndexMultiplier;
	        }
	        for (var _j = 0; _j < rowLength - realLength; ++_j) {
	          result.push(-1);
	        }
	      }
	      if (rowSplitSize > 0 && result.length !== rowSplit[rowSplitSize - 1]) {
	        throw new Error('Invalid row split size.');
	      }
	      return result;
	    }
	    // Calculate the output index of the first element of a list.
	    // The parentOutputIndex is the same computation for the previous list.
	    // -1 indicates an element or list that is out of range.
	    // The outputIndexMultiplier is the number of output indices one moves
	    // forward for each column.
	    // E.g., given:
	    // valueRowIds:[0 1 2 2 2 3 5 5 6]
	    // parentOutputIndex:[1000 1100 2000 2100 -1 3000 4000]
	    // outputIndexMultiplier: 10
	    // outputSize: 2
	    // You get:
	    // result = [1000 1100 2000 2010 -1 2100 -1 -1 3000]
	    // result[0] = parentOutputIndex[valueRowIds[0]]
	    // result[1] = parentOutputIndex[valueRowIds[1]]
	    // result[2] = parentOutputIndex[valueRowIds[2]]
	    // result[3] = parentOutputIndex[valueRowIds[2] + 10]
	    // result[4] = -1 because it is the third element the size is 2.
	    // result[5] = parentOutputIndex[valueRowIds[3]]
	    // result[6] = -1 because parentOutputIndex[valueRowIds[6]] == -1
	    // result[7] = -1 because parentOutputIndex[valueRowIds[6]] == -1
	    // result[8] = parentOutputIndex[valueRowIds[7]]
	  }, {
	    key: "calculateOutputIndexValueRowID",
	    value: function calculateOutputIndexValueRowID(valueRowIds, parentOutputIndex, outputIndexMultiplier, outputSize) {
	      var indexSize = valueRowIds.length;
	      var result = [];
	      if (indexSize === 0) {
	        return [];
	      }
	      var currentOutputColumn = 0;
	      var currentValueRowId = valueRowIds[0];
	      if (currentValueRowId >= parentOutputIndex.length) {
	        throw new Error("Got currentValueRowId=".concat(currentValueRowId, ", which is not less than ").concat(parentOutputIndex.length));
	      }
	      var currentOutputIndex = parentOutputIndex[currentValueRowId];
	      result.push(currentOutputIndex);
	      for (var i = 1; i < indexSize; ++i) {
	        var nextValueRowId = valueRowIds[i];
	        if (nextValueRowId === currentValueRowId) {
	          if (currentOutputIndex >= 0) {
	            ++currentOutputColumn;
	            if (currentOutputColumn < outputSize) {
	              currentOutputIndex += outputIndexMultiplier;
	            } else {
	              currentOutputIndex = -1;
	            }
	          }
	        } else {
	          currentOutputColumn = 0;
	          currentValueRowId = nextValueRowId;
	          if (nextValueRowId >= parentOutputIndex.length) {
	            throw new Error("Got nextValueRowId=".concat(nextValueRowId, " which is not less than ").concat(parentOutputIndex.length));
	          }
	          currentOutputIndex = parentOutputIndex[nextValueRowId];
	        }
	        result.push(currentOutputIndex);
	      }
	      if (result.length !== valueRowIds.length) {
	        throw new Error('Invalid row ids.');
	      }
	      return result;
	    }
	  }, {
	    key: "calculateOutputIndex",
	    value: function calculateOutputIndex(dimension, parentOutputIndex, outputIndexMultiplier, outputSize) {
	      var rowPartitionTensor = this.getRowPartitionTensor(dimension);
	      var partitionType = this.getRowPartitionTypeByDimension(dimension);
	      switch (partitionType) {
	        case RowPartitionType.VALUE_ROWIDS:
	          return this.calculateOutputIndexValueRowID(rowPartitionTensor, parentOutputIndex, outputIndexMultiplier, outputSize);
	        case RowPartitionType.ROW_SPLITS:
	          if (rowPartitionTensor.length - 1 > parentOutputIndex.length) {
	            throw new Error("Row partition size is greater than output size: ".concat(rowPartitionTensor.length - 1, " > ").concat(parentOutputIndex.length));
	          }
	          return this.calculateOutputIndexRowSplit(rowPartitionTensor, parentOutputIndex, outputIndexMultiplier, outputSize);
	        default:
	          throw new Error("Unsupported partition type: ".concat(RowPartitionType[partitionType]));
	      }
	    }
	  }, {
	    key: "getFirstDimensionSize",
	    value: function getFirstDimensionSize() {
	      var firstPartitionTensor = this.rowPartitionValues[0];
	      if (this.rowPartitionTypes.length === 0) {
	        throw new Error('No row_partition_types given.');
	      }
	      var firstPartitionType = this.rowPartitionTypes[0];
	      switch (firstPartitionType) {
	        case RowPartitionType.FIRST_DIM_SIZE:
	          return firstPartitionTensor[0];
	        case RowPartitionType.VALUE_ROWIDS:
	          throw new Error('Cannot handle VALUE_ROWIDS in first dimension.');
	        case RowPartitionType.ROW_SPLITS:
	          return this.rowPartitionValuesShapes[0][0] - 1;
	        default:
	          throw new Error("Cannot handle type ".concat(RowPartitionType[firstPartitionType]));
	      }
	    }
	  }, {
	    key: "compute",
	    value: function compute() {
	      var firstPartitionTensor = this.rowPartitionValues[0];
	      if (firstPartitionTensor.length <= 0) {
	        throw new Error('Invalid first partition input. ' + 'Tensor requires at least one element.');
	      }
	      var firstDimension = this.getFirstDimensionSize();
	      var outputSize = this.calculateOutputSize(firstDimension);
	      var multiplier = new Array(this.raggedRank + 1);
	      multiplier[multiplier.length - 1] = 1;
	      for (var i = multiplier.length - 2; i >= 0; --i) {
	        multiplier[i] = multiplier[i + 1] * outputSize[i + 1];
	      }
	      // Full size of the tensor.
	      var outputShape = makeShape(outputSize, false);
	      var outputTensor = getArrayFromDType(this.valuesDType, sizeFromShape(outputShape));
	      var fullSize = multiplier[0] * outputSize[0];
	      if (fullSize > 0) {
	        var outputIndex = this.calculateFirstParentOutputIndex(firstDimension, multiplier[0], outputSize[0]);
	        for (var _i2 = 1; _i2 <= this.raggedRank; ++_i2) {
	          var newOutputIndex = this.calculateOutputIndex(_i2 - 1, outputIndex, multiplier[_i2], outputSize[_i2]);
	          outputIndex = newOutputIndex;
	        }
	        this.setOutput(this.raggedRank, outputIndex, outputTensor, outputShape);
	      }
	      return [outputShape, outputTensor];
	    }
	  }, {
	    key: "setOutput",
	    value: function setOutput(raggedRank, outputIndex, outputTensor, outputShape) {
	      if (outputTensor.length === 0) {
	        return;
	      }
	      var valuesBase = this.values;
	      var outputBase = outputTensor;
	      var elementShape = outputShape.slice();
	      elementShape = elementShape.slice(raggedRank + 1);
	      var valueElementSize = sizeFromShape(elementShape);
	      var outputIndexSize = outputIndex.length;
	      // Broadcast the default value to value_element_size.  (We can skip this
	      // if defaultValueTensor.size == 1, since we use fill when that's true.)
	      var defaultValue = this.defaultValue;
	      if (defaultValue.length !== valueElementSize && defaultValue.length !== 1) {
	        var srcShape = this.defaultValueShape;
	        tidy(function () {
	          var defaultValueTensor = reshape$3(defaultValue, srcShape);
	          var bCastDefault = broadcastTo(defaultValueTensor, elementShape);
	          defaultValue = bCastDefault.dataSync();
	        });
	      }
	      // Loop through the outputIndex array, finding contiguous regions that
	      // should be copied.  Once we find the end of a contiguous region, copy it
	      // and add any necessary padding (with defaultValue).
	      var srcStart = 0; // Start of contiguous region (in values)
	      var dstStart = 0; // Destination for contiguous region (in output)
	      var dstEnd = 0; // Destination for contiguous region (in output)
	      for (var srcI = 0; srcI <= outputIndexSize; ++srcI) {
	        // dstI is the destination where the value at srcI should be copied.
	        var dstI = srcI < outputIndexSize ? outputIndex[srcI] : -1;
	        // If we're still in a contiguous region, then update dstEnd go to the
	        // next srcI.
	        if (dstI === dstEnd) {
	          ++dstEnd;
	          continue;
	        }
	        // We found the end of contiguous region.  This can be because we found
	        // a gap (dstI > dstEnd), or a source value that shouldn't be copied
	        // because it's out-of-bounds (dstI == -1), or the end of the tensor
	        // (dstI === -1).
	        if (dstStart < dstEnd) {
	          // Copy the contiguous region.
	          var src = valuesBase.subarray(srcStart * valueElementSize);
	          var dst = outputBase.subarray(dstStart * valueElementSize);
	          var nVals = (dstEnd - dstStart) * valueElementSize;
	          copyArray(dst, src, nVals);
	        }
	        // Add any necessary padding (w/ defaultValue).
	        if (srcI >= outputIndexSize) {
	          // We reached the end of values: pad to the end of output.
	          var outputSize = outputTensor.length;
	          dstI = Math.floor(outputSize / valueElementSize);
	        }
	        if (dstI > dstEnd) {
	          if (this.defaultValue.length === 1) {
	            outputBase.subarray(dstEnd * valueElementSize, dstI * valueElementSize).fill(this.defaultValue[0]);
	            dstEnd = dstI;
	          } else {
	            while (dstI > dstEnd) {
	              var _dst = outputBase.slice(dstEnd * valueElementSize);
	              copyArray(_dst, defaultValue, valueElementSize);
	              ++dstEnd;
	            }
	          }
	        }
	        // Update indices.
	        if (dstI < 0) {
	          // srcI should be skipped -- leave it out of the contiguous region.
	          srcStart = srcI + 1;
	          dstStart = dstEnd;
	        } else {
	          // srcI should be copied -- include it in the contiguous region.
	          srcStart = srcI;
	          dstStart = dstEnd;
	          dstEnd = dstStart + 1;
	        }
	      }
	    }
	  }], [{
	    key: "getMaxWidthRowSplit",
	    value: function getMaxWidthRowSplit(rowSplit) {
	      var tensorLength = rowSplit.length;
	      if (tensorLength === 0 || tensorLength === 1) {
	        return 0;
	      }
	      var maxWidth = 0;
	      for (var i = 0; i < tensorLength - 1; ++i) {
	        var currentWidth = rowSplit[i + 1] - rowSplit[i];
	        if (currentWidth > maxWidth) {
	          maxWidth = currentWidth;
	        }
	      }
	      return maxWidth;
	    }
	  }, {
	    key: "getMaxWidthValueRowID",
	    value: function getMaxWidthValueRowID(valueRowIds) {
	      var indexLength = valueRowIds.length;
	      if (indexLength === 0) {
	        return 0;
	      }
	      var firstEqualIndex = 0;
	      var firstEqualIndexValue = valueRowIds[0];
	      var maxWidth = 0;
	      for (var i = 1; i < indexLength; ++i) {
	        var value = valueRowIds[i];
	        if (value !== firstEqualIndexValue) {
	          firstEqualIndexValue = value;
	          maxWidth = Math.max(i - firstEqualIndex, maxWidth);
	          firstEqualIndex = i;
	        }
	      }
	      return Math.max(indexLength - firstEqualIndex, maxWidth);
	    }
	  }]);
	  return RaggedTensorToTensorOp;
	}();
	function copyArray(dst, src, size) {
	  for (var i = 0; i < size; i++) {
	    dst[i] = src[i];
	  }
	}
	function makeShape(shape, isPartial) {
	  var out = [];
	  var _iterator = _createForOfIteratorHelper(shape),
	    _step;
	  try {
	    for (_iterator.s(); !(_step = _iterator.n()).done;) {
	      var dim = _step.value;
	      if (dim < 0) {
	        if (!isPartial) {
	          throw new Error("Dimension ".concat(dim, " must be >= 0"));
	        }
	        if (dim < -1) {
	          throw new Error("Dimension ".concat(dim, " must be >= -1"));
	        }
	        dim = -1;
	      }
	      out.push(dim);
	    }
	  } catch (err) {
	    _iterator.e(err);
	  } finally {
	    _iterator.f();
	  }
	  return out;
	}
	function raggedTensorToTensorImpl(shape, shapesShape, values, valuesShape, valuesDType, defaultValue, defaultValueShape, rowPartitionValues, rowPartitionValuesShapes, rowPartitionTypes) {
	  return new RaggedTensorToTensorOp(shape, shapesShape, values, valuesShape, valuesDType, defaultValue, defaultValueShape, rowPartitionValues, rowPartitionValuesShapes, rowPartitionTypes).compute();
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function rangeImpl(start, stop, step, dtype) {
	  var sameStartStop = start === stop;
	  var increasingRangeNegativeStep = start < stop && step < 0;
	  var decreasingRangePositiveStep = stop < start && step > 1;
	  if (sameStartStop || increasingRangeNegativeStep || decreasingRangePositiveStep) {
	    return makeZerosTypedArray(0, dtype);
	  }
	  var numElements = Math.abs(Math.ceil((stop - start) / step));
	  var values = makeZerosTypedArray(numElements, dtype);
	  if (stop < start && step === 1) {
	    // Auto adjust the step's sign if it hasn't been set
	    // (or was set to 1)
	    step = -1;
	  }
	  values[0] = start;
	  for (var i = 1; i < values.length; i++) {
	    values[i] = values[i - 1] + step;
	  }
	  return values;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var rsqrtImpl = createSimpleUnaryImpl(function (xi) {
	  return 1 / Math.sqrt(xi);
	});
	var rsqrt$1 = unaryKernelFuncFromImpl(Rsqrt, rsqrtImpl);
	var rsqrtConfig$1 = {
	  kernelName: Rsqrt,
	  backendName: 'cpu',
	  kernelFunc: rsqrt$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function scatterImpl(indices, updates, shape, outputSize, sliceSize, numUpdates, sliceRank, strides, defaultValue, sumDupeIndices) {
	  var flattenShape = [outputSize / sliceSize, sliceSize];
	  var indicesData = indices.values;
	  var updatesData = updates.values;
	  if (outputSize === 0) {
	    return buffer(shape, updates.dtype);
	  }
	  var outBuf = defaultValue instanceof TensorBuffer ? defaultValue : buffer(flattenShape, updates.dtype);
	  if (typeof defaultValue === 'string') {
	    outBuf.values.fill(defaultValue);
	  } else if (typeof defaultValue === 'number') {
	    outBuf.values.fill(defaultValue);
	  } else if (typeof defaultValue === 'boolean') {
	    outBuf.values.fill(+defaultValue);
	  }
	  for (var i = 0; i < numUpdates; i++) {
	    var index = [];
	    var flattenIndex = 0;
	    for (var j = 0; j < sliceRank; j++) {
	      var dim = indicesData[i * sliceRank + j];
	      index.push(dim);
	      flattenIndex += dim * strides[j];
	    }
	    if (flattenIndex < 0 || flattenIndex >= outputSize / sliceSize) {
	      throw new Error("Invalid indices: ".concat(index, " does not index into ").concat(shape));
	    }
	    for (var k = 0; k < sliceSize; k++) {
	      if (sumDupeIndices) {
	        outBuf.values[flattenIndex * sliceSize + k] += updatesData[i * sliceSize + k];
	      } else {
	        outBuf.values[flattenIndex * sliceSize + k] = updates.rank === 0 ? updatesData[0] : updatesData[i * sliceSize + k];
	      }
	    }
	  }
	  return outBuf;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var sigmoidImpl = createSimpleUnaryImpl(function (xi) {
	  return 1 / (1 + Math.exp(-xi));
	});
	var sigmoid$1 = unaryKernelFunc$1(Sigmoid$1, function (xi) {
	  return 1 / (1 + Math.exp(-xi));
	});
	var sigmoidConfig$1 = {
	  kernelName: Sigmoid$1,
	  backendName: 'cpu',
	  kernelFunc: sigmoid$1
	};

	function sliceImpl(vals, begin, size, shape, dtype) {
	  var isContinous = isSliceContinous(shape, begin, size);
	  var length = sizeFromShape(size);
	  var xStrides = computeStrides(shape);
	  if (isContinous) {
	    var flatOffset = computeFlatOffset(begin, xStrides);
	    if (dtype === 'string') {
	      return vals.slice(flatOffset, flatOffset + length);
	    }
	    return vals.subarray(flatOffset, flatOffset + length);
	  }
	  var decodedData = dtype === 'string' ? fromUint8ToStringArray(vals) : vals;
	  var inBuf = buffer(shape, dtype, decodedData);
	  var outBuf = buffer(size, dtype);
	  for (var i = 0; i < outBuf.size; ++i) {
	    var outLoc = outBuf.indexToLoc(i);
	    var inLoc = outLoc.map(function (idx, j) {
	      return idx + begin[j];
	    });
	    outBuf.set.apply(outBuf, [inBuf.get.apply(inBuf, _toConsumableArray(inLoc))].concat(_toConsumableArray(outLoc)));
	  }
	  if (dtype === 'string') {
	    return fromStringArrayToUint8(outBuf.values);
	  }
	  return outBuf.values;
	}
	function slice$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var begin = attrs.begin,
	    size = attrs.size;
	  assertNotComplex$1(x, 'slice');
	  var _slice_util$parseSlic = parseSliceParams(x, begin, size),
	    _slice_util$parseSlic2 = _slicedToArray(_slice_util$parseSlic, 2),
	    $begin = _slice_util$parseSlic2[0],
	    $size = _slice_util$parseSlic2[1];
	  assertParamsValid(x, $begin, $size);
	  var vals = backend.data.get(x.dataId).values;
	  var outVals = sliceImpl(vals, $begin, $size, x.shape, x.dtype);
	  return backend.makeTensorInfo($size, x.dtype, outVals);
	}
	var sliceConfig$1 = {
	  kernelName: Slice,
	  backendName: 'cpu',
	  kernelFunc: slice$1
	};

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function sparseFillEmptyRowsImpl(indices, indicesShape, indicesDType, values, valuesDType, denseShape, defaultValue) {
	  var indicesCount = indicesShape[0];
	  var denseRows = denseShape[0];
	  var emptyRowIndicator = new Array(denseRows);
	  var reverseIndexMap = new Array(indicesCount);
	  var rank = indicesShape[1];
	  if (denseRows === 0) {
	    if (indicesCount !== 0) {
	      throw new Error(getSparseFillEmptyRowsIndicesDenseShapeMismatch(indicesCount));
	    }
	    var outputIndices = getArrayFromDType(indicesDType, 0);
	    var outputValues = getArrayFromDType(valuesDType, 0);
	    return [outputIndices, [0, rank], outputValues, emptyRowIndicator, reverseIndexMap];
	  }
	  var rowsAreOrdered = true;
	  var lastIndicesRow = 0;
	  var csrOffset = new Array(denseRows).fill(0);
	  for (var i = 0; i < indicesCount; ++i) {
	    // indices is a 2d tensor with shape of [N, rank]
	    var row = indices[i * rank];
	    if (row < 0) {
	      throw new Error(getSparseFillEmptyRowsNegativeIndexErrorMessage(i, row));
	    }
	    if (row >= denseRows) {
	      throw new Error(getSparseFillEmptyRowsOutOfRangeIndexErrorMessage(i, row, denseRows));
	    }
	    ++csrOffset[row];
	    rowsAreOrdered = rowsAreOrdered && row >= lastIndicesRow;
	    lastIndicesRow = row;
	  }
	  var allRowsFull = true;
	  for (var _row = 0; _row < denseRows; ++_row) {
	    // csrOffset here describes the number of elements in this dense row
	    var rowEmpty = csrOffset[_row] === 0;
	    emptyRowIndicator[_row] = rowEmpty;
	    allRowsFull = allRowsFull && !rowEmpty;
	    // In filled version, each row has at least one element.
	    csrOffset[_row] = Math.max(csrOffset[_row], 1);
	    // Update csrOffset to represent the number of elements up to and
	    // including denseRows + 1:
	    //  csrOffset[0] == #{elements of row 0}
	    //  csrOffset[1] == #{elements of row 1} + #{elements of row 0}
	    //  ..
	    //  csrOffset[i] == starting index for elements in row i + 1.
	    if (_row > 0) {
	      csrOffset[_row] += csrOffset[_row - 1];
	    }
	  }
	  if (allRowsFull && rowsAreOrdered) {
	    var _outputIndices = indices;
	    var _outputValues = values;
	    for (var _i = 0; _i < indicesCount; ++_i) {
	      reverseIndexMap[_i] = _i;
	    }
	    return [_outputIndices, [indicesCount, rank], _outputValues, emptyRowIndicator, reverseIndexMap];
	  } else {
	    var fullIndicesCount = csrOffset[denseRows - 1];
	    var _outputIndices2 = getArrayFromDType(indicesDType, fullIndicesCount * rank);
	    var _outputValues2 = getArrayFromDType(valuesDType, fullIndicesCount);
	    var filledCount = new Array(denseRows).fill(0);
	    // Fill in values for rows that are not missing
	    for (var _i2 = 0; _i2 < indicesCount; ++_i2) {
	      // indices is a 2d tensor with shape of [N, rank]
	      var _row2 = indices[_i2 * rank];
	      var offset = filledCount[_row2];
	      var outputI = (_row2 === 0 ? 0 : csrOffset[_row2 - 1]) + offset;
	      filledCount[_row2]++; // Increment the filled count for this row.
	      for (var j = 0; j < rank; ++j) {
	        // indices and outputIndices are 2d tensors with shape of [N, rank]
	        _outputIndices2[outputI * rank + j] = indices[_i2 * rank + j];
	      }
	      _outputValues2[outputI] = values[_i2];
	      // We'll need this reverse index map to backprop correctly.
	      reverseIndexMap[_i2] = outputI;
	    }
	    // Fill in values for rows that are missing
	    for (var _row3 = 0; _row3 < denseRows; ++_row3) {
	      var rowCount = filledCount[_row3];
	      if (rowCount === 0) {
	        // We haven't filled this row
	        var startingIndex = _row3 === 0 ? 0 : csrOffset[_row3 - 1];
	        // Remaining index values were set to zero already.
	        // Just need to set the row index in the right location.
	        // outputIndices is a 2d tensor with shape of [N, rank]
	        _outputIndices2[startingIndex * rank + 0] = _row3;
	        for (var col = 1; col < rank; ++col) {
	          _outputIndices2[startingIndex * rank + col] = 0;
	        }
	        _outputValues2[startingIndex] = defaultValue;
	      }
	    }
	    return [_outputIndices2, [fullIndicesCount, rank], _outputValues2, emptyRowIndicator, reverseIndexMap];
	  }
	}

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function sparseReshapeImpl(inputIndices, inputIndicesShape, inputDType, inputShape, targetShape) {
	  var denseSize = sizeFromShape(inputShape);
	  var nnz = inputIndicesShape[0];
	  var outputRank = targetShape.length;
	  // Compute the output shape. Determine product of specified dimensions, and
	  // find the index of the unspecified one.
	  var outputShape = [];
	  var product = 1;
	  var unknownIndex = -1;
	  for (var d = 0; d < outputRank; ++d) {
	    var size = targetShape[d];
	    if (size === -1) {
	      if (unknownIndex !== -1) {
	        throw new Error(getSparseReshapeMultipleNegativeOneOutputDimErrorMessage(unknownIndex, d));
	      }
	      unknownIndex = d;
	      outputShape.push(1);
	    } else {
	      if (size < 0) {
	        throw new Error(getSparseReshapeNegativeOutputDimErrorMessage(d, size));
	      }
	      product *= size;
	      outputShape.push(size);
	    }
	  }
	  if (unknownIndex !== -1) {
	    if (product <= 0) {
	      throw new Error(getSparseReshapeEmptyTensorZeroOutputDimErrorMessage());
	    }
	    var missing = Math.trunc(denseSize / product);
	    if (product * missing !== denseSize) {
	      throw new Error(getSparseReshapeInputOutputMultipleErrorMessage(inputShape, outputShape));
	    }
	    outputShape[unknownIndex] = missing;
	  }
	  var outputSize = sizeFromShape(outputShape);
	  if (outputSize !== denseSize) {
	    throw new Error(getSparseReshapeInputOutputMismatchErrorMessage(inputShape, outputShape));
	  }
	  var inputRank = inputShape.length;
	  var inputStrides = [];
	  if (inputRank > 0) {
	    inputStrides[inputRank - 1] = 1;
	    for (var _d = inputRank - 2; _d >= 0; --_d) {
	      inputStrides[_d] = inputStrides[_d + 1] * inputShape[_d + 1];
	    }
	  }
	  var outputStrides = [];
	  if (outputRank > 0) {
	    outputStrides[outputRank - 1] = 1;
	    for (var _d2 = outputRank - 2; _d2 >= 0; --_d2) {
	      outputStrides[_d2] = outputStrides[_d2 + 1] * outputShape[_d2 + 1];
	    }
	  }
	  var newIndices = getArrayFromDType(inputDType, nnz * outputRank);
	  for (var i = 0; i < nnz; ++i) {
	    var id = 0;
	    for (var j = 0; j < inputRank; ++j) {
	      // inputIndices is a 2d tensor with shape of [nnz, inputRank]
	      id += inputIndices[i * inputRank + j] * inputStrides[j];
	    }
	    for (var _j = 0; _j < outputRank; ++_j) {
	      // newIndices is a 2d tensor with shape of [nnz, outputRank]
	      newIndices[i * outputRank + _j] = Math.trunc(id / outputStrides[_j]);
	      id %= outputStrides[_j];
	    }
	  }
	  return [newIndices, [nnz, outputRank], outputShape];
	}

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function sparseSegmentReductionImpl(input, inputShape, inputDType, indices, segmentIds) {
	  var isMean = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : false;
	  var defaultValue = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : 0;
	  var numIndices = indices.length;
	  // Flatten the array to two dimensions
	  var inputFlat = [inputShape[0], input.length / inputShape[0]];
	  var numCol = inputFlat[1];
	  // Note that the current implementation assumes that segmentIds values are
	  // sorted.
	  var lastSegmentIdPlusOne = numIndices > 0 ? segmentIds[numIndices - 1] + 1 : 0;
	  var outputRows = lastSegmentIdPlusOne;
	  if (outputRows < 0) {
	    throw new Error(getSparseSegmentReductionNegativeSegmentIdsErrorMessage());
	  }
	  var outputShape = inputShape.slice();
	  outputShape[0] = outputRows;
	  var outputLength = outputShape.reduce(function (product, value) {
	    return product * value;
	  }, 1);
	  // Output array is initialized with the value 0 by default.
	  var output = getArrayFromDType(inputDType, outputLength);
	  // Note that we do not initialize the output buffer with a default value, so
	  // we need to explicitly set missing indices to the default value.
	  if (numIndices === 0) {
	    if (outputRows > 0) {
	      output.fill(defaultValue);
	    }
	    return [output, outputShape];
	  }
	  if (outputRows <= 0) {
	    throw new Error(getSparseSegmentReductionNegativeSegmentIdsErrorMessage());
	  }
	  var start = 0,
	    end = 1;
	  // Index from which the output is not initialized.
	  var uninitializedIndex = 0;
	  var outIndex = segmentIds[start];
	  while (true) {
	    // We initialize nextIndex to 0 to avoid may be uninitialized warning
	    var nextIndex = 0;
	    if (end < numIndices) {
	      nextIndex = segmentIds[end];
	      if (outIndex === nextIndex) {
	        ++end;
	        continue;
	      }
	      // We have a new segment here.  Verify that the segment ids are growing.
	      if (outIndex >= nextIndex) {
	        throw new Error(getSparseSegmentReductionNonIncreasingSegmentIdsErrorMessage());
	      }
	    }
	    if (outIndex < 0 || outIndex >= outputRows) {
	      throw new Error(getSparseSegmentReductionSegmentIdOutOfRangeErrorMessage(outIndex, outputRows));
	    }
	    // If there is a gap between two indices, we need to set that gap to the
	    // default value.
	    if (outIndex > uninitializedIndex) {
	      output.fill(defaultValue, uninitializedIndex * numCol, outIndex * numCol);
	    }
	    for (var i = start; i < end; ++i) {
	      var index = indices[i];
	      if (index < 0 || index >= inputFlat[0]) {
	        throw new Error(getSparseSegmentReductionIndicesOutOfRangeErrorMessage(i, indices[i], inputFlat[0]));
	      }
	      for (var j = 0; j < numCol; j++) {
	        output[outIndex * numCol + j] += input[index * numCol + j];
	      }
	    }
	    if (isMean) {
	      for (var _j = 0; _j < numCol; _j++) {
	        output[outIndex * numCol + _j] /= end - start;
	      }
	    }
	    start = end;
	    ++end;
	    uninitializedIndex = outIndex + 1;
	    outIndex = nextIndex;
	    if (end > numIndices) {
	      break;
	    }
	  }
	  // Fill the gap at the end with the default value.
	  if (uninitializedIndex < outputRows) {
	    output.fill(defaultValue, uninitializedIndex * numCol, outputRows * numCol);
	  }
	  return [output, outputShape];
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var sqrtImpl = createSimpleUnaryImpl(function (xi) {
	  return Math.sqrt(xi);
	});
	var sqrt$1 = unaryKernelFunc$1(Sqrt, function (xi) {
	  return Math.sqrt(xi);
	});
	var sqrtConfig$1 = {
	  kernelName: Sqrt,
	  backendName: 'cpu',
	  kernelFunc: sqrt$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var squaredDifferenceImpl = createSimpleBinaryKernelImpl(function (a, b) {
	  var diff = a - b;
	  return diff * diff;
	});
	var squaredDifference$1 = binaryKernelFunc$1(SquaredDifference, squaredDifferenceImpl);
	var squaredDifferenceConfig$1 = {
	  kernelName: SquaredDifference,
	  backendName: 'cpu',
	  kernelFunc: squaredDifference$1
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var staticRegexReplaceImpl = createSimpleUnaryImpl(function (x, attrs) {
	  var pattern = attrs.pattern,
	    replaceGlobal = attrs.replaceGlobal,
	    rewrite = attrs.rewrite;
	  // TODO(mattSoulanille): Don't create a regex each time.
	  return x.replace(new RegExp(pattern, replaceGlobal ? 'g' : ''), rewrite);
	});
	var staticRegexReplace$1 = unaryKernelFuncFromImpl(StaticRegexReplace, staticRegexReplaceImpl);
	var staticRegexReplaceConfig$1 = {
	  kernelName: StaticRegexReplace,
	  backendName: 'cpu',
	  kernelFunc: staticRegexReplace$1
	};

	function stridedSliceImpl(outShape, xBuf, strides, begin) {
	  var outBuf = buffer(outShape, xBuf.dtype);
	  for (var i = 0; i < outBuf.size; i++) {
	    var loc = outBuf.indexToLoc(i);
	    var newLoc = new Array(loc.length);
	    for (var j = 0; j < newLoc.length; j++) {
	      newLoc[j] = loc[j] * strides[j] + begin[j];
	    }
	    outBuf.set.apply(outBuf, [xBuf.get.apply(xBuf, newLoc)].concat(_toConsumableArray(loc)));
	  }
	  return outBuf;
	}

	/**
	 * The StringNGramsOp class creates ngrams from ragged string data.
	 * The constructor contains all attributes related to the operation such as
	 * padding widths and strings, and the compute function can be used to
	 * compute the ngrams for different ragged tensor inputs.
	 */
	var StringNGramsOp = /*#__PURE__*/function () {
	  function StringNGramsOp(separator, nGramWidths, leftPad, rightPad, padWidth, preserveShortSequences) {
	    _classCallCheck(this, StringNGramsOp);
	    this.separator = encodeString(separator);
	    this.nGramWidths = nGramWidths;
	    this.leftPad = encodeString(leftPad);
	    this.rightPad = encodeString(rightPad);
	    this.padWidth = padWidth;
	    this.preserveShort = preserveShortSequences;
	  }
	  _createClass(StringNGramsOp, [{
	    key: "getPadWidth",
	    value: function getPadWidth(nGramWidth) {
	      // Ngrams can be padded with either a fixed pad width or a dynamic pad
	      // width depending on the 'padWidth' arg, but in no case should the padding
	      // ever be wider than 'nGramWidth' - 1.
	      return Math.min(this.padWidth < 0 ? nGramWidth - 1 : this.padWidth, nGramWidth - 1);
	    }
	  }, {
	    key: "getNumNGrams",
	    value: function getNumNGrams(length, nGramWidth) {
	      var padWidth = this.getPadWidth(nGramWidth);
	      return Math.max(0, length + 2 * padWidth - nGramWidth + 1);
	    }
	  }, {
	    key: "createNGrams",
	    value: function createNGrams(data, splitIndex, output, outputStartIndex, numNGrams, nGramWidth) {
	      var _this = this;
	      var _loop = function _loop() {
	        var padWidth = _this.getPadWidth(nGramWidth);
	        var leftPadding = Math.max(0, padWidth - nGramIndex);
	        var rightPadding = Math.max(0, padWidth - (numNGrams - (nGramIndex + 1)));
	        var numTokens = nGramWidth - (leftPadding + rightPadding);
	        var dataStartIndex = splitIndex + (leftPadding > 0 ? 0 : nGramIndex - padWidth);
	        // Calculate the total expected size of the nGram so we can reserve the
	        // correct amount of space in the string.
	        var nGramSize = 0;
	        // Size of the left padding.
	        nGramSize += leftPadding * _this.leftPad.length;
	        // Size of the tokens.
	        for (var n = 0; n < numTokens; ++n) {
	          nGramSize += data[dataStartIndex + n].length;
	        }
	        // Size of the right padding.
	        nGramSize += rightPadding * _this.rightPad.length;
	        // Size of the separators.
	        var numSeparators = leftPadding + rightPadding + numTokens - 1;
	        nGramSize += numSeparators * _this.separator.length;
	        // Build the nGram.
	        output[outputStartIndex + nGramIndex] = new Uint8Array(nGramSize);
	        var nGram = output[outputStartIndex + nGramIndex];
	        var nextNGramIndex = 0;
	        var appendToNGram = function appendToNGram(str) {
	          return str.forEach(function (value) {
	            return nGram[nextNGramIndex++] = value;
	          });
	        };
	        for (var _n = 0; _n < leftPadding; ++_n) {
	          appendToNGram(_this.leftPad);
	          appendToNGram(_this.separator);
	        }
	        // Only output first numTokens - 1 pairs of data and separator
	        for (var _n2 = 0; _n2 < numTokens - 1; ++_n2) {
	          appendToNGram(data[dataStartIndex + _n2]);
	          appendToNGram(_this.separator);
	        }
	        // Handle case when there are no tokens or no right padding as these
	        // can result in consecutive separators.
	        if (numTokens > 0) {
	          // If we have tokens, then output last and then pair each separator
	          // with the right padding that follows, to ensure nGram ends either with
	          // the token or with the right pad.
	          appendToNGram(data[dataStartIndex + numTokens - 1]);
	          for (var _n3 = 0; _n3 < rightPadding; ++_n3) {
	            appendToNGram(_this.separator);
	            appendToNGram(_this.rightPad);
	          }
	        } else {
	          // If we don't have tokens, then the last item inserted into the nGram
	          // has been the separator from the left padding loop above. Hence,
	          // output right pad and separator and make sure to finish with a
	          // padding, not a separator.
	          for (var _n4 = 0; _n4 < rightPadding - 1; ++_n4) {
	            appendToNGram(_this.rightPad);
	            appendToNGram(_this.separator);
	          }
	          appendToNGram(_this.rightPad);
	        }
	      };
	      for (var nGramIndex = 0; nGramIndex < numNGrams; ++nGramIndex) {
	        _loop();
	      }
	    }
	    // Data and splits together form the definition of the ragged tensor,
	    // where data is 1 dimensional and contains the values of the tensor
	    // and splits denotes the indices at which each row starts.
	  }, {
	    key: "compute",
	    value: function compute(data, splits) {
	      var _this2 = this;
	      // Validate that the splits are valid indices into data, only if there are
	      // splits specified.
	      var inputDataSize = data.length;
	      var splitsSize = splits.length;
	      if (splitsSize > 0) {
	        var prevSplit = splits[0];
	        if (prevSplit !== 0) {
	          throw new Error("First split value must be 0, got ".concat(prevSplit));
	        }
	        for (var i = 1; i < splitsSize; ++i) {
	          var validSplits = splits[i] >= prevSplit;
	          validSplits = validSplits && splits[i] <= inputDataSize;
	          if (!validSplits) {
	            throw new Error("Invalid split value ".concat(splits[i], ", must be in [").concat(prevSplit, ", ").concat(inputDataSize, "]"));
	          }
	          prevSplit = splits[i];
	        }
	        if (prevSplit !== inputDataSize) {
	          throw new Error("Last split value must be data size. Expected ".concat(inputDataSize, ", got ").concat(prevSplit));
	        }
	      }
	      var numBatchItems = splitsSize - 1;
	      var nGramsSplits = getArrayFromDType('int32', splitsSize);
	      // If there is no data or size, return an empty ragged tensor.
	      if (inputDataSize === 0 || splitsSize === 0) {
	        var empty = new Array(inputDataSize);
	        for (var _i = 0; _i <= numBatchItems; ++_i) {
	          nGramsSplits[_i] = 0;
	        }
	        return [empty, nGramsSplits];
	      }
	      nGramsSplits[0] = 0;
	      var _loop2 = function _loop2() {
	        var length = splits[_i2] - splits[_i2 - 1];
	        var numNGrams = 0;
	        _this2.nGramWidths.forEach(function (nGramWidth) {
	          numNGrams += _this2.getNumNGrams(length, nGramWidth);
	        });
	        if (_this2.preserveShort && length > 0 && numNGrams === 0) {
	          numNGrams = 1;
	        }
	        nGramsSplits[_i2] = nGramsSplits[_i2 - 1] + numNGrams;
	      };
	      for (var _i2 = 1; _i2 <= numBatchItems; ++_i2) {
	        _loop2();
	      }
	      var nGrams = new Array(nGramsSplits[numBatchItems]);
	      var _loop3 = function _loop3(_i3) {
	        var splitIndex = splits[_i3];
	        var outputStartIdx = nGramsSplits[_i3];
	        _this2.nGramWidths.forEach(function (nGramWidth) {
	          var length = splits[_i3 + 1] - splits[_i3];
	          var numNGrams = _this2.getNumNGrams(length, nGramWidth);
	          _this2.createNGrams(data, splitIndex, nGrams, outputStartIdx, numNGrams, nGramWidth);
	          outputStartIdx += numNGrams;
	        });
	        // If we're preserving short sequences, check to see if no sequence was
	        // generated by comparing the current output start idx to the original
	        // one (nGramSplitsdata). If no ngrams were generated, then they will
	        // be equal (since we increment outputStartIdx by numNGrams every
	        // time we create a set of ngrams.)
	        if (_this2.preserveShort && outputStartIdx === nGramsSplits[_i3]) {
	          var dataLength = splits[_i3 + 1] - splits[_i3];
	          // One legitimate reason to not have any ngrams when this.preserveShort
	          // is true is if the sequence itself is empty. In that case, move on.
	          if (dataLength === 0) {
	            return "continue";
	          }
	          // We don't have to worry about dynamic padding sizes here: if padding
	          // was dynamic, every sequence would have had sufficient padding to
	          // generate at least one nGram.
	          var nGramWidth = dataLength + 2 * _this2.padWidth;
	          var numNGrams = 1;
	          _this2.createNGrams(data, splitIndex, nGrams, outputStartIdx, numNGrams, nGramWidth);
	        }
	      };
	      for (var _i3 = 0; _i3 < numBatchItems; ++_i3) {
	        var _ret = _loop3(_i3);
	        if (_ret === "continue") continue;
	      }
	      return [nGrams, nGramsSplits];
	    }
	  }]);
	  return StringNGramsOp;
	}();
	function stringNGramsImpl(data, dataSplits, separator, nGramWidths, leftPad, rightPad, padWidth, preserveShortSequences) {
	  return new StringNGramsOp(separator, nGramWidths, leftPad, rightPad, padWidth, preserveShortSequences).compute(data, dataSplits);
	}

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function split(str, delimiters, skipEmpty, result) {
	  if (!str.length) {
	    return;
	  }
	  // When the delimiter is empty, the input is split into individual characters.
	  if (delimiters.length === 0) {
	    for (var i = 0; i < str.length; ++i) {
	      result.push(str.subarray(i, i + 1));
	    }
	    return;
	  }
	  // When there is one delimiter, the input is split only at that delimiter.
	  if (delimiters.length === 1) {
	    var delimiter = delimiters[0];
	    var f = str.indexOf(delimiter);
	    while (f !== -1) {
	      var token = str.subarray(0, f);
	      if (!skipEmpty || token.length !== 0) {
	        result.push(token);
	      }
	      str = str.subarray(f + 1);
	      f = str.indexOf(delimiter);
	    }
	    if (!skipEmpty || str.length !== 0) {
	      result.push(str);
	    }
	    return;
	  }
	  // When there are multiple delimiters, the input is split at every instance
	  // one of the delimiters appears.
	  var tokenStart = 0;
	  for (var _i = 0; _i < str.length + 1; _i++) {
	    if (_i === str.length || delimiters.indexOf(str[_i]) !== -1) {
	      var _token = str.subarray(tokenStart, _i);
	      if (!skipEmpty || _token.length !== 0) {
	        result.push(_token);
	      }
	      tokenStart = _i + 1;
	    }
	  }
	}
	function stringSplitImpl(input, delimiter, skipEmpty) {
	  var batchSize = input.length;
	  // Empty delimiter means split the input character by character.
	  var tokens = [];
	  var outputSize = 0;
	  var maxNumEntries = 0;
	  var numIndices = new Array(batchSize);
	  for (var i = 0; i < batchSize; ++i) {
	    var prevTokensLength = tokens.length;
	    split(input[i], delimiter, skipEmpty, tokens);
	    var nEntries = tokens.length - prevTokensLength;
	    numIndices[i] = nEntries;
	    outputSize += nEntries;
	    maxNumEntries = Math.max(maxNumEntries, nEntries);
	  }
	  var indices = getArrayFromDType('int32', outputSize * 2);
	  var values = new Array(outputSize);
	  var shape = [batchSize, maxNumEntries];
	  var c = 0;
	  for (var _i2 = 0; _i2 < batchSize; ++_i2) {
	    for (var j = 0; j < numIndices[_i2]; ++j) {
	      // indices is a 2d tensor with shape of [outputSize, 2]
	      indices[c * 2] = _i2;
	      indices[c * 2 + 1] = j;
	      values[c] = tokens[c];
	      ++c;
	    }
	  }
	  return [indices, values, shape];
	}

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function stringToHashBucketFastImpl(input, numBuckets) {
	  var output = getArrayFromDType('int32', input.length);
	  for (var i = 0; i < input.length; ++i) {
	    output[i] = fingerPrint64(input[i]).modulo(numBuckets).getLowBitsUnsigned();
	  }
	  return output;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var subImpl = createSimpleBinaryKernelImpl(function (aValue, bValue) {
	  return aValue - bValue;
	});
	var subComplexImpl = createComplexBinaryKernelImpl(function (aReal, aImag, bReal, bImag) {
	  return {
	    real: aReal - bReal,
	    imag: aImag - bImag
	  };
	});
	var sub$1 = binaryKernelFunc$1(Sub, subImpl, subComplexImpl);
	var subConfig$1 = {
	  kernelName: Sub,
	  backendName: 'cpu',
	  kernelFunc: sub$1
	};

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * An implementation of the tile kernel shared between webgl and cpu for string
	 * tensors only.
	 */
	function tileImpl(xBuf, reps) {
	  var newShape = new Array(xBuf.rank);
	  for (var i = 0; i < newShape.length; i++) {
	    newShape[i] = xBuf.shape[i] * reps[i];
	  }
	  var result = buffer(newShape, xBuf.dtype);
	  for (var _i = 0; _i < result.values.length; ++_i) {
	    var newLoc = result.indexToLoc(_i);
	    var originalLoc = new Array(xBuf.rank);
	    for (var j = 0; j < originalLoc.length; j++) {
	      originalLoc[j] = newLoc[j] % xBuf.shape[j];
	    }
	    var originalIndex = xBuf.locToIndex(originalLoc);
	    result.values[_i] = xBuf.values[originalIndex];
	  }
	  return result;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var comparePair = function comparePair(a, b) {
	  var valueDiff = b.value - a.value;
	  return valueDiff === 0 ? a.index - b.index : valueDiff;
	};
	/**
	 * Partitions array where all elements smaller than the (k+1) smallest element
	 * are found to the left of it, and all larger to the right of it.
	 * Based on the Floyd-Rivest Algorithm, ref:
	 * https://en.wikipedia.org/wiki/Floyd%E2%80%93Rivest_algorithm
	 * @param array: Array to partition
	 * @param left: Left index for the interval
	 * @param right: Right index for the interval
	 * @param k: Desired index value, where array[k] is the (k+1)th smallest element
	 *           when left = 0
	 */
	function select$2(array, k) {
	  var left = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
	  var right = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : array.length - 1;
	  while (right > left) {
	    // Use select recursively to sample a smaller set of size s
	    // the arbitrary constants 600 and 0.5 are used in the original
	    // version to minimize execution time.
	    if (right - left > 600) {
	      var n = right - left + 1;
	      var _i = k - left + 1;
	      var z = Math.log(n);
	      var s = 0.5 * Math.exp(2 * z / 3);
	      var sd = 0.5 * Math.sqrt(z * s * (n - s) / n) * Math.sign(_i - n / 2);
	      var newLeft = Math.max(left, Math.floor(k - _i * s / n + sd));
	      var newRight = Math.min(right, Math.floor(k + (n - _i) * s / n + sd));
	      select$2(array, k, newLeft, newRight);
	    }
	    // partition the elements between left and right around t
	    var t = array[k];
	    var i = left;
	    var j = right;
	    swap(array, left, k);
	    if (comparePair(array[right], t) > 0) {
	      swap(array, left, right);
	    }
	    while (i < j) {
	      swap(array, i, j);
	      i++;
	      j--;
	      while (comparePair(array[i], t) < 0) {
	        i = i + 1;
	      }
	      while (comparePair(array[j], t) > 0) {
	        j = j - 1;
	      }
	    }
	    if (comparePair(array[left], t) === 0) {
	      swap(array, left, j);
	    } else {
	      j = j + 1;
	      swap(array, j, right);
	    }
	    // Adjust left and right towards the boundaries of the subset
	    // containing the (k - left + 1)th smallest element.
	    if (j <= k) {
	      left = j + 1;
	    }
	    if (k <= j) {
	      right = j - 1;
	    }
	  }
	}
	function topKImpl(x, xShape, xDtype, k, sorted) {
	  // Reshape into a 2d tensor [batch, lastDim] and compute topk along lastDim.
	  var lastDim = xShape[xShape.length - 1];
	  var batch = x.length / lastDim,
	    size = lastDim;
	  var allTopKVals = getTypedArrayFromDType(xDtype, batch * k);
	  var allTopKIndices = getTypedArrayFromDType('int32', batch * k);
	  var _loop = function _loop() {
	    var offset = b * size;
	    var vals = x.subarray(offset, offset + size);
	    var valAndInd = new Array(vals.length);
	    vals.forEach(function (value, index) {
	      return valAndInd[index] = {
	        value: value,
	        index: index
	      };
	    });
	    if (k < valAndInd.length) {
	      select$2(valAndInd, k);
	      valAndInd = valAndInd.slice(0, k);
	    }
	    if (sorted) {
	      valAndInd.sort(comparePair);
	    }
	    var outOffset = b * k;
	    var topKVals = allTopKVals.subarray(outOffset, outOffset + k);
	    var topKIndices = allTopKIndices.subarray(outOffset, outOffset + k);
	    for (var i = 0; i < k; i++) {
	      topKVals[i] = valAndInd[i].value;
	      topKIndices[i] = valAndInd[i].index;
	    }
	  };
	  for (var b = 0; b < batch; b++) {
	    _loop();
	  }
	  // Reshape back to the original input shape, except that the last
	  // dimension is k.
	  var outputShape = xShape.slice();
	  outputShape[outputShape.length - 1] = k;
	  return [buffer(outputShape, xDtype, allTopKVals), buffer(outputShape, 'int32', allTopKIndices)];
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function uniqueImpl(values, axis, shape, dtype) {
	  // Normalize and validate axis.
	  var $axis = parseAxisParam(axis, shape)[0];
	  // Calculate the new shape that is suitable for extracting data along the
	  // given axis.
	  //
	  // The rank is 3.
	  // The size of the 1st dimension is the size of all the axes < the given axis.
	  // The size of the 2nd dimension is the same as the size of the given axis.
	  // The size of the 3rd dimension is the size of all the axes > the given axis.
	  //
	  // For example, for a 4D tensor with shape=[2, 3, 5, 4] and axis=2, the
	  // newShape would be: [2*3, 5, 4].
	  //
	  // Note that this is not the final output shape. This will be the shape for an
	  // intermediate TensorBuffer (see inputBuffer below) to allow us to extract
	  // values along the given axis. To demonstrate how it works, consider the
	  // following example:
	  //
	  // Input: a 3D tensor, with shape [1, 2, 3]
	  // [
	  //   [
	  //      [1,2,3],
	  //      [4,5,6]
	  //   ]
	  // ]
	  // Axis: 2 (the last axis).
	  // Along axis 2, we expect to extract 3 tensors: [1,4], [2,5], [3,6].
	  //
	  // For this example, newShape would be: [2, 3, 1], where 2 is calculated from
	  // 1*2. The re-shaped data would look like:
	  //
	  // [
	  //   [
	  //     [1], [2], [3]
	  //   ],
	  //   [
	  //     [4], [5], [6]
	  //   ]
	  // ]
	  //
	  // Then, we can construct a 3-level nested loop by the following dimension
	  // order to extract the values along the axis (dimension1):
	  // i: dimension1       // 0,1,2 (newShape[1])
	  //   m: dimension0     // 0,1   (newShape[0])
	  //     n: dimension2   // 0     (newShape[2])
	  //
	  //                       m, i, n
	  //                      ---------
	  // Iteration 0: data at [0, 0, 0] => "1"
	  // Iteration 1: data at [1, 0, 0] => "4"
	  // We got [1,4].
	  // Iteration 2: data at [0, 1, 0] => "2"
	  // Iteration 3: data at [1, 1, 0] => "5"
	  // We got [2,5].
	  // Iteration 4: data at [0, 2, 0] => "3"
	  // Iteration 5: data at [1, 2, 0] => "6"
	  // We got [3,6].
	  var newShape = [1, shape[0], 1];
	  for (var i = 0; i < $axis; i++) {
	    newShape[0] *= shape[i];
	  }
	  newShape[1] = shape[$axis];
	  for (var _i = $axis + 1; _i < shape.length; _i++) {
	    newShape[2] *= shape[_i];
	  }
	  // A map from unique elements (their string representations) to their values
	  // in "indices" (below).
	  var uniqueElements = new Map();
	  // The indices of each unique element in the original tensor along the given
	  // axis. It is 1D and has the same size as the given axis.
	  var indices = new Int32Array(shape[$axis]);
	  // Create a buffer so we can easily extract value at a given location.
	  var inputBuffer = new TensorBuffer(newShape, dtype, values);
	  // The indices along the given axis that have unique elements. This is a
	  // de-duped version of "indices" above.
	  var uniqueIndices = [];
	  var is1DTensor = newShape[0] === 1 && newShape[2] === 1;
	  for (var _i2 = 0; _i2 < shape[$axis]; _i2++) {
	    // Extract values along the axis.
	    var element = void 0;
	    if (is1DTensor) {
	      // Fast path for 1D tensor input.
	      element = values[_i2].toString();
	    } else {
	      var axisValues = [];
	      for (var m = 0; m < newShape[0]; m++) {
	        for (var n = 0; n < newShape[2]; n++) {
	          axisValues.push(inputBuffer.get(m, _i2, n));
	        }
	      }
	      element = axisValues.join(',');
	    }
	    // Dedup and update various indices.
	    var existingIndex = uniqueElements.get(element);
	    if (existingIndex != null) {
	      indices[_i2] = existingIndex;
	    } else {
	      var uniqueIndex = uniqueElements.size;
	      uniqueElements.set(element, uniqueIndex);
	      indices[_i2] = uniqueIndex;
	      uniqueIndices.push(_i2);
	    }
	  }
	  // Now we know where each of the unique elements are located along the axis
	  // (uniqueIndices). Extract them from input buffer and store them in the
	  // output buffer.
	  var outputTmpShape = newShape.slice();
	  outputTmpShape[1] = uniqueElements.size;
	  var outputBuffer = new TensorBuffer(outputTmpShape, dtype);
	  uniqueIndices.forEach(function (uniqueElementIndex, i) {
	    for (var _m = 0; _m < newShape[0]; _m++) {
	      for (var _n = 0; _n < newShape[2]; _n++) {
	        outputBuffer.set(inputBuffer.get(_m, uniqueElementIndex, _n), _m, i, _n);
	      }
	    }
	  });
	  // The output shape can be calculated from the input shape with the size of
	  // the given axis replaced by the number of unique elements along that axis.
	  var outputShape = shape.slice();
	  outputShape[$axis] = outputTmpShape[1];
	  return {
	    outputValues: outputBuffer.values,
	    outputShape: outputShape,
	    indices: indices
	  };
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */

	var shared = {
		__proto__: null,
		addImpl: addImpl,
		bincountImpl: bincountImpl,
		bincountReduceImpl: bincountReduceImpl,
		bitwiseAndImpl: bitwiseAndImpl,
		castImpl: castImpl,
		ceilImpl: ceilImpl,
		concatImpl: concatImpl$1,
		equalImpl: equalImpl,
		expImpl: expImpl,
		expm1Impl: expm1Impl,
		floorDivImpl: floorDivImpl,
		floorImpl: floorImpl,
		gatherNdImpl: gatherNdImpl,
		gatherV2Impl: gatherV2Impl,
		greaterEqualImpl: greaterEqualImpl,
		greaterImpl: greaterImpl,
		lessEqualImpl: lessEqualImpl,
		lessImpl: lessImpl,
		linSpaceImpl: linSpaceImpl,
		logImpl: logImpl,
		maxImpl: maxImpl$1,
		maximumImpl: maximumImpl,
		minimumImpl: minimumImpl,
		multiplyImpl: multiplyImpl,
		negImpl: negImpl,
		notEqualImpl: notEqualImpl,
		prodImpl: prodImpl,
		raggedGatherImpl: raggedGatherImpl,
		raggedRangeImpl: raggedRangeImpl,
		raggedTensorToTensorImpl: raggedTensorToTensorImpl,
		rangeImpl: rangeImpl,
		rsqrtImpl: rsqrtImpl,
		scatterImpl: scatterImpl,
		sigmoidImpl: sigmoidImpl,
		simpleAbsImpl: simpleAbsImpl,
		sliceImpl: sliceImpl,
		sparseFillEmptyRowsImpl: sparseFillEmptyRowsImpl,
		sparseReshapeImpl: sparseReshapeImpl,
		sparseSegmentReductionImpl: sparseSegmentReductionImpl,
		sqrtImpl: sqrtImpl,
		squaredDifferenceImpl: squaredDifferenceImpl,
		staticRegexReplaceImpl: staticRegexReplaceImpl,
		stridedSliceImpl: stridedSliceImpl,
		stringNGramsImpl: stringNGramsImpl,
		stringSplitImpl: stringSplitImpl,
		stringToHashBucketFastImpl: stringToHashBucketFastImpl,
		subImpl: subImpl,
		tileImpl: tileImpl,
		topKImpl: topKImpl,
		transposeImpl: transposeImpl$1,
		uniqueImpl: uniqueImpl
	};

	/** @license See the LICENSE file. */
	// This code is auto-generated, do not modify this file!
	var version$3 = '4.22.0';

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	// Side effects for default initialization of MathBackendCPU
	registerBackend('cpu', function () {
	  return new MathBackendCPU();
	}, 1 /* priority */);

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var elu$1 = unaryKernelFunc$1(Elu$1, function (xi) {
	  return xi >= 0 ? xi : Math.exp(xi) - 1;
	});
	var eluConfig$1 = {
	  kernelName: Elu$1,
	  backendName: 'cpu',
	  kernelFunc: elu$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function leakyRelu$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var alpha = attrs.alpha;
	  assertNotComplex$1([x], 'leakyRelu');
	  var xSize = sizeFromShape(x.shape);
	  var xVals = backend.data.get(x.dataId).values;
	  var outVals = getTypedArrayFromDType('float32', xSize);
	  for (var i = 0; i < xVals.length; i++) {
	    outVals[i] = xVals[i] < 0 ? alpha * xVals[i] : xVals[i];
	  }
	  return backend.makeTensorInfo(x.shape, 'float32', outVals);
	}
	var leakyReluConfig$1 = {
	  kernelName: LeakyRelu,
	  backendName: 'cpu',
	  kernelFunc: leakyRelu$1
	};

	var preluImpl = createSimpleBinaryKernelImpl(function (xValue, aValue) {
	  return xValue < 0 ? aValue * xValue : xValue;
	});
	function prelu$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var x = inputs.x,
	    alpha = inputs.alpha;
	  assertNotComplex$1([x, alpha], 'prelu');
	  var aVals = backend.data.get(x.dataId).values;
	  var bVals = backend.data.get(alpha.dataId).values;
	  var _preluImpl = preluImpl(x.shape, alpha.shape, aVals, bVals, 'float32'),
	    _preluImpl2 = _slicedToArray(_preluImpl, 2),
	    resultData = _preluImpl2[0],
	    resultShape = _preluImpl2[1];
	  return backend.makeTensorInfo(resultShape, 'float32', resultData);
	}
	var preluConfig$1 = {
	  kernelName: Prelu,
	  backendName: 'cpu',
	  kernelFunc: prelu$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var relu$1 = unaryKernelFunc$1(Relu$1, function (xi) {
	  return Math.max(0, xi);
	});
	var reluConfig$1 = {
	  kernelName: Relu$1,
	  backendName: 'cpu',
	  kernelFunc: relu$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var relu6$1 = unaryKernelFunc$1(Relu6$1, function (xi) {
	  return Math.min(Math.max(0, xi), 6);
	});
	var relu6Config$1 = {
	  kernelName: Relu6$1,
	  backendName: 'cpu',
	  kernelFunc: relu6$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function applyActivation(backend, x, activation, preluActivationWeights, leakyreluAlpha) {
	  if (activation === 'linear') {
	    return identity$1({
	      inputs: {
	        x: x
	      },
	      backend: backend
	    });
	  } else if (activation === 'relu') {
	    return relu$1({
	      inputs: {
	        x: x
	      },
	      backend: backend
	    });
	  } else if (activation === 'elu') {
	    return elu$1({
	      inputs: {
	        x: x
	      },
	      backend: backend
	    });
	  } else if (activation === 'relu6') {
	    return relu6$1({
	      inputs: {
	        x: x
	      },
	      backend: backend
	    });
	  } else if (activation === 'prelu') {
	    return prelu$1({
	      inputs: {
	        x: x,
	        alpha: preluActivationWeights
	      },
	      backend: backend
	    });
	  } else if (activation === 'leakyrelu') {
	    return leakyRelu$1({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        alpha: leakyreluAlpha
	      }
	    });
	  } else if (activation === 'sigmoid') {
	    return sigmoid$1({
	      inputs: {
	        x: x
	      },
	      backend: backend
	    });
	  }
	  throw new Error("Activation ".concat(activation, " has not been implemented for the CPU backend."));
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function reshape$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var shape = attrs.shape;
	  var xSize = sizeFromShape(x.shape);
	  var $shape = inferFromImplicitShape(shape, xSize);
	  var $xSize = sizeFromShape($shape);
	  assert$1(xSize === $xSize, function () {
	    return "The new shape (".concat($shape, ") has ").concat($xSize, " elements and the old ") + "shape (".concat(x.shape, ") has ").concat(xSize, " elements. The new shape and old ") + "shape must have the same number of elements.";
	  });
	  backend.incRef(x.dataId);
	  var xData = backend.data.get(x.dataId);
	  if (xData.complexTensorInfos != null) {
	    var real = xData.complexTensorInfos.real;
	    var imag = xData.complexTensorInfos.imag;
	    real.shape = $shape;
	    imag.shape = $shape;
	  }
	  return {
	    dataId: x.dataId,
	    shape: $shape,
	    dtype: x.dtype
	  };
	}
	var reshapeConfig$1 = {
	  kernelName: Reshape$1,
	  backendName: 'cpu',
	  kernelFunc: reshape$1
	};

	function batchMatMul$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var a = inputs.a,
	    b = inputs.b;
	  var transposeA = attrs.transposeA,
	    transposeB = attrs.transposeB;
	  assertNotComplex$1([a, b], 'matMul');
	  var aRank = a.shape.length;
	  var bRank = b.shape.length;
	  var innerShapeA = transposeA ? a.shape[aRank - 2] : a.shape[aRank - 1];
	  var innerShapeB = transposeB ? b.shape[bRank - 1] : b.shape[bRank - 2];
	  var outerShapeA = transposeA ? a.shape[aRank - 1] : a.shape[aRank - 2];
	  var outerShapeB = transposeB ? b.shape[bRank - 2] : b.shape[bRank - 1];
	  var outerDimsA = a.shape.slice(0, -2);
	  var outerDimsB = b.shape.slice(0, -2);
	  var batchDimA = sizeFromShape(outerDimsA);
	  var batchDimB = sizeFromShape(outerDimsB);
	  var outShapeOuterDims = assertAndGetBroadcastShape(a.shape.slice(0, -2), b.shape.slice(0, -2));
	  var outShape = outShapeOuterDims.concat([outerShapeA, outerShapeB]);
	  assert$1(innerShapeA === innerShapeB, function () {
	    return "Error in matMul: inner shapes (".concat(innerShapeA, ") and (") + "".concat(innerShapeB, ") of Tensors with shapes ").concat(a.shape, " and ") + "".concat(b.shape, " and transposeA=").concat(transposeA) + " and transposeB=".concat(transposeB, " must match.");
	  });
	  var a3dShape = transposeA ? [batchDimA, innerShapeA, outerShapeA] : [batchDimA, outerShapeA, innerShapeA];
	  var b3dShape = transposeB ? [batchDimB, outerShapeB, innerShapeB] : [batchDimB, innerShapeB, outerShapeB];
	  // The rest of the implementation is designed to operate on rank-3 tensors
	  var a3d = reshape$1({
	    inputs: {
	      x: a
	    },
	    backend: backend,
	    attrs: {
	      shape: a3dShape
	    }
	  });
	  var b3d = reshape$1({
	    inputs: {
	      x: b
	    },
	    backend: backend,
	    attrs: {
	      shape: b3dShape
	    }
	  });
	  var sharedDim = transposeA ? a3d.shape[1] : a3d.shape[2];
	  var leftDim = transposeA ? a3d.shape[2] : a3d.shape[1];
	  var rightDim = transposeB ? b3d.shape[1] : b3d.shape[2];
	  var batchDim = Math.max(batchDimA, batchDimB);
	  var a3dValues = backend.data.get(a3d.dataId).values;
	  var b3dValues = backend.data.get(b3d.dataId).values;
	  var a3dStrides = computeStrides(a3d.shape);
	  var b3dStrides = computeStrides(b3d.shape);
	  var _ref = transposeA ? [a3dStrides[0], 1, a3dStrides[1]] : [a3dStrides[0], a3dStrides[1], 1],
	    _ref2 = _slicedToArray(_ref, 3),
	    aBatch = _ref2[0],
	    aOuterStep = _ref2[1],
	    aInnerStep = _ref2[2];
	  var _ref3 = transposeB ? [1, b3dStrides[1], b3dStrides[0]] : [b3dStrides[1], 1, b3dStrides[0]],
	    _ref4 = _slicedToArray(_ref3, 3),
	    bInnerStep = _ref4[0],
	    bOuterStep = _ref4[1],
	    bBatch = _ref4[2];
	  var size = leftDim * rightDim;
	  var result = buffer([batchDim, leftDim, rightDim], a3d.dtype);
	  var resVals = result.values;
	  var blockSize = backend.blockSize;
	  for (var bi = 0; bi < batchDim; bi++) {
	    var batchIndexA = bi % batchDimA;
	    var batchIndexB = bi % batchDimB;
	    for (var i0 = 0; i0 < leftDim; i0 += blockSize) {
	      // for when blockSize doesn't evenly divide the input
	      var iBlock = Math.min(i0 + blockSize, leftDim);
	      for (var j0 = 0; j0 < rightDim; j0 += blockSize) {
	        var jBlock = Math.min(j0 + blockSize, rightDim);
	        for (var k0 = 0; k0 < sharedDim; k0 += blockSize) {
	          var kBlock = Math.min(k0 + blockSize, sharedDim);
	          for (var i = i0; i < iBlock; i++) {
	            for (var j = j0; j < jBlock; j++) {
	              var sum = 0.0;
	              for (var k = k0; k < kBlock; k++) {
	                var aVal =
	                // tslint:disable-next-line: max-line-length
	                a3dValues[batchIndexA * aBatch + i * aOuterStep + k * aInnerStep];
	                var bVal =
	                // tslint:disable-next-line: max-line-length
	                b3dValues[k * bInnerStep + j * bOuterStep + batchIndexB * bBatch];
	                sum += aVal * bVal;
	              }
	              resVals[bi * size + (i * rightDim + j)] += sum;
	            }
	          }
	        }
	      }
	    }
	  }
	  backend.disposeIntermediateTensorInfo(a3d);
	  backend.disposeIntermediateTensorInfo(b3d);
	  // set correct shape on output.
	  return backend.makeTensorInfo(outShape, result.dtype, result.values);
	}
	var batchMatMulConfig$1 = {
	  kernelName: BatchMatMul,
	  backendName: 'cpu',
	  kernelFunc: batchMatMul$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function _fusedMatMul$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var a = inputs.a,
	    b = inputs.b,
	    bias = inputs.bias,
	    preluActivationWeights = inputs.preluActivationWeights;
	  var transposeA = attrs.transposeA,
	    transposeB = attrs.transposeB,
	    activation = attrs.activation,
	    leakyreluAlpha = attrs.leakyreluAlpha;
	  var current;
	  var addRes;
	  var activationRes;
	  var intermediates = [];
	  var matMulRes = batchMatMul$1({
	    inputs: {
	      a: a,
	      b: b
	    },
	    attrs: {
	      transposeA: transposeA,
	      transposeB: transposeB
	    },
	    backend: backend
	  });
	  current = matMulRes;
	  if (bias) {
	    addRes = add({
	      inputs: {
	        a: current,
	        b: bias
	      },
	      backend: backend
	    });
	    intermediates.push(current);
	    current = addRes;
	  }
	  if (activation) {
	    activationRes = applyActivation(backend, current, activation, preluActivationWeights, leakyreluAlpha);
	    intermediates.push(current);
	    current = activationRes;
	  }
	  for (var _i = 0, _intermediates = intermediates; _i < _intermediates.length; _i++) {
	    var i = _intermediates[_i];
	    backend.disposeIntermediateTensorInfo(i);
	  }
	  return current;
	}
	var _fusedMatMulConfig$1 = {
	  kernelName: _FusedMatMul,
	  backendName: 'cpu',
	  kernelFunc: _fusedMatMul$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var acos$1 = unaryKernelFunc$1(Acos, function (xi) {
	  return Math.acos(xi);
	});
	var acosConfig$1 = {
	  kernelName: Acos,
	  backendName: 'cpu',
	  kernelFunc: acos$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var acosh$1 = unaryKernelFunc$1(Acosh, function (xi) {
	  return Math.acosh(xi);
	});
	var acoshConfig$1 = {
	  kernelName: Acosh,
	  backendName: 'cpu',
	  kernelFunc: acosh$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function addN$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var tensors = inputs;
	  assertNotComplex$1(inputs, 'addN');
	  var vals = tensors.map(function (t) {
	    return backend.data.get(t.dataId).values;
	  });
	  var outBuf = buffer(tensors[0].shape, tensors[0].dtype);
	  var outVals = outBuf.values;
	  for (var i = 0; i < tensors.length; i++) {
	    var currVals = vals[i];
	    for (var j = 0; j < outVals.length; j++) {
	      outVals[j] += currVals[j];
	    }
	  }
	  return backend.makeTensorInfo(outBuf.shape, outBuf.dtype, outBuf.values);
	}
	var addNConfig$1 = {
	  kernelName: AddN,
	  backendName: 'cpu',
	  kernelFunc: addN$1
	};

	function all$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis,
	    keepDims = attrs.keepDims;
	  assertNotComplex$1(x, 'all');
	  var origAxes = parseAxisParam(axis, x.shape);
	  var axes = origAxes;
	  var permutedAxes = getAxesPermutation(axes, x.shape.length);
	  var $x = x;
	  if (permutedAxes != null) {
	    $x = transpose$1({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        perm: permutedAxes
	      }
	    });
	    axes = getInnerMostAxes(axes.length, x.shape.length);
	  }
	  assertAxesAreInnerMostDims('all', axes, $x.shape.length);
	  var _backend_util$compute = computeOutAndReduceShapes($x.shape, axes),
	    _backend_util$compute2 = _slicedToArray(_backend_util$compute, 2),
	    outShape = _backend_util$compute2[0],
	    reduceShape = _backend_util$compute2[1];
	  var reduceSize = sizeFromShape(reduceShape);
	  var vals = makeZerosTypedArray(sizeFromShape(outShape), $x.dtype);
	  var aVals = backend.data.get($x.dataId).values;
	  for (var i = 0; i < vals.length; ++i) {
	    var offset = i * reduceSize;
	    var _all = aVals[offset];
	    for (var j = 0; j < reduceSize; ++j) {
	      var value = aVals[offset + j];
	      _all = _all && value;
	    }
	    vals[i] = _all;
	  }
	  if (permutedAxes != null) {
	    backend.disposeIntermediateTensorInfo($x);
	  }
	  var result = backend.makeTensorInfo(outShape, $x.dtype, vals);
	  if (keepDims) {
	    var expandedShape = expandShapeToKeepDim(outShape, origAxes);
	    var reshapedResult = reshape$1({
	      inputs: {
	        x: result
	      },
	      backend: backend,
	      attrs: {
	        shape: expandedShape
	      }
	    });
	    backend.disposeIntermediateTensorInfo(result);
	    return reshapedResult;
	  }
	  return result;
	}
	var allConfig$1 = {
	  kernelName: All,
	  backendName: 'cpu',
	  kernelFunc: all$1
	};

	function any$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis,
	    keepDims = attrs.keepDims;
	  assertNotComplex$1(x, 'any');
	  var origAxes = parseAxisParam(axis, x.shape);
	  var axes = origAxes;
	  var permutedAxes = getAxesPermutation(axes, x.shape.length);
	  var $x = x;
	  if (permutedAxes != null) {
	    $x = transpose$1({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        perm: permutedAxes
	      }
	    });
	    axes = getInnerMostAxes(axes.length, x.shape.length);
	  }
	  assertAxesAreInnerMostDims('any', axes, $x.shape.length);
	  var _backend_util$compute = computeOutAndReduceShapes($x.shape, axes),
	    _backend_util$compute2 = _slicedToArray(_backend_util$compute, 2),
	    outShape = _backend_util$compute2[0],
	    reduceShape = _backend_util$compute2[1];
	  var reduceSize = sizeFromShape(reduceShape);
	  var vals = makeZerosTypedArray(sizeFromShape(outShape), $x.dtype);
	  var aVals = backend.data.get($x.dataId).values;
	  for (var i = 0; i < vals.length; ++i) {
	    var offset = i * reduceSize;
	    var anyVal = aVals[offset];
	    for (var j = 0; j < reduceSize; ++j) {
	      var value = aVals[offset + j];
	      anyVal = anyVal || value;
	    }
	    vals[i] = anyVal;
	  }
	  if (permutedAxes != null) {
	    backend.disposeIntermediateTensorInfo($x);
	  }
	  var result = backend.makeTensorInfo(outShape, $x.dtype, vals);
	  if (keepDims) {
	    var expandedShape = expandShapeToKeepDim(outShape, origAxes);
	    var reshapedResult = reshape$1({
	      inputs: {
	        x: result
	      },
	      backend: backend,
	      attrs: {
	        shape: expandedShape
	      }
	    });
	    backend.disposeIntermediateTensorInfo(result);
	    return reshapedResult;
	  }
	  return result;
	}
	var anyConfig$1 = {
	  kernelName: Any,
	  backendName: 'cpu',
	  kernelFunc: any$1
	};

	function argMax$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis;
	  assertNotComplex$1(x, 'argMax');
	  var axes = parseAxisParam(axis, x.shape);
	  var permutedAxes = getAxesPermutation(axes, x.shape.length);
	  var $x = x;
	  var intermediateTensorInfos = [];
	  if (permutedAxes != null) {
	    $x = transpose$1({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        perm: permutedAxes
	      }
	    });
	    intermediateTensorInfos.push($x);
	    axes = getInnerMostAxes(axes.length, $x.shape.length);
	  }
	  axes = [axes[0]];
	  assertAxesAreInnerMostDims('argMax', axes, $x.shape.length);
	  var _backend_util$compute = computeOutAndReduceShapes($x.shape, axes),
	    _backend_util$compute2 = _slicedToArray(_backend_util$compute, 2),
	    outShape = _backend_util$compute2[0],
	    reduceShape = _backend_util$compute2[1];
	  var outSize = sizeFromShape(outShape);
	  var vals = makeZerosTypedArray(outSize, 'int32');
	  var reduceSize = sizeFromShape(reduceShape);
	  var aVals = backend.data.get($x.dataId).values;
	  for (var i = 0; i < vals.length; ++i) {
	    var offset = i * reduceSize;
	    var max = aVals[offset];
	    var maxIndex = 0;
	    for (var j = 0; j < reduceSize; ++j) {
	      var value = aVals[offset + j];
	      if (value > max) {
	        max = value;
	        maxIndex = j;
	      }
	    }
	    vals[i] = maxIndex;
	  }
	  intermediateTensorInfos.forEach(function (t) {
	    return backend.disposeIntermediateTensorInfo(t);
	  });
	  return backend.makeTensorInfo(outShape, 'int32', vals);
	}
	var argMaxConfig$1 = {
	  kernelName: ArgMax,
	  backendName: 'cpu',
	  kernelFunc: argMax$1
	};

	function argMin$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis;
	  assertNotComplex$1(x, 'argMin');
	  var axes = parseAxisParam(axis, x.shape);
	  var permutedAxes = getAxesPermutation(axes, x.shape.length);
	  var $x = x;
	  var intermediateTensorInfos = [];
	  if (permutedAxes != null) {
	    $x = transpose$1({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        perm: permutedAxes
	      }
	    });
	    intermediateTensorInfos.push($x);
	    axes = getInnerMostAxes(axes.length, $x.shape.length);
	  }
	  axes = [axes[0]];
	  assertAxesAreInnerMostDims('argMin', axes, $x.shape.length);
	  var _backend_util$compute = computeOutAndReduceShapes($x.shape, axes),
	    _backend_util$compute2 = _slicedToArray(_backend_util$compute, 2),
	    outShape = _backend_util$compute2[0],
	    reduceShape = _backend_util$compute2[1];
	  var outSize = sizeFromShape(outShape);
	  var vals = makeZerosTypedArray(outSize, 'int32');
	  var reduceSize = sizeFromShape(reduceShape);
	  var aVals = backend.data.get($x.dataId).values;
	  for (var i = 0; i < vals.length; ++i) {
	    var offset = i * reduceSize;
	    var min = aVals[offset];
	    var minIndex = 0;
	    for (var j = 0; j < reduceSize; ++j) {
	      var value = aVals[offset + j];
	      if (value < min) {
	        min = value;
	        minIndex = j;
	      }
	    }
	    vals[i] = minIndex;
	  }
	  intermediateTensorInfos.forEach(function (t) {
	    return backend.disposeIntermediateTensorInfo(t);
	  });
	  return backend.makeTensorInfo(outShape, 'int32', vals);
	}
	var argMinConfig$1 = {
	  kernelName: ArgMin,
	  backendName: 'cpu',
	  kernelFunc: argMin$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var asin$1 = unaryKernelFunc$1(Asin, function (xi) {
	  return Math.asin(xi);
	});
	var asinConfig$1 = {
	  kernelName: Asin,
	  backendName: 'cpu',
	  kernelFunc: asin$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var asinh$1 = unaryKernelFunc$1(Asinh, function (xi) {
	  return Math.asinh(xi);
	});
	var asinhConfig$1 = {
	  kernelName: Asinh,
	  backendName: 'cpu',
	  kernelFunc: asinh$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var atan$1 = unaryKernelFunc$1(Atan, function (xi) {
	  return Math.atan(xi);
	});
	var atanConfig$1 = {
	  kernelName: Atan,
	  backendName: 'cpu',
	  kernelFunc: atan$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var atan2Impl = createSimpleBinaryKernelImpl(function (aValue, bValue) {
	  return Math.atan2(aValue, bValue);
	});
	var atan2$1 = binaryKernelFunc$1(Atan2, atan2Impl);
	var atan2Config$1 = {
	  kernelName: Atan2,
	  backendName: 'cpu',
	  kernelFunc: atan2$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var atanh$1 = unaryKernelFunc$1(Atanh, function (xi) {
	  return Math.atanh(xi);
	});
	var atanhConfig$1 = {
	  kernelName: Atanh,
	  backendName: 'cpu',
	  kernelFunc: atanh$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function pool(xValues, xShape, dtype, strides, convInfo, poolType) {
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var dilationHeight = convInfo.dilationHeight;
	  var dilationWidth = convInfo.dilationWidth;
	  var effectiveFilterHeight = convInfo.effectiveFilterHeight;
	  var effectiveFilterWidth = convInfo.effectiveFilterWidth;
	  var padTop = convInfo.padInfo.top;
	  var padLeft = convInfo.padInfo.left;
	  var initialValue = poolType === 'max' ? Number.NEGATIVE_INFINITY : Number.POSITIVE_INFINITY;
	  var output = buffer(convInfo.outShape, dtype);
	  var outputVals = output.values;
	  var outputBatchStrides = convInfo.outShape[1] * convInfo.outShape[2] * convInfo.outShape[3];
	  var outputRowStrides = convInfo.outShape[2] * convInfo.outShape[3];
	  var outputColStrides = convInfo.outShape[3];
	  for (var b = 0; b < convInfo.batchSize; ++b) {
	    var outputBatchOffset = b * outputBatchStrides;
	    var inputBatchOffset = b * strides[0];
	    for (var d = 0; d < convInfo.inChannels; ++d) {
	      for (var yR = 0; yR < convInfo.outHeight; ++yR) {
	        var xRCorner = yR * strideHeight - padTop;
	        var xRMin = Math.max(0, xRCorner);
	        var xRMax = Math.min(convInfo.inHeight, effectiveFilterHeight + xRCorner);
	        var outputRowOffset = outputBatchOffset + yR * outputRowStrides;
	        for (var yC = 0; yC < convInfo.outWidth; ++yC) {
	          var xCCorner = yC * strideWidth - padLeft;
	          var xCMin = Math.max(0, xCCorner);
	          var xCMax = Math.min(convInfo.inWidth, effectiveFilterWidth + xCCorner);
	          var minMaxValue = initialValue;
	          var avgValue = 0;
	          var count = 0;
	          for (var xR = xRMin; xR < xRMax; xR += dilationHeight) {
	            var xROffset = inputBatchOffset + xR * strides[1];
	            for (var xC = xCMin; xC < xCMax; xC += dilationWidth) {
	              var xCOffset = xROffset + xC * strides[2];
	              var pixel = xValues[xCOffset + d];
	              if (poolType === 'max' && pixel > minMaxValue) {
	                minMaxValue = pixel;
	              } else if (poolType === 'avg') {
	                avgValue += pixel;
	                count++;
	              }
	            }
	            if (isNaN(minMaxValue)) {
	              break;
	            }
	          }
	          var outputOffset = outputRowOffset + yC * outputColStrides + d;
	          outputVals[outputOffset] = poolType === 'avg' ? avgValue / count : minMaxValue;
	        }
	      }
	    }
	  }
	  return output;
	}
	function maxPoolPositions(xValues, xShape, dtype, convInfo) {
	  var flattenPositions = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
	  var includeBatchInIndex = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : false;
	  var maxPositions = buffer(convInfo.outShape, 'int32');
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var dilationHeight = convInfo.dilationHeight;
	  var dilationWidth = convInfo.dilationWidth;
	  var effectiveFilterHeight = convInfo.effectiveFilterHeight;
	  var effectiveFilterWidth = convInfo.effectiveFilterWidth;
	  var padTop = convInfo.padInfo.top;
	  var padLeft = convInfo.padInfo.left;
	  var xBuf = buffer(xShape, dtype, xValues);
	  for (var b = 0; b < convInfo.batchSize; ++b) {
	    for (var d = 0; d < convInfo.inChannels; ++d) {
	      for (var yR = 0; yR < convInfo.outHeight; ++yR) {
	        var xRCorner = yR * strideHeight - padTop;
	        var xRMin = xRCorner;
	        while (xRMin < 0) {
	          xRMin += dilationHeight;
	        }
	        // const xRMin = Math.max(0, xRCorner);
	        var xRMax = Math.min(convInfo.inHeight, effectiveFilterHeight + xRCorner);
	        for (var yC = 0; yC < convInfo.outWidth; ++yC) {
	          var xCCorner = yC * strideWidth - padLeft;
	          var xCMin = xCCorner;
	          while (xCMin < 0) {
	            xCMin += dilationWidth;
	          }
	          var xCMax = Math.min(convInfo.inWidth, effectiveFilterWidth + xCCorner);
	          var maxValue = Number.NEGATIVE_INFINITY;
	          var maxPosition = -1;
	          for (var xR = xRMin; xR < xRMax; xR += dilationHeight) {
	            var wR = xR - xRCorner;
	            for (var xC = xCMin; xC < xCMax; xC += dilationWidth) {
	              var wC = xC - xCCorner;
	              // For some reason, disable-next-line is not working
	              // TODO(mattsoulanille): Remove this when switching to TS5.
	              /* tslint:disable: no-unnecessary-type-assertion */
	              var pixel = xBuf.get(b, xR, xC, d);
	              if (pixel > maxValue) {
	                maxValue = pixel;
	                if (flattenPositions) {
	                  maxPosition = includeBatchInIndex ? ((b * convInfo.inHeight + xR) * convInfo.inWidth + xC) * convInfo.inChannels + d : (xR * convInfo.inWidth + xC) * convInfo.inChannels + d;
	                } else {
	                  maxPosition = wR * effectiveFilterWidth + wC;
	                }
	              }
	            }
	          }
	          maxPositions.set(maxPosition, b, yR, yC, d);
	        }
	      }
	    }
	  }
	  return maxPositions;
	}
	function pool3d(xValues, xShape, dtype, strides, convInfo, poolType) {
	  var strideDepth = convInfo.strideDepth;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var dilationDepth = convInfo.dilationDepth;
	  var dilationHeight = convInfo.dilationHeight;
	  var dilationWidth = convInfo.dilationWidth;
	  var effectiveFilterDepth = convInfo.effectiveFilterDepth;
	  var effectiveFilterHeight = convInfo.effectiveFilterHeight;
	  var effectiveFilterWidth = convInfo.effectiveFilterWidth;
	  var padFront = convInfo.padInfo.front;
	  var padTop = convInfo.padInfo.top;
	  var padLeft = convInfo.padInfo.left;
	  var initialValue = poolType === 'max' ? Number.NEGATIVE_INFINITY : Number.POSITIVE_INFINITY;
	  var output = buffer(convInfo.outShape, dtype);
	  var outputVals = output.values;
	  var outputBatchStrides = convInfo.outShape[1] * convInfo.outShape[2] * convInfo.outShape[3] * convInfo.outShape[4];
	  var outputDepthStrides = convInfo.outShape[2] * convInfo.outShape[3] * convInfo.outShape[4];
	  var outputRowStrides = convInfo.outShape[3] * convInfo.outShape[4];
	  var outputColStrides = convInfo.outShape[4];
	  for (var batch = 0; batch < convInfo.batchSize; ++batch) {
	    var outputBatchOffset = batch * outputBatchStrides;
	    var inputBatchOffset = batch * strides[0];
	    for (var channel = 0; channel < convInfo.inChannels; ++channel) {
	      for (var yDepth = 0; yDepth < convInfo.outDepth; ++yDepth) {
	        var xDepthCorner = yDepth * strideDepth - padFront;
	        var xDepthMin = xDepthCorner;
	        while (xDepthMin < 0) {
	          xDepthMin += dilationDepth;
	        }
	        var xDepthMax = Math.min(convInfo.inDepth, effectiveFilterDepth + xDepthCorner);
	        var outputDepthOffset = outputBatchOffset + yDepth * outputDepthStrides;
	        for (var yRow = 0; yRow < convInfo.outHeight; ++yRow) {
	          var xRowCorner = yRow * strideHeight - padTop;
	          var xRowMin = xRowCorner;
	          while (xRowMin < 0) {
	            xRowMin += dilationHeight;
	          }
	          var xRowMax = Math.min(convInfo.inHeight, effectiveFilterHeight + xRowCorner);
	          var outputRowOffset = outputDepthOffset + yRow * outputRowStrides;
	          for (var yCol = 0; yCol < convInfo.outWidth; ++yCol) {
	            var xColCorner = yCol * strideWidth - padLeft;
	            var xColMin = xColCorner;
	            while (xColMin < 0) {
	              xColMin += dilationWidth;
	            }
	            var xColMax = Math.min(convInfo.inWidth, effectiveFilterWidth + xColCorner);
	            // Shader code begins
	            var outputColOffset = outputRowOffset + yCol * outputColStrides;
	            var minMaxValue = initialValue;
	            var avgValue = 0;
	            var count = 0;
	            for (var xDepth = xDepthMin; xDepth < xDepthMax; xDepth += dilationDepth) {
	              var xDepthOffset = inputBatchOffset + xDepth * strides[1];
	              for (var xRow = xRowMin; xRow < xRowMax; xRow += dilationHeight) {
	                var xRowOffset = xDepthOffset + xRow * strides[2];
	                for (var xCol = xColMin; xCol < xColMax; xCol += dilationWidth) {
	                  var xColOffset = xRowOffset + xCol * strides[3];
	                  var pixel = xValues[xColOffset + channel];
	                  if (poolType === 'max' && pixel > minMaxValue) {
	                    minMaxValue = pixel;
	                  } else if (poolType === 'avg') {
	                    avgValue += pixel;
	                    count++;
	                  }
	                  if (isNaN(minMaxValue)) {
	                    break;
	                  }
	                }
	                if (isNaN(minMaxValue)) {
	                  break;
	                }
	              }
	              if (isNaN(minMaxValue)) {
	                break;
	              }
	            }
	            var outputOffset = outputColOffset + channel;
	            outputVals[outputOffset] = poolType === 'avg' ? avgValue / Math.max(count, 1) : minMaxValue;
	          }
	        }
	      }
	    }
	  }
	  return output;
	}
	function maxPool3dPositions(xBuf, convInfo) {
	  var maxPositions = buffer(convInfo.outShape, 'int32');
	  var strideDepth = convInfo.strideDepth;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var dilationDepth = convInfo.dilationDepth;
	  var dilationHeight = convInfo.dilationHeight;
	  var dilationWidth = convInfo.dilationWidth;
	  var effectiveFilterDepth = convInfo.effectiveFilterDepth;
	  var effectiveFilterHeight = convInfo.effectiveFilterHeight;
	  var effectiveFilterWidth = convInfo.effectiveFilterWidth;
	  var padFront = convInfo.padInfo.front;
	  var padTop = convInfo.padInfo.top;
	  var padLeft = convInfo.padInfo.left;
	  for (var batch = 0; batch < convInfo.batchSize; ++batch) {
	    for (var channel = 0; channel < convInfo.inChannels; ++channel) {
	      for (var yDepth = 0; yDepth < convInfo.outDepth; ++yDepth) {
	        var xDepthCorner = yDepth * strideDepth - padFront;
	        var xDepthMin = xDepthCorner;
	        while (xDepthMin < 0) {
	          xDepthMin += dilationDepth;
	        }
	        var xDepthMax = Math.min(convInfo.inDepth, effectiveFilterDepth + xDepthCorner);
	        for (var yRow = 0; yRow < convInfo.outHeight; ++yRow) {
	          var xRowCorner = yRow * strideHeight - padTop;
	          var xRowMin = xRowCorner;
	          while (xRowMin < 0) {
	            xRowMin += dilationHeight;
	          }
	          var xRowMax = Math.min(convInfo.inHeight, effectiveFilterHeight + xRowCorner);
	          for (var yCol = 0; yCol < convInfo.outWidth; ++yCol) {
	            var xColCorner = yCol * strideWidth - padLeft;
	            var xColMin = xColCorner;
	            while (xColMin < 0) {
	              xColMin += dilationWidth;
	            }
	            var xColMax = Math.min(convInfo.inWidth, effectiveFilterWidth + xColCorner);
	            // Shader code begins
	            var maxValue = Number.NEGATIVE_INFINITY;
	            var maxPosition = -1;
	            for (var xDepth = xDepthMin; xDepth < xDepthMax; xDepth += dilationDepth) {
	              var wDepth = xDepth - xDepthCorner;
	              for (var xRow = xRowMin; xRow < xRowMax; xRow += dilationHeight) {
	                var wRow = xRow - xRowCorner;
	                for (var xCol = xColMin; xCol < xColMax; xCol += dilationWidth) {
	                  var wCol = xCol - xColCorner;
	                  var pixel = xBuf.get(batch, xDepth, xRow, xCol, channel);
	                  if (pixel >= maxValue) {
	                    maxValue = pixel;
	                    maxPosition = wDepth * effectiveFilterHeight * effectiveFilterWidth + wRow * effectiveFilterHeight + wCol;
	                  }
	                }
	              }
	            }
	            maxPositions.set(maxPosition, batch, yDepth, yRow, yCol, channel);
	          }
	        }
	      }
	    }
	  }
	  return maxPositions;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function avgPool$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  assertNotComplex$1(x, 'avgPool');
	  var filterSize = attrs.filterSize,
	    strides = attrs.strides,
	    pad = attrs.pad,
	    dimRoundingMode = attrs.dimRoundingMode;
	  var dilations = 1;
	  assert$1(eitherStridesOrDilationsAreOne(strides, dilations), function () {
	    return 'Error in avgPool: Either strides or dilations must be 1. ' + "Got strides ".concat(strides, " and dilations '").concat(dilations, "'");
	  });
	  var convInfo = computePool2DInfo(x.shape, filterSize, strides, dilations, pad, dimRoundingMode);
	  var res;
	  if (convInfo.filterWidth === 1 && convInfo.filterHeight === 1 && arraysEqual(convInfo.inShape, convInfo.outShape)) {
	    res = identity$1({
	      inputs: {
	        x: x
	      },
	      backend: backend
	    });
	  } else {
	    var xValues = backend.data.get(x.dataId).values;
	    var _strides = computeStrides(x.shape);
	    var buffer = pool(xValues, x.shape, x.dtype, _strides, convInfo, 'avg');
	    res = backend.makeTensorInfo(convInfo.outShape, x.dtype, buffer.values);
	  }
	  return res;
	}
	var avgPoolConfig$1 = {
	  kernelName: AvgPool,
	  backendName: 'cpu',
	  kernelFunc: avgPool$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function avgPool3D$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var filterSize = attrs.filterSize,
	    strides = attrs.strides,
	    pad = attrs.pad,
	    dimRoundingMode = attrs.dimRoundingMode,
	    dataFormat = attrs.dataFormat;
	  assertNotComplex$1(x, 'avgPool3d');
	  var convInfo = computePool3DInfo(x.shape, filterSize, strides, 1 /* dilations */, pad, dimRoundingMode, dataFormat);
	  var xValues = backend.data.get(x.dataId).values;
	  var outBuf = pool3d(xValues, x.shape, x.dtype, computeStrides(x.shape), convInfo, 'avg');
	  return backend.makeTensorInfo(outBuf.shape, 'float32', outBuf.values);
	}
	var avgPool3DConfig$1 = {
	  kernelName: AvgPool3D,
	  backendName: 'cpu',
	  kernelFunc: avgPool3D$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function avgPool3DGrad$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var dy = inputs.dy,
	    input = inputs.input;
	  var filterSize = attrs.filterSize,
	    strides = attrs.strides,
	    pad = attrs.pad,
	    dimRoundingMode = attrs.dimRoundingMode;
	  assertNotComplex$1([dy, input], 'avgPool3DGrad');
	  var convInfo = computePool3DInfo(input.shape, filterSize, strides, 1 /* dilations */, pad, dimRoundingMode);
	  var strideDepth = convInfo.strideDepth;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var filterDepth = convInfo.filterDepth;
	  var filterHeight = convInfo.filterHeight;
	  var filterWidth = convInfo.filterWidth;
	  var dilationDepth = convInfo.dilationDepth;
	  var dilationHeight = convInfo.dilationHeight;
	  var dilationWidth = convInfo.dilationWidth;
	  var effectiveFilterDepth = convInfo.effectiveFilterDepth;
	  var effectiveFilterHeight = convInfo.effectiveFilterHeight;
	  var effectiveFilterWidth = convInfo.effectiveFilterWidth;
	  var padFront = effectiveFilterDepth - 1 - convInfo.padInfo.front;
	  var padLeft = effectiveFilterWidth - 1 - convInfo.padInfo.left;
	  var padTop = effectiveFilterHeight - 1 - convInfo.padInfo.top;
	  var dx = buffer(input.shape, 'float32');
	  var avgMultiplier = 1 / (filterDepth * filterHeight * filterWidth);
	  var dyBuf = backend.bufferSync(dy);
	  for (var batch = 0; batch < convInfo.batchSize; ++batch) {
	    for (var channel = 0; channel < convInfo.inChannels; ++channel) {
	      for (var dxDepth = 0; dxDepth < convInfo.inDepth; ++dxDepth) {
	        for (var dxRow = 0; dxRow < convInfo.inHeight; ++dxRow) {
	          for (var dxCol = 0; dxCol < convInfo.inWidth; ++dxCol) {
	            // Shader code begins.
	            var dyDepthCorner = dxDepth - padFront;
	            var dyRowCorner = dxRow - padTop;
	            var dyColCorner = dxCol - padLeft;
	            var dotProd = 0;
	            for (var wDepth = 0; wDepth < effectiveFilterDepth; wDepth += dilationDepth) {
	              var dyDepth = (dyDepthCorner + wDepth) / strideDepth;
	              if (dyDepth < 0 || dyDepth >= convInfo.outDepth || Math.floor(dyDepth) !== dyDepth) {
	                continue;
	              }
	              for (var wRow = 0; wRow < effectiveFilterHeight; wRow += dilationHeight) {
	                var dyRow = (dyRowCorner + wRow) / strideHeight;
	                if (dyRow < 0 || dyRow >= convInfo.outHeight || Math.floor(dyRow) !== dyRow) {
	                  continue;
	                }
	                for (var wCol = 0; wCol < effectiveFilterWidth; wCol += dilationWidth) {
	                  var dyCol = (dyColCorner + wCol) / strideWidth;
	                  if (dyCol < 0 || dyCol >= convInfo.outWidth || Math.floor(dyCol) !== dyCol) {
	                    continue;
	                  }
	                  var pixel = dyBuf.get(batch, dyDepth, dyRow, dyCol, channel);
	                  dotProd += pixel;
	                }
	              }
	            }
	            dx.set(dotProd * avgMultiplier, batch, dxDepth, dxRow, dxCol, channel);
	          }
	        }
	      }
	    }
	  }
	  return backend.makeTensorInfo(dx.shape, dx.dtype, dx.values);
	}
	var avgPool3DGradConfig$1 = {
	  kernelName: AvgPool3DGrad,
	  backendName: 'cpu',
	  kernelFunc: avgPool3DGrad$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function avgPoolGrad$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var dy = inputs.dy,
	    input = inputs.input;
	  var x = input;
	  assertNotComplex$1([dy, input], 'avgPoolGrad');
	  var filterSize = attrs.filterSize,
	    strides = attrs.strides,
	    pad = attrs.pad;
	  var convInfo = computePool2DInfo(x.shape, filterSize, strides, 1 /* dilations */, pad);
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var filterHeight = convInfo.filterHeight;
	  var filterWidth = convInfo.filterWidth;
	  var dilationHeight = convInfo.dilationHeight;
	  var dilationWidth = convInfo.dilationWidth;
	  var effectiveFilterHeight = convInfo.effectiveFilterHeight;
	  var effectiveFilterWidth = convInfo.effectiveFilterWidth;
	  var padLeft = effectiveFilterWidth - 1 - convInfo.padInfo.left;
	  var padTop = effectiveFilterHeight - 1 - convInfo.padInfo.top;
	  var dx = buffer(x.shape, 'float32');
	  var avgMultiplier = 1 / (filterHeight * filterWidth);
	  var dyData = backend.data.get(dy.dataId).values;
	  var dyBuf = buffer(dy.shape, 'float32', dyData);
	  for (var b = 0; b < convInfo.batchSize; ++b) {
	    for (var d = 0; d < convInfo.inChannels; ++d) {
	      for (var dxR = 0; dxR < convInfo.inHeight; ++dxR) {
	        for (var dxC = 0; dxC < convInfo.inWidth; ++dxC) {
	          // Shader code begins.
	          var dyRCorner = dxR - padTop;
	          var dyCCorner = dxC - padLeft;
	          var dotProd = 0;
	          for (var wR = 0; wR < effectiveFilterHeight; wR += dilationHeight) {
	            var dyR = (dyRCorner + wR) / strideHeight;
	            if (dyR < 0 || dyR >= convInfo.outHeight || Math.floor(dyR) !== dyR) {
	              continue;
	            }
	            for (var wC = 0; wC < effectiveFilterWidth; wC += dilationWidth) {
	              var dyC = (dyCCorner + wC) / strideWidth;
	              if (dyC < 0 || dyC >= convInfo.outWidth || Math.floor(dyC) !== dyC) {
	                continue;
	              }
	              var pixel = dyBuf.get(b, dyR, dyC, d);
	              dotProd += pixel;
	            }
	          }
	          dx.set(dotProd * avgMultiplier, b, dxR, dxC, d);
	        }
	      }
	    }
	  }
	  return backend.makeTensorInfo(dx.shape, dx.dtype, dx.values);
	}
	var avgPoolGradConfig$1 = {
	  kernelName: AvgPoolGrad,
	  backendName: 'cpu',
	  kernelFunc: avgPoolGrad$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function batchNorm$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    scale = inputs.scale,
	    offset = inputs.offset,
	    mean = inputs.mean,
	    variance = inputs.variance;
	  assert$1(mean.shape.length === variance.shape.length, function () {
	    return 'Batch normalization gradient requires mean and variance to have ' + 'equal ranks.';
	  });
	  assert$1(offset == null || mean.shape.length === offset.shape.length, function () {
	    return 'Batch normalization gradient requires mean and offset to have ' + 'equal ranks.';
	  });
	  assert$1(scale == null || mean.shape.length === scale.shape.length, function () {
	    return 'Batch normalization gradient requires mean and scale to have ' + 'equal ranks.';
	  });
	  assertNotComplex$1([x, mean, variance, scale, offset], 'batchNorm');
	  var varianceEpsilon = attrs.varianceEpsilon;
	  if (varianceEpsilon == null) {
	    varianceEpsilon = 0.001;
	  }
	  var xVals = backend.data.get(x.dataId).values;
	  var mVals = backend.data.get(mean.dataId).values;
	  var varVals = backend.data.get(variance.dataId).values;
	  var sVals = scale ? backend.data.get(scale.dataId).values : new Float32Array([1]);
	  var offVals = offset ? backend.data.get(offset.dataId).values : new Float32Array([0]);
	  var outVals = new Float32Array(xVals.length);
	  var offValsLength = offVals.length;
	  var sValsLength = sVals.length;
	  var varValsLength = varVals.length;
	  var mValsLength = mVals.length;
	  var offi = 0;
	  var mi = 0;
	  var si = 0;
	  var vi = 0;
	  for (var i = 0; i < xVals.length; ++i) {
	    outVals[i] = offVals[offi++] + (xVals[i] - mVals[mi++]) * sVals[si++] / Math.sqrt(varVals[vi++] + varianceEpsilon);
	    if (offi >= offValsLength) {
	      offi = 0;
	    }
	    if (mi >= mValsLength) {
	      mi = 0;
	    }
	    if (si >= sValsLength) {
	      si = 0;
	    }
	    if (vi >= varValsLength) {
	      vi = 0;
	    }
	  }
	  return backend.makeTensorInfo(x.shape, x.dtype, outVals);
	}
	var batchNormConfig$1 = {
	  kernelName: FusedBatchNorm,
	  backendName: 'cpu',
	  kernelFunc: batchNorm$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function batchToSpaceND$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var blockShape = attrs.blockShape,
	    crops = attrs.crops;
	  assertNotComplex$1([x], 'batchToSpaceND');
	  var prod = blockShape.reduce(function (a, b) {
	    return a * b;
	  });
	  var reshaped = getReshaped(x.shape, blockShape, prod);
	  var permuted = getPermuted(reshaped.length, blockShape.length);
	  var reshapedPermuted = getReshapedPermuted(x.shape, blockShape, prod);
	  var sliceBeginCoords = getSliceBeginCoords(crops, blockShape.length);
	  var sliceSize = getSliceSize(reshapedPermuted, crops, blockShape.length);
	  var xReshaped = reshape$1({
	    inputs: {
	      x: x
	    },
	    backend: backend,
	    attrs: {
	      shape: reshaped
	    }
	  });
	  var xTransposed = transpose$1({
	    inputs: {
	      x: xReshaped
	    },
	    backend: backend,
	    attrs: {
	      perm: permuted
	    }
	  });
	  var xTransposedReshaped = reshape$1({
	    inputs: {
	      x: xTransposed
	    },
	    backend: backend,
	    attrs: {
	      shape: reshapedPermuted
	    }
	  });
	  var result = slice$1({
	    inputs: {
	      x: xTransposedReshaped
	    },
	    backend: backend,
	    attrs: {
	      begin: sliceBeginCoords,
	      size: sliceSize
	    }
	  });
	  backend.disposeIntermediateTensorInfo(xReshaped);
	  backend.disposeIntermediateTensorInfo(xTransposed);
	  backend.disposeIntermediateTensorInfo(xTransposedReshaped);
	  return result;
	}
	var batchToSpaceNDConfig$1 = {
	  kernelName: BatchToSpaceND,
	  backendName: 'cpu',
	  kernelFunc: batchToSpaceND$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function bincount$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    weights = inputs.weights;
	  var size = attrs.size;
	  var xVals = backend.data.get(x.dataId).values;
	  var weightsVals = backend.data.get(weights.dataId).values;
	  var outVals = bincountImpl(xVals, weightsVals, weights.dtype, weights.shape, size);
	  return backend.makeTensorInfo([size], weights.dtype, outVals);
	}
	var bincountConfig$1 = {
	  kernelName: Bincount,
	  backendName: 'cpu',
	  kernelFunc: bincount$1
	};

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function broadcastArgs$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var s0 = inputs.s0,
	    s1 = inputs.s1;
	  var s0Vals = backend.data.get(s0.dataId).values;
	  var s1Vals = backend.data.get(s1.dataId).values;
	  var broadcastShape = assertAndGetBroadcastShape(Array.from(s0Vals), Array.from(s1Vals));
	  return backend.makeTensorInfo([broadcastShape.length], 'int32', Int32Array.from(broadcastShape));
	}
	var broadcastArgsConfig$1 = {
	  kernelName: BroadcastArgs,
	  backendName: 'cpu',
	  kernelFunc: broadcastArgs$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var clipByValue$1 = unaryKernelFunc$1(ClipByValue, function (xi, attrs) {
	  var clipAttrs = attrs;
	  if (xi > clipAttrs.clipValueMax) {
	    return clipAttrs.clipValueMax;
	  }
	  return xi < clipAttrs.clipValueMin ? clipAttrs.clipValueMin : xi;
	});
	var clipByValueConfig$1 = {
	  kernelName: ClipByValue,
	  backendName: 'cpu',
	  kernelFunc: clipByValue$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var complexAbs$1 = function complexAbs(args) {
	  var x = args.inputs.x;
	  var cpuBackend = args.backend;
	  var resultValues = new Float32Array(sizeFromShape(x.shape));
	  var complexVals = cpuBackend.data.get(x.dataId);
	  var real = complexVals.complexTensorInfos.real;
	  var imag = complexVals.complexTensorInfos.imag;
	  var realVals = cpuBackend.data.get(real.dataId).values;
	  var imagVals = cpuBackend.data.get(imag.dataId).values;
	  for (var i = 0; i < realVals.length; i++) {
	    var _real = realVals[i];
	    var _imag = imagVals[i];
	    resultValues[i] = Math.hypot(_real, _imag);
	  }
	  return cpuBackend.makeOutput(resultValues, x.shape, 'float32');
	};
	var complexAbsConfig$1 = {
	  kernelName: ComplexAbs,
	  backendName: 'cpu',
	  kernelFunc: complexAbs$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function imag$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var input = inputs.input;
	  var imag = backend.data.get(input.dataId).complexTensorInfos.imag;
	  var imagVal = backend.data.get(imag.dataId).values;
	  // When complex tensor is disposed, its underlying parts will be disposed too.
	  // Make new tensor out of the imag value of the complex. This makes sure the
	  // value is still accessible even if complex tensor is disposed.
	  return backend.makeTensorInfo(imag.shape, imag.dtype, imagVal);
	}
	var imagConfig$1 = {
	  kernelName: Imag,
	  backendName: 'cpu',
	  kernelFunc: imag$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function concat$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var axis = attrs.axis;
	  var $axis = parseAxisParam(axis, inputs[0].shape)[0];
	  var shapes = inputs.map(function (t) {
	    return t.shape;
	  });
	  assertParamsConsistent(shapes, $axis);
	  var outShape = computeOutShape$1(inputs.map(function (t) {
	    return t.shape;
	  }), $axis);
	  if (sizeFromShape(outShape) === 0) {
	    return backend.makeTensorInfo(outShape, inputs[0].dtype, []);
	  }
	  // Keep only non-empty tensors (ignore tensors with 0 in their shape).
	  var $inputs = inputs.filter(function (t) {
	    return sizeFromShape(t.shape) > 0;
	  });
	  if ($inputs.length === 1) {
	    return identity$1({
	      inputs: {
	        x: $inputs[0]
	      },
	      backend: backend
	    });
	  }
	  if ($inputs[0].dtype === 'complex64') {
	    var reals = $inputs.map(function (t) {
	      return real$1({
	        inputs: {
	          input: t
	        },
	        backend: backend
	      });
	    });
	    var imags = $inputs.map(function (t) {
	      return imag$1({
	        inputs: {
	          input: t
	        },
	        backend: backend
	      });
	    });
	    var realConcated = concat$1({
	      inputs: reals,
	      backend: backend,
	      attrs: {
	        axis: $axis
	      }
	    });
	    var imagConcated = concat$1({
	      inputs: imags,
	      backend: backend,
	      attrs: {
	        axis: $axis
	      }
	    });
	    var result = complex$1({
	      inputs: {
	        real: realConcated,
	        imag: imagConcated
	      },
	      backend: backend
	    });
	    reals.forEach(function (r) {
	      return backend.disposeIntermediateTensorInfo(r);
	    });
	    imags.forEach(function (i) {
	      return backend.disposeIntermediateTensorInfo(i);
	    });
	    backend.disposeIntermediateTensorInfo(realConcated);
	    backend.disposeIntermediateTensorInfo(imagConcated);
	    return result;
	  }
	  // Any concat of n-dimensional tensors across any axis can be reduced to
	  // a concatenation of two-dimensional tensors across the axis 1 by first
	  // partitioning the axes of the original tensors into those less than the
	  // axis to be concatenated and the rest. Then reshape the tensors
	  // into a two-dimensional tensor by collapsing these two sets of axes and
	  // concatenate the resulting matrices across the axis 1, finally reshaping
	  // the result to have the proper shape.
	  var inputs2D = $inputs.map(function (t) {
	    var innerSize = sizeFromShape(t.shape.slice($axis));
	    var shape = [-1, innerSize];
	    return reshape$1({
	      inputs: {
	        x: t
	      },
	      backend: backend,
	      attrs: {
	        shape: shape
	      }
	    });
	  });
	  var inputsValShapes = inputs2D.map(function (t) {
	    return {
	      vals: backend.data.get(t.dataId).values,
	      shape: t.shape
	    };
	  });
	  // Concats 2d tensors along axis=1.
	  outShape = computeOutShape$1(inputs2D.map(function (t) {
	    return t.shape;
	  }), 1 /* axis */);
	  var simplyConcat = inputs2D[0].shape[0] === 1;
	  var outVals = concatImpl$1(inputsValShapes, outShape, inputs[0].dtype, simplyConcat);
	  var finalOutShape = computeOutShape$1($inputs.map(function (t) {
	    return t.shape;
	  }), $axis);
	  var outInfo = backend.makeTensorInfo(finalOutShape, inputs[0].dtype, outVals);
	  inputs2D.forEach(function (t) {
	    return backend.disposeIntermediateTensorInfo(t);
	  });
	  return outInfo;
	}
	var concatConfig$1 = {
	  kernelName: Concat,
	  backendName: 'cpu',
	  kernelFunc: concat$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function conv2D(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    filter = inputs.filter;
	  var strides = attrs.strides,
	    pad = attrs.pad,
	    dataFormat = attrs.dataFormat,
	    dilations = attrs.dilations,
	    dimRoundingMode = attrs.dimRoundingMode;
	  assertNotComplex$1([x, filter], 'conv2d');
	  var $dataFormat = convertConv2DDataFormat(dataFormat);
	  var convInfo = computeConv2DInfo(x.shape, filter.shape, strides, dilations, pad, dimRoundingMode, false /* depthwise */, $dataFormat);
	  var filterHeight = convInfo.filterHeight;
	  var filterWidth = convInfo.filterWidth;
	  var dilationHeight = convInfo.dilationHeight;
	  var dilationWidth = convInfo.dilationWidth;
	  var padLeft = convInfo.padInfo.left;
	  var padTop = convInfo.padInfo.top;
	  var isChannelsLast = convInfo.dataFormat === 'channelsLast';
	  var y = new TensorBuffer(convInfo.outShape, x.dtype);
	  var xStrides = computeStrides(x.shape);
	  var filterStrides = computeStrides(filter.shape);
	  var xBatchStride = xStrides[0];
	  var xRowStride = isChannelsLast ? xStrides[1] : xStrides[2];
	  var xColStride = isChannelsLast ? xStrides[2] : 1;
	  var xChannelStride = isChannelsLast ? 1 : xStrides[1];
	  var yBatchStride = y.strides[0];
	  var yRowStride = isChannelsLast ? y.strides[1] : y.strides[2];
	  var yColStride = isChannelsLast ? y.strides[2] : 1;
	  var yChannelStride = isChannelsLast ? 1 : y.strides[1];
	  var xVals = backend.data.get(x.dataId).values;
	  var wVals = backend.data.get(filter.dataId).values;
	  var yVals = y.values;
	  for (var b = 0; b < convInfo.batchSize; ++b) {
	    var xOffset1 = b * xBatchStride;
	    var yOffset1 = b * yBatchStride;
	    for (var yR = 0; yR < convInfo.outHeight; ++yR) {
	      var yOffset2 = yOffset1 + yR * yRowStride;
	      var xRCorner = yR * convInfo.strideHeight - padTop;
	      for (var wR = 0; wR < filterHeight; ++wR) {
	        var xR = xRCorner + wR * dilationHeight;
	        if (xR < 0 || xR >= convInfo.inHeight) {
	          continue;
	        }
	        var wOffset1 = wR * filterStrides[0];
	        var xOffset2 = xOffset1 + xR * xRowStride;
	        for (var yC = 0; yC < convInfo.outWidth; ++yC) {
	          var yOffset3 = yOffset2 + yC * yColStride;
	          var xCCorner = yC * convInfo.strideWidth - padLeft;
	          for (var wC = 0; wC < filterWidth; ++wC) {
	            var xC = xCCorner + wC * dilationWidth;
	            if (xC < 0 || xC >= convInfo.inWidth) {
	              continue;
	            }
	            var wOffset2 = wOffset1 + wC * filterStrides[1];
	            var xOffset3 = xOffset2 + xC * xColStride;
	            var wOffset3 = wOffset2;
	            for (var d1 = 0; d1 < convInfo.inChannels; ++d1) {
	              var xVal = xVals[xOffset3 + d1 * xChannelStride];
	              for (var d2 = 0; d2 < convInfo.outChannels; ++d2) {
	                yVals[yOffset3 + d2 * yChannelStride] += xVal * wVals[wOffset3 + d2];
	              }
	              wOffset3 += convInfo.outChannels;
	            }
	          }
	        }
	      }
	    }
	  }
	  return backend.makeTensorInfo(y.shape, y.dtype, yVals);
	}
	var conv2DConfig$1 = {
	  kernelName: Conv2D$1,
	  backendName: 'cpu',
	  kernelFunc: conv2D
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function conv2DBackpropFilter$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    dy = inputs.dy;
	  var strides = attrs.strides,
	    pad = attrs.pad,
	    dataFormat = attrs.dataFormat,
	    dimRoundingMode = attrs.dimRoundingMode,
	    filterShape = attrs.filterShape;
	  assertNotComplex$1([x, dy], 'conv2dBackpropFilter');
	  var $dataFormat = convertConv2DDataFormat(dataFormat);
	  var convInfo = computeConv2DInfo(x.shape, filterShape, strides, 1 /* dilations */, pad, dimRoundingMode, false /* depthwise */, $dataFormat);
	  var strideHeight = convInfo.strideHeight,
	    strideWidth = convInfo.strideWidth,
	    filterHeight = convInfo.filterHeight,
	    filterWidth = convInfo.filterWidth;
	  var isChannelsLast = convInfo.dataFormat === 'channelsLast';
	  var dW = new TensorBuffer(convInfo.filterShape, 'float32');
	  var leftPad = convInfo.padInfo.left;
	  var topPad = convInfo.padInfo.top;
	  var xVals = backend.data.get(x.dataId).values;
	  var dyVals = backend.data.get(dy.dataId).values;
	  var xBuf = new TensorBuffer(x.shape, x.dtype, xVals);
	  var dyBuf = new TensorBuffer(dy.shape, dy.dtype, dyVals);
	  for (var wR = 0; wR < filterHeight; ++wR) {
	    var yRMin = Math.max(0, Math.ceil((topPad - wR) / strideHeight));
	    var yRMax = Math.min(convInfo.outHeight, (convInfo.inHeight + topPad - wR) / strideHeight);
	    for (var wC = 0; wC < filterWidth; ++wC) {
	      var yCMin = Math.max(0, Math.ceil((leftPad - wC) / strideWidth));
	      var yCMax = Math.min(convInfo.outWidth, (convInfo.inWidth + leftPad - wC) / strideWidth);
	      for (var d1 = 0; d1 < convInfo.inChannels; ++d1) {
	        for (var d2 = 0; d2 < convInfo.outChannels; ++d2) {
	          var dotProd = 0;
	          for (var b = 0; b < convInfo.batchSize; ++b) {
	            for (var yR = yRMin; yR < yRMax; ++yR) {
	              var xR = wR + yR * strideHeight - topPad;
	              for (var yC = yCMin; yC < yCMax; ++yC) {
	                var xC = wC + yC * strideWidth - leftPad;
	                if (isChannelsLast) {
	                  dotProd += xBuf.get(b, xR, xC, d1) * dyBuf.get(b, yR, yC, d2);
	                } else {
	                  dotProd += xBuf.get(b, d1, xR, xC) * dyBuf.get(b, d2, yR, yC);
	                }
	              }
	            }
	          }
	          dW.set(dotProd, wR, wC, d1, d2);
	        }
	      }
	    }
	  }
	  return backend.makeTensorInfo(dW.shape, dW.dtype, dW.values);
	}
	var conv2DBackpropFilterConfig$1 = {
	  kernelName: Conv2DBackpropFilter,
	  backendName: 'cpu',
	  kernelFunc: conv2DBackpropFilter$1
	};

	function conv2DBackpropInput$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var dy = inputs.dy,
	    filter = inputs.filter;
	  var inputShape = attrs.inputShape,
	    strides = attrs.strides,
	    pad = attrs.pad,
	    dataFormat = attrs.dataFormat,
	    dimRoundingMode = attrs.dimRoundingMode;
	  assertNotComplex$1([dy, filter], 'conv2dBackpropInput');
	  var filterStrides = computeStrides(filter.shape);
	  var dyStrides = computeStrides(dy.shape);
	  var $dataFormat = convertConv2DDataFormat(dataFormat);
	  var convInfo = computeConv2DInfo(inputShape, filter.shape, strides, 1 /* dilations */, pad, dimRoundingMode, false, $dataFormat);
	  var dx = new TensorBuffer(convInfo.inShape, 'float32');
	  var dxValues = dx.values;
	  var dyValues = backend.data.get(dy.dataId).values;
	  var fltValues = backend.data.get(filter.dataId).values;
	  var _filterStrides = _slicedToArray(filterStrides, 3),
	    fltS0 = _filterStrides[0],
	    fltS1 = _filterStrides[1],
	    fltS2 = _filterStrides[2];
	  var batchSize = convInfo.batchSize,
	    filterHeight = convInfo.filterHeight,
	    filterWidth = convInfo.filterWidth,
	    inChannels = convInfo.inChannels,
	    inHeight = convInfo.inHeight,
	    inWidth = convInfo.inWidth,
	    outChannels = convInfo.outChannels,
	    outHeight = convInfo.outHeight,
	    outWidth = convInfo.outWidth,
	    strideHeight = convInfo.strideHeight,
	    strideWidth = convInfo.strideWidth;
	  $dataFormat = convInfo.dataFormat;
	  var topPad = filterHeight - 1 - convInfo.padInfo.top;
	  var leftPad = filterWidth - 1 - convInfo.padInfo.left;
	  var isChannelsLast = $dataFormat === 'channelsLast';
	  var xBatchStride = dx.strides[0];
	  var xRowStride = isChannelsLast ? dx.strides[1] : dx.strides[2];
	  var xColStride = isChannelsLast ? dx.strides[2] : 1;
	  var xChannelStride = isChannelsLast ? 1 : dx.strides[1];
	  var yBatchStride = dyStrides[0];
	  var yRowStride = isChannelsLast ? dyStrides[1] : dyStrides[2];
	  var yColStride = isChannelsLast ? dyStrides[2] : 1;
	  var yChannelStride = isChannelsLast ? 1 : dyStrides[1];
	  for (var b = 0; b < batchSize; ++b) {
	    for (var d1 = 0; d1 < inChannels; ++d1) {
	      for (var xR = 0; xR < inHeight; ++xR) {
	        var xRCorner = xR - topPad;
	        var xRMin = Math.max(0, Math.ceil(xRCorner / strideHeight));
	        var yRMax = Math.min(outHeight, (filterHeight + xRCorner) / strideHeight);
	        for (var xC = 0; xC < inWidth; ++xC) {
	          var xCCorner = xC - leftPad;
	          var xCMin = Math.max(0, Math.ceil(xCCorner / strideWidth));
	          var yCMax = Math.min(outWidth, (filterWidth + xCCorner) / strideWidth);
	          var dotProd = 0;
	          for (var yR = xRMin; yR < yRMax; ++yR) {
	            var wR = yR * strideHeight - xRCorner;
	            for (var yC = xCMin; yC < yCMax; ++yC) {
	              var wC = yC * strideWidth - xCCorner;
	              var dyOffset = yBatchStride * b + yRowStride * yR + yColStride * yC;
	              var fltOffset = fltS0 * (filterHeight - 1 - wR) + fltS1 * (filterWidth - 1 - wC) + fltS2 * d1;
	              for (var d2 = 0; d2 < outChannels; ++d2) {
	                var pixel = dyValues[dyOffset + yChannelStride * d2];
	                var weight = fltValues[fltOffset + d2];
	                dotProd += pixel * weight;
	              }
	            }
	          }
	          var dxOffset = xBatchStride * b + xRowStride * xR + xColStride * xC + xChannelStride * d1;
	          dxValues[dxOffset] = dotProd;
	        }
	      }
	    }
	  }
	  return backend.makeTensorInfo(dx.shape, dx.dtype, dx.values);
	}
	var conv2DBackpropInputConfig$1 = {
	  kernelName: Conv2DBackpropInput,
	  backendName: 'cpu',
	  kernelFunc: conv2DBackpropInput$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function conv3D$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    filter = inputs.filter;
	  var strides = attrs.strides,
	    pad = attrs.pad,
	    dilations = attrs.dilations;
	  assertNotComplex$1([x, filter], 'conv3d');
	  var convInfo = computeConv3DInfo(x.shape, filter.shape, strides, dilations, pad);
	  var filterDepth = convInfo.filterDepth,
	    filterHeight = convInfo.filterHeight,
	    filterWidth = convInfo.filterWidth,
	    dilationDepth = convInfo.dilationDepth,
	    dilationHeight = convInfo.dilationHeight,
	    dilationWidth = convInfo.dilationWidth,
	    padInfo = convInfo.padInfo;
	  var padFront = padInfo.front;
	  var padLeft = padInfo.left;
	  var padTop = padInfo.top;
	  var y = new TensorBuffer(convInfo.outShape, x.dtype);
	  var xVals = backend.data.get(x.dataId).values;
	  var wVals = backend.data.get(filter.dataId).values;
	  var yVals = y.values;
	  var xStrides = computeStrides(x.shape);
	  var filterStrides = computeStrides(filter.shape);
	  for (var b = 0; b < convInfo.batchSize; ++b) {
	    var xOffset1 = b * xStrides[0];
	    var yOffset1 = b * y.strides[0];
	    for (var yF = 0; yF < convInfo.outDepth; ++yF) {
	      var yOffset2 = yOffset1 + yF * y.strides[1];
	      var xFCorner = yF * convInfo.strideDepth - padFront;
	      for (var wF = 0; wF < filterDepth; ++wF) {
	        var xF = xFCorner + wF * dilationDepth;
	        if (xF < 0 || xF >= convInfo.inDepth) {
	          continue;
	        }
	        var wOffset1 = wF * filterStrides[0];
	        var xOffset2 = xOffset1 + xF * xStrides[1];
	        for (var yR = 0; yR < convInfo.outHeight; ++yR) {
	          var yOffset3 = yOffset2 + yR * y.strides[2];
	          var xRCorner = yR * convInfo.strideHeight - padTop;
	          for (var wR = 0; wR < filterHeight; ++wR) {
	            var xR = xRCorner + wR * dilationHeight;
	            if (xR < 0 || xR >= convInfo.inHeight) {
	              continue;
	            }
	            var wOffset2 = wOffset1 + wR * filterStrides[1];
	            var xOffset3 = xOffset2 + xR * xStrides[2];
	            for (var yC = 0; yC < convInfo.outWidth; ++yC) {
	              var yOffset4 = yOffset3 + yC * convInfo.outChannels;
	              var xCCorner = yC * convInfo.strideWidth - padLeft;
	              for (var wC = 0; wC < filterWidth; ++wC) {
	                var xC = xCCorner + wC * dilationWidth;
	                if (xC < 0 || xC >= convInfo.inWidth) {
	                  continue;
	                }
	                var wOffset3 = wOffset2 + wC * filterStrides[2];
	                var xOffset4 = xOffset3 + xC * convInfo.inChannels;
	                var wOffset4 = wOffset3;
	                for (var d1 = 0; d1 < convInfo.inChannels; ++d1) {
	                  var xVal = xVals[xOffset4 + d1];
	                  for (var d2 = 0; d2 < convInfo.outChannels; ++d2) {
	                    yVals[yOffset4 + d2] += xVal * wVals[wOffset4 + d2];
	                  }
	                  wOffset4 += convInfo.outChannels;
	                }
	              }
	            }
	          }
	        }
	      }
	    }
	  }
	  return backend.makeTensorInfo(y.shape, y.dtype, y.values);
	}
	var conv3DConfig$1 = {
	  kernelName: Conv3D$1,
	  backendName: 'cpu',
	  kernelFunc: conv3D$1
	};

	function conv3DBackpropFilterV2$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    dy = inputs.dy;
	  var strides = attrs.strides,
	    pad = attrs.pad,
	    filterShape = attrs.filterShape;
	  assertNotComplex$1([x, dy], 'conv3dBackpropFilterV2');
	  var xStrides = computeStrides(x.shape);
	  var dyStrides = computeStrides(dy.shape);
	  var convInfo = computeConv3DInfo(x.shape, filterShape, strides, 1 /* dilations */, pad);
	  var strideDepth = convInfo.strideDepth;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var filterDepth = convInfo.filterDepth;
	  var filterHeight = convInfo.filterHeight;
	  var filterWidth = convInfo.filterWidth;
	  var dw = new TensorBuffer(convInfo.filterShape, 'float32');
	  var dwValues = dw.values;
	  var _dw$strides = _slicedToArray(dw.strides, 4),
	    dwS0 = _dw$strides[0],
	    dwS1 = _dw$strides[1],
	    dwS2 = _dw$strides[2],
	    dwS3 = _dw$strides[3];
	  var dyValues = backend.data.get(dy.dataId).values;
	  var _dyStrides = _slicedToArray(dyStrides, 4),
	    dyS0 = _dyStrides[0],
	    dyS1 = _dyStrides[1],
	    dyS2 = _dyStrides[2],
	    dyS3 = _dyStrides[3];
	  var xValues = backend.data.get(x.dataId).values;
	  var _xStrides = _slicedToArray(xStrides, 4),
	    xS0 = _xStrides[0],
	    xS1 = _xStrides[1],
	    xS2 = _xStrides[2],
	    xS3 = _xStrides[3];
	  var frontPad = convInfo.padInfo.front;
	  var leftPad = convInfo.padInfo.left;
	  var topPad = convInfo.padInfo.top;
	  for (var wF = 0; wF < filterDepth; ++wF) {
	    var yFMin = Math.max(0, Math.ceil((frontPad - wF) / strideDepth));
	    var yFMax = Math.min(convInfo.outDepth, (convInfo.inDepth + frontPad - wF) / strideDepth);
	    var wOffset1 = wF * dwS0;
	    for (var wR = 0; wR < filterHeight; ++wR) {
	      var yRMin = Math.max(0, Math.ceil((topPad - wR) / strideHeight));
	      var yRMax = Math.min(convInfo.outHeight, (convInfo.inHeight + topPad - wR) / strideHeight);
	      var wOffset2 = wR * dwS1 + wOffset1;
	      for (var wC = 0; wC < filterWidth; ++wC) {
	        var yCMin = Math.max(0, Math.ceil((leftPad - wC) / strideWidth));
	        var yCMax = Math.min(convInfo.outWidth, (convInfo.inWidth + leftPad - wC) / strideWidth);
	        var wOffset3 = wC * dwS2 + wOffset2;
	        for (var d1 = 0; d1 < convInfo.inChannels; ++d1) {
	          var wOffset4 = d1 * dwS3 + wOffset3;
	          for (var d2 = 0; d2 < convInfo.outChannels; ++d2) {
	            var dotProd = 0;
	            for (var b = 0; b < convInfo.batchSize; ++b) {
	              var xOffset1 = b * xS0;
	              var yOffset1 = b * dyS0;
	              for (var yF = yFMin; yF < yFMax; ++yF) {
	                var xF = wF + yF * strideDepth - frontPad;
	                var xOffset2 = xF * xS1 + xOffset1;
	                var yOffset2 = yF * dyS1 + yOffset1;
	                for (var yR = yRMin; yR < yRMax; ++yR) {
	                  var xR = wR + yR * strideHeight - topPad;
	                  var xOffset3 = xR * xS2 + xOffset2;
	                  var yOffset3 = yR * dyS2 + yOffset2;
	                  for (var yC = yCMin; yC < yCMax; ++yC) {
	                    var xC = wC + yC * strideWidth - leftPad;
	                    var xOffset4 = xC * xS3 + xOffset3;
	                    var yOffset4 = yC * dyS3 + yOffset3;
	                    dotProd += xValues[xOffset4 + d1] * dyValues[yOffset4 + d2];
	                  }
	                }
	              }
	            }
	            dwValues[wOffset4 + d2] = dotProd;
	          }
	        }
	      }
	    }
	  }
	  return backend.makeTensorInfo(dw.shape, dw.dtype, dw.values);
	}
	var conv3DBackpropFilterV2Config$1 = {
	  kernelName: Conv3DBackpropFilterV2,
	  backendName: 'cpu',
	  kernelFunc: conv3DBackpropFilterV2$1
	};

	function conv3DBackpropInputV2(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var dy = inputs.dy,
	    filter = inputs.filter;
	  var pad = attrs.pad,
	    strides = attrs.strides,
	    inputShape = attrs.inputShape;
	  assertNotComplex$1([dy], 'conv3dBackpropInputV2');
	  var dyStrides = computeStrides(dy.shape);
	  var filterStrides = computeStrides(filter.shape);
	  var convInfo = computeConv3DInfo(inputShape, filter.shape, strides, 1 /* dilations */, pad);
	  var dx = new TensorBuffer(convInfo.inShape, 'float32');
	  var dxValues = dx.values;
	  var _dx$strides = _slicedToArray(dx.strides, 4),
	    dxS0 = _dx$strides[0],
	    dxS1 = _dx$strides[1],
	    dxS2 = _dx$strides[2],
	    dxS3 = _dx$strides[3];
	  var dyValues = backend.data.get(dy.dataId).values;
	  var _dyStrides = _slicedToArray(dyStrides, 4),
	    dyS0 = _dyStrides[0],
	    dyS1 = _dyStrides[1],
	    dyS2 = _dyStrides[2],
	    dyS3 = _dyStrides[3];
	  var fltValues = backend.data.get(filter.dataId).values;
	  var _filterStrides = _slicedToArray(filterStrides, 4),
	    fltS0 = _filterStrides[0],
	    fltS1 = _filterStrides[1],
	    fltS2 = _filterStrides[2],
	    fltS3 = _filterStrides[3];
	  var batchSize = convInfo.batchSize,
	    filterDepth = convInfo.filterDepth,
	    filterHeight = convInfo.filterHeight,
	    filterWidth = convInfo.filterWidth,
	    inChannels = convInfo.inChannels,
	    inDepth = convInfo.inDepth,
	    inHeight = convInfo.inHeight,
	    inWidth = convInfo.inWidth,
	    outChannels = convInfo.outChannels,
	    outDepth = convInfo.outDepth,
	    outHeight = convInfo.outHeight,
	    outWidth = convInfo.outWidth,
	    strideDepth = convInfo.strideDepth,
	    strideHeight = convInfo.strideHeight,
	    strideWidth = convInfo.strideWidth;
	  var frontPad = filterDepth - 1 - convInfo.padInfo.front;
	  var topPad = filterHeight - 1 - convInfo.padInfo.top;
	  var leftPad = filterWidth - 1 - convInfo.padInfo.left;
	  for (var b = 0; b < batchSize; ++b) {
	    for (var d1 = 0; d1 < inChannels; ++d1) {
	      // Frames of depth
	      for (var xF = 0; xF < inDepth; ++xF) {
	        var xFCorner = xF - frontPad;
	        var xFMin = Math.max(0, Math.ceil(xFCorner / strideDepth));
	        var yFMax = Math.min(outDepth, (filterDepth + xFCorner) / strideDepth);
	        // Rows as per standard 2d matrix notation
	        for (var xR = 0; xR < inHeight; ++xR) {
	          var xRCorner = xR - topPad;
	          var xRMin = Math.max(0, Math.ceil(xRCorner / strideHeight));
	          var yRMax = Math.min(outHeight, (filterHeight + xRCorner) / strideHeight);
	          // Columns as per standard 2d matrix notation
	          for (var xC = 0; xC < inWidth; ++xC) {
	            var xCCorner = xC - leftPad;
	            var xCMin = Math.max(0, Math.ceil(xCCorner / strideWidth));
	            var yCMax = Math.min(outWidth, (filterWidth + xCCorner) / strideWidth);
	            var dotProd = 0;
	            for (var yF = xFMin; yF < yFMax; ++yF) {
	              var wF = yF * strideDepth - xFCorner;
	              for (var yR = xRMin; yR < yRMax; ++yR) {
	                var wR = yR * strideHeight - xRCorner;
	                for (var yC = xCMin; yC < yCMax; ++yC) {
	                  var wC = yC * strideWidth - xCCorner;
	                  var dyOffset = dyS0 * b + dyS1 * yF + dyS2 * yR + dyS3 * yC;
	                  var fltOffset = fltS0 * (filterDepth - 1 - wF) + fltS1 * (filterHeight - 1 - wR) + fltS2 * (filterWidth - 1 - wC) + fltS3 * d1;
	                  for (var d2 = 0; d2 < outChannels; ++d2) {
	                    var pixel = dyValues[dyOffset + d2];
	                    var weight = fltValues[fltOffset + d2];
	                    dotProd += pixel * weight;
	                  }
	                }
	              }
	            }
	            dxValues[dxS0 * b + dxS1 * xF + dxS2 * xR + dxS3 * xC + d1] = dotProd;
	          }
	        }
	      }
	    }
	  }
	  return backend.makeTensorInfo(dx.shape, dx.dtype, dx.values);
	}
	var conv3DBackpropInputV2Config = {
	  kernelName: Conv3DBackpropInputV2,
	  backendName: 'cpu',
	  kernelFunc: conv3DBackpropInputV2
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var cos$1 = unaryKernelFunc$1(Cos, function (xi) {
	  return Math.cos(xi);
	});
	var cosConfig$1 = {
	  kernelName: Cos,
	  backendName: 'cpu',
	  kernelFunc: cos$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var cosh$1 = unaryKernelFunc$1(Cosh, function (xi) {
	  return Math.cosh(xi);
	});
	var coshConfig$1 = {
	  kernelName: Cosh,
	  backendName: 'cpu',
	  kernelFunc: cosh$1
	};

	function cropAndResize$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var image = inputs.image,
	    boxes = inputs.boxes,
	    boxInd = inputs.boxInd;
	  var cropSize = attrs.cropSize,
	    method = attrs.method,
	    extrapolationValue = attrs.extrapolationValue;
	  var _image$shape = _slicedToArray(image.shape, 4),
	    batch = _image$shape[0],
	    imageHeight = _image$shape[1],
	    imageWidth = _image$shape[2],
	    numChannels = _image$shape[3];
	  var numBoxes = boxes.shape[0];
	  var _cropSize = _slicedToArray(cropSize, 2),
	    cropHeight = _cropSize[0],
	    cropWidth = _cropSize[1];
	  var output = buffer([numBoxes, cropHeight, cropWidth, numChannels], 'float32');
	  var boxVals = backend.data.get(boxes.dataId).values;
	  var boxIndVals = backend.data.get(boxInd.dataId).values;
	  var imageVals = backend.data.get(image.dataId).values;
	  var inStride = computeStrides(image.shape); // to calculate flat indexes into image
	  var outStride = computeStrides(output.shape); // to calculate flat indexes into output
	  // Reference implementation
	  // tslint:disable-next-line:max-line-length
	  // https://github.com/tensorflow/tensorflow/blob/master/tensorflow/core/kernels/crop_and_resize_op.cc
	  for (var b = 0; b < numBoxes; b++) {
	    var startInd = b * 4;
	    var y1 = boxVals[startInd];
	    var x1 = boxVals[startInd + 1];
	    var y2 = boxVals[startInd + 2];
	    var x2 = boxVals[startInd + 3];
	    var bInd = boxIndVals[b];
	    if (bInd >= batch) {
	      continue;
	    }
	    var heightScale = cropHeight > 1 ? (y2 - y1) * (imageHeight - 1) / (cropHeight - 1) : 0;
	    var widthScale = cropWidth > 1 ? (x2 - x1) * (imageWidth - 1) / (cropWidth - 1) : 0;
	    for (var y = 0; y < cropHeight; y++) {
	      var yInd = cropHeight > 1 ? y1 * (imageHeight - 1) + y * heightScale : 0.5 * (y1 + y2) * (imageHeight - 1);
	      if (yInd < 0 || yInd > imageHeight - 1) {
	        for (var x = 0; x < cropWidth; x++) {
	          for (var c = 0; c < numChannels; c++) {
	            var ind = c + x * outStride[2] + y * outStride[1] + b * outStride[0];
	            output.values[ind] = extrapolationValue;
	          }
	        }
	        continue;
	      }
	      if (method === 'bilinear') {
	        var topInd = Math.floor(yInd);
	        var bottomInd = Math.ceil(yInd);
	        var yLerp = yInd - topInd;
	        for (var _x = 0; _x < cropWidth; _x++) {
	          var xInd = cropWidth > 1 ? x1 * (imageWidth - 1) + _x * widthScale : 0.5 * (x1 + x2) * (imageWidth - 1);
	          if (xInd < 0 || xInd > imageWidth - 1) {
	            for (var _c = 0; _c < numChannels; _c++) {
	              var _ind = _c + _x * outStride[2] + y * outStride[1] + b * outStride[0];
	              output.values[_ind] = extrapolationValue;
	            }
	            continue;
	          }
	          var leftInd = Math.floor(xInd);
	          var rightInd = Math.ceil(xInd);
	          var xLerp = xInd - leftInd;
	          for (var _c2 = 0; _c2 < numChannels; _c2++) {
	            var _ind2 = _c2 + leftInd * inStride[2] + topInd * inStride[1] + bInd * inStride[0];
	            var topLeft = imageVals[_ind2];
	            _ind2 = _c2 + rightInd * inStride[2] + topInd * inStride[1] + bInd * inStride[0];
	            var topRight = imageVals[_ind2];
	            _ind2 = _c2 + leftInd * inStride[2] + bottomInd * inStride[1] + bInd * inStride[0];
	            var bottomLeft = imageVals[_ind2];
	            _ind2 = _c2 + rightInd * inStride[2] + bottomInd * inStride[1] + bInd * inStride[0];
	            var bottomRight = imageVals[_ind2];
	            var top = topLeft + (topRight - topLeft) * xLerp;
	            var bottom = bottomLeft + (bottomRight - bottomLeft) * xLerp;
	            _ind2 = _c2 + _x * outStride[2] + y * outStride[1] + b * outStride[0];
	            output.values[_ind2] = top + (bottom - top) * yLerp;
	          }
	        }
	      } else {
	        // method == "nearest"
	        for (var _x2 = 0; _x2 < cropWidth; ++_x2) {
	          var _xInd = cropWidth > 1 ? x1 * (imageWidth - 1) + _x2 * widthScale : 0.5 * (x1 + x2) * (imageWidth - 1);
	          if (_xInd < 0 || _xInd > imageWidth - 1) {
	            for (var _c3 = 0; _c3 < numChannels; _c3++) {
	              var _ind3 = _c3 + _x2 * outStride[2] + y * outStride[1] + b * outStride[0];
	              output.values[_ind3] = extrapolationValue;
	            }
	            continue;
	          }
	          var closestX = Math.round(_xInd);
	          var closestY = Math.round(yInd);
	          for (var _c4 = 0; _c4 < numChannels; _c4++) {
	            var inInd = _c4 + closestX * inStride[2] + closestY * inStride[1] + bInd * inStride[0];
	            var outInd = _c4 + _x2 * outStride[2] + y * outStride[1] + b * outStride[0];
	            output.values[outInd] = imageVals[inInd];
	          }
	        }
	      }
	    }
	  }
	  return backend.makeTensorInfo(output.shape, output.dtype, output.values);
	}
	var cropAndResizeConfig$1 = {
	  kernelName: CropAndResize,
	  backendName: 'cpu',
	  kernelFunc: cropAndResize$1
	};

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function cumprod$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis,
	    exclusive = attrs.exclusive,
	    reverse = attrs.reverse;
	  assertNotComplex$1(x, 'cumprod');
	  var permutation = getAxesPermutation([axis], x.shape.length);
	  var $x = x;
	  if (permutation != null) {
	    $x = transpose$1({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        perm: permutation
	      }
	    });
	  }
	  var permutedAxis = getInnerMostAxes(1, x.shape.length)[0];
	  if (permutedAxis !== $x.shape.length - 1) {
	    throw new Error("backend.cumprod in CPU expects an inner-most " + "axis=".concat($x.shape.length - 1, " but got axis=").concat(permutedAxis));
	  }
	  var resultDtype = upcastType($x.dtype, 'int32');
	  var vals = makeOnesTypedArray(sizeFromShape($x.shape), resultDtype);
	  var aVals = backend.data.get($x.dataId).values;
	  var finalDim = $x.shape[$x.shape.length - 1];
	  var indexAdjuster = reverse ? function (i, j) {
	    return i + finalDim - j - 1;
	  } : function (i, j) {
	    return i + j;
	  };
	  for (var i = 0; i < aVals.length; i += finalDim) {
	    for (var j = 0; j < finalDim; j++) {
	      var idx = indexAdjuster(i, j);
	      if (j === 0) {
	        vals[idx] = exclusive ? 1 : aVals[idx];
	      } else {
	        var prevIdx = indexAdjuster(i, j - 1);
	        vals[idx] = exclusive ? aVals[prevIdx] * vals[prevIdx] : aVals[idx] * vals[prevIdx];
	      }
	    }
	  }
	  var result = backend.makeTensorInfo($x.shape, resultDtype, vals);
	  if (permutation != null) {
	    var reversePermutation = getUndoAxesPermutation(permutation);
	    var reverseTransposedResult = transpose$1({
	      inputs: {
	        x: result
	      },
	      backend: backend,
	      attrs: {
	        perm: reversePermutation
	      }
	    });
	    backend.disposeIntermediateTensorInfo(result);
	    backend.disposeIntermediateTensorInfo($x);
	    return reverseTransposedResult;
	  }
	  return result;
	}
	var cumprodConfig$1 = {
	  kernelName: Cumprod,
	  backendName: 'cpu',
	  kernelFunc: cumprod$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function cumsum$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis,
	    exclusive = attrs.exclusive,
	    reverse = attrs.reverse;
	  assertNotComplex$1(x, 'cumsum');
	  var permutation = getAxesPermutation([axis], x.shape.length);
	  var $x = x;
	  if (permutation != null) {
	    $x = transpose$1({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        perm: permutation
	      }
	    });
	  }
	  var permutedAxis = getInnerMostAxes(1, x.shape.length)[0];
	  if (permutedAxis !== $x.shape.length - 1) {
	    throw new Error("backend.cumsum in CPU expects an inner-most " + "axis=".concat($x.shape.length - 1, " but got axis=").concat(permutedAxis));
	  }
	  var resultDtype = upcastType($x.dtype, 'int32');
	  var vals = makeZerosTypedArray(sizeFromShape($x.shape), resultDtype);
	  var aVals = backend.data.get($x.dataId).values;
	  var finalDim = $x.shape[$x.shape.length - 1];
	  var indexAdjuster = reverse ? function (i, j) {
	    return i + finalDim - j - 1;
	  } : function (i, j) {
	    return i + j;
	  };
	  for (var i = 0; i < aVals.length; i += finalDim) {
	    for (var j = 0; j < finalDim; j++) {
	      var idx = indexAdjuster(i, j);
	      if (j === 0) {
	        vals[idx] = exclusive ? 0 : aVals[idx];
	      } else {
	        var prevIdx = indexAdjuster(i, j - 1);
	        vals[idx] = exclusive ? aVals[prevIdx] + vals[prevIdx] : aVals[idx] + vals[prevIdx];
	      }
	    }
	  }
	  var result = backend.makeTensorInfo($x.shape, resultDtype, vals);
	  if (permutation != null) {
	    var reversePermutation = getUndoAxesPermutation(permutation);
	    var reverseTransposedResult = transpose$1({
	      inputs: {
	        x: result
	      },
	      backend: backend,
	      attrs: {
	        perm: reversePermutation
	      }
	    });
	    backend.disposeIntermediateTensorInfo(result);
	    backend.disposeIntermediateTensorInfo($x);
	    return reverseTransposedResult;
	  }
	  return result;
	}
	var cumsumConfig$1 = {
	  kernelName: Cumsum,
	  backendName: 'cpu',
	  kernelFunc: cumsum$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function denseBincount$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    weights = inputs.weights;
	  var size = attrs.size,
	    binaryOutput = attrs.binaryOutput;
	  if (x.shape.length === 1) {
	    var xVals = backend.data.get(x.dataId).values;
	    var weightsVals = backend.data.get(weights.dataId).values;
	    var outVals = bincountImpl(xVals, weightsVals, weights.dtype, weights.shape, size);
	    return backend.makeTensorInfo([size], weights.dtype, outVals);
	  } else if (x.shape.length === 2) {
	    var xBuf = backend.bufferSync(x);
	    var weightsBuf = backend.bufferSync(weights);
	    var outBuf = bincountReduceImpl(xBuf, weightsBuf, size, binaryOutput);
	    return backend.makeTensorInfo(outBuf.shape, weights.dtype, outBuf.values);
	  }
	  throw new Error("Error in denseBincount: input must be at most rank 2, but got rank" + "".concat(x.shape.length, "."));
	}
	var denseBincountConfig$1 = {
	  kernelName: DenseBincount,
	  backendName: 'cpu',
	  kernelFunc: denseBincount$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function depthToSpace$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var blockSize = attrs.blockSize,
	    dataFormat = attrs.dataFormat;
	  assert$1(dataFormat === 'NHWC', function () {
	    return "Only NHWC dataFormat supported on CPU for depthToSpace. Got ".concat(dataFormat);
	  });
	  var batchSize = x.shape[0];
	  var inputHeight = x.shape[1];
	  var inputWidth = x.shape[2];
	  var inputDepth = x.shape[3];
	  var outputHeight = inputHeight * blockSize;
	  var outputWidth = inputWidth * blockSize;
	  var outputDepth = inputDepth / (blockSize * blockSize);
	  var xValues = backend.data.get(x.dataId).values;
	  var result = new Float32Array(batchSize * outputHeight * outputWidth * outputDepth);
	  var outputIdx = 0;
	  for (var b = 0; b < batchSize; ++b) {
	    for (var h = 0; h < outputHeight; ++h) {
	      var inH = Math.floor(h / blockSize);
	      var offsetH = h % blockSize;
	      for (var w = 0; w < outputWidth; ++w) {
	        var inW = Math.floor(w / blockSize);
	        var offsetW = w % blockSize;
	        var offsetD = (offsetH * blockSize + offsetW) * outputDepth;
	        for (var d = 0; d < outputDepth; ++d) {
	          var inD = d + offsetD;
	          var inputIdx = inD + inputDepth * (inW + inputWidth * (inH + inputHeight * b));
	          result[outputIdx++] = xValues[inputIdx];
	        }
	      }
	    }
	  }
	  return backend.makeTensorInfo([batchSize, outputHeight, outputWidth, outputDepth], x.dtype, result);
	}
	var depthToSpaceConfig$1 = {
	  kernelName: DepthToSpace,
	  backendName: 'cpu',
	  kernelFunc: depthToSpace$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function depthwiseConv2dNative$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    filter = inputs.filter;
	  var strides = attrs.strides,
	    pad = attrs.pad,
	    dilations = attrs.dilations,
	    dimRoundingMode = attrs.dimRoundingMode;
	  assertNotComplex$1([x, filter], 'depthwiseConv2DNative');
	  var xStrides = computeStrides(x.shape);
	  var filterStrides = computeStrides(filter.shape);
	  var $dilations = dilations;
	  if ($dilations == null) {
	    $dilations = [1, 1];
	  }
	  assert$1(eitherStridesOrDilationsAreOne(strides, $dilations), function () {
	    return 'Error in depthwiseConv2d: Either strides or dilations must be ' + "1. Got strides ".concat(strides, " and dilations '").concat($dilations, "'");
	  });
	  var convInfo = computeConv2DInfo(x.shape, filter.shape, strides, $dilations, pad, dimRoundingMode, true /* depthwise */);
	  var filterHeight = convInfo.filterHeight,
	    filterWidth = convInfo.filterWidth,
	    dilationHeight = convInfo.dilationHeight,
	    dilationWidth = convInfo.dilationWidth,
	    padInfo = convInfo.padInfo;
	  var padLeft = padInfo.left;
	  var padTop = padInfo.top;
	  var chMul = convInfo.outChannels / convInfo.inChannels;
	  var y = new TensorBuffer(convInfo.outShape, x.dtype);
	  var xVals = backend.data.get(x.dataId).values;
	  var wVals = backend.data.get(filter.dataId).values;
	  var yVals = y.values;
	  for (var b = 0; b < convInfo.batchSize; ++b) {
	    var xOffset1 = b * xStrides[0];
	    var yOffset1 = b * y.strides[0];
	    for (var yR = 0; yR < convInfo.outHeight; ++yR) {
	      var yOffset2 = yOffset1 + yR * y.strides[1];
	      var xRCorner = yR * convInfo.strideHeight - padTop;
	      for (var wR = 0; wR < filterHeight; ++wR) {
	        var xR = xRCorner + wR * dilationHeight;
	        if (xR < 0 || xR >= convInfo.inHeight) {
	          continue;
	        }
	        var wOffset1 = wR * filterStrides[0];
	        var xOffset2 = xOffset1 + xR * xStrides[1];
	        for (var yC = 0; yC < convInfo.outWidth; ++yC) {
	          var yOffset3 = yOffset2 + yC * y.strides[2];
	          var xCCorner = yC * convInfo.strideWidth - padLeft;
	          for (var wC = 0; wC < filterWidth; ++wC) {
	            var xC = xCCorner + wC * dilationWidth;
	            if (xC < 0 || xC >= convInfo.inWidth) {
	              continue;
	            }
	            var wOffset2 = wOffset1 + wC * filterStrides[1];
	            var xOffset3 = xOffset2 + xC * convInfo.inChannels;
	            var yOffset4 = yOffset3;
	            var wOffset3 = wOffset2;
	            for (var d1 = 0; d1 < convInfo.inChannels; ++d1) {
	              var xVal = xVals[xOffset3 + d1];
	              for (var q = 0; q < chMul; ++q) {
	                yVals[yOffset4 + q] += xVal * wVals[wOffset3 + q];
	              }
	              yOffset4 += chMul;
	              wOffset3 += chMul;
	            }
	          }
	        }
	      }
	    }
	  }
	  return backend.makeTensorInfo(y.shape, y.dtype, y.values);
	}
	var depthwiseConv2dNativeConfig$1 = {
	  kernelName: DepthwiseConv2dNative,
	  backendName: 'cpu',
	  kernelFunc: depthwiseConv2dNative$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function depthwiseConv2dNativeBackpropFilter$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    dy = inputs.dy;
	  var strides = attrs.strides,
	    dilations = attrs.dilations,
	    pad = attrs.pad,
	    dimRoundingMode = attrs.dimRoundingMode,
	    filterShape = attrs.filterShape;
	  assertNotComplex$1([x, dy], 'depthwiseConv2dNativeBackpropFilter');
	  var convInfo = computeConv2DInfo(x.shape, filterShape, strides, dilations, pad, dimRoundingMode, true /* depthwise */);
	  var strideHeight = convInfo.strideHeight,
	    strideWidth = convInfo.strideWidth,
	    filterHeight = convInfo.filterHeight,
	    filterWidth = convInfo.filterWidth;
	  var dW = new TensorBuffer(convInfo.filterShape, 'float32');
	  var leftPad = convInfo.padInfo.left;
	  var topPad = convInfo.padInfo.top;
	  var chMul = convInfo.outChannels / convInfo.inChannels;
	  var xVals = backend.data.get(x.dataId).values;
	  var xBuf = new TensorBuffer(x.shape, x.dtype, xVals);
	  var dyVals = backend.data.get(dy.dataId).values;
	  var dyBuf = new TensorBuffer(dy.shape, dy.dtype, dyVals);
	  for (var wR = 0; wR < filterHeight; ++wR) {
	    var yRMin = Math.max(0, Math.ceil((topPad - wR) / strideHeight));
	    var yRMax = Math.min(convInfo.outHeight, (convInfo.inHeight + topPad - wR) / strideHeight);
	    for (var wC = 0; wC < filterWidth; ++wC) {
	      var yCMin = Math.max(0, Math.ceil((leftPad - wC) / strideWidth));
	      var yCMax = Math.min(convInfo.outWidth, (convInfo.inWidth + leftPad - wC) / strideWidth);
	      for (var d2 = 0; d2 < convInfo.outChannels; ++d2) {
	        var d1 = Math.trunc(d2 / chMul);
	        var dm = d2 % chMul;
	        var dotProd = 0;
	        for (var b = 0; b < convInfo.batchSize; ++b) {
	          for (var yR = yRMin; yR < yRMax; ++yR) {
	            var xR = wR + yR * strideHeight - topPad;
	            for (var yC = yCMin; yC < yCMax; ++yC) {
	              var xC = wC + yC * strideWidth - leftPad;
	              dotProd += xBuf.get(b, xR, xC, d1) * dyBuf.get(b, yR, yC, d2);
	            }
	          }
	        }
	        dW.set(dotProd, wR, wC, d1, dm);
	      }
	    }
	  }
	  return backend.makeTensorInfo(dW.shape, dW.dtype, dW.values);
	}
	var depthwiseConv2dNativeBackpropFilterConfig$1 = {
	  kernelName: DepthwiseConv2dNativeBackpropFilter,
	  backendName: 'cpu',
	  kernelFunc: depthwiseConv2dNativeBackpropFilter$1
	};

	function depthwiseConv2dNativeBackpropInput$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var dy = inputs.dy,
	    filter = inputs.filter;
	  var strides = attrs.strides,
	    dilations = attrs.dilations,
	    pad = attrs.pad,
	    dimRoundingMode = attrs.dimRoundingMode,
	    inputShape = attrs.inputShape;
	  assertNotComplex$1([dy, filter], 'depthwiseConv2DNativeBackpropInput');
	  var dyStrides = computeStrides(dy.shape);
	  var filterStrides = computeStrides(filter.shape);
	  var convInfo = computeConv2DInfo(inputShape, filter.shape, strides, dilations, pad, dimRoundingMode, true /* depthwise */);
	  var dx = new TensorBuffer(convInfo.inShape, 'float32');
	  var dxValues = dx.values;
	  var _dx$strides = _slicedToArray(dx.strides, 3),
	    dxS0 = _dx$strides[0],
	    dxS1 = _dx$strides[1],
	    dxS2 = _dx$strides[2];
	  var dyValues = backend.data.get(dy.dataId).values;
	  var _dyStrides = _slicedToArray(dyStrides, 3),
	    dyS0 = _dyStrides[0],
	    dyS1 = _dyStrides[1],
	    dyS2 = _dyStrides[2];
	  var fltValues = backend.data.get(filter.dataId).values;
	  var _filterStrides = _slicedToArray(filterStrides, 3),
	    fltS0 = _filterStrides[0],
	    fltS1 = _filterStrides[1],
	    fltS2 = _filterStrides[2];
	  var batchSize = convInfo.batchSize,
	    filterHeight = convInfo.filterHeight,
	    filterWidth = convInfo.filterWidth,
	    inChannels = convInfo.inChannels,
	    inHeight = convInfo.inHeight,
	    inWidth = convInfo.inWidth,
	    outChannels = convInfo.outChannels,
	    outHeight = convInfo.outHeight,
	    outWidth = convInfo.outWidth,
	    strideHeight = convInfo.strideHeight,
	    strideWidth = convInfo.strideWidth;
	  var topPad = filterHeight - 1 - convInfo.padInfo.top;
	  var leftPad = filterWidth - 1 - convInfo.padInfo.left;
	  var chMul = outChannels / inChannels;
	  for (var b = 0; b < batchSize; ++b) {
	    for (var d1 = 0; d1 < inChannels; ++d1) {
	      for (var xR = 0; xR < inHeight; ++xR) {
	        var xRCorner = xR - topPad;
	        var xRMin = Math.max(0, Math.ceil(xRCorner / strideHeight));
	        var yRMax = Math.min(outHeight, (filterHeight + xRCorner) / strideHeight);
	        for (var xC = 0; xC < inWidth; ++xC) {
	          var xCCorner = xC - leftPad;
	          var xCMin = Math.max(0, Math.ceil(xCCorner / strideWidth));
	          var yCMax = Math.min(outWidth, (filterWidth + xCCorner) / strideWidth);
	          var dotProd = 0;
	          for (var yR = xRMin; yR < yRMax; ++yR) {
	            var wR = yR * strideHeight - xRCorner;
	            for (var yC = xCMin; yC < yCMax; ++yC) {
	              var wC = yC * strideWidth - xCCorner;
	              var dyOffset = dyS0 * b + dyS1 * yR + dyS2 * yC;
	              var fltOffset = fltS0 * (filterHeight - 1 - wR) + fltS1 * (filterWidth - 1 - wC) + fltS2 * d1;
	              for (var dm = 0; dm < chMul; ++dm) {
	                var d2 = d1 * chMul + dm;
	                var pixel = dyValues[dyOffset + d2];
	                var weight = fltValues[fltOffset + dm];
	                dotProd += pixel * weight;
	              }
	            }
	          }
	          dxValues[dxS0 * b + dxS1 * xR + dxS2 * xC + d1] = dotProd;
	        }
	      }
	    }
	  }
	  return backend.makeTensorInfo(dx.shape, dx.dtype, dx.values);
	}
	var depthwiseConv2dNativeBackpropInputConfig$1 = {
	  kernelName: DepthwiseConv2dNativeBackpropInput,
	  backendName: 'cpu',
	  kernelFunc: depthwiseConv2dNativeBackpropInput$1
	};

	function diag$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var x = inputs.x;
	  var xSize = sizeFromShape(x.shape);
	  var xVals = backend.data.get(x.dataId).values;
	  var outBuf = buffer([xSize, xSize], x.dtype);
	  var vals = outBuf.values;
	  for (var i = 0; i < xVals.length; i++) {
	    vals[i * xSize + i] = xVals[i];
	  }
	  var outShape = [].concat(_toConsumableArray(x.shape), _toConsumableArray(x.shape));
	  return backend.makeTensorInfo(outShape, outBuf.dtype, outBuf.values);
	}
	var diagConfig$1 = {
	  kernelName: Diag,
	  backendName: 'cpu',
	  kernelFunc: diag$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var dilation2DConfig$1 = {
	  kernelName: Dilation2D,
	  backendName: 'cpu',
	  kernelFunc: function kernelFunc(_ref) {
	    var inputs = _ref.inputs,
	      backend = _ref.backend,
	      attrs = _ref.attrs;
	    var x = inputs.x,
	      filter = inputs.filter;
	    var strides = attrs.strides,
	      pad = attrs.pad,
	      dilations = attrs.dilations;
	    var cpuBackend = backend;
	    var xVals = cpuBackend.data.get(x.dataId).values;
	    var xRank = x.shape.length;
	    var filterVals = cpuBackend.data.get(filter.dataId).values;
	    var filterRank = filter.shape.length;
	    var _backend_util$compute = computeDilation2DInfo(x.shape, filter.shape, strides, pad, 'NHWC' /* dataFormat */, dilations),
	      batchSize = _backend_util$compute.batchSize,
	      inHeight = _backend_util$compute.inHeight,
	      inWidth = _backend_util$compute.inWidth,
	      inChannels = _backend_util$compute.inChannels,
	      outHeight = _backend_util$compute.outHeight,
	      outWidth = _backend_util$compute.outWidth,
	      padInfo = _backend_util$compute.padInfo,
	      strideHeight = _backend_util$compute.strideHeight,
	      strideWidth = _backend_util$compute.strideWidth,
	      filterHeight = _backend_util$compute.filterHeight,
	      filterWidth = _backend_util$compute.filterWidth,
	      dilationHeight = _backend_util$compute.dilationHeight,
	      dilationWidth = _backend_util$compute.dilationWidth,
	      outShape = _backend_util$compute.outShape;
	    var outSize = sizeFromShape(outShape);
	    var outRank = outShape.length;
	    var outputVals = getArrayFromDType(x.dtype, outSize);
	    // Upsampling the input by fill in `dilation size - 1` values between each
	    // input value.
	    // This implementation follows the TF c++ implementation:
	    // https://github.com/tensorflow/tensorflow/blob/d9a3a849edc198e90172bc58eb293de457f9d986/tensorflow/core/kernels/dilation_ops.cc
	    for (var b = 0; b < batchSize; ++b) {
	      for (var hOut = 0; hOut < outHeight; ++hOut) {
	        var hBeg = hOut * strideHeight - padInfo.top;
	        for (var wOut = 0; wOut < outWidth; ++wOut) {
	          var wBeg = wOut * strideWidth - padInfo.left;
	          for (var d = 0; d < inChannels; ++d) {
	            var curVal = Number.MIN_SAFE_INTEGER;
	            for (var h = 0; h < filterHeight; ++h) {
	              var hIn = hBeg + h * dilationHeight;
	              if (hIn >= 0 && hIn < inHeight) {
	                for (var w = 0; w < filterWidth; ++w) {
	                  var wIn = wBeg + w * dilationWidth;
	                  if (wIn >= 0 && wIn < inWidth) {
	                    var xIndex = locToIndex([b, hIn, wIn, d], xRank, computeStrides(x.shape));
	                    var filterIndex = locToIndex([h, w, d], filterRank, computeStrides(filter.shape));
	                    var val = xVals[xIndex] + filterVals[filterIndex];
	                    if (val > curVal) {
	                      curVal = val;
	                    }
	                  }
	                }
	              }
	            }
	            var outputIndex = locToIndex([b, hOut, wOut, d], outRank, computeStrides(outShape));
	            outputVals[outputIndex] = curVal;
	          }
	        }
	      }
	    }
	    var dataId = cpuBackend.write(toTypedArray(outputVals, x.dtype), outShape, x.dtype);
	    return {
	      dataId: dataId,
	      shape: outShape,
	      dtype: x.dtype
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var dilation2DBackpropFilterConfig = {
	  kernelName: Dilation2DBackpropFilter,
	  backendName: 'cpu',
	  kernelFunc: function kernelFunc(_ref) {
	    var inputs = _ref.inputs,
	      backend = _ref.backend,
	      attrs = _ref.attrs;
	    var x = inputs.x,
	      filter = inputs.filter,
	      dy = inputs.dy;
	    var strides = attrs.strides,
	      pad = attrs.pad,
	      dilations = attrs.dilations;
	    var cpuBackend = backend;
	    var $x = toNestedArray(x.shape, cpuBackend.data.get(x.dataId).values);
	    var $filter = toNestedArray(filter.shape, cpuBackend.data.get(filter.dataId).values);
	    var _backend_util$compute = computeDilation2DInfo(x.shape, filter.shape, strides, pad, 'NHWC' /* dataFormat */, dilations),
	      batchSize = _backend_util$compute.batchSize,
	      inHeight = _backend_util$compute.inHeight,
	      inWidth = _backend_util$compute.inWidth,
	      inChannels = _backend_util$compute.inChannels,
	      outHeight = _backend_util$compute.outHeight,
	      outWidth = _backend_util$compute.outWidth,
	      padInfo = _backend_util$compute.padInfo,
	      strideHeight = _backend_util$compute.strideHeight,
	      strideWidth = _backend_util$compute.strideWidth,
	      filterHeight = _backend_util$compute.filterHeight,
	      filterWidth = _backend_util$compute.filterWidth,
	      dilationHeight = _backend_util$compute.dilationHeight,
	      dilationWidth = _backend_util$compute.dilationWidth,
	      outShape = _backend_util$compute.outShape;
	    assert$1(dy.rank === outShape.length, function () {
	      return "Error in ".concat(Dilation2DBackpropFilter, ", dy ") + "must have the same rank as output ".concat(outShape.length, ", but got ") + "".concat(dy.rank);
	    });
	    var $dy = toNestedArray(outShape, cpuBackend.data.get(dy.dataId).values);
	    // The computed filter gradients has the same dimensions as the filter:
	    // [filterHeight, filterWidth, depth]
	    var gradients = makeZerosNestedTypedArray(filter.shape, filter.dtype);
	    // In the case of multiple argmax branches, we only back-propagate along the
	    // last branch, i.e., the one with largest value of `h * filter_cols + w`,
	    // similarly to the max-pooling backward routines.
	    // This implementation follows the TF c++ implementation:
	    // https://github.com/tensorflow/tensorflow/blob/d9a3a849edc198e90172bc58eb293de457f9d986/tensorflow/core/kernels/dilation_ops.cc
	    for (var b = 0; b < batchSize; ++b) {
	      for (var hOut = 0; hOut < outHeight; ++hOut) {
	        var hBeg = hOut * strideHeight - padInfo.top;
	        for (var wOut = 0; wOut < outWidth; ++wOut) {
	          var wBeg = wOut * strideWidth - padInfo.left;
	          for (var d = 0; d < inChannels; ++d) {
	            var curVal = Number.MIN_SAFE_INTEGER;
	            var hMax = 0;
	            var wMax = 0;
	            for (var h = 0; h < filterHeight; ++h) {
	              var hIn = hBeg + h * dilationHeight;
	              if (hIn >= 0 && hIn < inHeight) {
	                for (var w = 0; w < filterWidth; ++w) {
	                  var wIn = wBeg + w * dilationWidth;
	                  if (wIn >= 0 && wIn < inWidth) {
	                    var val = $x[b][hIn][wIn][d] + $filter[h][w][d];
	                    if (val > curVal) {
	                      curVal = val;
	                      hMax = h;
	                      wMax = w;
	                    }
	                  }
	                }
	              }
	            }
	            gradients[hMax][wMax][d] += $dy[b][hOut][wOut][d];
	          }
	        }
	      }
	    }
	    var dataId = cpuBackend.write(toTypedArray(gradients, x.dtype), filter.shape, filter.dtype);
	    return {
	      dataId: dataId,
	      shape: filter.shape,
	      dtype: filter.dtype
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var dilation2DBackpropInputConfig = {
	  kernelName: Dilation2DBackpropInput,
	  backendName: 'cpu',
	  kernelFunc: function kernelFunc(_ref) {
	    var inputs = _ref.inputs,
	      backend = _ref.backend,
	      attrs = _ref.attrs;
	    var x = inputs.x,
	      filter = inputs.filter,
	      dy = inputs.dy;
	    var strides = attrs.strides,
	      pad = attrs.pad,
	      dilations = attrs.dilations;
	    var cpuBackend = backend;
	    var $x = toNestedArray(x.shape, cpuBackend.data.get(x.dataId).values);
	    var $filter = toNestedArray(filter.shape, cpuBackend.data.get(filter.dataId).values);
	    var _backend_util$compute = computeDilation2DInfo(x.shape, filter.shape, strides, pad, 'NHWC' /* dataFormat */, dilations),
	      batchSize = _backend_util$compute.batchSize,
	      inHeight = _backend_util$compute.inHeight,
	      inWidth = _backend_util$compute.inWidth,
	      inChannels = _backend_util$compute.inChannels,
	      outHeight = _backend_util$compute.outHeight,
	      outWidth = _backend_util$compute.outWidth,
	      padInfo = _backend_util$compute.padInfo,
	      strideHeight = _backend_util$compute.strideHeight,
	      strideWidth = _backend_util$compute.strideWidth,
	      filterHeight = _backend_util$compute.filterHeight,
	      filterWidth = _backend_util$compute.filterWidth,
	      dilationHeight = _backend_util$compute.dilationHeight,
	      dilationWidth = _backend_util$compute.dilationWidth,
	      outShape = _backend_util$compute.outShape;
	    assert$1(dy.rank === outShape.length, function () {
	      return "Error in ".concat(Dilation2DBackpropInput, ", dy ") + "must have the same rank as output ".concat(outShape.length, ", but got ") + "".concat(dy.rank);
	    });
	    var $dy = toNestedArray(outShape, cpuBackend.data.get(dy.dataId).values);
	    // The computed gradients has the same dimensions as the input:
	    // [batch, inputHeight, inputCols, inChannel]
	    var gradients = makeZerosNestedTypedArray(x.shape, x.dtype);
	    // In the case of multiple argmax branches, we only back-propagate along the
	    // last branch, i.e., the one with largest value of `h * filter_cols + w`,
	    // similarly to the max-pooling backward routines.
	    // This implementation follows the TF c++ implementation:
	    // https://github.com/tensorflow/tensorflow/blob/d9a3a849edc198e90172bc58eb293de457f9d986/tensorflow/core/kernels/dilation_ops.cc
	    for (var b = 0; b < batchSize; ++b) {
	      for (var hOut = 0; hOut < outHeight; ++hOut) {
	        var hBeg = hOut * strideHeight - padInfo.top;
	        for (var wOut = 0; wOut < outWidth; ++wOut) {
	          var wBeg = wOut * strideWidth - padInfo.left;
	          for (var d = 0; d < inChannels; ++d) {
	            var curVal = Number.MIN_SAFE_INTEGER;
	            var hInMax = hBeg < 0 ? 0 : hBeg;
	            var wInMax = wBeg < 0 ? 0 : wBeg;
	            for (var h = 0; h < filterHeight; ++h) {
	              var hIn = hBeg + h * dilationHeight;
	              if (hIn >= 0 && hIn < inHeight) {
	                for (var w = 0; w < filterWidth; ++w) {
	                  var wIn = wBeg + w * dilationWidth;
	                  if (wIn >= 0 && wIn < inWidth) {
	                    var val = $x[b][hIn][wIn][d] + $filter[h][w][d];
	                    if (val > curVal) {
	                      curVal = val;
	                      hInMax = hIn;
	                      wInMax = wIn;
	                    }
	                  }
	                }
	              }
	            }
	            gradients[b][hInMax][wInMax][d] += $dy[b][hOut][wOut][d];
	          }
	        }
	      }
	    }
	    var dataId = cpuBackend.write(toTypedArray(gradients, x.dtype), x.shape, x.dtype);
	    return {
	      dataId: dataId,
	      shape: x.shape,
	      dtype: x.dtype
	    };
	  }
	};

	function draw(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var image = inputs.image;
	  var canvas = attrs.canvas,
	    options = attrs.options;
	  var _ref = options || {},
	    contextOptions = _ref.contextOptions,
	    imageOptions = _ref.imageOptions;
	  var alpha = (imageOptions === null || imageOptions === void 0 ? void 0 : imageOptions.alpha) || 1;
	  var contextType = (contextOptions === null || contextOptions === void 0 ? void 0 : contextOptions.contextType) || '2d';
	  if (contextType !== '2d') {
	    throw new Error("Context type ".concat(contextOptions.contextType, " is not supported by the CPU backend."));
	  }
	  var ctx = canvas.getContext(contextType, (contextOptions === null || contextOptions === void 0 ? void 0 : contextOptions.contextAttributes) || {});
	  if (ctx == null) {
	    throw new Error("Could not get the context with ".concat(contextType, " type."));
	  }
	  var _image$shape$slice = image.shape.slice(0, 2),
	    _image$shape$slice2 = _slicedToArray(_image$shape$slice, 2),
	    height = _image$shape$slice2[0],
	    width = _image$shape$slice2[1];
	  var depth = image.shape.length === 2 ? 1 : image.shape[2];
	  var data = backend.data.get(image.dataId).values;
	  var multiplier = image.dtype === 'float32' ? 255 : 1;
	  var bytes = new Uint8ClampedArray(width * height * 4);
	  for (var i = 0; i < height * width; ++i) {
	    var rgba = [0, 0, 0, 255 * alpha];
	    for (var d = 0; d < depth; d++) {
	      var value = data[i * depth + d];
	      if (image.dtype === 'float32') {
	        if (value < 0 || value > 1) {
	          throw new Error("Tensor values for a float32 Tensor must be in the " + "range [0 - 1] but encountered ".concat(value, "."));
	        }
	      } else if (image.dtype === 'int32') {
	        if (value < 0 || value > 255) {
	          throw new Error("Tensor values for a int32 Tensor must be in the " + "range [0 - 255] but encountered ".concat(value, "."));
	        }
	      }
	      if (depth === 1) {
	        rgba[0] = value * multiplier;
	        rgba[1] = value * multiplier;
	        rgba[2] = value * multiplier;
	      } else {
	        rgba[d] = value * multiplier;
	      }
	    }
	    var j = i * 4;
	    bytes[j + 0] = Math.round(rgba[0]);
	    bytes[j + 1] = Math.round(rgba[1]);
	    bytes[j + 2] = Math.round(rgba[2]);
	    bytes[j + 3] = Math.round(rgba[3]);
	  }
	  canvas.width = width;
	  canvas.height = height;
	  var imageData = new ImageData(bytes, width, height);
	  ctx.putImageData(imageData, 0, 0);
	  return image;
	}
	var drawConfig = {
	  kernelName: Draw,
	  backendName: 'cpu',
	  kernelFunc: draw
	};

	function sum$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis,
	    keepDims = attrs.keepDims;
	  assertNotComplex$1(x, 'sum');
	  var $x;
	  if (x.dtype === 'bool') {
	    $x = cast$1({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        dtype: 'int32'
	      }
	    });
	  } else {
	    $x = identity$1({
	      inputs: {
	        x: x
	      },
	      backend: backend
	    });
	  }
	  var xRank = $x.shape.length;
	  var axes = parseAxisParam(axis, $x.shape);
	  var permutation = getAxesPermutation(axes, xRank);
	  var reductionAxes = axes;
	  var permutedX = $x;
	  if (permutation != null) {
	    permutedX = transpose$1({
	      inputs: {
	        x: $x
	      },
	      backend: backend,
	      attrs: {
	        perm: permutation
	      }
	    });
	    reductionAxes = getInnerMostAxes(reductionAxes.length, xRank);
	  }
	  assertAxesAreInnerMostDims('sum', reductionAxes, permutedX.shape.length);
	  var _backend_util$compute = computeOutAndReduceShapes(permutedX.shape, reductionAxes),
	    _backend_util$compute2 = _slicedToArray(_backend_util$compute, 2),
	    outShape = _backend_util$compute2[0],
	    reduceShape = _backend_util$compute2[1];
	  var resultDtype = upcastType(permutedX.dtype, 'int32');
	  var result = zeros(backend, outShape, resultDtype);
	  var reduceSize = sizeFromShape(reduceShape);
	  var vals = backend.data.get(result.dataId).values;
	  var aVals = backend.data.get(permutedX.dataId).values;
	  for (var i = 0; i < vals.length; ++i) {
	    var offset = i * reduceSize;
	    var _sum = 0;
	    for (var j = 0; j < reduceSize; ++j) {
	      _sum += aVals[offset + j];
	    }
	    vals[i] = _sum;
	  }
	  if (keepDims) {
	    var newShape = expandShapeToKeepDim(result.shape, axes);
	    var oldResult = result;
	    result = reshape$1({
	      inputs: {
	        x: result
	      },
	      backend: backend,
	      attrs: {
	        shape: newShape
	      }
	    });
	    backend.disposeIntermediateTensorInfo(oldResult);
	  }
	  backend.disposeIntermediateTensorInfo($x);
	  if (permutation != null) {
	    backend.disposeIntermediateTensorInfo(permutedX);
	  }
	  return result;
	}
	var sumConfig$1 = {
	  kernelName: Sum,
	  backendName: 'cpu',
	  kernelFunc: sum$1
	};

	function einsum$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var equation = attrs.equation;
	  var tensors = inputs;
	  var _backend_util$decodeE = decodeEinsumEquation(equation, tensors.length),
	    allDims = _backend_util$decodeE.allDims,
	    summedDims = _backend_util$decodeE.summedDims,
	    idDims = _backend_util$decodeE.idDims;
	  checkEinsumDimSizes(allDims.length, idDims, tensors);
	  var _backend_util$getEins = getEinsumComputePath(summedDims, idDims),
	    path = _backend_util$getEins.path,
	    steps = _backend_util$getEins.steps;
	  var nSteps = steps.length;
	  var out = null;
	  var numDimsRemaining = allDims.length;
	  var tensorsToDispose = [];
	  for (var i = 0; i < nSteps; ++i) {
	    var _iterator = _createForOfIteratorHelper(steps[i]),
	      _step;
	    try {
	      for (_iterator.s(); !(_step = _iterator.n()).done;) {
	        var idTerm = _step.value;
	        var _backend_util$getEins2 = getEinsumPermutation(numDimsRemaining, idDims[idTerm]),
	          perm = _backend_util$getEins2.permutationIndices,
	          dimsToExpand = _backend_util$getEins2.expandDims;
	        var x = void 0;
	        if (isIdentityPermutation(perm)) {
	          x = tensors[idTerm];
	        } else {
	          x = transpose$1({
	            inputs: {
	              x: tensors[idTerm]
	            },
	            backend: backend,
	            attrs: {
	              perm: perm
	            }
	          });
	          tensorsToDispose.push(x);
	        }
	        var targetShape = x.shape.slice();
	        for (var k = 0; k < dimsToExpand.length; ++k) {
	          targetShape.splice(dimsToExpand[k], 0, 1);
	        }
	        if (!arraysEqual(x.shape, targetShape)) {
	          x = reshape$1({
	            inputs: {
	              x: x
	            },
	            backend: backend,
	            attrs: {
	              shape: targetShape
	            }
	          });
	          tensorsToDispose.push(x);
	        }
	        if (out === null) {
	          out = x;
	        } else {
	          // tslint:disable-next-line: no-unnecessary-type-assertion
	          out = multiply$1({
	            inputs: {
	              a: x,
	              b: out
	            },
	            backend: backend
	          });
	          tensorsToDispose.push(out);
	        }
	      }
	    } catch (err) {
	      _iterator.e(err);
	    } finally {
	      _iterator.f();
	    }
	    if (i < nSteps - 1) {
	      if (path[i] >= 0) {
	        out = sum$1({
	          inputs: {
	            x: out
	          },
	          backend: backend,
	          attrs: {
	            axis: path[i] - (allDims.length - numDimsRemaining),
	            keepDims: false
	          }
	        });
	        tensorsToDispose.push(out);
	      }
	      numDimsRemaining--;
	    }
	  }
	  // Clean up intermediate tensors.
	  for (var _i = 0, _tensorsToDispose = tensorsToDispose; _i < _tensorsToDispose.length; _i++) {
	    var tensorInfo = _tensorsToDispose[_i];
	    if (tensorInfo === out) {
	      continue;
	    }
	    backend.disposeIntermediateTensorInfo(tensorInfo);
	  }
	  return out;
	}
	var einsumConfig$1 = {
	  kernelName: Einsum,
	  backendName: 'cpu',
	  kernelFunc: einsum$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function eluGrad$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var dy = inputs.dy,
	    y = inputs.y;
	  assertNotComplex$1([dy, y], 'eluGrad');
	  var resultValues = new Float32Array(sizeFromShape(y.shape));
	  var values = backend.data.get(y.dataId).values;
	  var dyValues = backend.data.get(dy.dataId).values;
	  for (var i = 0; i < values.length; ++i) {
	    var v = values[i];
	    if (v >= 0) {
	      resultValues[i] = dyValues[i];
	    } else {
	      resultValues[i] = dyValues[i] * (v + 1);
	    }
	  }
	  return backend.makeTensorInfo(y.shape, 'float32', resultValues);
	}
	var eluGradConfig$1 = {
	  kernelName: EluGrad,
	  backendName: 'cpu',
	  kernelFunc: eluGrad$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var p = ERF_P;
	var a1 = ERF_A1;
	var a2 = ERF_A2;
	var a3 = ERF_A3;
	var a4 = ERF_A4;
	var a5 = ERF_A5;
	var erf$1 = unaryKernelFunc$1(Erf, function (xi) {
	  var sign = Math.sign(xi);
	  var v = Math.abs(xi);
	  var t = 1.0 / (1.0 + p * v);
	  return sign * (1.0 - ((((a5 * t + a4) * t + a3) * t + a2) * t + a1) * t * Math.exp(-v * v));
	});
	var erfConfig$1 = {
	  kernelName: Erf,
	  backendName: 'cpu',
	  kernelFunc: erf$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function expandDims$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var input = inputs.input;
	  var dim = attrs.dim;
	  var inputRank = input.shape.length;
	  var newShape = input.shape.slice();
	  var $dim = dim;
	  if (dim < 0) {
	    // Negative value is counted from the tail of rank.
	    assert$1(-(inputRank + 1) <= dim, function () {
	      return "Axis must be in the interval [".concat(-(inputRank + 1), ", ").concat(inputRank, "]");
	    });
	    $dim = inputRank + dim + 1;
	  }
	  newShape.splice($dim, 0, 1);
	  return reshape$1({
	    inputs: {
	      x: input
	    },
	    backend: backend,
	    attrs: {
	      shape: newShape
	    }
	  });
	}
	var expandDimsConfig$1 = {
	  kernelName: ExpandDims,
	  backendName: 'cpu',
	  kernelFunc: expandDims$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var realDivImpl = createSimpleBinaryKernelImpl(function (a, b) {
	  return a / b;
	});
	var div = binaryKernelFunc$1(RealDiv, realDivImpl);
	var realDivConfig$1 = {
	  kernelName: RealDiv,
	  backendName: 'cpu',
	  kernelFunc: div
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Calculate FFT of inner most elements of batch tensor.
	 */
	function fftBatch(input, inverse, cpuBackend) {
	  var inputShape = input.shape;
	  var batch = inputShape[0];
	  var innerDim = inputShape[1];
	  var inputVals = cpuBackend.data.get(input.dataId);
	  var real2D = inputVals.complexTensorInfos.real;
	  var imag2D = inputVals.complexTensorInfos.imag;
	  // Collects real and imaginary values separately.
	  var resultShape = [batch, innerDim];
	  var resultSize = sizeFromShape(resultShape);
	  var resultReal = getTypedArrayFromDType('float32', resultSize);
	  var resultImag = getTypedArrayFromDType('float32', resultSize);
	  for (var b = 0; b < batch; b++) {
	    // TODO: Support slice ops for complex type.
	    var r = slice$1({
	      inputs: {
	        x: real2D
	      },
	      backend: cpuBackend,
	      attrs: {
	        begin: [b, 0],
	        size: [1, innerDim]
	      }
	    });
	    var i = slice$1({
	      inputs: {
	        x: imag2D
	      },
	      backend: cpuBackend,
	      attrs: {
	        begin: [b, 0],
	        size: [1, innerDim]
	      }
	    });
	    var _input = complex$1({
	      inputs: {
	        real: r,
	        imag: i
	      },
	      backend: cpuBackend
	    });
	    // Run FFT by batch element.
	    var _fftImpl = fftImpl$1(_input, inverse, cpuBackend),
	      _real = _fftImpl.real,
	      _imag = _fftImpl.imag;
	    var res = mergeRealAndImagArrays(_real, _imag);
	    for (var d = 0; d < innerDim; d++) {
	      var c = getComplexWithIndex(res, d);
	      resultReal[b * innerDim + d] = c.real;
	      resultImag[b * innerDim + d] = c.imag;
	    }
	    cpuBackend.disposeIntermediateTensorInfo(r);
	    cpuBackend.disposeIntermediateTensorInfo(i);
	    cpuBackend.disposeIntermediateTensorInfo(_input);
	  }
	  var $realInfo = cpuBackend.makeTensorInfo(resultShape, 'float32', resultReal);
	  var $imagInfo = cpuBackend.makeTensorInfo(resultShape, 'float32', resultImag);
	  var result = complex$1({
	    inputs: {
	      real: $realInfo,
	      imag: $imagInfo
	    },
	    backend: cpuBackend
	  });
	  cpuBackend.disposeIntermediateTensorInfo($realInfo);
	  cpuBackend.disposeIntermediateTensorInfo($imagInfo);
	  return result;
	}
	function fftImpl$1(input, inverse, cpuBackend) {
	  var inputSize = sizeFromShape(input.shape);
	  var inputVals = cpuBackend.data.get(input.dataId);
	  var realVals = cpuBackend.data.get(inputVals.complexTensorInfos.real.dataId).values;
	  var imagVals = cpuBackend.data.get(inputVals.complexTensorInfos.imag.dataId).values;
	  if (isExponentOf2(inputSize)) {
	    var result = fftRadix2(realVals, imagVals, inputSize, inverse, cpuBackend);
	    var resultShape = [input.shape[0], input.shape[1]];
	    if (inverse) {
	      var realInfo = cpuBackend.makeTensorInfo(resultShape, 'float32', result.real);
	      var imagInfo = cpuBackend.makeTensorInfo(resultShape, 'float32', result.imag);
	      var sizeInfo = cpuBackend.makeTensorInfo([], 'float32', createScalarValue(inputSize, 'float32'));
	      var sizeInfoCopy = identity$1({
	        inputs: {
	          x: sizeInfo
	        },
	        backend: cpuBackend
	      });
	      var divRealInfo = realDivConfig$1.kernelFunc({
	        inputs: {
	          a: realInfo,
	          b: sizeInfo
	        },
	        backend: cpuBackend
	      });
	      var divImagInfo = realDivConfig$1.kernelFunc({
	        inputs: {
	          a: imagInfo,
	          b: sizeInfoCopy
	        },
	        backend: cpuBackend
	      });
	      var divRealVals = cpuBackend.data.get(divRealInfo.dataId).values;
	      var divImagVals = cpuBackend.data.get(divImagInfo.dataId).values;
	      cpuBackend.disposeIntermediateTensorInfo(realInfo);
	      cpuBackend.disposeIntermediateTensorInfo(imagInfo);
	      cpuBackend.disposeIntermediateTensorInfo(sizeInfo);
	      cpuBackend.disposeIntermediateTensorInfo(sizeInfoCopy);
	      cpuBackend.disposeIntermediateTensorInfo(divRealInfo);
	      cpuBackend.disposeIntermediateTensorInfo(divImagInfo);
	      return {
	        real: divRealVals,
	        imag: divImagVals
	      };
	    }
	    return result;
	  } else {
	    var data = mergeRealAndImagArrays(realVals, imagVals);
	    var rawOutput = fourierTransformByMatmul(data, inputSize, inverse);
	    return splitRealAndImagArrays(rawOutput);
	  }
	}
	function isExponentOf2(size) {
	  return (size & size - 1) === 0;
	}
	// FFT using Cooley-Tukey algorithm on radix 2 dimensional input.
	function fftRadix2(realVals, imagVals, size, inverse, cpuBackend) {
	  if (size === 1) {
	    return {
	      real: realVals,
	      imag: imagVals
	    };
	  }
	  var data = mergeRealAndImagArrays(realVals, imagVals);
	  var half = size / 2;
	  var evenComplex = complexWithEvenIndex(data);
	  var evenRealVals = evenComplex.real;
	  var evenImagVals = evenComplex.imag;
	  var evenShape = [evenRealVals.length];
	  var evenRealInfo = cpuBackend.makeTensorInfo(evenShape, 'float32', evenRealVals);
	  var evenImagInfo = cpuBackend.makeTensorInfo(evenShape, 'float32', evenImagVals);
	  var evenTensorInfo = complex$1({
	    inputs: {
	      real: evenRealInfo,
	      imag: evenImagInfo
	    },
	    backend: cpuBackend
	  });
	  var oddComplex = complexWithOddIndex(data);
	  var oddRealVals = oddComplex.real;
	  var oddImagVals = oddComplex.imag;
	  var oddShape = [oddRealVals.length];
	  var oddRealInfo = cpuBackend.makeTensorInfo(oddShape, 'float32', oddRealVals);
	  var oddImagInfo = cpuBackend.makeTensorInfo(oddShape, 'float32', oddImagVals);
	  var oddTensorInfo = complex$1({
	    inputs: {
	      real: oddRealInfo,
	      imag: oddImagInfo
	    },
	    backend: cpuBackend
	  });
	  // Recursive call for half part of original input.
	  var $evenComplex = fftRadix2(evenRealVals, evenImagVals, half, inverse, cpuBackend);
	  var $evenRealVals = $evenComplex.real;
	  var $evenImagVals = $evenComplex.imag;
	  var $evenShape = [$evenRealVals.length];
	  var $evenRealInfo = cpuBackend.makeTensorInfo($evenShape, 'float32', $evenRealVals);
	  var $evenImagInfo = cpuBackend.makeTensorInfo($evenShape, 'float32', $evenImagVals);
	  var $evenTensorInfo = complex$1({
	    inputs: {
	      real: $evenRealInfo,
	      imag: $evenImagInfo
	    },
	    backend: cpuBackend
	  });
	  var $oddComplex = fftRadix2(oddRealVals, oddImagVals, half, inverse, cpuBackend);
	  var $oddRealVals = $oddComplex.real;
	  var $oddImagVals = $oddComplex.imag;
	  var $oddShape = [$oddRealVals.length];
	  var $oddRealInfo = cpuBackend.makeTensorInfo($oddShape, 'float32', $oddRealVals);
	  var $oddImagInfo = cpuBackend.makeTensorInfo($oddShape, 'float32', $oddImagVals);
	  var $oddTensorInfo = complex$1({
	    inputs: {
	      real: $oddRealInfo,
	      imag: $oddImagInfo
	    },
	    backend: cpuBackend
	  });
	  var e = exponents(size, inverse);
	  var eShape = [e.real.length];
	  var eRealInfo = cpuBackend.makeTensorInfo(eShape, 'float32', e.real);
	  var eImagInfo = cpuBackend.makeTensorInfo(eShape, 'float32', e.imag);
	  var complexInfo = complex$1({
	    inputs: {
	      real: eRealInfo,
	      imag: eImagInfo
	    },
	    backend: cpuBackend
	  });
	  var exponentInfo = multiply$1({
	    inputs: {
	      a: complexInfo,
	      b: $oddTensorInfo
	    },
	    backend: cpuBackend
	  });
	  var addPart = add({
	    inputs: {
	      a: $evenTensorInfo,
	      b: exponentInfo
	    },
	    backend: cpuBackend
	  });
	  var subPart = sub$1({
	    inputs: {
	      a: $evenTensorInfo,
	      b: exponentInfo
	    },
	    backend: cpuBackend
	  });
	  var addPartReal = real$1({
	    inputs: {
	      input: addPart
	    },
	    backend: cpuBackend
	  });
	  var subPartReal = real$1({
	    inputs: {
	      input: subPart
	    },
	    backend: cpuBackend
	  });
	  var addPartImag = imag$1({
	    inputs: {
	      input: addPart
	    },
	    backend: cpuBackend
	  });
	  var subPartImag = imag$1({
	    inputs: {
	      input: subPart
	    },
	    backend: cpuBackend
	  });
	  var $real = concat$1({
	    inputs: [addPartReal, subPartReal],
	    backend: cpuBackend,
	    attrs: {
	      axis: 0
	    }
	  });
	  var $imag = concat$1({
	    inputs: [addPartImag, subPartImag],
	    backend: cpuBackend,
	    attrs: {
	      axis: 0
	    }
	  });
	  var $realVals = cpuBackend.data.get($real.dataId).values;
	  var $imagVals = cpuBackend.data.get($imag.dataId).values;
	  cpuBackend.disposeIntermediateTensorInfo(evenRealInfo);
	  cpuBackend.disposeIntermediateTensorInfo(evenImagInfo);
	  cpuBackend.disposeIntermediateTensorInfo(evenTensorInfo);
	  cpuBackend.disposeIntermediateTensorInfo(oddRealInfo);
	  cpuBackend.disposeIntermediateTensorInfo(oddImagInfo);
	  cpuBackend.disposeIntermediateTensorInfo(oddTensorInfo);
	  cpuBackend.disposeIntermediateTensorInfo($evenRealInfo);
	  cpuBackend.disposeIntermediateTensorInfo($evenImagInfo);
	  cpuBackend.disposeIntermediateTensorInfo($evenTensorInfo);
	  cpuBackend.disposeIntermediateTensorInfo($oddRealInfo);
	  cpuBackend.disposeIntermediateTensorInfo($oddImagInfo);
	  cpuBackend.disposeIntermediateTensorInfo($oddTensorInfo);
	  cpuBackend.disposeIntermediateTensorInfo(eRealInfo);
	  cpuBackend.disposeIntermediateTensorInfo(eImagInfo);
	  cpuBackend.disposeIntermediateTensorInfo(complexInfo);
	  cpuBackend.disposeIntermediateTensorInfo(exponentInfo);
	  cpuBackend.disposeIntermediateTensorInfo(addPart);
	  cpuBackend.disposeIntermediateTensorInfo(subPart);
	  cpuBackend.disposeIntermediateTensorInfo(addPartReal);
	  cpuBackend.disposeIntermediateTensorInfo(addPartImag);
	  cpuBackend.disposeIntermediateTensorInfo(subPartReal);
	  cpuBackend.disposeIntermediateTensorInfo(subPartImag);
	  cpuBackend.disposeIntermediateTensorInfo($real);
	  cpuBackend.disposeIntermediateTensorInfo($imag);
	  return {
	    real: $realVals,
	    imag: $imagVals
	  };
	}
	// Calculate fourier transform by multplying sinusoid matrix.
	function fourierTransformByMatmul(data, size, inverse) {
	  var ret = new Float32Array(size * 2);
	  // TODO: Use matmul instead once it supports complex64 type.
	  for (var r = 0; r < size; r++) {
	    var _real2 = 0.0;
	    var _imag2 = 0.0;
	    for (var c = 0; c < size; c++) {
	      var e = exponent(r * c, size, inverse);
	      var term = getComplexWithIndex(data, c);
	      _real2 += term.real * e.real - term.imag * e.imag;
	      _imag2 += term.real * e.imag + term.imag * e.real;
	    }
	    if (inverse) {
	      _real2 /= size;
	      _imag2 /= size;
	    }
	    assignToTypedArray(ret, _real2, _imag2, r);
	  }
	  return ret;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function fft$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var input = inputs.input;
	  var inputSize = sizeFromShape(input.shape);
	  // Collapse all outer dimensions to a single batch dimension.
	  var innerDimensionSize = input.shape[input.shape.length - 1];
	  var batch = inputSize / innerDimensionSize;
	  var input2D = reshape$1({
	    inputs: {
	      x: input
	    },
	    backend: backend,
	    attrs: {
	      shape: [batch, innerDimensionSize]
	    }
	  });
	  var result = fftBatch(input2D, false, backend);
	  var resultReshaped = reshape$1({
	    inputs: {
	      x: result
	    },
	    backend: backend,
	    attrs: {
	      shape: input.shape
	    }
	  });
	  backend.disposeIntermediateTensorInfo(input2D);
	  backend.disposeIntermediateTensorInfo(result);
	  return resultReshaped;
	}
	var fftConfig$1 = {
	  kernelName: FFT,
	  backendName: 'cpu',
	  kernelFunc: fft$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function fill$1(args) {
	  var backend = args.backend,
	    attrs = args.attrs;
	  var shape = attrs.shape,
	    value = attrs.value,
	    dtype = attrs.dtype;
	  var $dtype = dtype || inferDtype(value);
	  var values = getArrayFromDType($dtype, sizeFromShape(shape));
	  fillValues(values, value, $dtype);
	  return backend.makeTensorInfo(shape, $dtype, values);
	}
	var fillConfig$1 = {
	  kernelName: Fill,
	  backendName: 'cpu',
	  kernelFunc: fill$1
	};
	function fillValues(values, value, dtype) {
	  if (dtype === 'string') {
	    values.fill(value);
	  } else {
	    values.fill(value);
	  }
	}

	var flipLeftRightConfig$1 = {
	  kernelName: FlipLeftRight,
	  backendName: 'cpu',
	  kernelFunc: function kernelFunc(_ref) {
	    var inputs = _ref.inputs,
	      attrs = _ref.attrs,
	      backend = _ref.backend;
	    var image = inputs.image;
	    var cpuBackend = backend;
	    var output = getTypedArrayFromDType(image.dtype, sizeFromShape(image.shape));
	    var _image$shape = _slicedToArray(image.shape, 4),
	      batch = _image$shape[0],
	      imageHeight = _image$shape[1],
	      imageWidth = _image$shape[2],
	      numChannels = _image$shape[3];
	    var imageVals = cpuBackend.data.get(image.dataId).values;
	    for (var batchIdx = 0; batchIdx < batch; batchIdx++) {
	      var batchOffset = batchIdx * imageWidth * imageHeight * numChannels;
	      for (var row = 0; row < imageHeight; row++) {
	        var rowOffset = row * (imageWidth * numChannels);
	        for (var col = 0; col < imageWidth; col++) {
	          var colOffset = col * numChannels;
	          for (var channel = 0; channel < numChannels; channel++) {
	            var coordX = Math.round(imageWidth - col - 1);
	            var outIdx = batchOffset + rowOffset + colOffset + channel;
	            var outputValue = imageVals[outIdx];
	            // If the coordinate position falls within the image boundaries...
	            if (coordX >= 0 && coordX < imageWidth) {
	              // set the output to the image value at the coordinate position.
	              var rotatedColOffset = coordX * numChannels;
	              var imageIdx = batchOffset + rowOffset + rotatedColOffset + channel;
	              outputValue = imageVals[imageIdx];
	            }
	            output[outIdx] = outputValue;
	          }
	        }
	      }
	    }
	    var dataId = cpuBackend.write(output, image.shape, image.dtype);
	    return {
	      dataId: dataId,
	      shape: image.shape,
	      dtype: image.dtype
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function fusedConv2D(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    filter = inputs.filter,
	    bias = inputs.bias,
	    preluActivationWeights = inputs.preluActivationWeights;
	  var strides = attrs.strides,
	    pad = attrs.pad,
	    dataFormat = attrs.dataFormat,
	    dilations = attrs.dilations,
	    dimRoundingMode = attrs.dimRoundingMode,
	    activation = attrs.activation,
	    leakyreluAlpha = attrs.leakyreluAlpha;
	  var result = conv2D({
	    inputs: {
	      x: x,
	      filter: filter
	    },
	    backend: backend,
	    attrs: {
	      strides: strides,
	      pad: pad,
	      dataFormat: dataFormat,
	      dilations: dilations,
	      dimRoundingMode: dimRoundingMode
	    }
	  });
	  if (bias) {
	    var resultOld = result;
	    // For NCHW format, if bias is a 1-D tensor, it is supposed to be aligned
	    // to the channel of the conv2d's result; if the bias is a scalar, the
	    // bias_add is computed as if the bias was broadcasted to the shape of the
	    // conv2d's result.
	    if (dataFormat === 'NCHW' && bias.shape.length === 1 && bias.shape[0] !== 1) {
	      var reshapedBias = reshape$1({
	        inputs: {
	          x: bias
	        },
	        backend: backend,
	        attrs: {
	          shape: [bias.shape[0], 1, 1]
	        }
	      });
	      result = add({
	        inputs: {
	          a: result,
	          b: reshapedBias
	        },
	        backend: backend
	      });
	      backend.disposeIntermediateTensorInfo(reshapedBias);
	    } else {
	      // This condition handles NHWC and NCHW (scalar case). The only other case
	      // for NCHW (1D case) is handled above.
	      result = add({
	        inputs: {
	          a: result,
	          b: bias
	        },
	        backend: backend
	      });
	    }
	    backend.disposeIntermediateTensorInfo(resultOld);
	  }
	  if (activation) {
	    var _resultOld = result;
	    // For NCHW format, if PReLu activation weights is a 1-D tensor, it is
	    // supposed to be aligned with the channel of the conv2d's result. For other
	    // cases, whether NCHW or NHWC data format, the conv2d result is
	    // already aligned with the activation weights.
	    if (dataFormat === 'NCHW' && activation === 'prelu' && preluActivationWeights.shape.length === 1 && preluActivationWeights.shape[0] !== 1) {
	      var reshapedAlpha = reshape$1({
	        inputs: {
	          x: preluActivationWeights
	        },
	        backend: backend,
	        attrs: {
	          shape: [preluActivationWeights.shape[0], 1, 1]
	        }
	      });
	      result = applyActivation(backend, result, activation, reshapedAlpha, leakyreluAlpha);
	      backend.disposeIntermediateTensorInfo(reshapedAlpha);
	    } else {
	      result = applyActivation(backend, result, activation, preluActivationWeights, leakyreluAlpha);
	    }
	    backend.disposeIntermediateTensorInfo(_resultOld);
	  }
	  return result;
	}
	var fusedConv2DConfig$1 = {
	  kernelName: FusedConv2D,
	  backendName: 'cpu',
	  kernelFunc: fusedConv2D
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function fusedDepthwiseConv2D$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    filter = inputs.filter,
	    bias = inputs.bias,
	    preluActivationWeights = inputs.preluActivationWeights;
	  var strides = attrs.strides,
	    pad = attrs.pad,
	    dataFormat = attrs.dataFormat,
	    dilations = attrs.dilations,
	    dimRoundingMode = attrs.dimRoundingMode,
	    activation = attrs.activation,
	    leakyreluAlpha = attrs.leakyreluAlpha;
	  var result = depthwiseConv2dNative$1({
	    inputs: {
	      x: x,
	      filter: filter
	    },
	    backend: backend,
	    attrs: {
	      strides: strides,
	      pad: pad,
	      dataFormat: dataFormat,
	      dilations: dilations,
	      dimRoundingMode: dimRoundingMode
	    }
	  });
	  if (bias) {
	    var oldResult = result;
	    result = add({
	      inputs: {
	        a: result,
	        b: bias
	      },
	      backend: backend
	    });
	    backend.disposeIntermediateTensorInfo(oldResult);
	  }
	  if (activation) {
	    var _oldResult = result;
	    result = applyActivation(backend, result, activation, preluActivationWeights, leakyreluAlpha);
	    backend.disposeIntermediateTensorInfo(_oldResult);
	  }
	  return result;
	}
	var fusedDepthwiseConv2DConfig$1 = {
	  kernelName: FusedDepthwiseConv2D,
	  backendName: 'cpu',
	  kernelFunc: fusedDepthwiseConv2D$1
	};

	function gatherNd$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var params = inputs.params,
	    indices = inputs.indices;
	  var paramsSize = sizeFromShape(params.shape);
	  var indicesShape = indices.shape;
	  var sliceRank = indicesShape[indicesShape.length - 1];
	  var _backend_util$prepare = prepareAndValidate(params, indices),
	    _backend_util$prepare2 = _slicedToArray(_backend_util$prepare, 4),
	    resultShape = _backend_util$prepare2[0],
	    numSlices = _backend_util$prepare2[1],
	    sliceSize = _backend_util$prepare2[2],
	    strides = _backend_util$prepare2[3];
	  if (numSlices === 0) {
	    return backend.makeTensorInfo(resultShape, params.dtype, []);
	  }
	  var indicesData = backend.data.get(indices.dataId).values;
	  var paramsBuf = backend.bufferSync(params);
	  var outBuf = gatherNdImpl(indicesData, paramsBuf, params.dtype, numSlices, sliceRank, sliceSize, strides, params.shape, paramsSize);
	  return backend.makeTensorInfo(resultShape, params.dtype, outBuf.values);
	}
	var gatherNdConfig$1 = {
	  kernelName: GatherNd,
	  backendName: 'cpu',
	  kernelFunc: gatherNd$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function gatherV2$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    indices = inputs.indices;
	  var axis = attrs.axis,
	    batchDims = attrs.batchDims;
	  assertNotComplex$1([x, indices], 'gatherV2');
	  // Throw error when any index is out of bound.
	  var parsedAxis = parseAxisParam(axis, x.shape)[0];
	  var indicesVals = backend.data.get(indices.dataId).values;
	  var axisDim = x.shape[parsedAxis];
	  var _loop = function _loop() {
	    var index = indicesVals[i];
	    assert$1(index <= axisDim - 1 && index >= 0, function () {
	      return "GatherV2: the index value ".concat(index, " is not in [0, ").concat(axisDim - 1, "]");
	    });
	  };
	  for (var i = 0; i < indicesVals.length; ++i) {
	    _loop();
	  }
	  var $batchDims = batchDims;
	  if (batchDims == null) {
	    $batchDims = 0;
	  }
	  var indicesSize = sizeFromShape(indices.shape);
	  var shapeInfo = collectGatherOpShapeInfo(x, indices, parsedAxis, $batchDims);
	  var flattenX = reshape$1({
	    inputs: {
	      x: x
	    },
	    backend: backend,
	    attrs: {
	      shape: [shapeInfo.batchSize, shapeInfo.outerSize, shapeInfo.dimSize, shapeInfo.sliceSize]
	    }
	  });
	  var flattenIndex = reshape$1({
	    inputs: {
	      x: indices
	    },
	    backend: backend,
	    attrs: {
	      shape: [shapeInfo.batchSize, indicesSize / shapeInfo.batchSize]
	    }
	  });
	  var flattenOutputShape = [shapeInfo.batchSize, shapeInfo.outerSize, indicesSize / shapeInfo.batchSize, shapeInfo.sliceSize];
	  var indicesBuf = backend.bufferSync(flattenIndex);
	  var xBuf = backend.bufferSync(flattenX);
	  var outBuf = gatherV2Impl(xBuf, indicesBuf, flattenOutputShape);
	  backend.disposeIntermediateTensorInfo(flattenX);
	  backend.disposeIntermediateTensorInfo(flattenIndex);
	  return backend.makeTensorInfo(shapeInfo.outputShape, outBuf.dtype, outBuf.values);
	}
	var gatherV2Config$1 = {
	  kernelName: GatherV2,
	  backendName: 'cpu',
	  kernelFunc: gatherV2$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function ifft$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var input = inputs.input;
	  var inputSize = sizeFromShape(input.shape);
	  // Collapse all outer dimensions to a single batch dimension.
	  var innerDimensionSize = input.shape[input.shape.length - 1];
	  var batch = inputSize / innerDimensionSize;
	  var input2D = reshape$1({
	    inputs: {
	      x: input
	    },
	    backend: backend,
	    attrs: {
	      shape: [batch, innerDimensionSize]
	    }
	  });
	  var result = fftBatch(input2D, true, backend);
	  var resultReshaped = reshape$1({
	    inputs: {
	      x: result
	    },
	    backend: backend,
	    attrs: {
	      shape: input.shape
	    }
	  });
	  backend.disposeIntermediateTensorInfo(input2D);
	  backend.disposeIntermediateTensorInfo(result);
	  return resultReshaped;
	}
	var ifftConfig$1 = {
	  kernelName: IFFT,
	  backendName: 'cpu',
	  kernelFunc: ifft$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var isFinite$2 = unaryKernelFunc$1(IsFinite, function (xi) {
	  return Number.isFinite(xi) ? 1 : 0;
	}, 'bool');
	var isFiniteConfig$1 = {
	  kernelName: IsFinite,
	  backendName: 'cpu',
	  kernelFunc: isFinite$2
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var isInf$1 = unaryKernelFunc$1(IsInf, function (xi) {
	  return Math.abs(xi) === Infinity ? 1 : 0;
	}, 'bool');
	var isInfConfig$1 = {
	  kernelName: IsInf,
	  backendName: 'cpu',
	  kernelFunc: isInf$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var isNaN$2 = unaryKernelFunc$1(IsNan, function (xi) {
	  return Number.isNaN(xi) ? 1 : 0;
	}, 'bool');
	var isNaNConfig$1 = {
	  kernelName: IsNan,
	  backendName: 'cpu',
	  kernelFunc: isNaN$2
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function linSpace$1(args) {
	  var backend = args.backend,
	    attrs = args.attrs;
	  var start = attrs.start,
	    stop = attrs.stop,
	    num = attrs.num;
	  var outVals = linSpaceImpl(start, stop, num);
	  return backend.makeTensorInfo([outVals.length], 'float32', outVals);
	}
	var linSpaceConfig$1 = {
	  kernelName: LinSpace,
	  backendName: 'cpu',
	  kernelFunc: linSpace$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var log1p$1 = unaryKernelFunc$1(Log1p, function (xi) {
	  return Math.log1p(xi);
	});
	var log1pConfig$1 = {
	  kernelName: Log1p,
	  backendName: 'cpu',
	  kernelFunc: log1p$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var logicalAndImpl = createSimpleBinaryKernelImpl(function (a, b) {
	  return a && b;
	});
	var logicalAnd$1 = binaryKernelFunc$1(LogicalAnd, logicalAndImpl, null /* complexImpl */, 'bool');
	var logicalAndConfig$1 = {
	  kernelName: LogicalAnd,
	  backendName: 'cpu',
	  kernelFunc: logicalAnd$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var logicalNot$1 = unaryKernelFunc$1(LogicalNot, function (xi) {
	  return xi ? 0 : 1;
	}, 'bool');
	var logicalNotConfig$1 = {
	  kernelName: LogicalNot,
	  backendName: 'cpu',
	  kernelFunc: logicalNot$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var logicalOrImpl = createSimpleBinaryKernelImpl(function (a, b) {
	  return a || b;
	});
	var logicalOr$1 = binaryKernelFunc$1(LogicalOr, logicalOrImpl, null /* complexImpl */, 'bool');
	var logicalOrConfig$1 = {
	  kernelName: LogicalOr,
	  backendName: 'cpu',
	  kernelFunc: logicalOr$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function lRN(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var depthRadius = attrs.depthRadius,
	    bias = attrs.bias,
	    alpha = attrs.alpha,
	    beta = attrs.beta;
	  assertNotComplex$1(x, 'LRN');
	  var channels = x.shape[3];
	  var maxD = channels - 1;
	  var xValues = backend.data.get(x.dataId).values;
	  var size = sizeFromShape(x.shape);
	  var result = new Float32Array(size);
	  function sumAcrossChannels(offset) {
	    var currentChannel = offset % channels;
	    var beginSumOffset = offset - currentChannel + Math.max(0, currentChannel - depthRadius);
	    var endSumOffset = offset - currentChannel + Math.min(currentChannel + depthRadius, maxD);
	    var sum = 0.0;
	    for (; beginSumOffset <= endSumOffset; beginSumOffset++) {
	      var z = xValues[beginSumOffset];
	      sum += z * z;
	    }
	    return sum;
	  }
	  for (var offset = 0; offset < size; offset++) {
	    var sum = sumAcrossChannels(offset);
	    var val = xValues[offset] * Math.pow(bias + alpha * sum, -beta);
	    result[offset] = val;
	  }
	  return backend.makeTensorInfo(x.shape, x.dtype, result);
	}
	// tslint:disable-next-line: variable-name
	var LRNConfig$1 = {
	  kernelName: LRN,
	  backendName: 'cpu',
	  kernelFunc: lRN
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function lRNGrad(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    y = inputs.y,
	    dy = inputs.dy;
	  var depthRadius = attrs.depthRadius,
	    bias = attrs.bias,
	    alpha = attrs.alpha,
	    beta = attrs.beta;
	  assertNotComplex$1(dy, 'LRNGrad');
	  var dySize = sizeFromShape(dy.shape);
	  var channels = dy.shape[3];
	  var dyValues = backend.data.get(dy.dataId).values;
	  var xValues = backend.data.get(x.dataId).values;
	  var yValues = backend.data.get(y.dataId).values;
	  var result = new Float32Array(dySize);
	  var size = dySize;
	  for (var offset = 0; offset < size; offset++) {
	    var currentChannel = offset % channels;
	    var depthBegin = offset - currentChannel + Math.max(0, currentChannel - depthRadius);
	    var depthEnd = offset - currentChannel + Math.min(channels, currentChannel + depthRadius + 1);
	    var norm = 0;
	    for (var k = depthBegin; k < depthEnd; k++) {
	      norm += Math.pow(xValues[k], 2);
	    }
	    norm = alpha * norm + bias;
	    for (var _k = depthBegin; _k < depthEnd; _k++) {
	      var dyi = -2 * alpha * beta * xValues[_k] * yValues[offset] / norm;
	      if (offset === _k) {
	        dyi += Math.pow(norm, -beta);
	      }
	      dyi *= dyValues[offset];
	      result[_k] += dyi;
	    }
	  }
	  return backend.makeTensorInfo(dy.shape, x.dtype, result);
	}
	// tslint:disable-next-line: variable-name
	var LRNGradConfig$1 = {
	  kernelName: LRNGrad,
	  backendName: 'cpu',
	  kernelFunc: lRNGrad
	};

	function max$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var reductionIndices = attrs.reductionIndices,
	    keepDims = attrs.keepDims;
	  var cpuBackend = backend;
	  var xShape = x.shape;
	  var xRank = xShape.length;
	  var origAxes = parseAxisParam(reductionIndices, xShape);
	  var axes = origAxes;
	  var permutedAxes = getAxesPermutation(axes, xRank);
	  var xVals = cpuBackend.data.get(x.dataId).values;
	  if (permutedAxes != null) {
	    var newShape = new Array(xRank);
	    for (var i = 0; i < newShape.length; i++) {
	      newShape[i] = xShape[permutedAxes[i]];
	    }
	    xVals = transposeImpl$1(xVals, xShape, x.dtype, permutedAxes, newShape);
	    axes = getInnerMostAxes(axes.length, xRank);
	    xShape = newShape;
	  }
	  assertNotComplex$1(x, 'max');
	  assertAxesAreInnerMostDims('max', axes, xRank);
	  var _backend_util$compute = computeOutAndReduceShapes(xShape, axes),
	    _backend_util$compute2 = _slicedToArray(_backend_util$compute, 2),
	    maxOutShape = _backend_util$compute2[0],
	    reduceShape = _backend_util$compute2[1];
	  var reduceSize = sizeFromShape(reduceShape);
	  var result = maxImpl$1(xVals, reduceSize, maxOutShape, x.dtype);
	  var dataId = cpuBackend.write(result, maxOutShape, x.dtype);
	  var outShape = maxOutShape;
	  if (keepDims) {
	    // reshape
	    var _newShape = expandShapeToKeepDim(maxOutShape, origAxes);
	    outShape = _newShape;
	  }
	  return {
	    dataId: dataId,
	    shape: outShape,
	    dtype: x.dtype
	  };
	}
	var maxConfig$1 = {
	  kernelName: Max,
	  backendName: 'cpu',
	  kernelFunc: max$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function maxPool$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  assertNotComplex$1(x, 'maxPool');
	  var filterSize = attrs.filterSize,
	    strides = attrs.strides,
	    pad = attrs.pad,
	    dimRoundingMode = attrs.dimRoundingMode;
	  var dilations = 1;
	  assert$1(eitherStridesOrDilationsAreOne(strides, dilations), function () {
	    return 'Error in maxPool: Either strides or dilations must be 1. ' + "Got strides ".concat(strides, " and dilations '").concat(dilations, "'");
	  });
	  var convInfo = computePool2DInfo(x.shape, filterSize, strides, dilations, pad, dimRoundingMode);
	  var res;
	  if (convInfo.filterWidth === 1 && convInfo.filterHeight === 1 && arraysEqual(convInfo.inShape, convInfo.outShape)) {
	    res = identity$1({
	      inputs: {
	        x: x
	      },
	      backend: backend
	    });
	  } else {
	    var xValues = backend.data.get(x.dataId).values;
	    var _strides = computeStrides(x.shape);
	    var buffer = pool(xValues, x.shape, x.dtype, _strides, convInfo, 'max');
	    res = backend.makeTensorInfo(convInfo.outShape, x.dtype, buffer.values);
	  }
	  return res;
	}
	var maxPoolConfig$1 = {
	  kernelName: MaxPool,
	  backendName: 'cpu',
	  kernelFunc: maxPool$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function maxPool3D(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var filterSize = attrs.filterSize,
	    strides = attrs.strides,
	    pad = attrs.pad,
	    dimRoundingMode = attrs.dimRoundingMode,
	    dataFormat = attrs.dataFormat;
	  assertNotComplex$1(x, 'maxPool3d');
	  var convInfo = computePool3DInfo(x.shape, filterSize, strides, 1 /* dilations */, pad, dimRoundingMode, dataFormat);
	  var xValues = backend.data.get(x.dataId).values;
	  var outBuf = pool3d(xValues, x.shape, x.dtype, computeStrides(x.shape), convInfo, 'max');
	  return backend.makeTensorInfo(outBuf.shape, 'float32', outBuf.values);
	}
	var maxPool3DConfig$1 = {
	  kernelName: MaxPool3D,
	  backendName: 'cpu',
	  kernelFunc: maxPool3D
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function maxPool3DGrad$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var dy = inputs.dy,
	    input = inputs.input;
	  var filterSize = attrs.filterSize,
	    strides = attrs.strides,
	    pad = attrs.pad,
	    dimRoundingMode = attrs.dimRoundingMode;
	  assertNotComplex$1([dy, input], 'maxPool3DGrad');
	  var convInfo = computePool3DInfo(input.shape, filterSize, strides, 1 /* dilations */, pad, dimRoundingMode);
	  var inputBuf = backend.bufferSync(input);
	  var maxPosBuf = maxPool3dPositions(inputBuf, convInfo);
	  var strideDepth = convInfo.strideDepth;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var dilationDepth = convInfo.dilationDepth;
	  var dilationHeight = convInfo.dilationHeight;
	  var dilationWidth = convInfo.dilationWidth;
	  var effectiveFilterDepth = convInfo.effectiveFilterDepth;
	  var effectiveFilterHeight = convInfo.effectiveFilterHeight;
	  var effectiveFilterWidth = convInfo.effectiveFilterWidth;
	  var padFront = effectiveFilterDepth - 1 - convInfo.padInfo.front;
	  var padLeft = effectiveFilterWidth - 1 - convInfo.padInfo.left;
	  var padTop = effectiveFilterHeight - 1 - convInfo.padInfo.top;
	  var dx = buffer(input.shape, 'float32');
	  var dyBuf = backend.bufferSync(dy);
	  for (var batch = 0; batch < convInfo.batchSize; ++batch) {
	    for (var channel = 0; channel < convInfo.inChannels; ++channel) {
	      for (var dxDepth = 0; dxDepth < convInfo.inDepth; ++dxDepth) {
	        for (var dxRow = 0; dxRow < convInfo.inHeight; ++dxRow) {
	          for (var dxCol = 0; dxCol < convInfo.inWidth; ++dxCol) {
	            // Shader code begins
	            var dyDepthCorner = dxDepth - padFront;
	            var dyRowCorner = dxRow - padTop;
	            var dyColCorner = dxCol - padLeft;
	            var dotProd = 0;
	            for (var wDepth = 0; wDepth < effectiveFilterDepth; wDepth += dilationDepth) {
	              var dyDepth = (dyDepthCorner + wDepth) / strideDepth;
	              if (dyDepth < 0 || dyDepth >= convInfo.outDepth || Math.floor(dyDepth) !== dyDepth) {
	                continue;
	              }
	              for (var wRow = 0; wRow < effectiveFilterHeight; wRow += dilationHeight) {
	                var dyRow = (dyRowCorner + wRow) / strideHeight;
	                if (dyRow < 0 || dyRow >= convInfo.outHeight || Math.floor(dyRow) !== dyRow) {
	                  continue;
	                }
	                for (var wCol = 0; wCol < effectiveFilterWidth; wCol += dilationWidth) {
	                  var dyCol = (dyColCorner + wCol) / strideWidth;
	                  if (dyCol < 0 || dyCol >= convInfo.outWidth || Math.floor(dyCol) !== dyCol) {
	                    continue;
	                  }
	                  var maxPos = effectiveFilterDepth * effectiveFilterHeight * effectiveFilterWidth - 1 - maxPosBuf.get(batch, dyDepth, dyRow, dyCol, channel);
	                  var curPos = wDepth * effectiveFilterHeight * effectiveFilterWidth + wRow * effectiveFilterWidth + wCol;
	                  var mask = maxPos === curPos ? 1 : 0;
	                  if (mask === 0) {
	                    continue;
	                  }
	                  var pixel = dyBuf.get(batch, dyDepth, dyRow, dyCol, channel);
	                  dotProd += pixel * mask;
	                }
	              }
	            }
	            dx.set(dotProd, batch, dxDepth, dxRow, dxCol, channel);
	          }
	        }
	      }
	    }
	  }
	  return backend.makeTensorInfo(dx.shape, dx.dtype, dx.values);
	}
	var maxPool3DGradConfig$1 = {
	  kernelName: MaxPool3DGrad,
	  backendName: 'cpu',
	  kernelFunc: maxPool3DGrad$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function maxPoolGrad$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var dy = inputs.dy,
	    input = inputs.input,
	    output = inputs.output;
	  var x = input;
	  assertNotComplex$1([input, output], 'maxPoolGrad');
	  var filterSize = attrs.filterSize,
	    strides = attrs.strides,
	    pad = attrs.pad,
	    dimRoundingMode = attrs.dimRoundingMode;
	  var convInfo = computePool2DInfo(x.shape, filterSize, strides, 1 /* dilations */, pad, dimRoundingMode);
	  var xValues = backend.data.get(x.dataId).values;
	  var maxPosBuf = buffer(convInfo.outShape, x.dtype, maxPoolPositions(xValues, x.shape, x.dtype, convInfo).values);
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var dilationHeight = convInfo.dilationHeight;
	  var dilationWidth = convInfo.dilationWidth;
	  var effectiveFilterHeight = convInfo.effectiveFilterHeight;
	  var effectiveFilterWidth = convInfo.effectiveFilterWidth;
	  var padLeft = effectiveFilterWidth - 1 - convInfo.padInfo.left;
	  var padTop = effectiveFilterHeight - 1 - convInfo.padInfo.top;
	  var dx = buffer(x.shape, 'float32');
	  var dyData = backend.data.get(dy.dataId).values;
	  var dyBuf = buffer(dy.shape, 'float32', dyData);
	  for (var b = 0; b < convInfo.batchSize; ++b) {
	    for (var d = 0; d < convInfo.inChannels; ++d) {
	      for (var dxR = 0; dxR < convInfo.inHeight; ++dxR) {
	        for (var dxC = 0; dxC < convInfo.inWidth; ++dxC) {
	          // Shader code begins.
	          var dyRCorner = dxR - padTop;
	          var dyCCorner = dxC - padLeft;
	          var dotProd = 0;
	          for (var wR = 0; wR < effectiveFilterHeight; wR += dilationHeight) {
	            var dyR = (dyRCorner + wR) / strideHeight;
	            if (dyR < 0 || dyR >= convInfo.outHeight || Math.floor(dyR) !== dyR) {
	              continue;
	            }
	            for (var wC = 0; wC < effectiveFilterWidth; wC += dilationWidth) {
	              var dyC = (dyCCorner + wC) / strideWidth;
	              if (dyC < 0 || dyC >= convInfo.outWidth || Math.floor(dyC) !== dyC) {
	                continue;
	              }
	              var maxPos = effectiveFilterHeight * effectiveFilterWidth - 1 - maxPosBuf.get(b, dyR, dyC, d);
	              var curPos = wR * effectiveFilterWidth + wC;
	              var mask = maxPos === curPos ? 1 : 0;
	              if (mask === 0) {
	                continue;
	              }
	              var pixel = dyBuf.get(b, dyR, dyC, d);
	              dotProd += pixel * mask;
	            }
	          }
	          dx.set(dotProd, b, dxR, dxC, d);
	        }
	      }
	    }
	  }
	  return backend.makeTensorInfo(dx.shape, dx.dtype, dx.values);
	}
	var maxPoolGradConfig$1 = {
	  kernelName: MaxPoolGrad,
	  backendName: 'cpu',
	  kernelFunc: maxPoolGrad$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function maxPoolWithArgmaxImpl$1(xValues, xShape, dtype, includeBatchInIndex, convInfo) {
	  var strides = computeStrides(xShape);
	  var maxPools = pool(xValues, xShape, dtype, strides, convInfo, 'max');
	  var maxPositions = maxPoolPositions(xValues, xShape, dtype, convInfo, true, includeBatchInIndex);
	  return [maxPools.values, maxPositions.values];
	}

	var maxPoolWithArgmaxConfig$1 = {
	  kernelName: MaxPoolWithArgmax,
	  backendName: 'cpu',
	  kernelFunc: function kernelFunc(_ref) {
	    var inputs = _ref.inputs,
	      attrs = _ref.attrs,
	      backend = _ref.backend;
	    var x = inputs.x;
	    var filterSize = attrs.filterSize,
	      strides = attrs.strides,
	      pad = attrs.pad,
	      includeBatchInIndex = attrs.includeBatchInIndex;
	    var cpuBackend = backend;
	    assertNotComplex$1(x, 'MaxPoolWithArgmax');
	    var values = cpuBackend.data.get(x.dataId).values;
	    var convInfo = computePool2DInfo(x.shape, filterSize, strides, [1, 1], pad);
	    var _maxPoolWithArgmaxImp = maxPoolWithArgmaxImpl$1(values, x.shape, x.dtype, includeBatchInIndex, convInfo),
	      _maxPoolWithArgmaxImp2 = _slicedToArray(_maxPoolWithArgmaxImp, 2),
	      pooled = _maxPoolWithArgmaxImp2[0],
	      indexes = _maxPoolWithArgmaxImp2[1];
	    var pooledDataId = cpuBackend.write(pooled, convInfo.outShape, x.dtype);
	    var indexesDataId = cpuBackend.write(indexes, convInfo.outShape, x.dtype);
	    return [{
	      dataId: pooledDataId,
	      shape: convInfo.outShape,
	      dtype: x.dtype
	    }, {
	      dataId: indexesDataId,
	      shape: convInfo.outShape,
	      dtype: 'int32'
	    }];
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function mean(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis,
	    keepDims = attrs.keepDims;
	  var axes = parseAxisParam(axis, x.shape);
	  var shapes = computeOutAndReduceShapes(x.shape, axes);
	  var reduceShape = shapes[1];
	  var reduceSize = sizeFromShape(reduceShape);
	  var toDispose = [];
	  var reduceSizeScalar = backend.makeTensorInfo([], 'float32', new Float32Array([reduceSize]));
	  toDispose.push(reduceSizeScalar);
	  var $x = cast$1({
	    inputs: {
	      x: x
	    },
	    backend: backend,
	    attrs: {
	      dtype: 'float32'
	    }
	  });
	  toDispose.push($x);
	  var res = div({
	    inputs: {
	      a: $x,
	      b: reduceSizeScalar
	    },
	    backend: backend
	  });
	  toDispose.push(res);
	  var result = sum$1({
	    inputs: {
	      x: res
	    },
	    backend: backend,
	    attrs: {
	      axis: axis,
	      keepDims: keepDims
	    }
	  });
	  toDispose.forEach(function (t) {
	    return backend.disposeIntermediateTensorInfo(t);
	  });
	  return result;
	}
	var meanConfig$1 = {
	  kernelName: Mean,
	  backendName: 'cpu',
	  kernelFunc: mean
	};

	function min$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis,
	    keepDims = attrs.keepDims;
	  assertNotComplex$1(x, 'min');
	  var origAxes = parseAxisParam(axis, x.shape);
	  var axes = origAxes;
	  var permutedAxes = getAxesPermutation(axes, x.shape.length);
	  var $x = x;
	  if (permutedAxes != null) {
	    $x = transpose$1({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        perm: permutedAxes
	      }
	    });
	    axes = getInnerMostAxes(axes.length, x.shape.length);
	  }
	  assertAxesAreInnerMostDims('min', axes, $x.shape.length);
	  var _backend_util$compute = computeOutAndReduceShapes($x.shape, axes),
	    _backend_util$compute2 = _slicedToArray(_backend_util$compute, 2),
	    outShape = _backend_util$compute2[0],
	    reduceShape = _backend_util$compute2[1];
	  var reduceSize = sizeFromShape(reduceShape);
	  var vals = makeZerosTypedArray(sizeFromShape(outShape), $x.dtype);
	  var aVals = backend.data.get($x.dataId).values;
	  for (var i = 0; i < vals.length; ++i) {
	    var offset = i * reduceSize;
	    var _min = aVals[offset];
	    for (var j = 0; j < reduceSize; ++j) {
	      var value = aVals[offset + j];
	      if (Number.isNaN(value) || value < _min) {
	        // comparison with NaN always return false
	        _min = value;
	      }
	    }
	    vals[i] = _min;
	  }
	  if (permutedAxes != null) {
	    backend.disposeIntermediateTensorInfo($x);
	  }
	  var result = backend.makeTensorInfo(outShape, $x.dtype, vals);
	  if (keepDims) {
	    var expandedShape = expandShapeToKeepDim(outShape, origAxes);
	    var reshapedResult = reshape$1({
	      inputs: {
	        x: result
	      },
	      backend: backend,
	      attrs: {
	        shape: expandedShape
	      }
	    });
	    backend.disposeIntermediateTensorInfo(result);
	    return reshapedResult;
	  }
	  return result;
	}
	var minConfig$1 = {
	  kernelName: Min,
	  backendName: 'cpu',
	  kernelFunc: min$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function mirrorPad(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var paddings = attrs.paddings,
	    mode = attrs.mode;
	  assertNotComplex$1(x, 'mirrorPad');
	  var outShape = paddings.map(function (p, i) {
	    return p[0] /* beforePad */ + x.shape[i] + p[1];
	  } /* afterPad */);
	  var start = paddings.map(function (p) {
	    return p[0];
	  });
	  var end = paddings.map(function (p, i) {
	    return p[0] + x.shape[i];
	  });
	  var offset = mode === 'reflect' ? 0 : 1;
	  var xVals = backend.data.get(x.dataId).values;
	  var xRank = x.shape.length;
	  var xStrides = computeStrides(x.shape);
	  var resultSize = sizeFromShape(outShape);
	  var resultRank = outShape.length;
	  var resultStrides = computeStrides(outShape);
	  var resVals = getTypedArrayFromDType(x.dtype, resultSize);
	  for (var i = 0; i < resultSize; i++) {
	    var coords = indexToLoc(i, resultRank, resultStrides);
	    for (var _i = 0; _i < resultRank; _i++) {
	      if (coords[_i] < start[_i]) {
	        coords[_i] = start[_i] * 2 - coords[_i] - offset;
	      } else if (coords[_i] >= end[_i]) {
	        coords[_i] = (end[_i] - 1) * 2 - coords[_i] + offset;
	      }
	    }
	    coords = coords.map(function (c, i) {
	      return c - start[i];
	    });
	    var inIndex = locToIndex(coords, xRank, xStrides);
	    resVals[i] = xVals[inIndex];
	  }
	  var outId = backend.write(resVals, outShape, x.dtype);
	  return {
	    dataId: outId,
	    shape: outShape,
	    dtype: x.dtype
	  };
	}
	var mirrorPadConfig$1 = {
	  kernelName: MirrorPad,
	  backendName: 'cpu',
	  kernelFunc: mirrorPad
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var modImpl = createSimpleBinaryKernelImpl(function (aValue, bValue) {
	  var rem = aValue % bValue;
	  if (aValue < 0 && bValue < 0 || aValue >= 0 && bValue >= 0) {
	    return rem;
	  } else {
	    return (rem + bValue) % bValue;
	  }
	});
	var mod$1 = binaryKernelFunc$1(Mod, modImpl);
	var modConfig$1 = {
	  kernelName: Mod,
	  backendName: 'cpu',
	  kernelFunc: mod$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function softmax$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var logits = inputs.logits;
	  var dim = attrs.dim;
	  var logitsRank = logits.shape.length;
	  var $dim = dim;
	  if ($dim === -1) {
	    $dim = logitsRank - 1;
	  }
	  if ($dim !== logitsRank - 1) {
	    throw Error('Softmax along a non-last dimension is not yet supported. ' + "Logits was rank ".concat(logitsRank, " and dim was ").concat($dim));
	  }
	  var axes = parseAxisParam([$dim], logits.shape);
	  var maxLogit = max$1({
	    inputs: {
	      x: logits
	    },
	    backend: backend,
	    attrs: {
	      reductionIndices: axes,
	      keepDims: false
	    }
	  });
	  var expandedShape = expandShapeToKeepDim(maxLogit.shape, axes);
	  var maxLogitReshaped = reshape$1({
	    inputs: {
	      x: maxLogit
	    },
	    backend: backend,
	    attrs: {
	      shape: expandedShape
	    }
	  });
	  var a = sub$1({
	    inputs: {
	      a: logits,
	      b: maxLogitReshaped
	    },
	    backend: backend
	  });
	  var b = exp$1({
	    inputs: {
	      x: a
	    },
	    backend: backend
	  });
	  var sumExp = sum$1({
	    inputs: {
	      x: b
	    },
	    backend: backend,
	    attrs: {
	      axis: axes,
	      keepDims: false
	    }
	  });
	  var sumReshaped = reshape$1({
	    inputs: {
	      x: sumExp
	    },
	    backend: backend,
	    attrs: {
	      shape: expandedShape
	    }
	  });
	  var result = div({
	    inputs: {
	      a: b,
	      b: sumReshaped
	    },
	    backend: backend
	  });
	  backend.disposeIntermediateTensorInfo(maxLogit);
	  backend.disposeIntermediateTensorInfo(maxLogitReshaped);
	  backend.disposeIntermediateTensorInfo(a);
	  backend.disposeIntermediateTensorInfo(b);
	  backend.disposeIntermediateTensorInfo(sumExp);
	  backend.disposeIntermediateTensorInfo(sumReshaped);
	  return result;
	}
	var softmaxConfig$1 = {
	  kernelName: Softmax$2,
	  backendName: 'cpu',
	  kernelFunc: softmax$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function multinomial$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var logits = inputs.logits;
	  var numSamples = attrs.numSamples,
	    seed = attrs.seed,
	    normalized = attrs.normalized;
	  assertNotComplex$1(logits, 'multinomial');
	  var probabilities = normalized ? logits : softmax$1({
	    inputs: {
	      logits: logits
	    },
	    backend: backend,
	    attrs: {
	      dim: -1
	    }
	  });
	  var batchSize = probabilities.shape[0];
	  var numEvents = probabilities.shape[1];
	  var probVals = backend.data.get(probabilities.dataId).values;
	  var resShape = [batchSize, numSamples];
	  var resVals = makeZerosTypedArray(sizeFromShape(resShape), 'int32');
	  for (var b = 0; b < batchSize; ++b) {
	    var offset = b * numEvents;
	    // The cdf won't include the last event. It will be implicit if no other
	    // event happened.
	    var cdf = new Float32Array(numEvents - 1);
	    cdf[0] = probVals[offset];
	    for (var event = 1; event < cdf.length; ++event) {
	      cdf[event] = cdf[event - 1] + probVals[offset + event];
	    }
	    var random = seedrandom.alea(seed.toString());
	    var outOffset = b * numSamples;
	    for (var sampleId = 0; sampleId < numSamples; ++sampleId) {
	      var r = random();
	      // Assume last event happened by default.
	      resVals[outOffset + sampleId] = cdf.length;
	      for (var _event = 0; _event < cdf.length; _event++) {
	        if (r < cdf[_event]) {
	          resVals[outOffset + sampleId] = _event;
	          break;
	        }
	      }
	    }
	  }
	  if (!normalized) {
	    backend.disposeIntermediateTensorInfo(probabilities);
	  }
	  return backend.makeTensorInfo(resShape, 'int32', resVals);
	}
	var multinomialConfig$1 = {
	  kernelName: Multinomial,
	  backendName: 'cpu',
	  kernelFunc: multinomial$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var nonMaxSuppressionV3Impl$1 = nonMaxSuppressionV3Impl$2;
	function nonMaxSuppressionV3$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var boxes = inputs.boxes,
	    scores = inputs.scores;
	  var maxOutputSize = attrs.maxOutputSize,
	    iouThreshold = attrs.iouThreshold,
	    scoreThreshold = attrs.scoreThreshold;
	  assertNotComplex$1(boxes, 'NonMaxSuppression');
	  var boxesVals = backend.data.get(boxes.dataId).values;
	  var scoresVals = backend.data.get(scores.dataId).values;
	  var _nonMaxSuppressionV3I = nonMaxSuppressionV3Impl$1(boxesVals, scoresVals, maxOutputSize, iouThreshold, scoreThreshold),
	    selectedIndices = _nonMaxSuppressionV3I.selectedIndices;
	  return backend.makeTensorInfo([selectedIndices.length], 'int32', new Int32Array(selectedIndices));
	}
	var nonMaxSuppressionV3Config$1 = {
	  kernelName: NonMaxSuppressionV3,
	  backendName: 'cpu',
	  kernelFunc: nonMaxSuppressionV3$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var nonMaxSuppressionV4Impl$1 = nonMaxSuppressionV4Impl$2;
	function nonMaxSuppressionV4$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var boxes = inputs.boxes,
	    scores = inputs.scores;
	  var maxOutputSize = attrs.maxOutputSize,
	    iouThreshold = attrs.iouThreshold,
	    scoreThreshold = attrs.scoreThreshold,
	    padToMaxOutputSize = attrs.padToMaxOutputSize;
	  assertNotComplex$1(boxes, 'NonMaxSuppressionPadded');
	  var boxesVals = backend.data.get(boxes.dataId).values;
	  var scoresVals = backend.data.get(scores.dataId).values;
	  var _nonMaxSuppressionV4I = nonMaxSuppressionV4Impl$1(boxesVals, scoresVals, maxOutputSize, iouThreshold, scoreThreshold, padToMaxOutputSize),
	    selectedIndices = _nonMaxSuppressionV4I.selectedIndices,
	    validOutputs = _nonMaxSuppressionV4I.validOutputs;
	  return [backend.makeTensorInfo([selectedIndices.length], 'int32', new Int32Array(selectedIndices)), backend.makeTensorInfo([], 'int32', new Int32Array([validOutputs]))];
	}
	var nonMaxSuppressionV4Config$1 = {
	  kernelName: NonMaxSuppressionV4,
	  backendName: 'cpu',
	  kernelFunc: nonMaxSuppressionV4$1
	};

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var nonMaxSuppressionV5Impl$1 = nonMaxSuppressionV5Impl$2;
	function nonMaxSuppressionV5$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var boxes = inputs.boxes,
	    scores = inputs.scores;
	  var maxOutputSize = attrs.maxOutputSize,
	    iouThreshold = attrs.iouThreshold,
	    scoreThreshold = attrs.scoreThreshold,
	    softNmsSigma = attrs.softNmsSigma;
	  assertNotComplex$1(boxes, 'NonMaxSuppressionWithScore');
	  var boxesVals = backend.data.get(boxes.dataId).values;
	  var scoresVals = backend.data.get(scores.dataId).values;
	  var maxOutputSizeVal = maxOutputSize;
	  var iouThresholdVal = iouThreshold;
	  var scoreThresholdVal = scoreThreshold;
	  var softNmsSigmaVal = softNmsSigma;
	  var _nonMaxSuppressionV5I = nonMaxSuppressionV5Impl$1(boxesVals, scoresVals, maxOutputSizeVal, iouThresholdVal, scoreThresholdVal, softNmsSigmaVal),
	    selectedIndices = _nonMaxSuppressionV5I.selectedIndices,
	    selectedScores = _nonMaxSuppressionV5I.selectedScores;
	  return [backend.makeTensorInfo([selectedIndices.length], 'int32', new Int32Array(selectedIndices)), backend.makeTensorInfo([selectedScores.length], 'float32', new Float32Array(selectedScores))];
	}
	var nonMaxSuppressionV5Config$1 = {
	  kernelName: NonMaxSuppressionV5,
	  backendName: 'cpu',
	  kernelFunc: nonMaxSuppressionV5$1
	};

	function oneHot$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var indices = inputs.indices;
	  var dtype = attrs.dtype,
	    depth = attrs.depth,
	    onValue = attrs.onValue,
	    offValue = attrs.offValue;
	  assertNotComplex$1(indices, 'oneHot');
	  var indicesSize = sizeFromShape(indices.shape);
	  var res = new Float32Array(indicesSize * depth);
	  res.fill(offValue);
	  var indicesVal = backend.data.get(indices.dataId).values;
	  for (var event = 0; event < indicesSize; ++event) {
	    if (indicesVal[event] >= 0 && indicesVal[event] < depth) {
	      res[event * depth + indicesVal[event]] = onValue;
	    }
	  }
	  return backend.makeTensorInfo([].concat(_toConsumableArray(indices.shape), [depth]), dtype, res);
	}
	var oneHotConfig$1 = {
	  kernelName: OneHot,
	  backendName: 'cpu',
	  kernelFunc: oneHot$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function zerosLike$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var x = inputs.x;
	  if (x.dtype === 'string') {
	    throw new Error('zerosLike is not supported for string tensors');
	  } else if (x.dtype === 'complex64') {
	    var realPart = real$1({
	      inputs: {
	        input: x
	      },
	      backend: backend
	    });
	    var r = zerosLike$1({
	      inputs: {
	        x: realPart
	      },
	      backend: backend
	    });
	    var imagPart = imag$1({
	      inputs: {
	        input: x
	      },
	      backend: backend
	    });
	    var i = zerosLike$1({
	      inputs: {
	        x: imagPart
	      },
	      backend: backend
	    });
	    var result = complex$1({
	      inputs: {
	        real: r,
	        imag: i
	      },
	      backend: backend
	    });
	    backend.disposeIntermediateTensorInfo(realPart);
	    backend.disposeIntermediateTensorInfo(r);
	    backend.disposeIntermediateTensorInfo(imagPart);
	    backend.disposeIntermediateTensorInfo(i);
	    return result;
	  } else {
	    return fill$1({
	      backend: backend,
	      attrs: {
	        shape: x.shape,
	        value: 0,
	        dtype: x.dtype
	      }
	    });
	  }
	}
	var zerosLikeConfig$1 = {
	  kernelName: ZerosLike,
	  backendName: 'cpu',
	  kernelFunc: zerosLike$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function onesLike$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var x = inputs.x;
	  if (x.dtype === 'string') {
	    throw new Error('onesLike is not supported for string tensors');
	  } else if (x.dtype === 'complex64') {
	    var realPart = real$1({
	      inputs: {
	        input: x
	      },
	      backend: backend
	    });
	    var r = onesLike$1({
	      inputs: {
	        x: realPart
	      },
	      backend: backend
	    });
	    var imagPart = imag$1({
	      inputs: {
	        input: x
	      },
	      backend: backend
	    });
	    var i = zerosLike$1({
	      inputs: {
	        x: imagPart
	      },
	      backend: backend
	    });
	    var result = complex$1({
	      inputs: {
	        real: r,
	        imag: i
	      },
	      backend: backend
	    });
	    backend.disposeIntermediateTensorInfo(realPart);
	    backend.disposeIntermediateTensorInfo(r);
	    backend.disposeIntermediateTensorInfo(imagPart);
	    backend.disposeIntermediateTensorInfo(i);
	    return result;
	  } else {
	    return fill$1({
	      backend: backend,
	      attrs: {
	        shape: x.shape,
	        value: 1,
	        dtype: x.dtype
	      }
	    });
	  }
	}
	var onesLikeConfig$1 = {
	  kernelName: OnesLike,
	  backendName: 'cpu',
	  kernelFunc: onesLike$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function pack$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var axis = attrs.axis;
	  if (inputs.length === 1) {
	    return expandDims$1({
	      inputs: {
	        input: inputs[0]
	      },
	      backend: backend,
	      attrs: {
	        dim: axis
	      }
	    });
	  }
	  var shape = inputs[0].shape;
	  var dtype = inputs[0].dtype;
	  inputs.forEach(function (t) {
	    assertShapesMatch(shape, t.shape, 'All tensors passed to stack must have matching shapes');
	    assert$1(dtype === t.dtype, function () {
	      return 'All tensors passed to stack must have matching dtypes';
	    });
	  });
	  var intermediateTensorInfos = [];
	  var expandedTensors = inputs.map(function (t) {
	    var expandedT = expandDims$1({
	      inputs: {
	        input: t
	      },
	      backend: backend,
	      attrs: {
	        dim: axis
	      }
	    });
	    intermediateTensorInfos.push(expandedT);
	    return expandedT;
	  });
	  var result = concat$1({
	    inputs: expandedTensors,
	    backend: backend,
	    attrs: {
	      axis: axis
	    }
	  });
	  intermediateTensorInfos.forEach(function (t) {
	    return backend.disposeIntermediateTensorInfo(t);
	  });
	  return result;
	}
	var packConfig$1 = {
	  kernelName: Pack,
	  backendName: 'cpu',
	  kernelFunc: pack$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function padV2$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var paddings = attrs.paddings,
	    constantValue = attrs.constantValue;
	  assertNotComplex$1(x, 'pad');
	  var outShape = paddings.map(function (p, i) {
	    return p[0] /* beforePad */ + x.shape[i] + p[1];
	  } /* afterPad */);
	  var start = paddings.map(function (p) {
	    return p[0];
	  });
	  var xVals = backend.data.get(x.dataId).values;
	  var xSize = sizeFromShape(x.shape);
	  var xRank = x.shape.length;
	  var xStrides = computeStrides(x.shape);
	  var resultSize = sizeFromShape(outShape);
	  var resultRank = outShape.length;
	  var resultStrides = computeStrides(outShape);
	  var resVals = getTypedArrayFromDType(x.dtype, resultSize);
	  if (constantValue !== 0) {
	    resVals.fill(constantValue);
	  }
	  for (var i = 0; i < xSize; i++) {
	    var coords = indexToLoc(i, xRank, xStrides);
	    var outCoords = coords.map(function (c, i) {
	      return c + start[i];
	    });
	    var outIndex = locToIndex(outCoords, resultRank, resultStrides);
	    resVals[outIndex] = xVals[i];
	  }
	  var outId = backend.write(resVals, outShape, x.dtype);
	  return {
	    dataId: outId,
	    shape: outShape,
	    dtype: x.dtype
	  };
	}
	var padV2Config$1 = {
	  kernelName: PadV2,
	  backendName: 'cpu',
	  kernelFunc: padV2$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var powImpl = createSimpleBinaryKernelImpl(function (a, b) {
	  return Math.pow(a, b);
	});
	var pow$1 = binaryKernelFunc$1(Pow, powImpl);
	var powConfig$1 = {
	  kernelName: Pow,
	  backendName: 'cpu',
	  kernelFunc: pow$1
	};

	function raggedGather$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var paramsNestedSplits = inputs.paramsNestedSplits,
	    paramsDenseValues = inputs.paramsDenseValues,
	    indices = inputs.indices;
	  var outputRaggedRank = attrs.outputRaggedRank;
	  var $paramsNestedSplits = paramsNestedSplits.map(function (t) {
	    return backend.data.get(t.dataId).values;
	  });
	  var $paramsNestedSplitsShapes = paramsNestedSplits.map(function (t) {
	    return t.shape;
	  });
	  var $paramsDenseValues = backend.data.get(paramsDenseValues.dataId).values;
	  var $indices = backend.data.get(indices.dataId).values;
	  var _raggedGatherImpl = raggedGatherImpl($paramsNestedSplits, $paramsNestedSplitsShapes, $paramsDenseValues, paramsDenseValues.shape, paramsDenseValues.dtype, $indices, indices.shape, outputRaggedRank),
	    _raggedGatherImpl2 = _slicedToArray(_raggedGatherImpl, 3),
	    outputNestedSplits = _raggedGatherImpl2[0],
	    outputDenseValues = _raggedGatherImpl2[1],
	    outputDenseValuesShape = _raggedGatherImpl2[2];
	  var outputNestedSplitsTensors = outputNestedSplits.map(function (splits) {
	    return backend.makeTensorInfo([splits.length], 'int32', splits);
	  });
	  var outputDenseValuesTensor = backend.makeTensorInfo(outputDenseValuesShape, paramsDenseValues.dtype, outputDenseValues);
	  return outputNestedSplitsTensors.concat([outputDenseValuesTensor]);
	}
	var raggedGatherConfig$1 = {
	  kernelName: RaggedGather,
	  backendName: 'cpu',
	  kernelFunc: raggedGather$1
	};

	function raggedRange$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var starts = inputs.starts,
	    limits = inputs.limits,
	    deltas = inputs.deltas;
	  var $starts = backend.data.get(starts.dataId).values;
	  var $limits = backend.data.get(limits.dataId).values;
	  var $deltas = backend.data.get(deltas.dataId).values;
	  var _raggedRangeImpl = raggedRangeImpl($starts, starts.shape, starts.dtype, $limits, limits.shape, $deltas, deltas.shape),
	    _raggedRangeImpl2 = _slicedToArray(_raggedRangeImpl, 2),
	    rtNestedSplitsData = _raggedRangeImpl2[0],
	    rtDenseValuesData = _raggedRangeImpl2[1];
	  var rtNestedSplits = backend.makeTensorInfo([rtNestedSplitsData.length], 'int32', rtNestedSplitsData);
	  var rtDenseValues = backend.makeTensorInfo([rtDenseValuesData.length], starts.dtype, rtDenseValuesData);
	  return [rtNestedSplits, rtDenseValues];
	}
	var raggedRangeConfig$1 = {
	  kernelName: RaggedRange,
	  backendName: 'cpu',
	  kernelFunc: raggedRange$1
	};

	function raggedTensorToTensor$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var shape = inputs.shape,
	    values = inputs.values,
	    defaultValue = inputs.defaultValue,
	    rowPartitionTensors = inputs.rowPartitionTensors;
	  var rowPartitionTypes = attrs.rowPartitionTypes;
	  var $shape = backend.data.get(shape.dataId).values;
	  var $values = backend.data.get(values.dataId).values;
	  var $defaultValue = backend.data.get(defaultValue.dataId).values;
	  var $rowPartitionValues = rowPartitionTensors.map(function (t) {
	    return backend.data.get(t.dataId).values;
	  });
	  var rowPartitionValuesShapes = rowPartitionTensors.map(function (t) {
	    return t.shape;
	  });
	  var _raggedTensorToTensor = raggedTensorToTensorImpl($shape, shape.shape, $values, values.shape, values.dtype, $defaultValue, defaultValue.shape, $rowPartitionValues, rowPartitionValuesShapes, rowPartitionTypes),
	    _raggedTensorToTensor2 = _slicedToArray(_raggedTensorToTensor, 2),
	    outputShape = _raggedTensorToTensor2[0],
	    output = _raggedTensorToTensor2[1];
	  return backend.makeTensorInfo(outputShape, values.dtype, output);
	}
	var raggedTensorToTensorConfig$1 = {
	  kernelName: RaggedTensorToTensor,
	  backendName: 'cpu',
	  kernelFunc: raggedTensorToTensor$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function range$1(args) {
	  var backend = args.backend,
	    attrs = args.attrs;
	  var start = attrs.start,
	    stop = attrs.stop,
	    dtype = attrs.dtype,
	    step = attrs.step;
	  var values = rangeImpl(start, stop, step, dtype);
	  return backend.makeTensorInfo([values.length], dtype, values);
	}
	var rangeConfig$1 = {
	  kernelName: Range,
	  backendName: 'cpu',
	  kernelFunc: range$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var reciprocal$1 = unaryKernelFunc$1(Reciprocal, function (xi) {
	  return 1 / xi;
	});
	var reciprocalConfig$1 = {
	  kernelName: Reciprocal,
	  backendName: 'cpu',
	  kernelFunc: reciprocal$1
	};

	function resizeBilinear$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var images = inputs.images;
	  var alignCorners = attrs.alignCorners,
	    halfPixelCenters = attrs.halfPixelCenters,
	    size = attrs.size;
	  assertNotComplex$1(images, 'resizeBilinear');
	  var imagesStrides = computeStrides(images.shape);
	  var _size = _slicedToArray(size, 2),
	    newHeight = _size[0],
	    newWidth = _size[1];
	  var _images$shape = _slicedToArray(images.shape, 4),
	    batch = _images$shape[0],
	    oldHeight = _images$shape[1],
	    oldWidth = _images$shape[2],
	    numChannels = _images$shape[3];
	  var xValues = backend.data.get(images.dataId).values;
	  var result = new Float32Array(sizeFromShape([batch, newHeight, newWidth, numChannels]));
	  var effectiveInputSize = [alignCorners && newHeight > 1 ? oldHeight - 1 : oldHeight, alignCorners && newWidth > 1 ? oldWidth - 1 : oldWidth];
	  var effectiveOutputSize = [alignCorners && newHeight > 1 ? newHeight - 1 : newHeight, alignCorners && newWidth > 1 ? newWidth - 1 : newWidth];
	  var outputIdx = 0;
	  var effectiveRowSizeRatio = effectiveInputSize[0] / effectiveOutputSize[0];
	  var effectiveColSizeRatio = effectiveInputSize[1] / effectiveOutputSize[1];
	  for (var b = 0; b < batch; b++) {
	    for (var r = 0; r < newHeight; r++) {
	      var sourceFracRow = void 0;
	      if (halfPixelCenters) {
	        sourceFracRow = effectiveRowSizeRatio * (r + 0.5) - 0.5;
	      } else {
	        sourceFracRow = effectiveRowSizeRatio * r;
	      }
	      var sourceRowFloor = Math.max(0, Math.floor(sourceFracRow));
	      var rowFrac = sourceFracRow - sourceRowFloor;
	      var sourceRowCeil = Math.min(oldHeight - 1, Math.ceil(sourceFracRow));
	      var topRowOffset = b * imagesStrides[0] + sourceRowFloor * imagesStrides[1];
	      var botRowOffset = b * imagesStrides[0] + sourceRowCeil * imagesStrides[1];
	      for (var c = 0; c < newWidth; c++) {
	        var sourceFracCol = void 0;
	        if (halfPixelCenters) {
	          sourceFracCol = effectiveColSizeRatio * (c + 0.5) - 0.5;
	        } else {
	          sourceFracCol = effectiveColSizeRatio * c;
	        }
	        var sourceColFloor = Math.max(0, Math.floor(sourceFracCol));
	        var colFrac = sourceFracCol - sourceColFloor;
	        var sourceColCeil = Math.min(oldWidth - 1, Math.ceil(sourceFracCol));
	        var topLeftOffest = topRowOffset + sourceColFloor * imagesStrides[2];
	        var botLeftOffset = botRowOffset + sourceColFloor * imagesStrides[2];
	        var topRightOffset = topRowOffset + sourceColCeil * imagesStrides[2];
	        var botRightOffest = botRowOffset + sourceColCeil * imagesStrides[2];
	        for (var d = 0; d < numChannels; d++) {
	          // Begin shader.
	          // Compute the fractional index of the source.
	          var topLeft = xValues[topLeftOffest + d];
	          var bottomLeft = xValues[botLeftOffset + d];
	          var topRight = xValues[topRightOffset + d];
	          var bottomRight = xValues[botRightOffest + d];
	          var top = topLeft + (topRight - topLeft) * colFrac;
	          var bottom = bottomLeft + (bottomRight - bottomLeft) * colFrac;
	          var newValue = top + (bottom - top) * rowFrac;
	          result[outputIdx++] = newValue;
	        }
	      }
	    }
	  }
	  return backend.makeTensorInfo([batch, newHeight, newWidth, numChannels], 'float32', result);
	}
	var resizeBilinearConfig$1 = {
	  kernelName: ResizeBilinear,
	  backendName: 'cpu',
	  kernelFunc: resizeBilinear$1
	};

	function resizeBilinearGrad$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var images = inputs.images,
	    dy = inputs.dy;
	  var alignCorners = attrs.alignCorners;
	  assertNotComplex$1([dy, images], 'resizeBilinearGrad');
	  var imagesStrides = computeStrides(images.shape);
	  var _images$shape = _slicedToArray(images.shape, 4),
	    batch = _images$shape[0],
	    xHeight = _images$shape[1],
	    xWidth = _images$shape[2],
	    depth = _images$shape[3];
	  var _dy$shape = _slicedToArray(dy.shape, 3),
	    yHeight = _dy$shape[1],
	    yWidth = _dy$shape[2];
	  var output = new Float32Array(batch * xHeight * xWidth * depth);
	  // In the backwards pass, we want to find the pixels that were generated
	  // for each pixel in the input image the forward pass and add the
	  // corresponding coefficient from dy to the gradient (with some
	  // interpolation).
	  var effectiveXSize = [alignCorners && yHeight > 1 ? xHeight - 1 : xHeight, alignCorners && yWidth > 1 ? xWidth - 1 : xWidth];
	  var effectiveYSize = [alignCorners && yHeight > 1 ? yHeight - 1 : yHeight, alignCorners && yWidth > 1 ? yWidth - 1 : yWidth];
	  var heightScale = effectiveXSize[0] / effectiveYSize[0];
	  var widthScale = effectiveXSize[1] / effectiveYSize[1];
	  // Reference implementation
	  // tslint:disable-next-line:max-line-length
	  // https://github.com/tensorflow/tensorflow/blob/3039375c86a5bbc9610c7725dcaa95d635f87ba2/tensorflow/core/kernels/resize_bilinear_op.cc#L275
	  var dyValues = backend.data.get(dy.dataId).values;
	  var offset = 0;
	  for (var b = 0; b < batch; b++) {
	    var bOffset = b * imagesStrides[0];
	    for (var r = 0; r < yHeight; r++) {
	      var dxR = r * heightScale;
	      var topDxRIndex = Math.floor(dxR);
	      var bottomDxRIndex = Math.min(Math.ceil(dxR), xHeight - 1);
	      var topDxROffset = bOffset + topDxRIndex * imagesStrides[1];
	      var bottomDxROffset = bOffset + bottomDxRIndex * imagesStrides[1];
	      var dxRLerp = dxR - topDxRIndex;
	      var inverseDxRLerp = 1.0 - dxRLerp;
	      for (var c = 0; c < yWidth; c++) {
	        var dxC = c * widthScale;
	        var leftDxCIndex = Math.floor(dxC);
	        var rightDxCIndex = Math.min(Math.ceil(dxC), xWidth - 1);
	        var dxCLerp = dxC - leftDxCIndex;
	        var inverseDxCLerp = 1.0 - dxCLerp;
	        var topLeftRCOffset = topDxROffset + leftDxCIndex * imagesStrides[2];
	        var topRightRCOffset = topDxROffset + rightDxCIndex * imagesStrides[2];
	        var bottomLeftRCOffset = bottomDxROffset + leftDxCIndex * imagesStrides[2];
	        var bottomRightRCOffset = bottomDxROffset + rightDxCIndex * imagesStrides[2];
	        var inverseDxRLerpTimesInverseDxCLerp = inverseDxRLerp * inverseDxCLerp;
	        var inverseDxRLerpTimesDxCLerp = inverseDxRLerp * dxCLerp;
	        var dxRLerpTimesInverseDxCLerp = dxRLerp * inverseDxCLerp;
	        var dxRLerpTimesDxCLerp = dxRLerp * dxCLerp;
	        for (var d = 0; d < depth; d++) {
	          var dyVal = dyValues[offset++];
	          output[topLeftRCOffset + d] += dyVal * inverseDxRLerpTimesInverseDxCLerp;
	          output[topRightRCOffset + d] += dyVal * inverseDxRLerpTimesDxCLerp;
	          output[bottomLeftRCOffset + d] += dyVal * dxRLerpTimesInverseDxCLerp;
	          output[bottomRightRCOffset + d] += dyVal * dxRLerpTimesDxCLerp;
	        }
	      }
	    }
	  }
	  return backend.makeTensorInfo([batch, xWidth, xHeight, depth], 'float32', output);
	}
	var resizeBilinearGradConfig$1 = {
	  kernelName: ResizeBilinearGrad,
	  backendName: 'cpu',
	  kernelFunc: resizeBilinearGrad$1
	};

	function resizeNearestNeighbor$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var images = inputs.images;
	  var alignCorners = attrs.alignCorners,
	    halfPixelCenters = attrs.halfPixelCenters,
	    size = attrs.size;
	  assertNotComplex$1(images, 'resizeNearestNeighbor');
	  var imagesStrides = computeStrides(images.shape);
	  var _size = _slicedToArray(size, 2),
	    newHeight = _size[0],
	    newWidth = _size[1];
	  var _images$shape = _slicedToArray(images.shape, 4),
	    batch = _images$shape[0],
	    oldHeight = _images$shape[1],
	    oldWidth = _images$shape[2],
	    numChannels = _images$shape[3];
	  var xValues = backend.data.get(images.dataId).values;
	  var output = new Float32Array(batch * newHeight * newWidth * numChannels);
	  var effectiveInputSize = [alignCorners && newHeight > 1 ? oldHeight - 1 : oldHeight, alignCorners && newWidth > 1 ? oldWidth - 1 : oldWidth];
	  var effectiveOutputSize = [alignCorners && newHeight > 1 ? newHeight - 1 : newHeight, alignCorners && newWidth > 1 ? newWidth - 1 : newWidth];
	  var effectiveRowSizeRatio = effectiveInputSize[0] / effectiveOutputSize[0];
	  var effectiveColSizeRatio = effectiveInputSize[1] / effectiveOutputSize[1];
	  var outputOffset = 0;
	  for (var b = 0; b < batch; b++) {
	    var batchOffset = b * imagesStrides[0];
	    for (var r = 0; r < newHeight; r++) {
	      var sourceFracRow = halfPixelCenters ? effectiveRowSizeRatio * (r + 0.5) : effectiveRowSizeRatio * r;
	      var sourceNearestRow = Math.min(oldHeight - 1, alignCorners ? Math.round(sourceFracRow) : Math.floor(sourceFracRow));
	      if (halfPixelCenters) {
	        sourceNearestRow = Math.max(0, sourceNearestRow);
	      }
	      var rowOffset = batchOffset + sourceNearestRow * imagesStrides[1];
	      for (var c = 0; c < newWidth; c++) {
	        var sourceFracCol = halfPixelCenters ? effectiveColSizeRatio * (c + 0.5) : effectiveColSizeRatio * c;
	        var sourceNearestCol = Math.min(oldWidth - 1, alignCorners ? Math.round(sourceFracCol) : Math.floor(sourceFracCol));
	        if (halfPixelCenters) {
	          sourceNearestCol = Math.max(0, sourceNearestCol);
	        }
	        var colOffset = rowOffset + sourceNearestCol * imagesStrides[2];
	        for (var d = 0; d < numChannels; d++) {
	          // Begin shader.
	          // Compute the fractional index of the source.
	          var newVal = xValues[colOffset + d];
	          output[outputOffset++] = newVal;
	        }
	      }
	    }
	  }
	  return backend.makeTensorInfo([batch, newHeight, newWidth, numChannels], images.dtype, output);
	}
	var resizeNearestNeighborConfig$1 = {
	  kernelName: ResizeNearestNeighbor,
	  backendName: 'cpu',
	  kernelFunc: resizeNearestNeighbor$1
	};

	function resizeNearestNeighborGrad$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var images = inputs.images,
	    dy = inputs.dy;
	  var alignCorners = attrs.alignCorners;
	  assertNotComplex$1([dy, images], 'resizeNearestNeighborGrad');
	  var imagesStrides = computeStrides(images.shape);
	  var dyStrides = computeStrides(dy.shape);
	  var _images$shape = _slicedToArray(images.shape, 4),
	    batch = _images$shape[0],
	    xHeight = _images$shape[1],
	    xWidth = _images$shape[2],
	    depth = _images$shape[3];
	  var _dy$shape = _slicedToArray(dy.shape, 3),
	    yHeight = _dy$shape[1],
	    yWidth = _dy$shape[2];
	  var output = new Float32Array(batch * xHeight * xWidth * depth);
	  var dyValues = backend.data.get(dy.dataId).values;
	  // In the backwards pass, we want to find the pixels that were generated
	  // for each pixel in the input image the forward pass
	  var effectiveXSize = [alignCorners && yHeight > 1 ? xHeight - 1 : xHeight, alignCorners && yWidth > 1 ? xWidth - 1 : xWidth];
	  var effectiveYSize = [alignCorners && yHeight > 1 ? yHeight - 1 : yHeight, alignCorners && yWidth > 1 ? yWidth - 1 : yWidth];
	  var heightScale = effectiveXSize[0] / effectiveYSize[0];
	  var widthScale = effectiveXSize[1] / effectiveYSize[1];
	  var invHeightScale = 1 / heightScale;
	  var invWidthScale = 1 / widthScale;
	  // This defines the size of the window of values around a particular
	  // index in dy that we want to search for contributions to dx.
	  var winHeight = Math.ceil(invHeightScale) * 2 + 2;
	  var winWidth = Math.ceil(invWidthScale) * 2 + 2;
	  // Loop over the output space.
	  for (var b = 0; b < batch; b++) {
	    var batchOffset = b * imagesStrides[0];
	    for (var r = 0; r < xHeight; r++) {
	      var rowOffset = batchOffset + r * imagesStrides[1];
	      // Compute bounds for where in dy we will look
	      var startRLerp = Math.floor(r * invHeightScale);
	      var startDyR = Math.floor(startRLerp - winHeight / 2);
	      for (var c = 0; c < xWidth; c++) {
	        var colOffset = rowOffset + c * imagesStrides[2];
	        // Compute bounds for where in dy we will look
	        var startCLerp = Math.floor(c * invWidthScale);
	        var startDyC = Math.floor(startCLerp - winWidth / 2);
	        for (var d = 0; d < depth; d++) {
	          var accum = 0;
	          // loop over dy
	          for (var dyRIndex = 0; dyRIndex < winHeight; dyRIndex++) {
	            var dyR = dyRIndex + startDyR;
	            // Guard against the window exceeding the bounds of dy
	            if (dyR < 0 || dyR >= yHeight) {
	              continue;
	            }
	            var dyROffset = batchOffset + dyR * dyStrides[1];
	            var sourceFracRow = dyR * heightScale;
	            var sourceNearestRow = Math.min(xHeight - 1, alignCorners ? Math.round(sourceFracRow) : Math.floor(sourceFracRow));
	            if (r !== sourceNearestRow) {
	              continue;
	            }
	            for (var dyCIndex = 0; dyCIndex < winWidth; dyCIndex++) {
	              var dyC = dyCIndex + startDyC;
	              // Guard against the window exceeding the bounds of dy
	              if (dyC < 0 || dyC >= yWidth) {
	                continue;
	              }
	              var dyCOffset = dyROffset + dyC * dyStrides[2];
	              var sourceFracCol = dyC * widthScale;
	              var sourceNearestCol = Math.min(xWidth - 1, alignCorners ? Math.round(sourceFracCol) : Math.floor(sourceFracCol));
	              if (c === sourceNearestCol) {
	                accum += dyValues[dyCOffset + d];
	              }
	            }
	          }
	          output[colOffset + d] = accum;
	        }
	      }
	    }
	  }
	  return backend.makeTensorInfo(images.shape, images.dtype, output);
	}
	var resizeNearestNeighborGradConfig$1 = {
	  kernelName: ResizeNearestNeighborGrad,
	  backendName: 'cpu',
	  kernelFunc: resizeNearestNeighborGrad$1
	};

	function reverse$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var dims = attrs.dims;
	  assertNotComplex$1(x, 'reverse');
	  var xRank = x.shape.length;
	  var $dims = parseAxisParam(dims, x.shape);
	  if (xRank === 0) {
	    return identity$1({
	      inputs: {
	        x: x
	      },
	      backend: backend
	    });
	  }
	  var outBuf = new TensorBuffer(x.shape, x.dtype);
	  var xBuf = backend.bufferSync(x);
	  var _loop = function _loop() {
	    var outLoc = outBuf.indexToLoc(i);
	    var inLoc = outLoc.slice();
	    $dims.forEach(function (d) {
	      return inLoc[d] = x.shape[d] - 1 - inLoc[d];
	    });
	    outBuf.set.apply(outBuf, [xBuf.get.apply(xBuf, _toConsumableArray(inLoc))].concat(_toConsumableArray(outLoc)));
	  };
	  for (var i = 0; i < outBuf.size; i++) {
	    _loop();
	  }
	  return backend.makeTensorInfo(outBuf.shape, outBuf.dtype, outBuf.values);
	}
	var reverseConfig$1 = {
	  kernelName: Reverse,
	  backendName: 'cpu',
	  kernelFunc: reverse$1
	};

	var rotateWithOffsetConfig$1 = {
	  kernelName: RotateWithOffset,
	  backendName: 'cpu',
	  kernelFunc: function kernelFunc(_ref) {
	    var inputs = _ref.inputs,
	      attrs = _ref.attrs,
	      backend = _ref.backend;
	    var image = inputs.image;
	    var radians = attrs.radians,
	      fillValue = attrs.fillValue,
	      center = attrs.center;
	    var cpuBackend = backend;
	    var output = getTypedArrayFromDType(image.dtype, sizeFromShape(image.shape));
	    var _image$shape = _slicedToArray(image.shape, 4),
	      batch = _image$shape[0],
	      imageHeight = _image$shape[1],
	      imageWidth = _image$shape[2],
	      numChannels = _image$shape[3];
	    var _backend_util$getImag = getImageCenter(center, imageHeight, imageWidth),
	      _backend_util$getImag2 = _slicedToArray(_backend_util$getImag, 2),
	      centerX = _backend_util$getImag2[0],
	      centerY = _backend_util$getImag2[1];
	    var fullOpacityValue = 255;
	    var sinFactor = Math.sin(radians);
	    var cosFactor = Math.cos(radians);
	    var imageVals = cpuBackend.data.get(image.dataId).values;
	    for (var batchIdx = 0; batchIdx < batch; batchIdx++) {
	      var batchOffset = batchIdx * imageWidth * imageHeight * numChannels;
	      for (var row = 0; row < imageHeight; row++) {
	        var rowOffset = row * (imageWidth * numChannels);
	        for (var col = 0; col < imageWidth; col++) {
	          var colOffset = col * numChannels;
	          for (var channel = 0; channel < numChannels; channel++) {
	            var coords = [batch, row, col, channel];
	            var x = coords[2];
	            var y = coords[1];
	            // coordX/coordY are the result of rotating and translating x/y.
	            var coordX = (x - centerX) * cosFactor - (y - centerY) * sinFactor;
	            var coordY = (x - centerX) * sinFactor + (y - centerY) * cosFactor;
	            coordX = Math.round(coordX + centerX);
	            coordY = Math.round(coordY + centerY);
	            var outputValue = fillValue;
	            if (typeof fillValue !== 'number') {
	              if (channel === 3) {
	                outputValue = fullOpacityValue;
	              } else {
	                outputValue = fillValue[channel];
	              }
	            }
	            // If the coordinate position falls within the image boundaries...
	            if (coordX >= 0 && coordX < imageWidth && coordY >= 0 && coordY < imageHeight) {
	              // set the output to the image value at the coordinate position.
	              var rotatedRowOffset = coordY * (imageWidth * numChannels);
	              var rotatedColOffset = coordX * numChannels;
	              var imageIdx = batchOffset + rotatedRowOffset + rotatedColOffset + channel;
	              outputValue = imageVals[imageIdx];
	            }
	            var outIdx = batchOffset + rowOffset + colOffset + channel;
	            output[outIdx] = outputValue;
	          }
	        }
	      }
	    }
	    var dataId = cpuBackend.write(output, image.shape, image.dtype);
	    return {
	      dataId: dataId,
	      shape: image.shape,
	      dtype: image.dtype
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var round$1 = unaryKernelFunc$1(Round, function (xi) {
	  // The algorithm is based on banker's rounding.
	  var base = Math.floor(xi);
	  if (xi - base < 0.5) {
	    return Math.floor(xi);
	  } else if (xi - base > 0.5) {
	    return Math.ceil(xi);
	  } else {
	    if (base % 2.0 === 0.0) {
	      return base;
	    } else {
	      return base + 1.0;
	    }
	  }
	});
	var roundConfig$1 = {
	  kernelName: Round,
	  backendName: 'cpu',
	  kernelFunc: round$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function scatterNd$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var indices = inputs.indices,
	    updates = inputs.updates;
	  var shape = attrs.shape;
	  var _backend_util$calcula = calculateShapes(updates, indices, shape),
	    sliceRank = _backend_util$calcula.sliceRank,
	    numUpdates = _backend_util$calcula.numUpdates,
	    sliceSize = _backend_util$calcula.sliceSize,
	    strides = _backend_util$calcula.strides,
	    outputSize = _backend_util$calcula.outputSize;
	  var sumDupeIndices = true;
	  var indicesBuf = backend.bufferSync(indices);
	  var updatesBuf = backend.bufferSync(updates);
	  var outBuf = scatterImpl(indicesBuf, updatesBuf, shape, outputSize, sliceSize, numUpdates, sliceRank, strides, 0 /* defaultValue */, sumDupeIndices);
	  return backend.makeTensorInfo(shape, outBuf.dtype, outBuf.values);
	}
	var scatterNdConfig$1 = {
	  kernelName: ScatterNd,
	  backendName: 'cpu',
	  kernelFunc: scatterNd$1
	};

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function lowerBound(array, value) {
	  var left = 0;
	  var right = array.length;
	  var mid = 0;
	  while (left < right) {
	    mid = Math.floor((left + right) / 2);
	    if (array[mid] < value) {
	      left = mid + 1;
	    } else {
	      right = mid;
	    }
	  }
	  return right;
	}
	function upperBound(array, value) {
	  var left = 0;
	  var right = array.length;
	  var mid = 0;
	  while (left < right) {
	    mid = Math.floor((left + right) / 2);
	    if (array[mid] <= value) {
	      left = mid + 1;
	    } else {
	      right = mid;
	    }
	  }
	  return right;
	}
	function searchSortedImpl(sortedInputs, values, batchSize, numInputs, numValues, side) {
	  var output = getArrayFromDType('int32', batchSize * numValues);
	  for (var b = 0; b < batchSize; ++b) {
	    var sortedInputsSlice = sortedInputs.slice(b * numInputs, (b + 1) * numInputs);
	    var outputOffset = b * numValues;
	    for (var i = 0; i < numValues; ++i) {
	      output[outputOffset + i] = side === 'left' ? lowerBound(sortedInputsSlice, values[i + outputOffset]) : upperBound(sortedInputsSlice, values[i + outputOffset]);
	    }
	  }
	  return output;
	}

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function searchSorted$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var sortedSequence = inputs.sortedSequence,
	    values = inputs.values;
	  var side = attrs.side;
	  var $sortedSequence = backend.data.get(sortedSequence.dataId).values;
	  var $values = backend.data.get(values.dataId).values;
	  var output = searchSortedImpl($sortedSequence, $values, sortedSequence.shape[0], sortedSequence.shape[1], values.shape[1], side);
	  return backend.makeTensorInfo(values.shape, 'int32', output);
	}
	var searchSortedConfig$1 = {
	  kernelName: SearchSorted,
	  backendName: 'cpu',
	  kernelFunc: searchSorted$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function select$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var condition = inputs.condition,
	    t = inputs.t,
	    e = inputs.e;
	  assertNotComplex$1([condition, t, e], 'select');
	  var conditionRank = condition.shape.length;
	  var values = backend.data.get(condition.dataId).values;
	  var tValues = backend.data.get(t.dataId).values;
	  var eValues = backend.data.get(e.dataId).values;
	  var resultDtype = upcastType(t.dtype, e.dtype);
	  var newValues = makeZerosTypedArray(sizeFromShape(t.shape), resultDtype);
	  var index = 0;
	  var offset = conditionRank === 0 || conditionRank > 1 || t.shape.length === 1 ? 1 : sizeFromShape(t.shape.slice(1));
	  for (var i = 0; i < values.length; i++) {
	    for (var j = 0; j < offset; j++) {
	      if (values[i] === 1) {
	        newValues[index++] = tValues[i];
	      } else {
	        newValues[index++] = eValues[i];
	      }
	    }
	  }
	  return backend.makeTensorInfo(t.shape, resultDtype, newValues);
	}
	var selectConfig$1 = {
	  kernelName: Select,
	  backendName: 'cpu',
	  kernelFunc: select$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var scaleAlpha = SELU_SCALEALPHA;
	var scale = SELU_SCALE;
	var selu$1 = unaryKernelFunc$1(Selu$1, function (xi) {
	  if (xi >= 0) {
	    return scale * xi;
	  } else {
	    return scaleAlpha * (Math.exp(xi) - 1);
	  }
	});
	var seluConfig$1 = {
	  kernelName: Selu$1,
	  backendName: 'cpu',
	  kernelFunc: selu$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var sign$1 = unaryKernelFunc$1(Sign, function (xi) {
	  if (xi < 0) {
	    return -1;
	  } else if (xi > 0) {
	    return 1;
	  } else {
	    return 0;
	  }
	});
	var signConfig$1 = {
	  kernelName: Sign,
	  backendName: 'cpu',
	  kernelFunc: sign$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var sin$1 = unaryKernelFunc$1(Sin, function (xi) {
	  return Math.sin(xi);
	});
	var sinConfig$1 = {
	  kernelName: Sin,
	  backendName: 'cpu',
	  kernelFunc: sin$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var sinh$1 = unaryKernelFunc$1(Sinh, function (xi) {
	  return Math.sinh(xi);
	});
	var sinhConfig$1 = {
	  kernelName: Sinh,
	  backendName: 'cpu',
	  kernelFunc: sinh$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	// mirrors the implementation of tf.nn.softplus: https://goo.gl/vkcvwX
	// epsilon is the difference between 1.0 and the next representable float.
	// For a single precision 32 bit float this should be 2^-23, see:
	// https://math.byu.edu/~schow/work/IEEEFloatingPoint.htm
	var epsilon = 1.1920928955078125e-7;
	var threshold = Math.log(epsilon) + 2.0;
	var softplus$1 = unaryKernelFunc$1(Softplus$1, function (xi) {
	  // Value above which exp(x) may overflow, but softplus(x) == x
	  // is within machine epsilon.
	  var tooLarge = xi > -threshold;
	  // Value below which exp(x) may underflow, but softplus(x) == exp(x)
	  // is within machine epsilon.
	  var tooSmall = xi < threshold;
	  var expX = Math.exp(xi);
	  var result;
	  if (tooSmall) {
	    result = expX;
	  } else if (tooLarge) {
	    result = xi;
	  } else {
	    result = Math.log(1.0 + expX);
	  }
	  return result;
	});
	var softplusConfig$1 = {
	  kernelName: Softplus$1,
	  backendName: 'cpu',
	  kernelFunc: softplus$1
	};

	function spaceToBatchND$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var blockShape = attrs.blockShape,
	    paddings = attrs.paddings;
	  assertNotComplex$1([x], 'spaceToBatchND');
	  var prod = sizeFromShape(blockShape);
	  var completePaddings = [[0, 0]];
	  completePaddings.push.apply(completePaddings, _toConsumableArray(paddings));
	  for (var i = 1 + blockShape.length; i < x.shape.length; ++i) {
	    completePaddings.push([0, 0]);
	  }
	  var paddedX = padV2Config$1.kernelFunc({
	    inputs: {
	      x: x
	    },
	    backend: backend,
	    attrs: {
	      paddings: completePaddings,
	      constantValue: 0
	    }
	  });
	  var reshapedPaddedShape = getReshaped(paddedX.shape, blockShape, prod, false);
	  var permutedReshapedPaddedPermutation = getPermuted(reshapedPaddedShape.length, blockShape.length, false);
	  var flattenShape = getReshapedPermuted(paddedX.shape, blockShape, prod, false);
	  var reshapeInputs = {
	    x: paddedX
	  };
	  var reshapeAttrs = {
	    shape: reshapedPaddedShape
	  };
	  var paddedXReshaped = reshape$1({
	    inputs: reshapeInputs,
	    backend: backend,
	    attrs: reshapeAttrs
	  });
	  var transposeInputs = {
	    x: paddedXReshaped
	  };
	  var transposeAttrs = {
	    perm: permutedReshapedPaddedPermutation
	  };
	  var paddedXT = transpose$1({
	    inputs: transposeInputs,
	    backend: backend,
	    attrs: transposeAttrs
	  });
	  var resultReshapeInputs = {
	    x: paddedXT
	  };
	  var resultReshapeAttrs = {
	    shape: flattenShape
	  };
	  var result = reshape$1({
	    inputs: resultReshapeInputs,
	    backend: backend,
	    attrs: resultReshapeAttrs
	  });
	  backend.disposeIntermediateTensorInfo(paddedX);
	  backend.disposeIntermediateTensorInfo(paddedXReshaped);
	  backend.disposeIntermediateTensorInfo(paddedXT);
	  return result;
	}
	var spaceToBatchNDConfig$1 = {
	  kernelName: SpaceToBatchND,
	  backendName: 'cpu',
	  kernelFunc: spaceToBatchND$1
	};

	function sparseFillEmptyRows$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var indices = inputs.indices,
	    values = inputs.values,
	    denseShape = inputs.denseShape,
	    defaultValue = inputs.defaultValue;
	  if (denseShape.shape.length !== 1) {
	    throw new Error("Dense shape must be a vector, saw:\n        ".concat(denseShape.shape));
	  }
	  if (indices.shape.length !== 2) {
	    throw new Error("Indices must be a matrix, saw:\n        ".concat(indices.shape));
	  }
	  if (values.shape.length !== 1) {
	    throw new Error("Values must be a vector, saw:\n        ".concat(values.shape));
	  }
	  if (defaultValue.shape.length !== 0) {
	    throw new Error("Default value must be a scalar, saw:\n        ".concat(defaultValue.shape));
	  }
	  var $indices = backend.data.get(indices.dataId).values;
	  var $values = backend.data.get(values.dataId).values;
	  var $denseShape = backend.data.get(denseShape.dataId).values;
	  var $defaultValue = backend.data.get(defaultValue.dataId).values[0];
	  var _sparseFillEmptyRowsI = sparseFillEmptyRowsImpl($indices, indices.shape, indices.dtype, $values, values.dtype, $denseShape, $defaultValue),
	    _sparseFillEmptyRowsI2 = _slicedToArray(_sparseFillEmptyRowsI, 5),
	    outputIndices = _sparseFillEmptyRowsI2[0],
	    outputIndicesShape = _sparseFillEmptyRowsI2[1],
	    outputValues = _sparseFillEmptyRowsI2[2],
	    emptyRowIndicator = _sparseFillEmptyRowsI2[3],
	    reverseIndexMap = _sparseFillEmptyRowsI2[4];
	  return [backend.makeTensorInfo(outputIndicesShape, indices.dtype, outputIndices), backend.makeTensorInfo([outputIndicesShape[0]], values.dtype, outputValues), backend.makeTensorInfo([emptyRowIndicator.length], 'bool', new Uint8Array(emptyRowIndicator.map(function (value) {
	    return Number(value);
	  }))), backend.makeTensorInfo([reverseIndexMap.length], indices.dtype, new Int32Array(reverseIndexMap))];
	}
	var sparseFillEmptyRowsConfig$1 = {
	  kernelName: SparseFillEmptyRows,
	  backendName: 'cpu',
	  kernelFunc: sparseFillEmptyRows$1
	};

	function sparseReshape$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var inputIndices = inputs.inputIndices,
	    inputShape = inputs.inputShape,
	    newShape = inputs.newShape;
	  if (inputIndices.shape.length !== 2) {
	    throw new Error("Input indices should be a matrix but received shape\n        ".concat(inputIndices.shape));
	  }
	  if (inputShape.shape.length !== 1) {
	    throw new Error("Input shape should be a vector but received shape\n        ".concat(inputShape.shape));
	  }
	  if (newShape.shape.length !== 1) {
	    throw new Error("Target shape should be a vector but received shape ".concat(newShape.shape));
	  }
	  var $inputShape = Array.from(backend.data.get(inputShape.dataId).values);
	  var $inputIndices = backend.data.get(inputIndices.dataId).values;
	  var targetShape = Array.from(backend.data.get(newShape.dataId).values);
	  var _sparseReshapeImpl = sparseReshapeImpl($inputIndices, inputIndices.shape, inputIndices.dtype, $inputShape, targetShape),
	    _sparseReshapeImpl2 = _slicedToArray(_sparseReshapeImpl, 3),
	    newIndices = _sparseReshapeImpl2[0],
	    indicesShape = _sparseReshapeImpl2[1],
	    outputShape = _sparseReshapeImpl2[2];
	  return [backend.makeTensorInfo(indicesShape, inputIndices.dtype, newIndices), backend.makeTensorInfo([outputShape.length], newShape.dtype, new Int32Array(outputShape))];
	}
	var sparseReshapeConfig$1 = {
	  kernelName: SparseReshape,
	  backendName: 'cpu',
	  kernelFunc: sparseReshape$1
	};

	function sparseSegmentMean$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var data = inputs.data,
	    indices = inputs.indices,
	    segmentIds = inputs.segmentIds;
	  if (data.shape.length < 1) {
	    throw new Error("Data should be at least 1 dimensional but received scalar");
	  }
	  if (indices.shape.length !== 1) {
	    throw new Error("Indices should be a vector but received shape\n          ".concat(indices.shape));
	  }
	  if (segmentIds.shape.length !== 1) {
	    throw new Error("Segment ids should be a vector but received shape\n          ".concat(segmentIds.shape));
	  }
	  if (indices.shape[0] !== segmentIds.shape[0]) {
	    throw new Error("segmentIds and indices should have same size.");
	  }
	  var $data = backend.data.get(data.dataId).values;
	  var $indices = backend.data.get(indices.dataId).values;
	  var $segmentIds = backend.data.get(segmentIds.dataId).values;
	  var _sparseSegmentReducti = sparseSegmentReductionImpl($data, data.shape, data.dtype, $indices, $segmentIds, true),
	    _sparseSegmentReducti2 = _slicedToArray(_sparseSegmentReducti, 2),
	    outputData = _sparseSegmentReducti2[0],
	    outputDataShape = _sparseSegmentReducti2[1];
	  return backend.makeTensorInfo(outputDataShape, data.dtype, outputData);
	}
	var sparseSegmentMeanConfig$1 = {
	  kernelName: SparseSegmentMean,
	  backendName: 'cpu',
	  kernelFunc: sparseSegmentMean$1
	};

	function sparseSegmentSum$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var data = inputs.data,
	    indices = inputs.indices,
	    segmentIds = inputs.segmentIds;
	  if (data.shape.length < 1) {
	    throw new Error("Data should be at least 1 dimensional but received scalar");
	  }
	  if (indices.shape.length !== 1) {
	    throw new Error("Indices should be a vector but received shape\n         ".concat(indices.shape));
	  }
	  if (segmentIds.shape.length !== 1) {
	    throw new Error("Segment ids should be a vector but received shape\n         ".concat(segmentIds.shape));
	  }
	  if (indices.shape[0] !== segmentIds.shape[0]) {
	    throw new Error("segmentIds and indices should have same size.");
	  }
	  var $data = backend.data.get(data.dataId).values;
	  var $indices = backend.data.get(indices.dataId).values;
	  var $segmentIds = backend.data.get(segmentIds.dataId).values;
	  var _sparseSegmentReducti = sparseSegmentReductionImpl($data, data.shape, data.dtype, $indices, $segmentIds),
	    _sparseSegmentReducti2 = _slicedToArray(_sparseSegmentReducti, 2),
	    outputData = _sparseSegmentReducti2[0],
	    outputDataShape = _sparseSegmentReducti2[1];
	  return backend.makeTensorInfo(outputDataShape, data.dtype, outputData);
	}
	var sparseSegmentSumConfig$1 = {
	  kernelName: SparseSegmentSum,
	  backendName: 'cpu',
	  kernelFunc: sparseSegmentSum$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function sparseToDense$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var sparseIndices = inputs.sparseIndices,
	    sparseValues = inputs.sparseValues,
	    defaultValue = inputs.defaultValue;
	  var outputShape = attrs.outputShape;
	  var _backend_util$calcula = calculateShapes(sparseValues, sparseIndices, outputShape),
	    sliceRank = _backend_util$calcula.sliceRank,
	    numUpdates = _backend_util$calcula.numUpdates,
	    sliceSize = _backend_util$calcula.sliceSize,
	    strides = _backend_util$calcula.strides,
	    outputSize = _backend_util$calcula.outputSize;
	  var sumDupeIndices = false;
	  var indicesBuf = backend.bufferSync(sparseIndices);
	  var outBuf;
	  switch (sparseValues.dtype) {
	    case 'bool':
	      {
	        var updatesBuf = backend.bufferSync(sparseValues);
	        var $defaultValue = Boolean(backend.data.get(defaultValue.dataId).values[0]);
	        outBuf = scatterImpl(indicesBuf, updatesBuf, outputShape, outputSize, sliceSize, numUpdates, sliceRank, strides, $defaultValue, sumDupeIndices);
	        break;
	      }
	    case 'float32':
	      {
	        var _updatesBuf = backend.bufferSync(sparseValues);
	        var _$defaultValue = backend.data.get(defaultValue.dataId).values[0];
	        outBuf = scatterImpl(indicesBuf, _updatesBuf, outputShape, outputSize, sliceSize, numUpdates, sliceRank, strides, _$defaultValue, sumDupeIndices);
	        break;
	      }
	    case 'int32':
	      {
	        var _updatesBuf2 = backend.bufferSync(sparseValues);
	        var _$defaultValue2 = backend.data.get(defaultValue.dataId).values[0];
	        outBuf = scatterImpl(indicesBuf, _updatesBuf2, outputShape, outputSize, sliceSize, numUpdates, sliceRank, strides, _$defaultValue2, sumDupeIndices);
	        break;
	      }
	    case 'string':
	      {
	        var _updatesBuf3 = backend.bufferSync(sparseValues);
	        var _$defaultValue3 = decodeString(backend.data.get(defaultValue.dataId).values[0]);
	        outBuf = scatterImpl(indicesBuf, _updatesBuf3, outputShape, outputSize, sliceSize, numUpdates, sliceRank, strides, _$defaultValue3, sumDupeIndices);
	        break;
	      }
	    default:
	      throw new Error("Unsupported type ".concat(sparseValues.dtype));
	  }
	  return backend.makeTensorInfo(outputShape, outBuf.dtype, outBuf.values);
	}
	var sparseToDenseConfig$1 = {
	  kernelName: SparseToDense,
	  backendName: 'cpu',
	  kernelFunc: sparseToDense$1
	};

	function splitV$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var numOrSizeSplits = attrs.numOrSizeSplits,
	    axis = attrs.axis;
	  var $axis = parseAxisParam(axis, x.shape)[0];
	  var splitSizes = prepareSplitSize(x, numOrSizeSplits, $axis);
	  var begin = new Array(x.shape.length).fill(0);
	  var size = x.shape.slice();
	  return splitSizes.map(function (s) {
	    var sliceSize = _toConsumableArray(size);
	    sliceSize[$axis] = s;
	    var sliceT = slice$1({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        begin: begin,
	        size: sliceSize
	      }
	    });
	    begin[$axis] += s;
	    return sliceT;
	  });
	}
	var splitVConfig$1 = {
	  kernelName: SplitV,
	  backendName: 'cpu',
	  kernelFunc: splitV$1
	};

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var squareConfig$1 = {
	  kernelName: Square,
	  backendName: 'cpu',
	  kernelFunc: function kernelFunc(_ref) {
	    var inputs = _ref.inputs,
	      backend = _ref.backend;
	    var x = inputs.x;
	    var cpuBackend = backend;
	    assertNotComplex$1(x, 'square');
	    var values = cpuBackend.data.get(x.dataId).values;
	    var newValues = new Float32Array(values.length);
	    for (var i = 0; i < values.length; ++i) {
	      var value = values[i];
	      newValues[i] = value * value;
	    }
	    var dataId = cpuBackend.write(newValues, x.shape, x.dtype);
	    return {
	      dataId: dataId,
	      shape: x.shape,
	      dtype: x.dtype
	    };
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var step$1 = unaryKernelFunc$1(Step, function (xi, attrs) {
	  var stepAttrs = attrs;
	  if (isNaN(xi)) {
	    return NaN;
	  } else {
	    return xi > 0 ? 1 : stepAttrs.alpha;
	  }
	});
	var stepConfig$1 = {
	  kernelName: Step,
	  backendName: 'cpu',
	  kernelFunc: step$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function stridedSlice$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var begin = attrs.begin,
	    end = attrs.end,
	    strides = attrs.strides,
	    beginMask = attrs.beginMask,
	    endMask = attrs.endMask,
	    ellipsisMask = attrs.ellipsisMask,
	    newAxisMask = attrs.newAxisMask,
	    shrinkAxisMask = attrs.shrinkAxisMask;
	  assertNotComplex$1(x, 'stridedSlice');
	  var _slice_util$sliceInfo = sliceInfo(x.shape, begin, end, strides, beginMask, endMask, ellipsisMask, newAxisMask, shrinkAxisMask),
	    finalShapeSparse = _slice_util$sliceInfo.finalShapeSparse,
	    finalShape = _slice_util$sliceInfo.finalShape,
	    isIdentity = _slice_util$sliceInfo.isIdentity,
	    sliceDim0 = _slice_util$sliceInfo.sliceDim0,
	    isSimpleSlice = _slice_util$sliceInfo.isSimpleSlice,
	    $begin = _slice_util$sliceInfo.begin,
	    $end = _slice_util$sliceInfo.end,
	    $strides = _slice_util$sliceInfo.strides;
	  var result;
	  // ref:
	  // https://github.com/tensorflow/tensorflow/blob/master/tensorflow/core/kernels/strided_slice_op.cc
	  if (isIdentity) {
	    // Optimization #1, slice is a no-op plus reshape
	    result = reshape$1({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        shape: finalShape
	      }
	    });
	  } else if (sliceDim0 || isSimpleSlice) {
	    // Optimization #2, slice is memory contiguous (only occurs in dim 0)
	    assert$1(x.shape.length >= 1, function () {
	      return "Input must have rank at least 1, got: ".concat(x.shape.length);
	    });
	    var size = computeOutShape$2($begin, $end, $strides);
	    // To tolerate begin[0] > end[0] (a 0-output slice), we min(begin, end).
	    var sliced = slice$1({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        begin: $begin,
	        size: size
	      }
	    });
	    result = reshape$1({
	      inputs: {
	        x: sliced
	      },
	      backend: backend,
	      attrs: {
	        shape: finalShape
	      }
	    });
	    backend.disposeIntermediateTensorInfo(sliced);
	  } else {
	    var xBuf = backend.bufferSync(x);
	    var outBuf = stridedSliceImpl(finalShapeSparse, xBuf, $strides, $begin);
	    result = backend.makeTensorInfo(finalShape, outBuf.dtype, outBuf.values);
	  }
	  return result;
	}
	var stridedSliceConfig$1 = {
	  kernelName: StridedSlice,
	  backendName: 'cpu',
	  kernelFunc: stridedSlice$1
	};

	function stringNGrams$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var separator = attrs.separator,
	    nGramWidths = attrs.nGramWidths,
	    leftPad = attrs.leftPad,
	    rightPad = attrs.rightPad,
	    padWidth = attrs.padWidth,
	    preserveShortSequences = attrs.preserveShortSequences;
	  var data = inputs.data,
	    dataSplits = inputs.dataSplits;
	  var $data = backend.data.get(data.dataId).values;
	  var $dataSplits = backend.data.get(dataSplits.dataId).values;
	  var _stringNGramsImpl = stringNGramsImpl($data, $dataSplits, separator, nGramWidths, leftPad, rightPad, padWidth, preserveShortSequences),
	    _stringNGramsImpl2 = _slicedToArray(_stringNGramsImpl, 2),
	    nGrams = _stringNGramsImpl2[0],
	    nGramsSplits = _stringNGramsImpl2[1];
	  return [backend.makeTensorInfo([nGrams.length], 'string', nGrams), backend.makeTensorInfo(dataSplits.shape, 'int32', nGramsSplits)];
	}
	var stringNGramsConfig$1 = {
	  kernelName: StringNGrams,
	  backendName: 'cpu',
	  kernelFunc: stringNGrams$1
	};

	function stringSplit$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var skipEmpty = attrs.skipEmpty;
	  var input = inputs.input,
	    delimiter = inputs.delimiter;
	  if (input.dtype !== 'string') {
	    throw new Error('Input must be of datatype string');
	  }
	  if (input.shape.length !== 1) {
	    throw new Error("Input must be a vector, got shape: ".concat(input.shape));
	  }
	  if (delimiter.shape.length !== 0) {
	    throw new Error("Delimiter must be a scalar, got shape: ".concat(delimiter.shape));
	  }
	  var $input = backend.data.get(input.dataId).values;
	  var $delimiter = backend.data.get(delimiter.dataId).values[0];
	  var _stringSplitImpl = stringSplitImpl($input, $delimiter, skipEmpty),
	    _stringSplitImpl2 = _slicedToArray(_stringSplitImpl, 3),
	    indices = _stringSplitImpl2[0],
	    values = _stringSplitImpl2[1],
	    shape = _stringSplitImpl2[2];
	  var outputSize = values.length;
	  return [backend.makeTensorInfo([outputSize, 2], 'int32', indices), backend.makeTensorInfo([outputSize], 'string', values), backend.makeTensorInfo([2], 'int32', new Int32Array(shape))];
	}
	var stringSplitConfig$1 = {
	  kernelName: StringSplit,
	  backendName: 'cpu',
	  kernelFunc: stringSplit$1
	};

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function stringToHashBucketFast$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var numBuckets = attrs.numBuckets;
	  var input = inputs.input;
	  if (input.dtype !== 'string') {
	    throw new Error('Input must be of datatype string');
	  }
	  if (numBuckets <= 0) {
	    throw new Error("Number of buckets must be at least 1");
	  }
	  var $input = backend.data.get(input.dataId).values;
	  var output = stringToHashBucketFastImpl($input, numBuckets);
	  return backend.makeTensorInfo(input.shape, 'int32', output);
	}
	var stringToHashBucketFastConfig$1 = {
	  kernelName: StringToHashBucketFast,
	  backendName: 'cpu',
	  kernelFunc: stringToHashBucketFast$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var tan$1 = unaryKernelFunc$1(Tan, function (xi) {
	  return Math.tan(xi);
	});
	var tanConfig$1 = {
	  kernelName: Tan,
	  backendName: 'cpu',
	  kernelFunc: tan$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var tanh$1 = unaryKernelFunc$1(Tanh$1, function (xi) {
	  return Math.tanh(xi);
	});
	var tanhConfig$1 = {
	  kernelName: Tanh$1,
	  backendName: 'cpu',
	  kernelFunc: tanh$1
	};

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function tensorScatterUpdate$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var tensor = inputs.tensor,
	    indices = inputs.indices,
	    updates = inputs.updates;
	  var _backend_util$calcula = calculateShapes(updates, indices, tensor.shape),
	    sliceRank = _backend_util$calcula.sliceRank,
	    numUpdates = _backend_util$calcula.numUpdates,
	    sliceSize = _backend_util$calcula.sliceSize,
	    strides = _backend_util$calcula.strides,
	    outputSize = _backend_util$calcula.outputSize;
	  var sumDupeIndices = false;
	  var indicesBuf = backend.bufferSync(indices);
	  var updatesBuf = backend.bufferSync(updates);
	  var tensorBuf = backend.bufferSync(tensor);
	  var outBuf = scatterImpl(indicesBuf, updatesBuf, tensor.shape, outputSize, sliceSize, numUpdates, sliceRank, strides, tensorBuf, sumDupeIndices);
	  return backend.makeTensorInfo(tensor.shape, outBuf.dtype, outBuf.values);
	}
	var tensorScatterUpdateConfig$1 = {
	  kernelName: TensorScatterUpdate,
	  backendName: 'cpu',
	  kernelFunc: tensorScatterUpdate$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function tile$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var reps = attrs.reps;
	  assertNotComplex$1(x, 'tile');
	  var outBuf = tileImpl(backend.bufferSync(x), reps);
	  return backend.makeTensorInfo(outBuf.shape, outBuf.dtype, outBuf.values);
	}
	var tileConfig$1 = {
	  kernelName: Tile,
	  backendName: 'cpu',
	  kernelFunc: tile$1
	};

	function topK$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var k = attrs.k,
	    sorted = attrs.sorted;
	  assertNotComplex$1(x, 'topk');
	  var xVals = backend.data.get(x.dataId).values;
	  var _topKImpl = topKImpl(xVals, x.shape, x.dtype, k, sorted),
	    _topKImpl2 = _slicedToArray(_topKImpl, 2),
	    allTopKVals = _topKImpl2[0],
	    allTopKIndices = _topKImpl2[1];
	  return [backend.makeTensorInfo(allTopKVals.shape, allTopKVals.dtype, allTopKVals.values), backend.makeTensorInfo(allTopKIndices.shape, allTopKIndices.dtype, allTopKIndices.values)];
	}
	var topKConfig$1 = {
	  kernelName: TopK,
	  backendName: 'cpu',
	  kernelFunc: topK$1
	};

	function transform$1(args) {
	  var inputs = args.inputs,
	    attrs = args.attrs,
	    backend = args.backend;
	  var image = inputs.image,
	    transforms = inputs.transforms;
	  var interpolation = attrs.interpolation,
	    fillMode = attrs.fillMode,
	    fillValue = attrs.fillValue,
	    outputShape = attrs.outputShape;
	  var _image$shape = _slicedToArray(image.shape, 4),
	    batch = _image$shape[0],
	    imageHeight = _image$shape[1],
	    imageWidth = _image$shape[2],
	    numChannels = _image$shape[3];
	  var _ref = outputShape != null ? outputShape : [imageHeight, imageWidth],
	    _ref2 = _slicedToArray(_ref, 2),
	    outHeight = _ref2[0],
	    outWidth = _ref2[1];
	  var outShape = [batch, outHeight, outWidth, numChannels];
	  var inStrides = computeStrides(image.shape);
	  var batchInStride = inStrides[0];
	  var rowInStride = inStrides[1];
	  var colInStride = inStrides[2];
	  var outStrides = computeStrides(outShape);
	  var batchOutStride = outStrides[0];
	  var rowOutStride = outStrides[1];
	  var colOutStride = outStrides[2];
	  var outVals = getTypedArrayFromDType(image.dtype, sizeFromShape(outShape));
	  outVals.fill(fillValue);
	  var imageVals = backend.data.get(image.dataId).values;
	  var transformVals = backend.data.get(transforms.dataId).values;
	  // Ref TF implementation:
	  // https://github.com/tensorflow/tensorflow/blob/master/tensorflow/core/kernels/image/image_ops.h
	  for (var b = 0; b < batch; ++b) {
	    var _transform = transforms.shape[0] === 1 ? transformVals : transformVals.subarray(b * 8, b * 8 + 8);
	    for (var outY = 0; outY < outHeight; ++outY) {
	      for (var outX = 0; outX < outWidth; ++outX) {
	        for (var channel = 0; channel < numChannels; ++channel) {
	          var val = void 0;
	          var projection = _transform[6] * outX + _transform[7] * outY + 1;
	          if (projection === 0) {
	            // Return the fill value for infinite coordinates,
	            // which are outside the input image
	            continue;
	          }
	          var inX = (_transform[0] * outX + _transform[1] * outY + _transform[2]) / projection;
	          var inY = (_transform[3] * outX + _transform[4] * outY + _transform[5]) / projection;
	          var x = mapCoord(inX, imageWidth, fillMode);
	          var y = mapCoord(inY, imageHeight, fillMode);
	          switch (interpolation) {
	            case 'nearest':
	              val = nearestInterpolation(imageVals, imageHeight, imageWidth, batchInStride, rowInStride, colInStride, b, y, x, channel, fillValue);
	              break;
	            case 'bilinear':
	              val = bilinearInterpolation(imageVals, imageHeight, imageWidth, batchInStride, rowInStride, colInStride, b, y, x, channel, fillValue);
	              break;
	            default:
	              throw new Error("Error in Transform: Expect 'nearest' or " + "'bilinear', but got ".concat(interpolation));
	          }
	          var ind = b * batchOutStride + outY * rowOutStride + outX * colOutStride + channel;
	          outVals[ind] = val;
	        }
	      }
	    }
	    return backend.makeTensorInfo(outShape, image.dtype, outVals);
	  }
	  var dataId = backend.write(outVals, outShape, image.dtype);
	  return {
	    dataId: dataId,
	    shape: image.shape,
	    dtype: image.dtype
	  };
	}
	var transformConfig$1 = {
	  kernelName: Transform,
	  backendName: 'cpu',
	  kernelFunc: transform$1
	};
	function mapCoord(outCoord, len, mode) {
	  switch (mode) {
	    case 'reflect':
	      return mapCoordReflect(outCoord, len);
	    case 'wrap':
	      return mapCoordWrap(outCoord, len);
	    case 'nearest':
	      return mapCoordNearest(outCoord, len);
	    case 'constant':
	    default:
	      return mapCoordConstant(outCoord, len);
	  }
	}
	function mapCoordReflect(outCoord, len) {
	  // Reflect [abcd] to [dcba|abcd|dcba].
	  var inCoord = outCoord;
	  if (inCoord < 0) {
	    if (len <= 1) {
	      inCoord = 0;
	    } else {
	      var sz2 = 2 * len;
	      if (inCoord < sz2) {
	        inCoord = sz2 * Math.trunc(-inCoord / sz2) + inCoord;
	      }
	      inCoord = inCoord < -len ? inCoord + sz2 : -inCoord - 1;
	    }
	  } else if (inCoord > len - 1) {
	    if (len <= 1) {
	      inCoord = 0;
	    } else {
	      var _sz = 2 * len;
	      inCoord -= _sz * Math.trunc(inCoord / _sz);
	      if (inCoord >= len) {
	        inCoord = _sz - inCoord - 1;
	      }
	    }
	  }
	  // clamp is necessary because when outCoord = 3.5 and len = 4,
	  // inCoord = 3.5 and will be rounded to 4 in nearest interpolation.
	  return clamp(0, inCoord, len - 1);
	}
	function mapCoordWrap(outCoord, len) {
	  // Wrap [abcd] to [abcd|abcd|abcd].
	  var inCoord = outCoord;
	  if (inCoord < 0) {
	    if (len <= 1) {
	      inCoord = 0;
	    } else {
	      var sz = len - 1;
	      inCoord += len * (Math.trunc(-inCoord / sz) + 1);
	    }
	  } else if (inCoord > len - 1) {
	    if (len <= 1) {
	      inCoord = 0;
	    } else {
	      var _sz2 = len - 1;
	      inCoord -= len * Math.trunc(inCoord / _sz2);
	    }
	  }
	  // clamp is necessary because when outCoord = -0.5 and len = 4,
	  // inCoord = 3.5 and will be rounded to 4 in nearest interpolation.
	  return clamp(0, inCoord, len - 1);
	}
	function mapCoordConstant(outCoord, len) {
	  return outCoord;
	}
	function mapCoordNearest(outCoord, len) {
	  return clamp(0, outCoord, len - 1);
	}
	function readWithFillValue(imageVals, imageHeight, imageWidth, batchStride, rowStride, colStride, batch, y, x, channel, fillValue) {
	  var ind = batch * batchStride + y * rowStride + x * colStride + channel;
	  if (0 <= y && y < imageHeight && 0 <= x && x < imageWidth) {
	    return imageVals[ind];
	  } else {
	    return fillValue;
	  }
	}
	function nearestInterpolation(imageVals, imageHeight, imageWidth, batchStride, rowStride, colStride, batch, y, x, channel, fillValue) {
	  var $y = Math.round(y);
	  var $x = Math.round(x);
	  return readWithFillValue(imageVals, imageHeight, imageWidth, batchStride, rowStride, colStride, batch, $y, $x, channel, fillValue);
	}
	function bilinearInterpolation(imageVals, imageHeight, imageWidth, batchStride, rowStride, colStride, batch, y, x, channel, fillValue) {
	  var yFloor = Math.floor(y);
	  var xFloor = Math.floor(x);
	  var yCeil = yFloor + 1;
	  var xCeil = xFloor + 1;
	  // f(x, yFloor) = (xCeil - x) / (xCeil - xFloor) * f(xFloor, yFloor)
	  //               + (x - xFloor) / (xCeil - xFloor) * f(xCeil, yFloor)
	  var valueYFloor = (xCeil - x) * readWithFillValue(imageVals, imageHeight, imageWidth, batchStride, rowStride, colStride, batch, yFloor, xFloor, channel, fillValue) + (x - xFloor) * readWithFillValue(imageVals, imageHeight, imageWidth, batchStride, rowStride, colStride, batch, yFloor, xCeil, channel, fillValue);
	  // f(x, yCeil) = (xCeil - x) / (xCeil - xFloor) * f(xFloor, yCeil)
	  //             + (x - xFloor) / (xCeil - xFloor) * f(xCeil, yCeil)
	  var valueYCeil = (xCeil - x) * readWithFillValue(imageVals, imageHeight, imageWidth, batchStride, rowStride, colStride, batch, yCeil, xFloor, channel, fillValue) + (x - xFloor) * readWithFillValue(imageVals, imageHeight, imageWidth, batchStride, rowStride, colStride, batch, yCeil, xCeil, channel, fillValue);
	  // f(x, y) = (yCeil - y) / (yCeil - yFloor) * f(x, yFloor)
	  //         + (y - yFloor) / (yCeil - yFloor) * f(x, yCeil)
	  return (yCeil - y) * valueYFloor + (y - yFloor) * valueYCeil;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function unique$1(args) {
	  var inputs = args.inputs,
	    attrs = args.attrs,
	    backend = args.backend;
	  var axis = attrs.axis;
	  var x = inputs.x;
	  assertNotComplex$1(x, 'unique');
	  var values = backend.data.get(x.dataId).values;
	  var _uniqueImpl = uniqueImpl(values, axis, x.shape, x.dtype),
	    outputValues = _uniqueImpl.outputValues,
	    outputShape = _uniqueImpl.outputShape,
	    indices = _uniqueImpl.indices;
	  return [backend.makeTensorInfo(outputShape, x.dtype, outputValues), backend.makeTensorInfo([indices.length], 'int32', indices)];
	}
	var uniqueConfig$1 = {
	  kernelName: Unique,
	  backendName: 'cpu',
	  kernelFunc: unique$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function unpack$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var value = inputs.value;
	  var axis = attrs.axis;
	  if (axis < 0) {
	    axis += value.shape.length;
	  }
	  var valueRank = value.shape.length;
	  var num = value.shape[axis];
	  var outShape = new Array(valueRank - 1);
	  var outIndex = 0;
	  for (var i = 0; i < valueRank; i++) {
	    if (i !== axis) {
	      outShape[outIndex++] = value.shape[i];
	    }
	  }
	  var begin = new Array(valueRank).fill(0);
	  var size = value.shape.slice();
	  size[axis] = 1;
	  var res = new Array(num);
	  for (var _i = 0; _i < res.length; _i++) {
	    begin[axis] = _i;
	    var tempRes = slice$1({
	      inputs: {
	        x: value
	      },
	      backend: backend,
	      attrs: {
	        begin: begin,
	        size: size
	      }
	    });
	    res[_i] = reshape$1({
	      inputs: {
	        x: tempRes
	      },
	      backend: backend,
	      attrs: {
	        shape: outShape
	      }
	    });
	    backend.disposeIntermediateTensorInfo(tempRes);
	  }
	  return res;
	}
	var unpackConfig$1 = {
	  kernelName: Unpack,
	  backendName: 'cpu',
	  kernelFunc: unpack$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function unsortedSegmentSum$1(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    segmentIds = inputs.segmentIds;
	  var numSegments = attrs.numSegments;
	  assertNotComplex$1(x, 'unsortedSegmentSum');
	  var xRank = x.shape.length;
	  var segmentIdsRank = segmentIds.shape.length;
	  var res = [];
	  var intermediates = [];
	  // Reshape the segment id's so that they can be broadcast with
	  // x. The new shape should be [segmentIds.shape, 1, ..., 1]
	  var numIters = xRank - segmentIdsRank;
	  var $segmentIds = segmentIds;
	  for (var i = 0; i < numIters; ++i) {
	    var expanded = expandDims$1({
	      inputs: {
	        input: $segmentIds
	      },
	      backend: backend,
	      attrs: {
	        dim: i + 1
	      }
	    });
	    $segmentIds = expanded;
	    intermediates.push(expanded);
	  }
	  for (var _i = 0; _i < numSegments; ++_i) {
	    var scalarValue = createScalarValue(_i, 'int32');
	    var segmentId = backend.makeTensorInfo([], 'int32', scalarValue);
	    var mask = equal$1({
	      inputs: {
	        a: segmentId,
	        b: $segmentIds
	      },
	      backend: backend
	    });
	    var maskCasted = cast$1({
	      inputs: {
	        x: mask
	      },
	      backend: backend,
	      attrs: {
	        dtype: 'float32'
	      }
	    });
	    var mul = multiply$1({
	      inputs: {
	        a: maskCasted,
	        b: x
	      },
	      backend: backend
	    });
	    var sumTensorInfo = sum$1({
	      inputs: {
	        x: mul
	      },
	      backend: backend,
	      attrs: {
	        axis: 0,
	        keepDims: false
	      }
	    });
	    res.push(sumTensorInfo);
	    intermediates.push(segmentId);
	    intermediates.push(mask);
	    intermediates.push(maskCasted);
	    intermediates.push(mul);
	    intermediates.push(sumTensorInfo);
	  }
	  var result = pack$1({
	    inputs: res,
	    backend: backend,
	    attrs: {
	      axis: 0
	    }
	  });
	  intermediates.forEach(function (t) {
	    return backend.disposeIntermediateTensorInfo(t);
	  });
	  return result;
	}
	var unsortedSegmentSumConfig$1 = {
	  kernelName: UnsortedSegmentSum,
	  backendName: 'cpu',
	  kernelFunc: unsortedSegmentSum$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	// List all kernel configs here
	var kernelConfigs$1 = [_fusedMatMulConfig$1, absConfig$1, acosConfig$1, acoshConfig$1, addConfig$1, addNConfig$1, allConfig$1, anyConfig$1, argMaxConfig$1, argMinConfig$1, asinConfig$1, asinhConfig$1, atanConfig$1, atan2Config$1, atanhConfig$1, avgPoolConfig$1, avgPool3DConfig$1, avgPool3DGradConfig$1, avgPoolGradConfig$1, batchMatMulConfig$1, batchNormConfig$1, batchToSpaceNDConfig$1, bincountConfig$1, bitwiseAndConfig$1, broadcastArgsConfig$1, castConfig$1, ceilConfig$1, clipByValueConfig$1, complexConfig$1, complexAbsConfig$1, concatConfig$1, conv2DConfig$1, conv2DBackpropFilterConfig$1, conv2DBackpropInputConfig$1, conv3DConfig$1, conv3DBackpropFilterV2Config$1, conv3DBackpropInputV2Config, cosConfig$1, coshConfig$1, cropAndResizeConfig$1, cumprodConfig$1, cumsumConfig$1, denseBincountConfig$1, depthToSpaceConfig$1, depthwiseConv2dNativeConfig$1, depthwiseConv2dNativeBackpropFilterConfig$1, depthwiseConv2dNativeBackpropInputConfig$1, diagConfig$1, dilation2DConfig$1, dilation2DBackpropFilterConfig, dilation2DBackpropInputConfig, drawConfig, einsumConfig$1, eluConfig$1, eluGradConfig$1, equalConfig$1, erfConfig$1, expConfig$1, expandDimsConfig$1, expm1Config$1, fftConfig$1, fillConfig$1, flipLeftRightConfig$1, floorConfig$1, floorDivConfig$1, fusedConv2DConfig$1, fusedDepthwiseConv2DConfig$1, gatherNdConfig$1, gatherV2Config$1, greaterConfig$1, greaterEqualConfig$1, identityConfig$1, ifftConfig$1, imagConfig$1, isFiniteConfig$1, isInfConfig$1, isNaNConfig$1, leakyReluConfig$1, lessConfig$1, lessEqualConfig$1, linSpaceConfig$1, logConfig$1, log1pConfig$1, logicalAndConfig$1, logicalNotConfig$1, logicalOrConfig$1, LRNConfig$1, LRNGradConfig$1, maxConfig$1, maximumConfig$1, maxPoolConfig$1, maxPool3DConfig$1, maxPool3DGradConfig$1, maxPoolGradConfig$1, maxPoolWithArgmaxConfig$1, meanConfig$1, minConfig$1, minimumConfig$1, mirrorPadConfig$1, modConfig$1, multinomialConfig$1, multiplyConfig$1, negConfig$1, nonMaxSuppressionV3Config$1, nonMaxSuppressionV4Config$1, nonMaxSuppressionV5Config$1, notEqualConfig$1, oneHotConfig$1, onesLikeConfig$1, packConfig$1, padV2Config$1, powConfig$1, preluConfig$1, prodConfig$1, raggedGatherConfig$1, raggedRangeConfig$1, raggedTensorToTensorConfig$1, rangeConfig$1, realConfig$1, realDivConfig$1, reciprocalConfig$1, reluConfig$1, relu6Config$1, reshapeConfig$1, resizeBilinearConfig$1, resizeBilinearGradConfig$1, resizeNearestNeighborConfig$1, resizeNearestNeighborGradConfig$1, reverseConfig$1, rotateWithOffsetConfig$1, roundConfig$1, rsqrtConfig$1, scatterNdConfig$1, searchSortedConfig$1, selectConfig$1, seluConfig$1, sigmoidConfig$1, signConfig$1, sinConfig$1, sinhConfig$1, sliceConfig$1, softmaxConfig$1, softplusConfig$1, spaceToBatchNDConfig$1, sparseFillEmptyRowsConfig$1, sparseReshapeConfig$1, sparseSegmentMeanConfig$1, sparseSegmentSumConfig$1, sparseToDenseConfig$1, splitVConfig$1, sqrtConfig$1, squareConfig$1, squaredDifferenceConfig$1, staticRegexReplaceConfig$1, stepConfig$1, stridedSliceConfig$1, stringNGramsConfig$1, stringSplitConfig$1, stringToHashBucketFastConfig$1, subConfig$1, sumConfig$1, tanConfig$1, tanhConfig$1, tensorScatterUpdateConfig$1, tileConfig$1, topKConfig$1, transformConfig$1, transposeConfig$1, uniqueConfig$1, unpackConfig$1, unsortedSegmentSumConfig$1, zerosLikeConfig$1];
	for (var _i$1 = 0, _kernelConfigs$1 = kernelConfigs$1; _i$1 < _kernelConfigs$1.length; _i$1++) {
	  var kernelConfig$1 = _kernelConfigs$1[_i$1];
	  registerKernel(kernelConfig$1);
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var contexts = {};
	var WEBGL_ATTRIBUTES = {
	  alpha: false,
	  antialias: false,
	  premultipliedAlpha: false,
	  preserveDrawingBuffer: false,
	  depth: false,
	  stencil: false,
	  failIfMajorPerformanceCaveat: true
	};
	function clearWebGLContext(webGLVersion) {
	  delete contexts[webGLVersion];
	}
	function setWebGLContext(webGLVersion, gl) {
	  contexts[webGLVersion] = gl;
	}
	function getWebGLContext(webGLVersion, customCanvas) {
	  if (!(webGLVersion in contexts) || customCanvas != null) {
	    var newCtx = getWebGLRenderingContext(webGLVersion, customCanvas);
	    if (newCtx !== null) {
	      contexts[webGLVersion] = newCtx;
	    } else {
	      console.log('Could not get context for WebGL version', webGLVersion);
	      return null;
	    }
	  }
	  var gl = contexts[webGLVersion];
	  if (gl == null || gl.isContextLost()) {
	    delete contexts[webGLVersion];
	    return getWebGLContext(webGLVersion);
	  }
	  gl.disable(gl.DEPTH_TEST);
	  gl.disable(gl.STENCIL_TEST);
	  gl.disable(gl.BLEND);
	  gl.disable(gl.DITHER);
	  gl.disable(gl.POLYGON_OFFSET_FILL);
	  gl.disable(gl.SAMPLE_COVERAGE);
	  gl.enable(gl.SCISSOR_TEST);
	  gl.enable(gl.CULL_FACE);
	  gl.cullFace(gl.BACK);
	  return contexts[webGLVersion];
	}
	function createCanvas(webGLVersion) {
	  // Use canvas element for Safari, since its offscreen canvas does not support
	  // fencing.
	  if (!env().getBool('IS_SAFARI') && typeof OffscreenCanvas !== 'undefined' && webGLVersion === 2) {
	    return new OffscreenCanvas(300, 150);
	  } else if (typeof document !== 'undefined') {
	    return document.createElement('canvas');
	  } else {
	    throw new Error('Cannot create a canvas in this context');
	  }
	}
	function getWebGLRenderingContext(webGLVersion, customCanvas) {
	  if (webGLVersion !== 1 && webGLVersion !== 2) {
	    throw new Error('Cannot get WebGL rendering context, WebGL is disabled.');
	  }
	  var canvas = customCanvas == null ? createCanvas(webGLVersion) : customCanvas;
	  canvas.addEventListener('webglcontextlost', function (ev) {
	    ev.preventDefault();
	    delete contexts[webGLVersion];
	  }, false);
	  if (env().getBool('SOFTWARE_WEBGL_ENABLED')) {
	    WEBGL_ATTRIBUTES.failIfMajorPerformanceCaveat = false;
	  }
	  if (webGLVersion === 1) {
	    return (
	      // tslint:disable-next-line
	      canvas.getContext('webgl', WEBGL_ATTRIBUTES) || canvas.getContext('experimental-webgl', WEBGL_ATTRIBUTES)
	    );
	  }
	  return canvas.getContext('webgl2', WEBGL_ATTRIBUTES);
	}

	var PackingScheme;
	(function (PackingScheme) {
	  /**
	   * All values in a single texel are densely packed without any constraints.
	   *
	   * This is how the shader encodes a tensor with shape = [2, 3, 4]
	   * (indices are [batch, row, col]).
	   *
	   * 000|001   010|011   020|021
	   * -------   -------   -------
	   * 002|003   012|013   022|023
	   *
	   * 100|101   110|111   120|121
	   * -------   -------   -------
	   * 102|103   112|113   122|123
	   *
	   */
	  PackingScheme[PackingScheme["DENSE"] = 0] = "DENSE";
	  /**
	   * Single texels contain only values from the same batch, and from adjacent
	   * rows and columns.
	   *
	   * This is how the shader encodes a tensor with shape = [2, 3, 5]
	   * (indices are [batch, row, col]).
	   *
	   * 000|001   002|003   004|xxx   020|021   022|023   024|xxx
	   * -------   -------   -------   -------   -------   -------
	   * 010|011   012|013   014|xxx   xxx|xxx   xxx|xxx   xxx|xxx
	   *
	   * 100|101   102|103   104|xxx   120|121   122|123   124|xxx
	   * -------   -------   -------   -------   -------   -------
	   * 110|111   112|113   114|xxx   xxx|xxx   xxx|xxx   xxx|xxx
	   *
	   */
	  PackingScheme[PackingScheme["SHARED_BATCH"] = 1] = "SHARED_BATCH";
	})(PackingScheme || (PackingScheme = {}));
	var TextureUsage;
	(function (TextureUsage) {
	  TextureUsage[TextureUsage["RENDER"] = 0] = "RENDER";
	  TextureUsage[TextureUsage["UPLOAD"] = 1] = "UPLOAD";
	  TextureUsage[TextureUsage["PIXELS"] = 2] = "PIXELS";
	  TextureUsage[TextureUsage["DOWNLOAD"] = 3] = "DOWNLOAD";
	})(TextureUsage || (TextureUsage = {}));
	var PhysicalTextureType;
	(function (PhysicalTextureType) {
	  PhysicalTextureType[PhysicalTextureType["UNPACKED_FLOAT16"] = 0] = "UNPACKED_FLOAT16";
	  PhysicalTextureType[PhysicalTextureType["UNPACKED_FLOAT32"] = 1] = "UNPACKED_FLOAT32";
	  PhysicalTextureType[PhysicalTextureType["PACKED_4X1_UNSIGNED_BYTE"] = 2] = "PACKED_4X1_UNSIGNED_BYTE";
	  PhysicalTextureType[PhysicalTextureType["PACKED_2X2_FLOAT32"] = 3] = "PACKED_2X2_FLOAT32";
	  PhysicalTextureType[PhysicalTextureType["PACKED_2X2_FLOAT16"] = 4] = "PACKED_2X2_FLOAT16";
	})(PhysicalTextureType || (PhysicalTextureType = {}));
	function getUnpackedMatrixTextureShapeWidthHeight(rows, columns) {
	  return [columns, rows];
	}
	function getUnpackedArraySizeFromMatrixSize(matrixSize, channelsPerTexture) {
	  return matrixSize * channelsPerTexture;
	}
	function getColorMatrixTextureShapeWidthHeight(rows, columns) {
	  return [columns * 4, rows];
	}
	/**
	 * Get shape for densely packed RGBA texture.
	 */
	function getDenseTexShape(shape) {
	  var size = sizeFromShape(shape);
	  var texelsNeeded = Math.ceil(size / 4);
	  return sizeToSquarishShape(texelsNeeded);
	}
	function getMatrixSizeFromUnpackedArraySize(unpackedSize, channelsPerTexture) {
	  if (unpackedSize % channelsPerTexture !== 0) {
	    throw new Error("unpackedSize (".concat(unpackedSize, ") must be a multiple of ") + "".concat(channelsPerTexture));
	  }
	  return unpackedSize / channelsPerTexture;
	}
	function decodeMatrixFromUnpackedColorRGBAArray(unpackedArray, matrix, channels) {
	  var requiredSize = unpackedArray.length * channels / 4;
	  if (matrix.length < requiredSize) {
	    throw new Error("matrix length (".concat(matrix.length, ") must be >= ").concat(requiredSize));
	  }
	  var dst = 0;
	  for (var src = 0; src < unpackedArray.length; src += 4) {
	    for (var c = 0; c < channels; c++) {
	      matrix[dst++] = unpackedArray[src + c];
	    }
	  }
	}
	function getPackedMatrixTextureShapeWidthHeight(rows, columns) {
	  return [Math.max(1, Math.ceil(columns / 2)), Math.max(1, Math.ceil(rows / 2))];
	}
	function getPackedRGBAArraySizeFromMatrixShape(rows, columns) {
	  var _getPackedMatrixTextu = getPackedMatrixTextureShapeWidthHeight(rows, columns),
	    _getPackedMatrixTextu2 = _slicedToArray(_getPackedMatrixTextu, 2),
	    w = _getPackedMatrixTextu2[0],
	    h = _getPackedMatrixTextu2[1];
	  return w * h * 4;
	}
	function getTextureConfig(
	// tslint:disable-next-line:no-any
	gl, textureHalfFloatExtension) {
	  // tslint:disable-next-line:no-any
	  var glany = gl;
	  var internalFormatFloat;
	  var internalFormatHalfFloat;
	  var internalFormatPackedHalfFloat;
	  var internalFormatPackedFloat;
	  var textureFormatFloat;
	  var downloadTextureFormat;
	  var downloadUnpackNumChannels;
	  var defaultNumChannels;
	  var textureTypeHalfFloat;
	  var textureTypeFloat;
	  if (env().getNumber('WEBGL_VERSION') === 2) {
	    internalFormatFloat = glany.R32F;
	    internalFormatHalfFloat = glany.R16F;
	    internalFormatPackedHalfFloat = glany.RGBA16F;
	    internalFormatPackedFloat = glany.RGBA32F;
	    textureFormatFloat = glany.RED;
	    downloadUnpackNumChannels = 4;
	    defaultNumChannels = 1;
	    textureTypeHalfFloat = glany.HALF_FLOAT;
	    textureTypeFloat = glany.FLOAT;
	    downloadTextureFormat = glany.RGBA8;
	  } else {
	    internalFormatFloat = gl.RGBA;
	    internalFormatHalfFloat = gl.RGBA;
	    internalFormatPackedHalfFloat = gl.RGBA;
	    internalFormatPackedFloat = glany.RGBA;
	    textureFormatFloat = gl.RGBA;
	    downloadUnpackNumChannels = 4;
	    defaultNumChannels = 4;
	    textureTypeHalfFloat = textureHalfFloatExtension != null ? textureHalfFloatExtension.HALF_FLOAT_OES : null;
	    textureTypeFloat = gl.FLOAT;
	    downloadTextureFormat = gl.RGBA;
	  }
	  return {
	    internalFormatFloat: internalFormatFloat,
	    internalFormatHalfFloat: internalFormatHalfFloat,
	    internalFormatPackedHalfFloat: internalFormatPackedHalfFloat,
	    internalFormatPackedFloat: internalFormatPackedFloat,
	    textureFormatFloat: textureFormatFloat,
	    downloadTextureFormat: downloadTextureFormat,
	    downloadUnpackNumChannels: downloadUnpackNumChannels,
	    defaultNumChannels: defaultNumChannels,
	    textureTypeHalfFloat: textureTypeHalfFloat,
	    textureTypeFloat: textureTypeFloat
	  };
	}

	function callAndCheck(gl, func) {
	  var returnValue = func();
	  if (env().getBool('DEBUG')) {
	    checkWebGLError(gl);
	  }
	  return returnValue;
	}
	function checkWebGLError(gl) {
	  var error = gl.getError();
	  if (error !== gl.NO_ERROR) {
	    throw new Error('WebGL Error: ' + getWebGLErrorMessage(gl, error));
	  }
	}
	// https://en.wikipedia.org/wiki/Half-precision_floating-point_format
	var MIN_FLOAT16 = 5.96e-8;
	var MAX_FLOAT16 = 65504;
	function canBeRepresented(num) {
	  if (env().getBool('WEBGL_RENDER_FLOAT32_ENABLED') || num === 0 || MIN_FLOAT16 < Math.abs(num) && Math.abs(num) < MAX_FLOAT16) {
	    return true;
	  }
	  return false;
	}
	function getWebGLErrorMessage(gl, status) {
	  switch (status) {
	    case gl.NO_ERROR:
	      return 'NO_ERROR';
	    case gl.INVALID_ENUM:
	      return 'INVALID_ENUM';
	    case gl.INVALID_VALUE:
	      return 'INVALID_VALUE';
	    case gl.INVALID_OPERATION:
	      return 'INVALID_OPERATION';
	    case gl.INVALID_FRAMEBUFFER_OPERATION:
	      return 'INVALID_FRAMEBUFFER_OPERATION';
	    case gl.OUT_OF_MEMORY:
	      return 'OUT_OF_MEMORY';
	    case gl.CONTEXT_LOST_WEBGL:
	      return 'CONTEXT_LOST_WEBGL';
	    default:
	      return "Unknown error code ".concat(status);
	  }
	}
	function getExtensionOrThrow(gl, extensionName) {
	  return throwIfNull(gl, function () {
	    return gl.getExtension(extensionName);
	  }, 'Extension "' + extensionName + '" not supported on this browser.');
	}
	function createVertexShader$1(gl, vertexShaderSource) {
	  var vertexShader = throwIfNull(gl, function () {
	    return gl.createShader(gl.VERTEX_SHADER);
	  }, 'Unable to create vertex WebGLShader.');
	  callAndCheck(gl, function () {
	    return gl.shaderSource(vertexShader, vertexShaderSource);
	  });
	  callAndCheck(gl, function () {
	    return gl.compileShader(vertexShader);
	  });
	  if (gl.getShaderParameter(vertexShader, gl.COMPILE_STATUS) === false) {
	    console.log(gl.getShaderInfoLog(vertexShader));
	    throw new Error('Failed to compile vertex shader.');
	  }
	  return vertexShader;
	}
	function createFragmentShader(gl, fragmentShaderSource) {
	  var fragmentShader = throwIfNull(gl, function () {
	    return gl.createShader(gl.FRAGMENT_SHADER);
	  }, 'Unable to create fragment WebGLShader.');
	  callAndCheck(gl, function () {
	    return gl.shaderSource(fragmentShader, fragmentShaderSource);
	  });
	  callAndCheck(gl, function () {
	    return gl.compileShader(fragmentShader);
	  });
	  if (env().get('ENGINE_COMPILE_ONLY')) {
	    return fragmentShader;
	  }
	  if (gl.getShaderParameter(fragmentShader, gl.COMPILE_STATUS) === false) {
	    logShaderSourceAndInfoLog(fragmentShaderSource, gl.getShaderInfoLog(fragmentShader));
	    throw new Error('Failed to compile fragment shader.');
	  }
	  return fragmentShader;
	}
	var lineNumberRegex = /ERROR: [0-9]+:([0-9]+):/g;
	function logShaderSourceAndInfoLog(shaderSource, shaderInfoLog) {
	  var lineNumberRegexResult = lineNumberRegex.exec(shaderInfoLog);
	  if (lineNumberRegexResult == null) {
	    console.log("Couldn't parse line number in error: ".concat(shaderInfoLog));
	    console.log(shaderSource);
	    return;
	  }
	  var lineNumber = +lineNumberRegexResult[1];
	  var shaderLines = shaderSource.split('\n');
	  var pad = shaderLines.length.toString().length + 2;
	  var linesWithLineNumbers = shaderLines.map(function (line, lineNumber) {
	    return rightPad((lineNumber + 1).toString(), pad) + line;
	  });
	  var maxLineLength = 0;
	  for (var i = 0; i < linesWithLineNumbers.length; i++) {
	    maxLineLength = Math.max(linesWithLineNumbers[i].length, maxLineLength);
	  }
	  var beforeErrorLines = linesWithLineNumbers.slice(0, lineNumber - 1);
	  var errorLine = linesWithLineNumbers.slice(lineNumber - 1, lineNumber);
	  var afterErrorLines = linesWithLineNumbers.slice(lineNumber);
	  console.log(beforeErrorLines.join('\n'));
	  console.log(shaderInfoLog.split('\n')[0]);
	  console.log("%c ".concat(rightPad(errorLine[0], maxLineLength)), 'border:1px solid red; background-color:#e3d2d2; color:#a61717');
	  console.log(afterErrorLines.join('\n'));
	}
	function createProgram(gl) {
	  return throwIfNull(gl, function () {
	    return gl.createProgram();
	  }, 'Unable to create WebGLProgram.');
	}
	function linkProgram(gl, program) {
	  callAndCheck(gl, function () {
	    return gl.linkProgram(program);
	  });
	  if (env().get('ENGINE_COMPILE_ONLY')) {
	    return;
	  }
	  if (gl.getProgramParameter(program, gl.LINK_STATUS) === false) {
	    console.log(gl.getProgramInfoLog(program));
	    throw new Error('Failed to link vertex and fragment shaders.');
	  }
	}
	/// validateProgram is effectively "If we `useProgram(program); drawArrays();`,
	/// give feedback in log about perf/correctness warnings or errors that would
	/// occur."
	/// So make sure we set up all vertex/texture/sampler/uniform data before
	/// calling validateProgram!
	function validateProgram(gl, program) {
	  callAndCheck(gl, function () {
	    return gl.validateProgram(program);
	  });
	  if (gl.getProgramParameter(program, gl.VALIDATE_STATUS) === false) {
	    console.log(gl.getProgramInfoLog(program));
	    throw new Error('Shader program validation failed.');
	  }
	}
	function createStaticVertexBuffer(gl, data) {
	  var buffer = throwIfNull(gl, function () {
	    return gl.createBuffer();
	  }, 'Unable to create WebGLBuffer');
	  callAndCheck(gl, function () {
	    return gl.bindBuffer(gl.ARRAY_BUFFER, buffer);
	  });
	  callAndCheck(gl, function () {
	    return gl.bufferData(gl.ARRAY_BUFFER, data, gl.STATIC_DRAW);
	  });
	  return buffer;
	}
	function createStaticIndexBuffer(gl, data) {
	  var buffer = throwIfNull(gl, function () {
	    return gl.createBuffer();
	  }, 'Unable to create WebGLBuffer');
	  callAndCheck(gl, function () {
	    return gl.bindBuffer(gl.ELEMENT_ARRAY_BUFFER, buffer);
	  });
	  callAndCheck(gl, function () {
	    return gl.bufferData(gl.ELEMENT_ARRAY_BUFFER, data, gl.STATIC_DRAW);
	  });
	  return buffer;
	}
	function getNumChannels() {
	  if (env().getNumber('WEBGL_VERSION') === 2) {
	    return 1;
	  }
	  return 4;
	}
	function createTexture(gl) {
	  return throwIfNull(gl, function () {
	    return gl.createTexture();
	  }, 'Unable to create WebGLTexture.');
	}
	function validateTextureSize(width, height) {
	  var maxTextureSize = env().getNumber('WEBGL_MAX_TEXTURE_SIZE');
	  if (width <= 0 || height <= 0) {
	    var requested = "[".concat(width, "x").concat(height, "]");
	    throw new Error('Requested texture size ' + requested + ' is invalid.');
	  }
	  if (width > maxTextureSize || height > maxTextureSize) {
	    var _requested = "[".concat(width, "x").concat(height, "]");
	    var max = "[".concat(maxTextureSize, "x").concat(maxTextureSize, "]");
	    throw new Error('Requested texture size ' + _requested + ' greater than WebGL maximum on this browser / GPU ' + max + '.');
	  }
	}
	function createFramebuffer(gl) {
	  return throwIfNull(gl, function () {
	    return gl.createFramebuffer();
	  }, 'Unable to create WebGLFramebuffer.');
	}
	function bindVertexBufferToProgramAttribute(gl, program, attribute, buffer, arrayEntriesPerItem, itemStrideInBytes, itemOffsetInBytes) {
	  var loc = gl.getAttribLocation(program, attribute);
	  if (loc === -1) {
	    // The GPU compiler decided to strip out this attribute because it's unused,
	    // thus no need to bind.
	    return false;
	  }
	  callAndCheck(gl, function () {
	    return gl.bindBuffer(gl.ARRAY_BUFFER, buffer);
	  });
	  callAndCheck(gl, function () {
	    return gl.vertexAttribPointer(loc, arrayEntriesPerItem, gl.FLOAT, false, itemStrideInBytes, itemOffsetInBytes);
	  });
	  callAndCheck(gl, function () {
	    return gl.enableVertexAttribArray(loc);
	  });
	  return true;
	}
	function bindTextureUnit(gl, texture, textureUnit) {
	  validateTextureUnit(gl, textureUnit);
	  callAndCheck(gl, function () {
	    return gl.activeTexture(gl.TEXTURE0 + textureUnit);
	  });
	  callAndCheck(gl, function () {
	    return gl.bindTexture(gl.TEXTURE_2D, texture);
	  });
	}
	function unbindTextureUnit(gl, textureUnit) {
	  validateTextureUnit(gl, textureUnit);
	  callAndCheck(gl, function () {
	    return gl.activeTexture(gl.TEXTURE0 + textureUnit);
	  });
	  callAndCheck(gl, function () {
	    return gl.bindTexture(gl.TEXTURE_2D, null);
	  });
	}
	function getProgramUniformLocationOrThrow(gl, program, uniformName) {
	  return throwIfNull(gl, function () {
	    return gl.getUniformLocation(program, uniformName);
	  }, 'uniform "' + uniformName + '" not present in program.');
	}
	function getProgramUniformLocation(gl, program, uniformName) {
	  return gl.getUniformLocation(program, uniformName);
	}
	function bindTextureToProgramUniformSampler(gl, texture, uniformSamplerLocation, textureUnit) {
	  callAndCheck(gl, function () {
	    return bindTextureUnit(gl, texture, textureUnit);
	  });
	  callAndCheck(gl, function () {
	    return gl.uniform1i(uniformSamplerLocation, textureUnit);
	  });
	}
	function bindCanvasToFramebuffer(gl) {
	  callAndCheck(gl, function () {
	    return gl.bindFramebuffer(gl.FRAMEBUFFER, null);
	  });
	  callAndCheck(gl, function () {
	    return gl.viewport(0, 0, gl.canvas.width, gl.canvas.height);
	  });
	  callAndCheck(gl, function () {
	    return gl.scissor(0, 0, gl.canvas.width, gl.canvas.height);
	  });
	}
	function bindColorTextureToFramebuffer(gl, texture, framebuffer) {
	  callAndCheck(gl, function () {
	    return gl.bindFramebuffer(gl.FRAMEBUFFER, framebuffer);
	  });
	  callAndCheck(gl, function () {
	    return gl.framebufferTexture2D(gl.FRAMEBUFFER, gl.COLOR_ATTACHMENT0, gl.TEXTURE_2D, texture, 0);
	  });
	}
	function unbindColorTextureFromFramebuffer(gl, framebuffer) {
	  callAndCheck(gl, function () {
	    return gl.bindFramebuffer(gl.FRAMEBUFFER, framebuffer);
	  });
	  callAndCheck(gl, function () {
	    return gl.framebufferTexture2D(gl.FRAMEBUFFER, gl.COLOR_ATTACHMENT0, gl.TEXTURE_2D, null, 0);
	  });
	}
	function validateFramebuffer(gl) {
	  var status = gl.checkFramebufferStatus(gl.FRAMEBUFFER);
	  if (status !== gl.FRAMEBUFFER_COMPLETE) {
	    throw new Error('Error binding framebuffer: ' + getFramebufferErrorMessage(gl, status));
	  }
	}
	function getFramebufferErrorMessage(gl, status) {
	  switch (status) {
	    case gl.FRAMEBUFFER_INCOMPLETE_ATTACHMENT:
	      return 'FRAMEBUFFER_INCOMPLETE_ATTACHMENT';
	    case gl.FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT:
	      return 'FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT';
	    case gl.FRAMEBUFFER_INCOMPLETE_DIMENSIONS:
	      return 'FRAMEBUFFER_INCOMPLETE_DIMENSIONS';
	    case gl.FRAMEBUFFER_UNSUPPORTED:
	      return 'FRAMEBUFFER_UNSUPPORTED';
	    default:
	      return "unknown error ".concat(status);
	  }
	}
	function throwIfNull(gl, returnTOrNull, failureMessage) {
	  var tOrNull = callAndCheck(gl, function () {
	    return returnTOrNull();
	  });
	  if (tOrNull == null) {
	    throw new Error(failureMessage);
	  }
	  return tOrNull;
	}
	function validateTextureUnit(gl, textureUnit) {
	  var maxTextureUnit = gl.MAX_COMBINED_TEXTURE_IMAGE_UNITS - 1;
	  var glTextureUnit = textureUnit + gl.TEXTURE0;
	  if (glTextureUnit < gl.TEXTURE0 || glTextureUnit > maxTextureUnit) {
	    var textureUnitRange = "[gl.TEXTURE0, gl.TEXTURE".concat(maxTextureUnit, "]");
	    throw new Error("textureUnit must be in ".concat(textureUnitRange, "."));
	  }
	}
	function getBatchDim(shape) {
	  var dimsToSkip = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 2;
	  return sizeFromShape(shape.slice(0, shape.length - dimsToSkip));
	}
	function getRowsCols(shape) {
	  if (shape.length === 0) {
	    throw Error('Cannot get rows and columns of an empty shape array.');
	  }
	  return [shape.length > 1 ? shape[shape.length - 2] : 1, shape[shape.length - 1]];
	}
	function getShapeAs3D(shape) {
	  var shapeAs3D = [1, 1, 1];
	  var isScalar = shape.length === 0 || shape.length === 1 && shape[0] === 1;
	  if (!isScalar) {
	    shapeAs3D = [getBatchDim(shape)].concat(_toConsumableArray(getRowsCols(shape)));
	  }
	  return shapeAs3D;
	}
	function getTextureShapeFromLogicalShape(logShape) {
	  var isPacked = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
	  var maxTexSize = env().getNumber('WEBGL_MAX_TEXTURE_SIZE');
	  var maxSizeForNarrowTex = env().getNumber('WEBGL_MAX_SIZE_FOR_NARROW_TEXTURE');
	  if (maxSizeForNarrowTex === Infinity && env().getBool('WEBGL_AUTO_SQUARIFY_NARROW_TEXTURE_SHAPE')) {
	    maxSizeForNarrowTex = maxTexSize / 2;
	  }
	  if (isPacked) {
	    maxTexSize = maxTexSize * 2;
	    maxSizeForNarrowTex = maxSizeForNarrowTex * 2;
	    // This logic ensures we accurately count the number of packed texels needed
	    // to accommodate the tensor. We can only pack values in the same texel if
	    // they are from adjacent pairs of rows/cols within the same batch. So if a
	    // tensor has 3 rows, we pretend it has 4 rows in order to account for the
	    // fact that the texels containing the third row are half empty.
	    logShape = logShape.map(function (d, i) {
	      return i >= logShape.length - 2 ? nearestLargerEven(logShape[i]) : logShape[i];
	    });
	    // Packed texture height is at least 2 (the channel height of a single
	    // texel).
	    if (logShape.length === 1) {
	      logShape = [2, logShape[0]];
	    }
	  }
	  // If logical shape is 2, we don't squeeze, since we want to match physical.
	  if (logShape.length !== 2) {
	    var squeezeResult = squeezeShape(logShape);
	    logShape = squeezeResult.newShape;
	  }
	  var size = sizeFromShape(logShape);
	  var textureShape = null;
	  if (logShape.length <= 1 && size <= maxTexSize) {
	    textureShape = [1, size];
	  } else if (logShape.length === 2 && logShape[0] <= maxTexSize && logShape[1] <= maxTexSize) {
	    textureShape = logShape;
	  } else if (logShape.length === 3 && logShape[0] * logShape[1] <= maxTexSize && logShape[2] <= maxTexSize) {
	    textureShape = [logShape[0] * logShape[1], logShape[2]];
	  } else if (logShape.length === 3 && logShape[0] <= maxTexSize && logShape[1] * logShape[2] <= maxTexSize) {
	    textureShape = [logShape[0], logShape[1] * logShape[2]];
	  } else if (logShape.length === 4 && logShape[0] * logShape[1] * logShape[2] <= maxTexSize && logShape[3] <= maxTexSize) {
	    textureShape = [logShape[0] * logShape[1] * logShape[2], logShape[3]];
	  } else if (logShape.length === 4 && logShape[0] <= maxTexSize && logShape[1] * logShape[2] * logShape[3] <= maxTexSize) {
	    textureShape = [logShape[0], logShape[1] * logShape[2] * logShape[3]];
	  }
	  // true if one edge length is 1 (1 or 2, if packed), while another edge
	  // length exceeds maxSizeForNarrowTex.
	  var isLongNarrowTex = textureShape != null && Math.max.apply(Math, _toConsumableArray(textureShape)) > maxSizeForNarrowTex && Math.min.apply(Math, _toConsumableArray(textureShape)) <= (isPacked ? 2 : 1) && Math.min.apply(Math, _toConsumableArray(textureShape)) > 0;
	  if (textureShape == null || isLongNarrowTex) {
	    if (isPacked) {
	      // For packed textures size equals the number of channels required to
	      // accommodate the texture data. However in order to squarify such that
	      // inner dimensions stay even, we rewrite size to equal the number of
	      // texels. Then in the return statement we rehydrate the squarified
	      // dimensions to channel units.
	      var batchDim = getBatchDim(logShape);
	      var rows = 2,
	        cols = 2;
	      if (logShape.length) {
	        var _getRowsCols = getRowsCols(logShape);
	        var _getRowsCols2 = _slicedToArray(_getRowsCols, 2);
	        rows = _getRowsCols2[0];
	        cols = _getRowsCols2[1];
	      }
	      size = batchDim * (rows / 2) * (cols / 2);
	      textureShape = sizeToSquarishShape(size).map(function (d) {
	        return d * 2;
	      });
	    } else {
	      textureShape = sizeToSquarishShape(size);
	    }
	  }
	  return textureShape;
	}
	function isEven(n) {
	  return n % 2 === 0;
	}
	/**
	 * This determines whether reshaping a packed texture requires rearranging
	 * the data within the texture, assuming 2x2 packing.
	 */
	function isReshapeFree(shape1, shape2) {
	  shape1 = shape1.slice(-2);
	  shape2 = shape2.slice(-2);
	  if (arraysEqual(shape1, shape2)) {
	    return true;
	  }
	  if (!shape1.length || !shape2.length) {
	    // One of the shapes is a scalar.
	    return true;
	  }
	  if (shape1[0] === 0 || shape1[1] === 0 || shape2[0] === 0 || shape2[1] === 0) {
	    return true;
	  }
	  if (shape1.length !== shape2.length) {
	    // One of the shapes is a vector.
	    var shape1Cols = shape1[shape1.length - 1];
	    var shape2Cols = shape2[shape2.length - 1];
	    if (shape1Cols === shape2Cols) {
	      return true;
	    }
	    if (isEven(shape1Cols) && isEven(shape2Cols) && (shape1[0] === 1 || shape2[0] === 1)) {
	      return true;
	    }
	  }
	  return shape1[1] === shape2[1] && isEven(shape1[0]) && isEven(shape2[0]);
	}
	// We cache webgl params because the environment gets reset between
	// unit tests and we don't want to constantly query the WebGLContext for
	// MAX_TEXTURE_SIZE.
	var MAX_TEXTURE_SIZE;
	var MAX_TEXTURES_IN_SHADER;
	function getWebGLMaxTextureSize(webGLVersion) {
	  if (MAX_TEXTURE_SIZE == null) {
	    var gl = getWebGLContext(webGLVersion);
	    MAX_TEXTURE_SIZE = gl.getParameter(gl.MAX_TEXTURE_SIZE);
	  }
	  return MAX_TEXTURE_SIZE;
	}
	function resetMaxTextureSize() {
	  MAX_TEXTURE_SIZE = null;
	}
	function resetMaxTexturesInShader() {
	  MAX_TEXTURES_IN_SHADER = null;
	}
	function getMaxTexturesInShader(webGLVersion) {
	  if (MAX_TEXTURES_IN_SHADER == null) {
	    var gl = getWebGLContext(webGLVersion);
	    MAX_TEXTURES_IN_SHADER = gl.getParameter(gl.MAX_TEXTURE_IMAGE_UNITS);
	  }
	  // We cap at 16 to avoid spurious runtime "memory exhausted" error.
	  return Math.min(16, MAX_TEXTURES_IN_SHADER);
	}
	function getWebGLDisjointQueryTimerVersion(webGLVersion) {
	  if (webGLVersion === 0) {
	    return 0;
	  }
	  var queryTimerVersion;
	  var gl = getWebGLContext(webGLVersion);
	  if (hasExtension(gl, 'EXT_disjoint_timer_query_webgl2') && webGLVersion === 2) {
	    queryTimerVersion = 2;
	  } else if (hasExtension(gl, 'EXT_disjoint_timer_query')) {
	    queryTimerVersion = 1;
	  } else {
	    queryTimerVersion = 0;
	  }
	  return queryTimerVersion;
	}
	function hasExtension(gl, extensionName) {
	  var ext = gl.getExtension(extensionName);
	  return ext != null;
	}
	function isWebGLVersionEnabled(webGLVersion) {
	  try {
	    var gl = getWebGLContext(webGLVersion);
	    if (gl != null) {
	      return true;
	    }
	  } catch (e) {
	    console.log('Error when getting WebGL context: ', e);
	    return false;
	  }
	  return false;
	}
	function isCapableOfRenderingToFloatTexture(webGLVersion) {
	  if (webGLVersion === 0) {
	    return false;
	  }
	  var gl = getWebGLContext(webGLVersion);
	  if (webGLVersion === 1) {
	    if (!hasExtension(gl, 'OES_texture_float')) {
	      return false;
	    }
	  } else {
	    if (!hasExtension(gl, 'EXT_color_buffer_float')) {
	      return false;
	    }
	  }
	  var isFrameBufferComplete = createFloatTextureAndBindToFramebuffer(gl);
	  return isFrameBufferComplete;
	}
	/**
	 * Check if we can download values from a float/half-float texture.
	 *
	 * Note that for performance reasons we use binding a texture to a framebuffer
	 * as a proxy for ability to download float values later using readPixels. The
	 * texture params of this texture will not match those in readPixels exactly
	 * but if we are unable to bind some kind of float texture to the frameBuffer
	 * then we definitely will not be able to read float values from it.
	 */
	function isDownloadFloatTextureEnabled(webGLVersion) {
	  if (webGLVersion === 0) {
	    return false;
	  }
	  var gl = getWebGLContext(webGLVersion);
	  if (webGLVersion === 1) {
	    if (!hasExtension(gl, 'OES_texture_float')) {
	      return false;
	    }
	    if (!hasExtension(gl, 'WEBGL_color_buffer_float')) {
	      return false;
	    }
	  } else {
	    if (hasExtension(gl, 'EXT_color_buffer_float')) {
	      return createFloatTextureAndBindToFramebuffer(gl);
	    }
	    var COLOR_BUFFER_HALF_FLOAT = 'EXT_color_buffer_half_float';
	    if (hasExtension(gl, COLOR_BUFFER_HALF_FLOAT)) {
	      var textureHalfFloatExtension = gl.getExtension(COLOR_BUFFER_HALF_FLOAT);
	      return createHalfFloatTextureAndBindToFramebuffer(gl, textureHalfFloatExtension);
	    }
	    return false;
	  }
	  var isFrameBufferComplete = createFloatTextureAndBindToFramebuffer(gl);
	  return isFrameBufferComplete;
	}
	function createFloatTextureAndBindToFramebuffer(gl) {
	  var texConfig = getTextureConfig(gl);
	  var texture = gl.createTexture();
	  gl.bindTexture(gl.TEXTURE_2D, texture);
	  var width = 1;
	  var height = 1;
	  gl.texImage2D(gl.TEXTURE_2D, 0, texConfig.internalFormatFloat, width, height, 0, texConfig.textureFormatFloat, texConfig.textureTypeFloat, null);
	  var frameBuffer = gl.createFramebuffer();
	  gl.bindFramebuffer(gl.FRAMEBUFFER, frameBuffer);
	  gl.framebufferTexture2D(gl.FRAMEBUFFER, gl.COLOR_ATTACHMENT0, gl.TEXTURE_2D, texture, 0);
	  var isFrameBufferComplete = gl.checkFramebufferStatus(gl.FRAMEBUFFER) === gl.FRAMEBUFFER_COMPLETE;
	  gl.bindTexture(gl.TEXTURE_2D, null);
	  gl.bindFramebuffer(gl.FRAMEBUFFER, null);
	  gl.deleteTexture(texture);
	  gl.deleteFramebuffer(frameBuffer);
	  return isFrameBufferComplete;
	}
	function createHalfFloatTextureAndBindToFramebuffer(
	// tslint:disable-next-line:no-any
	gl, textureHalfFloatExtension) {
	  var texConfig = getTextureConfig(gl, textureHalfFloatExtension);
	  var texture = gl.createTexture();
	  gl.bindTexture(gl.TEXTURE_2D, texture);
	  var width = 1;
	  var height = 1;
	  gl.texImage2D(gl.TEXTURE_2D, 0, texConfig.internalFormatHalfFloat, width, height, 0, texConfig.textureFormatFloat, texConfig.textureTypeHalfFloat, null);
	  var frameBuffer = gl.createFramebuffer();
	  gl.bindFramebuffer(gl.FRAMEBUFFER, frameBuffer);
	  gl.framebufferTexture2D(gl.FRAMEBUFFER, gl.COLOR_ATTACHMENT0, gl.TEXTURE_2D, texture, 0);
	  var isFrameBufferComplete = gl.checkFramebufferStatus(gl.FRAMEBUFFER) === gl.FRAMEBUFFER_COMPLETE;
	  gl.bindTexture(gl.TEXTURE_2D, null);
	  gl.bindFramebuffer(gl.FRAMEBUFFER, null);
	  gl.deleteTexture(texture);
	  gl.deleteFramebuffer(frameBuffer);
	  return isFrameBufferComplete;
	}
	function isWebGLFenceEnabled(webGLVersion) {
	  if (webGLVersion !== 2) {
	    return false;
	  }
	  var gl = getWebGLContext(webGLVersion);
	  // tslint:disable-next-line:no-any
	  var isEnabled = gl.fenceSync != null;
	  return isEnabled;
	}
	function assertNotComplex(tensor, opName) {
	  if (!Array.isArray(tensor)) {
	    tensor = [tensor];
	  }
	  tensor.forEach(function (t) {
	    if (t != null) {
	      assert$1(t.dtype !== 'complex64', function () {
	        return "".concat(opName, " does not support complex64 tensors ") + 'in the WebGL backend.';
	      });
	    }
	  });
	}

	var webgl_util = {
		__proto__: null,
		assertNotComplex: assertNotComplex,
		bindCanvasToFramebuffer: bindCanvasToFramebuffer,
		bindColorTextureToFramebuffer: bindColorTextureToFramebuffer,
		bindTextureToProgramUniformSampler: bindTextureToProgramUniformSampler,
		bindTextureUnit: bindTextureUnit,
		bindVertexBufferToProgramAttribute: bindVertexBufferToProgramAttribute,
		callAndCheck: callAndCheck,
		canBeRepresented: canBeRepresented,
		createFragmentShader: createFragmentShader,
		createFramebuffer: createFramebuffer,
		createProgram: createProgram,
		createStaticIndexBuffer: createStaticIndexBuffer,
		createStaticVertexBuffer: createStaticVertexBuffer,
		createTexture: createTexture,
		createVertexShader: createVertexShader$1,
		getBatchDim: getBatchDim,
		getExtensionOrThrow: getExtensionOrThrow,
		getFramebufferErrorMessage: getFramebufferErrorMessage,
		getMaxTexturesInShader: getMaxTexturesInShader,
		getNumChannels: getNumChannels,
		getProgramUniformLocation: getProgramUniformLocation,
		getProgramUniformLocationOrThrow: getProgramUniformLocationOrThrow,
		getRowsCols: getRowsCols,
		getShapeAs3D: getShapeAs3D,
		getTextureShapeFromLogicalShape: getTextureShapeFromLogicalShape,
		getWebGLDisjointQueryTimerVersion: getWebGLDisjointQueryTimerVersion,
		getWebGLErrorMessage: getWebGLErrorMessage,
		getWebGLMaxTextureSize: getWebGLMaxTextureSize,
		hasExtension: hasExtension,
		isCapableOfRenderingToFloatTexture: isCapableOfRenderingToFloatTexture,
		isDownloadFloatTextureEnabled: isDownloadFloatTextureEnabled,
		isReshapeFree: isReshapeFree,
		isWebGLFenceEnabled: isWebGLFenceEnabled,
		isWebGLVersionEnabled: isWebGLVersionEnabled,
		linkProgram: linkProgram,
		logShaderSourceAndInfoLog: logShaderSourceAndInfoLog,
		resetMaxTextureSize: resetMaxTextureSize,
		resetMaxTexturesInShader: resetMaxTexturesInShader,
		unbindColorTextureFromFramebuffer: unbindColorTextureFromFramebuffer,
		unbindTextureUnit: unbindTextureUnit,
		validateFramebuffer: validateFramebuffer,
		validateProgram: validateProgram,
		validateTextureSize: validateTextureSize
	};

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ENV = env();
	/**
	 * This file contains WebGL-specific flag registrations.
	 */
	/**
	 * True if WebGL is supported.
	 */
	ENV.registerFlag('HAS_WEBGL', function () {
	  return ENV.getNumber('WEBGL_VERSION') > 0;
	});
	/** 0: No WebGL, 1: WebGL 1.0, 2: WebGL 2.0. */
	ENV.registerFlag('WEBGL_VERSION', function () {
	  if (isWebGLVersionEnabled(2)) {
	    return 2;
	  } else if (isWebGLVersionEnabled(1)) {
	    return 1;
	  }
	  return 0;
	});
	/** Whether to check for numerical representation problems. */
	ENV.registerFlag('WEBGL_CHECK_NUMERICAL_PROBLEMS', function () {
	  return false;
	});
	ENV.registerFlag('WEBGL_BUFFER_SUPPORTED', function () {
	  return ENV.get('WEBGL_VERSION') === 2;
	});
	/** Whether the WebGL backend will sometimes forward ops to the CPU. */
	ENV.registerFlag('WEBGL_CPU_FORWARD', function () {
	  return true;
	});
	/** Whether the WebGL backend will always use f16 textures for rendering. */
	ENV.registerFlag('WEBGL_FORCE_F16_TEXTURES', function () {
	  return false;
	});
	/** Whether to turn all packing related flags on. */
	ENV.registerFlag('WEBGL_PACK', function () {
	  return ENV.getBool('HAS_WEBGL');
	});
	/** Whether we will pack the batchnormalization op. */
	ENV.registerFlag('WEBGL_PACK_NORMALIZATION', function () {
	  return ENV.getBool('WEBGL_PACK');
	});
	/** Whether we will pack the clip op. */
	ENV.registerFlag('WEBGL_PACK_CLIP', function () {
	  return ENV.getBool('WEBGL_PACK');
	});
	/** Whether we will pack the depthwise conv op. */
	ENV.registerFlag('WEBGL_PACK_DEPTHWISECONV', function () {
	  return ENV.getBool('WEBGL_PACK');
	});
	/** Whether we will pack binary ops. */
	ENV.registerFlag('WEBGL_PACK_BINARY_OPERATIONS', function () {
	  return ENV.getBool('WEBGL_PACK');
	});
	/** Whether we will pack unary ops. */
	ENV.registerFlag('WEBGL_PACK_UNARY_OPERATIONS', function () {
	  return ENV.getBool('WEBGL_PACK');
	});
	/** Whether we will pack array ops. */
	ENV.registerFlag('WEBGL_PACK_ARRAY_OPERATIONS', function () {
	  return ENV.getBool('WEBGL_PACK');
	});
	/** Whether we will pack image ops. */
	ENV.registerFlag('WEBGL_PACK_IMAGE_OPERATIONS', function () {
	  return ENV.getBool('WEBGL_PACK');
	});
	/** Whether we will pack reduce ops. */
	ENV.registerFlag('WEBGL_PACK_REDUCE', function () {
	  return ENV.getBool('WEBGL_PACK');
	});
	/** Whether packed WebGL kernels lazily unpack their outputs. */
	ENV.registerFlag('WEBGL_LAZILY_UNPACK', function () {
	  return ENV.getBool('WEBGL_PACK');
	});
	/** Whether we will use the im2col algorithm to speed up convolutions. */
	ENV.registerFlag('WEBGL_CONV_IM2COL', function () {
	  return ENV.getBool('WEBGL_PACK');
	});
	/** Whether we will pack conv2dTranspose op. */
	ENV.registerFlag('WEBGL_PACK_CONV2DTRANSPOSE', function () {
	  return ENV.getBool('WEBGL_PACK');
	});
	/** The maximum texture dimension. */
	ENV.registerFlag('WEBGL_MAX_TEXTURE_SIZE', function () {
	  return getWebGLMaxTextureSize(ENV.getNumber('WEBGL_VERSION'));
	});
	/** The maximum texture dimension. */
	ENV.registerFlag('WEBGL_MAX_TEXTURES_IN_SHADER', function () {
	  return getMaxTexturesInShader(ENV.getNumber('WEBGL_VERSION'));
	});
	/**
	 * The disjoint_query_timer extension version.
	 * 0: disabled, 1: EXT_disjoint_timer_query, 2:
	 * EXT_disjoint_timer_query_webgl2.
	 * In Firefox with WebGL 2.0,
	 * EXT_disjoint_timer_query_webgl2 is not available, so we must use the
	 * WebGL 1.0 extension.
	 */
	ENV.registerFlag('WEBGL_DISJOINT_QUERY_TIMER_EXTENSION_VERSION', function () {
	  var webGLVersion = ENV.getNumber('WEBGL_VERSION');
	  if (webGLVersion === 0) {
	    return 0;
	  }
	  return getWebGLDisjointQueryTimerVersion(webGLVersion);
	});
	/**
	 * Whether the timer object from the disjoint_query_timer extension gives
	 * timing information that is reliable.
	 */
	ENV.registerFlag('WEBGL_DISJOINT_QUERY_TIMER_EXTENSION_RELIABLE', function () {
	  return ENV.getNumber('WEBGL_DISJOINT_QUERY_TIMER_EXTENSION_VERSION') > 0 && !isMobile();
	});
	/**
	 * Whether the device is physically capable of rendering to float32 textures.
	 */
	ENV.registerFlag('WEBGL_RENDER_FLOAT32_CAPABLE', function () {
	  return isCapableOfRenderingToFloatTexture(ENV.getNumber('WEBGL_VERSION'));
	});
	/**
	 * Whether rendering to float32 textures is enabled. If disabled, renders to
	 * float16 textures.
	 */
	ENV.registerFlag('WEBGL_RENDER_FLOAT32_ENABLED', function () {
	  return ENV.getBool('WEBGL_FORCE_F16_TEXTURES') ? false : ENV.getBool('WEBGL_RENDER_FLOAT32_CAPABLE');
	});
	/**
	 * Whether downloading float textures is enabled (16 or 32 bit). If disabled,
	 * uses IEEE 754 encoding of the float32 values to 4 uint8 when downloading.
	 */
	ENV.registerFlag('WEBGL_DOWNLOAD_FLOAT_ENABLED', function () {
	  return isDownloadFloatTextureEnabled(ENV.getNumber('WEBGL_VERSION'));
	});
	/** Whether the fence API is available. */
	ENV.registerFlag('WEBGL_FENCE_API_ENABLED', function () {
	  return isWebGLFenceEnabled(ENV.getNumber('WEBGL_VERSION'));
	});
	/**
	 * Tensors with size <= than this will be uploaded as uniforms, not textures.
	 */
	ENV.registerFlag('WEBGL_SIZE_UPLOAD_UNIFORM', function () {
	  // Use uniform uploads only when 32bit floats are supported. In
	  // 16bit
	  // environments there are problems with comparing a 16bit texture value
	  // with a 32bit uniform value.
	  var useUniforms = ENV.getBool('WEBGL_RENDER_FLOAT32_ENABLED');
	  return useUniforms ? 4 : 0;
	});
	/**
	 * If the total number of bytes allocated on the GPU is greater than this
	 * number, we will aggressively delete textures upon disposal with
	 * gl.deleteMatrixTexture, rather than making them available for reuse.
	 *
	 * Default value -1 indicates that we will never aggressively delete textures.
	 */
	ENV.registerFlag('WEBGL_DELETE_TEXTURE_THRESHOLD', function () {
	  return -1;
	}, function (threshold) {
	  if (!(typeof threshold === 'number')) {
	    throw new Error('WEBGL_DELETE_TEXTURE_THRESHOLD must be a number but ' + "got ".concat(threshold, "."));
	  }
	  if (threshold < 0 && threshold !== -1) {
	    throw new Error("WEBGL_DELETE_TEXTURE_THRESHOLD must be -1 (indicating never " + "delete) or at least 0, but got ".concat(threshold, "."));
	  }
	});
	/**
	 * Trigger a manual GL command flush if the threshold of time has passed since
	 * previous Kernel execution. This can be useful for Andorid device where GL
	 * command flush are delayed un til the end of javascript task. This value is
	 * measured in millisecond. Typically you want to set this value to close to 1.
	 *
	 * Default value 1 for mobile chrome, and -1 for rest cases. -1 indicates that
	 * we will not enforce manual flush and depend on system default flush schedule.
	 */
	ENV.registerFlag('WEBGL_FLUSH_THRESHOLD', function () {
	  return isMobile() ? 1 : -1;
	}, function (threshold) {
	  if (!(typeof threshold === 'number')) {
	    throw new Error('WEBGL_FLUSH_THRESHOLD must be a number but got ' + "".concat(threshold, "."));
	  }
	  if (threshold < 0 && threshold !== -1) {
	    throw new Error("WEBGL_FLUSH_THRESHOLD must be -1 (indicating never " + "manual flush) or at least 0, but got ".concat(threshold, "."));
	  }
	});
	/**
	 * Threshold for input tensor size that determines whether WebGL backend will
	 * delegate computation to CPU.
	 *
	 * Default value is 128.
	 */
	ENV.registerFlag('CPU_HANDOFF_SIZE_THRESHOLD', function () {
	  return 128;
	});
	/** Whether we will use shapes uniforms. */
	ENV.registerFlag('WEBGL_USE_SHAPES_UNIFORMS', function () {
	  return false;
	});
	/**
	 * Threshold for last dimension of input tensor that determines whether
	 * WebGL backend for the Top K op will delegate computation to CPU. If input
	 * is smaller than threshold then CPU will be used
	 *
	 * Default value is 100000.
	 */
	ENV.registerFlag('TOPK_LAST_DIM_CPU_HANDOFF_SIZE_THRESHOLD', function () {
	  return 100000;
	});
	/**
	 * Threshold for K that determines whether
	 * WebGL backend for the Top K op will delegate computation to CPU. If k
	 * is larger than threshold then CPU will be used
	 *
	 * Default value is 128.
	 */
	ENV.registerFlag('TOPK_K_CPU_HANDOFF_THRESHOLD', function () {
	  return 128;
	});
	/** Whether we will use the experimental conv op. */
	ENV.registerFlag('WEBGL_EXP_CONV', function () {
	  return false;
	});
	/**
	 * If the device performance is low or if no hardware GPU is available, whether
	 * software WebGL will be used.
	 */
	ENV.registerFlag('SOFTWARE_WEBGL_ENABLED', function () {
	  return ENV.getBool('IS_TEST');
	});
	/**
	 * For narrow texture (physical height or physical width is 1), if the length of
	 * any texture edges exceed the threshold, the texture will be reshaped to be
	 * more squarish.
	 *
	 * This flag is used to help some GPUs that could not provide correct
	 * interpolations for long skinny triangles. We found Mali GPU probably has this
	 * problem: https://github.com/tensorflow/tfjs/issues/6775.
	 */
	ENV.registerFlag('WEBGL_MAX_SIZE_FOR_NARROW_TEXTURE', function () {
	  return Infinity;
	});
	/**
	 * If the flag is set to true, the max size of the narrow texture will be auto
	 * computed and it will be considerred as a threshold to reshape the narrow
	 * texture to be more squarish.
	 *
	 * This flag is used to help some GPUs that could not provide correct
	 * interpolations for long skinny triangles. We found Mali GPU probably has this
	 * problem: https://github.com/tensorflow/tfjs/issues/6775.
	 */
	ENV.registerFlag('WEBGL_AUTO_SQUARIFY_NARROW_TEXTURE_SHAPE', function () {
	  return false;
	});
	/**
	 * Whether to use the customized isnan. It's only useful for webgl2 since webgl1
	 * doesn't have the builtin isnan.
	 */
	ENV.registerFlag('WEBGL2_ISNAN_CUSTOM', function () {
	  return false;
	});
	/** Experimental flag, whether enter compile only phase. */
	ENV.registerFlag('ENGINE_COMPILE_ONLY', function () {
	  return false;
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function getGlslDifferences() {
	  var version;
	  var attribute;
	  var varyingVs;
	  var varyingFs;
	  var texture2D;
	  var output;
	  var defineOutput;
	  var defineSpecialNaN;
	  var defineSpecialInf;
	  var defineRound;
	  if (env().getNumber('WEBGL_VERSION') === 2) {
	    version = '#version 300 es';
	    attribute = 'in';
	    varyingVs = 'out';
	    varyingFs = 'in';
	    texture2D = 'texture';
	    output = 'outputColor';
	    defineOutput = 'out vec4 outputColor;';
	    // Use custom isnan definition to work across differences between
	    // implementations on various platforms. While this should happen in ANGLE
	    // we still see differences between android and windows (on chrome) when
	    // using isnan directly. Since WebGL2 supports uint type and
	    // floatBitsToUinT built-in function, we could implment isnan following
	    // IEEE 754 rules.
	    // NaN defination in IEEE 754-1985 is :
	    //   - sign = either 0 or 1.
	    //   - biased exponent = all 1 bits.
	    //   - fraction = anything except all 0 bits (since all 0 bits represents
	    //   infinity).
	    // https://en.wikipedia.org/wiki/IEEE_754-1985#Representation_of_non-numbers
	    defineSpecialNaN = env().getBool('WEBGL2_ISNAN_CUSTOM') ? "\n      bool isnan_custom(float val) {\n        uint floatToUint = floatBitsToUint(val);\n        return (floatToUint & 0x7fffffffu) > 0x7f800000u;\n      }\n\n      bvec4 isnan_custom(vec4 val) {\n        return bvec4(isnan_custom(val.x),\n          isnan_custom(val.y), isnan_custom(val.z), isnan_custom(val.w));\n      }\n\n      #define isnan(value) isnan_custom(value)\n    " : '';
	    // In webgl 2 we do not need to specify a custom isinf so there is no
	    // need for a special INFINITY constant.
	    defineSpecialInf = "";
	    defineRound = "\n      #define round(value) newRound(value)\n      int newRound(float value) {\n        return int(floor(value + 0.5));\n      }\n\n      ivec4 newRound(vec4 value) {\n        return ivec4(floor(value + vec4(0.5)));\n      }\n    ";
	  } else {
	    version = '';
	    attribute = 'attribute';
	    varyingVs = 'varying';
	    varyingFs = 'varying';
	    texture2D = 'texture2D';
	    output = 'gl_FragColor';
	    defineOutput = '';
	    // WebGL1 has no built in isnan so we define one here.
	    defineSpecialNaN = "\n      #define isnan(value) isnan_custom(value)\n      bool isnan_custom(float val) {\n        return (val > 0. || val < 1. || val == 0.) ? false : true;\n      }\n      bvec4 isnan_custom(vec4 val) {\n        return bvec4(isnan(val.x), isnan(val.y), isnan(val.z), isnan(val.w));\n      }\n    ";
	    defineSpecialInf = "\n      uniform float INFINITY;\n\n      bool isinf(float val) {\n        return abs(val) == INFINITY;\n      }\n      bvec4 isinf(vec4 val) {\n        return equal(abs(val), vec4(INFINITY));\n      }\n    ";
	    defineRound = "\n      int round(float value) {\n        return int(floor(value + 0.5));\n      }\n\n      ivec4 round(vec4 value) {\n        return ivec4(floor(value + vec4(0.5)));\n      }\n    ";
	  }
	  return {
	    version: version,
	    attribute: attribute,
	    varyingVs: varyingVs,
	    varyingFs: varyingFs,
	    texture2D: texture2D,
	    output: output,
	    defineOutput: defineOutput,
	    defineSpecialNaN: defineSpecialNaN,
	    defineSpecialInf: defineSpecialInf,
	    defineRound: defineRound
	  };
	}

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Produces GLSL code that derives logical coordinates from a flat
	 * index. The code performs integer division with each stride and decrements
	 * the index until the index equals the final dimension coordinate.
	 */
	function getLogicalCoordinatesFromFlatIndex(coords, shape) {
	  var index = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'index';
	  var strides = computeStrides(shape);
	  return strides.map(function (stride, i) {
	    var line1 = "int ".concat(coords[i], " = ").concat(index, " / ").concat(stride);
	    var line2 = i === strides.length - 1 ? "int ".concat(coords[i + 1], " = ").concat(index, " - ").concat(coords[i], " * ").concat(stride) : "index -= ".concat(coords[i], " * ").concat(stride);
	    return "".concat(line1, "; ").concat(line2, ";");
	  }).join('');
	}
	function getOutputLogicalCoordinatesFromFlatIndexByUniform(coords, shape) {
	  var index = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'index';
	  var strides = computeStrides(shape);
	  return strides.map(function (_, i) {
	    var line1 = "int ".concat(coords[i], " = ").concat(index, " / outShapeStrides[").concat(i, "]");
	    var line2 = i === strides.length - 1 ? "int ".concat(coords[i + 1], " = ").concat(index, " - ").concat(coords[i], " * outShapeStrides[").concat(i, "]") : "index -= ".concat(coords[i], " * outShapeStrides[").concat(i, "]");
	    return "".concat(line1, "; ").concat(line2, ";");
	  }).join('');
	}
	// Produces GLSL code that computes strides.
	function symbolicallyComputeStrides(indicesArr, variableName) {
	  var numCoords = indicesArr.length;
	  var shape = indicesArr.map(function (d) {
	    return "".concat(variableName, "[").concat(d, "]");
	  });
	  var strides = new Array(numCoords - 1);
	  strides[numCoords - 2] = shape[numCoords - 1];
	  for (var i = numCoords - 3; i >= 0; --i) {
	    strides[i] = "(".concat(strides[i + 1], " * ").concat(shape[i + 1], ")");
	  }
	  return strides;
	}
	function getLogicalCoordinatesFromFlatIndexByUniform(coords, variableName) {
	  var index = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'index';
	  var indicesArray = coords.map(function (_, i) {
	    return i;
	  });
	  var strides = symbolicallyComputeStrides(indicesArray, variableName);
	  return strides.map(function (_, i) {
	    var line1 = "int ".concat(coords[i], " = ").concat(index, " / ").concat(strides[i]);
	    var line2 = i === strides.length - 1 ? "int ".concat(coords[i + 1], " = ").concat(index, " - ").concat(coords[i], " * ").concat(strides[i]) : "index -= ".concat(coords[i], " * ").concat(strides[i]);
	    return "".concat(line1, "; ").concat(line2, ";");
	  }).join('');
	}
	function buildVec(x) {
	  if (x.length === 1) {
	    return "".concat(x[0]);
	  }
	  return "vec".concat(x.length, "(").concat(x.join(','), ")");
	}
	/**
	 * Produces GLSL code that computes the dot product of the input x and y
	 * vectors. Handles splitting inputs into increments of vec4s when necessary.
	 */
	function dotify(x, y) {
	  if (x.length !== y.length) {
	    throw new Error("Vectors to be dotted must be of the same length -" + "got ".concat(x.length, " and ").concat(y.length));
	  }
	  var slices = [];
	  var nearestVec4 = Math.floor(x.length / 4);
	  var nearestVec4Remainder = x.length % 4;
	  for (var i = 0; i < nearestVec4; i++) {
	    var xSlice = x.slice(i * 4, i * 4 + 4);
	    var ySlice = y.slice(i * 4, i * 4 + 4);
	    slices.push("".concat(buildVec(xSlice), ", ").concat(buildVec(ySlice)));
	  }
	  if (nearestVec4Remainder !== 0) {
	    var _xSlice = x.slice(nearestVec4 * 4);
	    var _ySlice = y.slice(nearestVec4 * 4);
	    if (_xSlice.length === 1) {
	      _xSlice = _xSlice.map(function (d) {
	        return "float(".concat(d, ")");
	      });
	      _ySlice = _ySlice.map(function (d) {
	        return "float(".concat(d, ")");
	      });
	    }
	    slices.push("".concat(buildVec(_xSlice), ", ").concat(buildVec(_ySlice)));
	  }
	  return slices.map(function (d, i) {
	    return "dot(".concat(d, ")");
	  }).join('+');
	}
	/**
	 * Produces GLSL that computes the flat index from 3D coordinates.
	 */
	function getFlatIndexFrom3D(shape) {
	  var strides = computeStrides(shape).map(function (d) {
	    return d.toString();
	  });
	  return "\n  int getFlatIndex(ivec3 coords) {\n    return coords.x * ".concat(strides[0], " + coords.y * ").concat(strides[1], " + coords.z;\n  }\n");
	}
	function getFlatIndexFrom3DOutput() {
	  return "\n  int getFlatIndex(ivec3 coords) {\n    return coords.x * outShapeStrides[0] + coords.y * outShapeStrides[1] + coords.z;\n  }\n";
	}
	var ENCODE_FLOAT_SNIPPET = "\n  const float FLOAT_MAX = 1.70141184e38;\n  const float FLOAT_MIN = 1.17549435e-38;\n\n  lowp vec4 encode_float(highp float v) {\n    if (isnan(v)) {\n      return vec4(255, 255, 255, 255);\n    }\n\n    highp float av = abs(v);\n\n    if(av < FLOAT_MIN) {\n      return vec4(0.0, 0.0, 0.0, 0.0);\n    } else if(v > FLOAT_MAX) {\n      return vec4(0.0, 0.0, 128.0, 127.0) / 255.0;\n    } else if(v < -FLOAT_MAX) {\n      return vec4(0.0, 0.0,  128.0, 255.0) / 255.0;\n    }\n\n    highp vec4 c = vec4(0,0,0,0);\n\n    highp float e = floor(log2(av));\n    highp float m = exp2(fract(log2(av))) - 1.0;\n\n    c[2] = floor(128.0 * m);\n    m -= c[2] / 128.0;\n    c[1] = floor(32768.0 * m);\n    m -= c[1] / 32768.0;\n    c[0] = floor(8388608.0 * m);\n\n    highp float ebias = e + 127.0;\n    c[3] = floor(ebias / 2.0);\n    ebias -= c[3] * 2.0;\n    c[2] += floor(ebias) * 128.0;\n\n    c[3] += 128.0 * step(0.0, -v);\n\n    return c / 255.0;\n  }\n";

	var getBroadcastDims = getBroadcastDims$1;
	function makeShader(inputsInfo, outputShape, program) {
	  var prefixSnippets = [];
	  inputsInfo.forEach(function (x) {
	    var size = sizeFromShape(x.shapeInfo.logicalShape);
	    // Snippet when we decided to upload the values as uniform.
	    if (x.shapeInfo.isUniform) {
	      prefixSnippets.push("uniform float ".concat(x.name).concat(size > 1 ? "[".concat(size, "]") : '', ";"));
	    } else {
	      prefixSnippets.push("uniform sampler2D ".concat(x.name, ";"));
	      prefixSnippets.push("uniform int offset".concat(x.name, ";"));
	    }
	    if (program.enableShapeUniforms) {
	      var _getUniformInfoFromSh = getUniformInfoFromShape(program.packedInputs, x.shapeInfo.logicalShape, x.shapeInfo.texShape),
	        uniformShape = _getUniformInfoFromSh.uniformShape;
	      switch (uniformShape.length) {
	        case 1:
	          prefixSnippets.push("uniform int ".concat(x.name, "Shape;"));
	          break;
	        case 2:
	          prefixSnippets.push("uniform ivec2 ".concat(x.name, "Shape;"));
	          break;
	        case 3:
	          prefixSnippets.push("uniform ivec3 ".concat(x.name, "Shape;"));
	          break;
	        case 4:
	          prefixSnippets.push("uniform ivec4 ".concat(x.name, "Shape;"));
	          break;
	        default:
	          break;
	      }
	      prefixSnippets.push("uniform ivec2 ".concat(x.name, "TexShape;"));
	    }
	  });
	  if (program.enableShapeUniforms) {
	    switch (outputShape.logicalShape.length) {
	      case 1:
	        prefixSnippets.push("uniform int outShape;");
	        break;
	      case 2:
	        prefixSnippets.push("uniform ivec2 outShape;");
	        prefixSnippets.push("uniform int outShapeStrides;");
	        break;
	      case 3:
	        prefixSnippets.push("uniform ivec3 outShape;");
	        prefixSnippets.push("uniform ivec2 outShapeStrides;");
	        break;
	      case 4:
	        prefixSnippets.push("uniform ivec4 outShape;");
	        prefixSnippets.push("uniform ivec3 outShapeStrides;");
	        break;
	      default:
	        break;
	    }
	    prefixSnippets.push("uniform ivec2 outTexShape;");
	  }
	  if (program.customUniforms) {
	    program.customUniforms.forEach(function (d) {
	      prefixSnippets.push("uniform ".concat(d.type, " ").concat(d.name).concat(d.arrayIndex ? "[".concat(d.arrayIndex, "]") : '', ";"));
	    });
	  }
	  var inputPrefixSnippet = prefixSnippets.join('\n');
	  var inputSamplingSnippet = inputsInfo.map(function (x) {
	    return getInputSamplingSnippet(x, outputShape, program.packedInputs, program.enableShapeUniforms);
	  }).join('\n');
	  var outTexShape = outputShape.texShape;
	  var glsl = getGlslDifferences();
	  var floatTextureSampleSnippet = getFloatTextureSampleSnippet(glsl);
	  var outputSamplingSnippet;
	  var floatTextureSetOutputSnippet;
	  var shaderPrefix = getShaderPrefix(glsl);
	  if (outputShape.isPacked) {
	    outputSamplingSnippet = getPackedOutputSamplingSnippet(outputShape.logicalShape, outTexShape, program.enableShapeUniforms);
	    floatTextureSetOutputSnippet = getFloatTextureSetRGBASnippet(glsl);
	  } else {
	    outputSamplingSnippet = getOutputSamplingSnippet(outputShape.logicalShape, outTexShape, program.enableShapeUniforms);
	    floatTextureSetOutputSnippet = getFloatTextureSetRSnippet(glsl);
	  }
	  if (program.packedInputs) {
	    shaderPrefix += SHADER_PACKED_PREFIX;
	  }
	  var source = [shaderPrefix, floatTextureSampleSnippet, floatTextureSetOutputSnippet, inputPrefixSnippet, outputSamplingSnippet, inputSamplingSnippet, program.userCode].join('\n');
	  return source;
	}
	function getSamplerFromInInfo(inInfo) {
	  var enableShapeUniforms = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
	  var shape = inInfo.shapeInfo.logicalShape;
	  switch (shape.length) {
	    case 0:
	      return getSamplerScalar(inInfo, enableShapeUniforms);
	    case 1:
	      return getSampler1D(inInfo, enableShapeUniforms);
	    case 2:
	      return getSampler2D(inInfo, enableShapeUniforms);
	    case 3:
	      return getSampler3D(inInfo, enableShapeUniforms);
	    case 4:
	      return getSampler4D(inInfo, enableShapeUniforms);
	    case 5:
	      return getSampler5D(inInfo);
	    case 6:
	      return getSampler6D(inInfo);
	    default:
	      throw new Error("".concat(shape.length, "-D input sampling") + " is not yet supported");
	  }
	}
	function getPackedSamplerFromInInfo(inInfo, enableShapeUniforms) {
	  var shape = inInfo.shapeInfo.logicalShape;
	  switch (shape.length) {
	    case 0:
	      return getPackedSamplerScalar(inInfo);
	    case 1:
	      return getPackedSampler1D(inInfo, enableShapeUniforms);
	    case 2:
	      return getPackedSampler2D(inInfo, enableShapeUniforms);
	    case 3:
	      return getPackedSampler3D(inInfo, enableShapeUniforms);
	    default:
	      return getPackedSamplerND(inInfo, enableShapeUniforms);
	  }
	}
	function getInputSamplingSnippet(inInfo, outShapeInfo) {
	  var usesPackedTextures = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
	  var enableShapeUniforms = arguments.length > 3 ? arguments[3] : undefined;
	  var res = '';
	  if (usesPackedTextures) {
	    res += getPackedSamplerFromInInfo(inInfo, enableShapeUniforms);
	  } else {
	    res += getSamplerFromInInfo(inInfo, enableShapeUniforms);
	  }
	  var inShape = inInfo.shapeInfo.logicalShape;
	  var outShape = outShapeInfo.logicalShape;
	  if (inShape.length <= outShape.length) {
	    if (usesPackedTextures) {
	      res += getPackedSamplerAtOutputCoords(inInfo, outShapeInfo);
	    } else {
	      res += getSamplerAtOutputCoords(inInfo, outShapeInfo);
	    }
	  }
	  return res;
	}
	function getPackedOutputSamplingSnippet(outShape, outTexShape, enableShapeUniforms) {
	  switch (outShape.length) {
	    case 0:
	      return getOutputScalarCoords();
	    case 1:
	      return getOutputPacked1DCoords(outShape, outTexShape, enableShapeUniforms);
	    case 2:
	      return getOutputPacked2DCoords(outShape, outTexShape, enableShapeUniforms);
	    case 3:
	      return getOutputPacked3DCoords(outShape, outTexShape, enableShapeUniforms);
	    default:
	      return getOutputPackedNDCoords(outShape, outTexShape, enableShapeUniforms);
	  }
	}
	function getOutputSamplingSnippet(outShape, outTexShape, enableShapeUniforms) {
	  switch (outShape.length) {
	    case 0:
	      return getOutputScalarCoords();
	    case 1:
	      return getOutput1DCoords(outShape, outTexShape, enableShapeUniforms);
	    case 2:
	      return getOutput2DCoords(outShape, outTexShape, enableShapeUniforms);
	    case 3:
	      return getOutput3DCoords(outShape, outTexShape, enableShapeUniforms);
	    case 4:
	      return getOutput4DCoords(outShape, outTexShape, enableShapeUniforms);
	    case 5:
	      return getOutput5DCoords(outShape, outTexShape);
	    case 6:
	      return getOutput6DCoords(outShape, outTexShape);
	    default:
	      throw new Error("".concat(outShape.length, "-D output sampling is not yet supported"));
	  }
	}
	function getFloatTextureSampleSnippet(glsl) {
	  return "\n    float sampleTexture(sampler2D textureSampler, vec2 uv) {\n      return ".concat(glsl.texture2D, "(textureSampler, uv).r;\n    }\n  ");
	}
	function getFloatTextureSetRSnippet(glsl) {
	  return "\n    void setOutput(float val) {\n      ".concat(glsl.output, " = vec4(val, 0, 0, 0);\n    }\n  ");
	}
	function getFloatTextureSetRGBASnippet(glsl) {
	  return "\n    void setOutput(vec4 val) {\n      ".concat(glsl.output, " = val;\n    }\n  ");
	}
	function getShaderPrefix(glsl) {
	  var SHADER_PREFIX = "".concat(glsl.version, "\n    precision highp float;\n    precision highp int;\n    precision highp sampler2D;\n    ").concat(glsl.varyingFs, " vec2 resultUV;\n    ").concat(glsl.defineOutput, "\n    const vec2 halfCR = vec2(0.5, 0.5);\n\n    struct ivec5\n    {\n      int x;\n      int y;\n      int z;\n      int w;\n      int u;\n    };\n\n    struct ivec6\n    {\n      int x;\n      int y;\n      int z;\n      int w;\n      int u;\n      int v;\n    };\n\n    uniform float NAN;\n    ").concat(glsl.defineSpecialNaN, "\n    ").concat(glsl.defineSpecialInf, "\n    ").concat(glsl.defineRound, "\n\n    int imod(int x, int y) {\n      return x - y * (x / y);\n    }\n\n    int idiv(int a, int b, float sign) {\n      int res = a / b;\n      int mod = imod(a, b);\n      if (sign < 0. && mod != 0) {\n        res -= 1;\n      }\n      return res;\n    }\n\n    //Based on the work of Dave Hoskins\n    //https://www.shadertoy.com/view/4djSRW\n    #define HASHSCALE1 443.8975\n    float random(float seed){\n      vec2 p = resultUV * seed;\n      vec3 p3  = fract(vec3(p.xyx) * HASHSCALE1);\n      p3 += dot(p3, p3.yzx + 19.19);\n      return fract((p3.x + p3.y) * p3.z);\n    }\n\n    ").concat(SAMPLE_1D_SNIPPET, "\n    ").concat(SAMPLE_2D_SNIPPET, "\n    ").concat(SAMPLE_3D_SNIPPET, "\n  ");
	  return SHADER_PREFIX;
	}
	var SAMPLE_1D_SNIPPET = "\nvec2 uvFromFlat(int texNumR, int texNumC, int index) {\n  int texR = index / texNumC;\n  int texC = index - texR * texNumC;\n  return (vec2(texC, texR) + halfCR) / vec2(texNumC, texNumR);\n}\nvec2 packedUVfrom1D(int texNumR, int texNumC, int index) {\n  int texelIndex = index / 2;\n  int texR = texelIndex / texNumC;\n  int texC = texelIndex - texR * texNumC;\n  return (vec2(texC, texR) + halfCR) / vec2(texNumC, texNumR);\n}\n";
	var SAMPLE_2D_SNIPPET = "\nvec2 packedUVfrom2D(int texelsInLogicalRow, int texNumR,\n  int texNumC, int row, int col) {\n  int texelIndex = (row / 2) * texelsInLogicalRow + (col / 2);\n  int texR = texelIndex / texNumC;\n  int texC = texelIndex - texR * texNumC;\n  return (vec2(texC, texR) + halfCR) / vec2(texNumC, texNumR);\n}\n";
	var SAMPLE_3D_SNIPPET = "\nvec2 packedUVfrom3D(int texNumR, int texNumC,\n    int texelsInBatch, int texelsInLogicalRow, int b,\n    int row, int col) {\n  int index = b * texelsInBatch + (row / 2) * texelsInLogicalRow + (col / 2);\n  int texR = index / texNumC;\n  int texC = index - texR * texNumC;\n  return (vec2(texC, texR) + halfCR) / vec2(texNumC, texNumR);\n}\n";
	var SHADER_PACKED_PREFIX = "\n  float getChannel(vec4 frag, vec2 innerDims) {\n    vec2 modCoord = mod(innerDims, 2.);\n    return modCoord.x == 0. ?\n      (modCoord.y == 0. ? frag.r : frag.g) :\n      (modCoord.y == 0. ? frag.b : frag.a);\n  }\n  float getChannel(vec4 frag, int dim) {\n    float modCoord = mod(float(dim), 2.);\n    return modCoord == 0. ? frag.r : frag.g;\n  }\n";
	function getOutputScalarCoords() {
	  return "\n    int getOutputCoords() {\n      return 0;\n    }\n  ";
	}
	function getOutputPacked1DCoords(shape, texShape, enableShapeUniforms) {
	  var packedTexShape = [Math.ceil(texShape[0] / 2), Math.ceil(texShape[1] / 2)];
	  if (packedTexShape[0] === 1) {
	    if (enableShapeUniforms) {
	      return "\n      int getOutputCoords() {\n        return 2 * int(resultUV.x * ceil(float(outTexShape[1]) / 2.0));\n      }\n    ";
	    }
	    return "\n      int getOutputCoords() {\n        return 2 * int(resultUV.x * ".concat(packedTexShape[1], ".0);\n      }\n    ");
	  }
	  if (packedTexShape[1] === 1) {
	    if (enableShapeUniforms) {
	      return "\n      int getOutputCoords() {\n        return 2 * int(resultUV.y * ceil(float(outTexShape[0]) / 2.0));\n      }\n    ";
	    }
	    return "\n      int getOutputCoords() {\n        return 2 * int(resultUV.y * ".concat(packedTexShape[0], ".0);\n      }\n    ");
	  }
	  if (enableShapeUniforms) {
	    return "\n    int getOutputCoords() {\n      ivec2 packedTexShape = ivec2(ceil(float(outTexShape[0]) / 2.0), ceil(float(outTexShape[1]) / 2.0));\n      ivec2 resTexRC = ivec2(resultUV.yx *\n                             vec2(packedTexShape[0], packedTexShape[1]));\n      return 2 * (resTexRC.x * packedTexShape[1] + resTexRC.y);\n    }\n  ";
	  }
	  return "\n    int getOutputCoords() {\n      ivec2 resTexRC = ivec2(resultUV.yx *\n                             vec2(".concat(packedTexShape[0], ", ").concat(packedTexShape[1], "));\n      return 2 * (resTexRC.x * ").concat(packedTexShape[1], " + resTexRC.y);\n    }\n  ");
	}
	function getOutput1DCoords(shape, texShape, enableShapeUniforms) {
	  if (texShape[0] === 1) {
	    if (enableShapeUniforms) {
	      return "\n      int getOutputCoords() {\n        return int(resultUV.x * float(outTexShape[1]));\n      }\n    ";
	    }
	    return "\n      int getOutputCoords() {\n        return int(resultUV.x * ".concat(texShape[1], ".0);\n      }\n    ");
	  }
	  if (texShape[1] === 1) {
	    if (enableShapeUniforms) {
	      return "\n      int getOutputCoords() {\n        return int(resultUV.y * float(outTexShape[0]));\n      }\n    ";
	    }
	    return "\n      int getOutputCoords() {\n        return int(resultUV.y * ".concat(texShape[0], ".0);\n      }\n    ");
	  }
	  if (enableShapeUniforms) {
	    return "\n    int getOutputCoords() {\n      ivec2 resTexRC = ivec2(resultUV.yx *\n                             vec2(outTexShape[0], outTexShape[1]));\n      return resTexRC.x * outTexShape[1] + resTexRC.y;\n    }\n  ";
	  }
	  return "\n    int getOutputCoords() {\n      ivec2 resTexRC = ivec2(resultUV.yx *\n                             vec2(".concat(texShape[0], ", ").concat(texShape[1], "));\n      return resTexRC.x * ").concat(texShape[1], " + resTexRC.y;\n    }\n  ");
	}
	function getOutputPacked3DCoords(shape, texShape, enableShapeUniforms) {
	  if (enableShapeUniforms) {
	    return "\n    ivec3 getOutputCoords() {\n      ivec2 packedTexShape = ivec2(ceil(float(outTexShape[0]) / 2.0), ceil(float(outTexShape[1]) / 2.0));\n      int texelsInLogicalRow = int(ceil(float(outShape[2]) / 2.0));\n      int texelsInBatch = texelsInLogicalRow * int(ceil(float(outShape[1]) / 2.0));\n      ivec2 resTexRC = ivec2(resultUV.yx *\n                             vec2(packedTexShape[0], packedTexShape[1]));\n      int index = resTexRC.x * packedTexShape[1] + resTexRC.y;\n\n      int b = index / texelsInBatch;\n      index -= b * texelsInBatch;\n\n      int r = 2 * (index / texelsInLogicalRow);\n      int c = imod(index, texelsInLogicalRow) * 2;\n\n      return ivec3(b, r, c);\n    }\n  ";
	  }
	  var packedTexShape = [Math.ceil(texShape[0] / 2), Math.ceil(texShape[1] / 2)];
	  var texelsInLogicalRow = Math.ceil(shape[2] / 2);
	  var texelsInBatch = texelsInLogicalRow * Math.ceil(shape[1] / 2);
	  return "\n    ivec3 getOutputCoords() {\n      ivec2 resTexRC = ivec2(resultUV.yx *\n                             vec2(".concat(packedTexShape[0], ", ").concat(packedTexShape[1], "));\n      int index = resTexRC.x * ").concat(packedTexShape[1], " + resTexRC.y;\n\n      int b = index / ").concat(texelsInBatch, ";\n      index -= b * ").concat(texelsInBatch, ";\n\n      int r = 2 * (index / ").concat(texelsInLogicalRow, ");\n      int c = imod(index, ").concat(texelsInLogicalRow, ") * 2;\n\n      return ivec3(b, r, c);\n    }\n  ");
	}
	function getOutput3DCoords(shape, texShape, enableShapeUniforms) {
	  if (enableShapeUniforms) {
	    var _coordsFromIndexSnippet = getOutputLogicalCoordinatesFromFlatIndexByUniform(['r', 'c', 'd'], shape);
	    return "\n  ivec3 getOutputCoords() {\n    ivec2 resTexRC = ivec2(resultUV.yx *\n                           vec2(outTexShape[0], outTexShape[1]));\n    int index = resTexRC.x * outTexShape[1] + resTexRC.y;\n    ".concat(_coordsFromIndexSnippet, "\n    return ivec3(r, c, d);\n  }\n");
	  }
	  var coordsFromIndexSnippet = getLogicalCoordinatesFromFlatIndex(['r', 'c', 'd'], shape);
	  return "\n    ivec3 getOutputCoords() {\n      ivec2 resTexRC = ivec2(resultUV.yx *\n                             vec2(".concat(texShape[0], ", ").concat(texShape[1], "));\n      int index = resTexRC.x * ").concat(texShape[1], " + resTexRC.y;\n      ").concat(coordsFromIndexSnippet, "\n      return ivec3(r, c, d);\n    }\n  ");
	}
	function getOutputPackedNDCoords(shape, texShape, enableShapeUniforms) {
	  if (enableShapeUniforms) {
	    // TODO: support 5d and 6d
	    return "\n    ivec4 getOutputCoords() {\n      ivec2 packedTexShape = ivec2(ceil(float(outTexShape[0]) / 2.0), ceil(float(outTexShape[1]) / 2.0));\n      ivec2 resTexRC = ivec2(resultUV.yx *\n                             vec2(packedTexShape[0], packedTexShape[1]));\n      int index = resTexRC.x * packedTexShape[1] + resTexRC.y;\n\n      int texelsInLogicalRow = int(ceil(float(outShape[3]) / 2.0));\n      int texelsInBatch = texelsInLogicalRow * int(ceil(float(outShape[2]) / 2.0));\n      int texelsInBatchN = texelsInBatch * outShape[1];\n\n      int b2 = index / texelsInBatchN;\n      index -= b2 * texelsInBatchN;\n\n      int b = index / texelsInBatch;\n      index -= b * texelsInBatch;\n\n      int r = 2 * (index / texelsInLogicalRow);\n      int c = imod(index, texelsInLogicalRow) * 2;\n\n      return ivec4(b2, b, r, c);\n    }\n  ";
	  }
	  var packedTexShape = [Math.ceil(texShape[0] / 2), Math.ceil(texShape[1] / 2)];
	  var texelsInLogicalRow = Math.ceil(shape[shape.length - 1] / 2);
	  var texelsInBatch = texelsInLogicalRow * Math.ceil(shape[shape.length - 2] / 2);
	  var texelsInBatchN = texelsInBatch;
	  var batches = "";
	  var coords = 'b, r, c';
	  for (var b = 2; b < shape.length - 1; b++) {
	    texelsInBatchN *= shape[shape.length - b - 1];
	    batches = "\n      int b".concat(b, " = index / ").concat(texelsInBatchN, ";\n      index -= b").concat(b, " * ").concat(texelsInBatchN, ";\n    ") + batches;
	    coords = "b".concat(b, ", ") + coords;
	  }
	  return "\n    ivec".concat(shape.length, " getOutputCoords() {\n      ivec2 resTexRC = ivec2(resultUV.yx *\n                             vec2(").concat(packedTexShape[0], ", ").concat(packedTexShape[1], "));\n      int index = resTexRC.x * ").concat(packedTexShape[1], " + resTexRC.y;\n\n      ").concat(batches, "\n\n      int b = index / ").concat(texelsInBatch, ";\n      index -= b * ").concat(texelsInBatch, ";\n\n      int r = 2 * (index / ").concat(texelsInLogicalRow, ");\n      int c = imod(index, ").concat(texelsInLogicalRow, ") * 2;\n\n      return ivec").concat(shape.length, "(").concat(coords, ");\n    }\n  ");
	}
	function getOutput4DCoords(shape, texShape, enableShapeUniforms) {
	  if (enableShapeUniforms) {
	    var _coordsFromIndexSnippet2 = getOutputLogicalCoordinatesFromFlatIndexByUniform(['r', 'c', 'd', 'd2'], shape);
	    return "\n    ivec4 getOutputCoords() {\n      ivec2 resTexRC = ivec2(resultUV.yx *\n        vec2(outTexShape[0], outTexShape[1]));\n      int index = resTexRC.x * outTexShape[1] + resTexRC.y;\n      ".concat(_coordsFromIndexSnippet2, "\n      return ivec4(r, c, d, d2);\n    }\n  ");
	  }
	  var coordsFromIndexSnippet = getLogicalCoordinatesFromFlatIndex(['r', 'c', 'd', 'd2'], shape);
	  return "\n    ivec4 getOutputCoords() {\n      ivec2 resTexRC = ivec2(resultUV.yx *\n        vec2(".concat(texShape[0], ", ").concat(texShape[1], "));\n      int index = resTexRC.x * ").concat(texShape[1], " + resTexRC.y;\n      ").concat(coordsFromIndexSnippet, "\n      return ivec4(r, c, d, d2);\n    }\n  ");
	}
	function getOutput5DCoords(shape, texShape) {
	  var coordsFromIndexSnippet = getLogicalCoordinatesFromFlatIndex(['r', 'c', 'd', 'd2', 'd3'], shape);
	  return "\n    ivec5 getOutputCoords() {\n      ivec2 resTexRC = ivec2(resultUV.yx * vec2(".concat(texShape[0], ",\n                             ").concat(texShape[1], "));\n\n      int index = resTexRC.x * ").concat(texShape[1], " + resTexRC.y;\n\n      ").concat(coordsFromIndexSnippet, "\n\n      ivec5 outShape = ivec5(r, c, d, d2, d3);\n      return outShape;\n    }\n  ");
	}
	function getOutput6DCoords(shape, texShape) {
	  var coordsFromIndexSnippet = getLogicalCoordinatesFromFlatIndex(['r', 'c', 'd', 'd2', 'd3', 'd4'], shape);
	  return "\n    ivec6 getOutputCoords() {\n      ivec2 resTexRC = ivec2(resultUV.yx *\n        vec2(".concat(texShape[0], ", ").concat(texShape[1], "));\n      int index = resTexRC.x * ").concat(texShape[1], " + resTexRC.y;\n\n      ").concat(coordsFromIndexSnippet, "\n\n      ivec6 result = ivec6(r, c, d, d2, d3, d4);\n      return result;\n    }\n  ");
	}
	function getOutputPacked2DCoords(shape, texShape, enableShapeUniforms) {
	  var packedTexShape = [Math.ceil(texShape[0] / 2), Math.ceil(texShape[1] / 2)];
	  if (arraysEqual(shape, texShape)) {
	    if (enableShapeUniforms) {
	      return "\n      ivec2 getOutputCoords() {\n        ivec2 packedTexShape = ivec2(ceil(float(outTexShape[0]) / 2.0), ceil(float(outTexShape[1]) / 2.0));\n        return 2 * ivec2(resultUV.yx * vec2(packedTexShape[0], packedTexShape[1]));\n      }\n    ";
	    }
	    return "\n      ivec2 getOutputCoords() {\n        return 2 * ivec2(resultUV.yx * vec2(".concat(packedTexShape[0], ", ").concat(packedTexShape[1], "));\n      }\n    ");
	  }
	  // texels needed to accommodate a logical row
	  var texelsInLogicalRow = Math.ceil(shape[1] / 2);
	  /**
	   * getOutputCoords
	   *
	   * resTexRC: The rows and columns of the texels. If you move over one
	   * texel to the right in the packed texture, you are moving over one column
	   * (not two).
	   *
	   * index: The texel index
	   */
	  if (enableShapeUniforms) {
	    return "\n    ivec2 getOutputCoords() {\n      ivec2 packedTexShape = ivec2(ceil(float(outTexShape[0]) / 2.0), ceil(float(outTexShape[1]) / 2.0));\n      int texelsInLogicalRow = int(ceil(float(outShape[1]) / 2.0));\n      ivec2 resTexRC = ivec2(resultUV.yx *\n                             vec2(packedTexShape[0], packedTexShape[1]));\n\n      int index = resTexRC.x * packedTexShape[1] + resTexRC.y;\n      int r = 2 * (index / texelsInLogicalRow);\n      int c = imod(index, texelsInLogicalRow) * 2;\n\n      return ivec2(r, c);\n    }\n  ";
	  }
	  return "\n    ivec2 getOutputCoords() {\n      ivec2 resTexRC = ivec2(resultUV.yx *\n                             vec2(".concat(packedTexShape[0], ", ").concat(packedTexShape[1], "));\n\n      int index = resTexRC.x * ").concat(packedTexShape[1], " + resTexRC.y;\n      int r = 2 * (index / ").concat(texelsInLogicalRow, ");\n      int c = imod(index, ").concat(texelsInLogicalRow, ") * 2;\n\n      return ivec2(r, c);\n    }\n  ");
	}
	function getOutput2DCoords(shape, texShape, enableShapeUniforms) {
	  if (arraysEqual(shape, texShape)) {
	    if (enableShapeUniforms) {
	      return "\n      ivec2 getOutputCoords() {\n        return ivec2(resultUV.yx * vec2(outTexShape[0], outTexShape[1]));\n      }\n    ";
	    }
	    return "\n      ivec2 getOutputCoords() {\n        return ivec2(resultUV.yx * vec2(".concat(texShape[0], ", ").concat(texShape[1], "));\n      }\n    ");
	  }
	  if (shape[1] === 1) {
	    if (enableShapeUniforms) {
	      return "\n      ivec2 getOutputCoords() {\n        ivec2 resTexRC = ivec2(resultUV.yx *\n                               vec2(outTexShape[0], outTexShape[1]));\n        int index = resTexRC.x * outTexShape[1] + resTexRC.y;\n        return ivec2(index, 0);\n      }\n    ";
	    }
	    return "\n      ivec2 getOutputCoords() {\n        ivec2 resTexRC = ivec2(resultUV.yx *\n                               vec2(".concat(texShape[0], ", ").concat(texShape[1], "));\n        int index = resTexRC.x * ").concat(texShape[1], " + resTexRC.y;\n        return ivec2(index, 0);\n      }\n    ");
	  }
	  if (shape[0] === 1) {
	    if (enableShapeUniforms) {
	      return "\n      ivec2 getOutputCoords() {\n        ivec2 resTexRC = ivec2(resultUV.yx *\n                               vec2(outTexShape[0], outTexShape[1]));\n        int index = resTexRC.x * outTexShape[1] + resTexRC.y;\n        return ivec2(0, index);\n      }\n    ";
	    }
	    return "\n      ivec2 getOutputCoords() {\n        ivec2 resTexRC = ivec2(resultUV.yx *\n                               vec2(".concat(texShape[0], ", ").concat(texShape[1], "));\n        int index = resTexRC.x * ").concat(texShape[1], " + resTexRC.y;\n        return ivec2(0, index);\n      }\n    ");
	  }
	  if (enableShapeUniforms) {
	    return "\n    ivec2 getOutputCoords() {\n      ivec2 resTexRC = ivec2(resultUV.yx *\n                             vec2(outTexShape[0], outTexShape[1]));\n      int index = resTexRC.x * outTexShape[1] + resTexRC.y;\n      int r = index / outShape[1];\n      int c = index - r * outShape[1];\n      return ivec2(r, c);\n    }\n  ";
	  }
	  return "\n    ivec2 getOutputCoords() {\n      ivec2 resTexRC = ivec2(resultUV.yx *\n                             vec2(".concat(texShape[0], ", ").concat(texShape[1], "));\n      int index = resTexRC.x * ").concat(texShape[1], " + resTexRC.y;\n      int r = index / ").concat(shape[1], ";\n      int c = index - r * ").concat(shape[1], ";\n      return ivec2(r, c);\n    }\n  ");
	}
	function getFlatOffsetUniformName(texName) {
	  return "offset".concat(texName);
	}
	function getPackedSamplerScalar(inputInfo) {
	  var texName = inputInfo.name;
	  var funcName = 'get' + texName.charAt(0).toUpperCase() + texName.slice(1);
	  var glsl = getGlslDifferences();
	  return "\n    vec4 ".concat(funcName, "() {\n      return ").concat(glsl.texture2D, "(").concat(texName, ", halfCR);\n    }\n  ");
	}
	function getSamplerScalar(inputInfo, enableShapeUniforms) {
	  var texName = inputInfo.name;
	  var funcName = 'get' + texName.charAt(0).toUpperCase() + texName.slice(1);
	  if (inputInfo.shapeInfo.isUniform) {
	    return "float ".concat(funcName, "() {return ").concat(texName, ";}");
	  }
	  var _inputInfo$shapeInfo$ = _slicedToArray(inputInfo.shapeInfo.texShape, 2),
	    texNumR = _inputInfo$shapeInfo$[0],
	    texNumC = _inputInfo$shapeInfo$[1];
	  if (texNumR === 1 && texNumC === 1) {
	    return "\n      float ".concat(funcName, "() {\n        return sampleTexture(").concat(texName, ", halfCR);\n      }\n    ");
	  }
	  var offset = getFlatOffsetUniformName(texName);
	  if (enableShapeUniforms) {
	    return "\n    float ".concat(funcName, "() {\n      vec2 uv = uvFromFlat(").concat(texName, "TexShape[0], ").concat(texName, "TexShape[1], ").concat(offset, ");\n      return sampleTexture(").concat(texName, ", uv);\n    }\n  ");
	  }
	  var _inputInfo$shapeInfo$2 = _slicedToArray(inputInfo.shapeInfo.texShape, 2),
	    tNumR = _inputInfo$shapeInfo$2[0],
	    tNumC = _inputInfo$shapeInfo$2[1];
	  return "\n    float ".concat(funcName, "() {\n      vec2 uv = uvFromFlat(").concat(tNumR, ", ").concat(tNumC, ", ").concat(offset, ");\n      return sampleTexture(").concat(texName, ", uv);\n    }\n  ");
	}
	function getPackedSampler1D(inputInfo, enableShapeUniforms) {
	  var texName = inputInfo.name;
	  var funcName = 'get' + texName.charAt(0).toUpperCase() + texName.slice(1);
	  var texShape = inputInfo.shapeInfo.texShape;
	  var glsl = getGlslDifferences();
	  if (enableShapeUniforms) {
	    return "\n    vec4 ".concat(funcName, "(int index) {\n      ivec2 packedTexShape = ivec2(ceil(float(").concat(texName, "TexShape[0]) / 2.0), ceil(float(").concat(texName, "TexShape[1]) / 2.0));\n      vec2 uv = packedUVfrom1D(\n        packedTexShape[0], packedTexShape[1], index);\n      return ").concat(glsl.texture2D, "(").concat(texName, ", uv);\n    }\n  ");
	  }
	  var packedTexShape = [Math.ceil(texShape[0] / 2), Math.ceil(texShape[1] / 2)];
	  return "\n    vec4 ".concat(funcName, "(int index) {\n      vec2 uv = packedUVfrom1D(\n        ").concat(packedTexShape[0], ", ").concat(packedTexShape[1], ", index);\n      return ").concat(glsl.texture2D, "(").concat(texName, ", uv);\n    }\n  ");
	}
	function getSampler1D(inputInfo, enableShapeUniforms) {
	  var texName = inputInfo.name;
	  var funcName = 'get' + texName.charAt(0).toUpperCase() + texName.slice(1);
	  if (inputInfo.shapeInfo.isUniform) {
	    // Uniform arrays will be less than 65505 (no risk of float16 overflow).
	    return "\n      float ".concat(funcName, "(int index) {\n        ").concat(getUniformSampler(inputInfo), "\n      }\n    ");
	  }
	  var texShape = inputInfo.shapeInfo.texShape;
	  var tNumR = texShape[0];
	  var tNumC = texShape[1];
	  if (tNumC === 1 && tNumR === 1) {
	    return "\n      float ".concat(funcName, "(int index) {\n        return sampleTexture(").concat(texName, ", halfCR);\n      }\n    ");
	  }
	  var offset = getFlatOffsetUniformName(texName);
	  if (tNumC === 1) {
	    if (enableShapeUniforms) {
	      return "\n      float ".concat(funcName, "(int index) {\n        vec2 uv = vec2(0.5, (float(index + ").concat(offset, ") + 0.5) / float(").concat(texName, "TexShape[0]));\n        return sampleTexture(").concat(texName, ", uv);\n      }\n    ");
	    }
	    return "\n      float ".concat(funcName, "(int index) {\n        vec2 uv = vec2(0.5, (float(index + ").concat(offset, ") + 0.5) / ").concat(tNumR, ".0);\n        return sampleTexture(").concat(texName, ", uv);\n      }\n    ");
	  }
	  if (tNumR === 1) {
	    if (enableShapeUniforms) {
	      return "\n      float ".concat(funcName, "(int index) {\n        vec2 uv = vec2((float(index + ").concat(offset, ") + 0.5) / float(").concat(texName, "TexShape[1]), 0.5);\n        return sampleTexture(").concat(texName, ", uv);\n      }\n    ");
	    }
	    return "\n      float ".concat(funcName, "(int index) {\n        vec2 uv = vec2((float(index + ").concat(offset, ") + 0.5) / ").concat(tNumC, ".0, 0.5);\n        return sampleTexture(").concat(texName, ", uv);\n      }\n    ");
	  }
	  if (enableShapeUniforms) {
	    return "\n    float ".concat(funcName, "(int index) {\n      vec2 uv = uvFromFlat(").concat(texName, "TexShape[0], ").concat(texName, "TexShape[1], index + ").concat(offset, ");\n      return sampleTexture(").concat(texName, ", uv);\n    }\n  ");
	  }
	  return "\n    float ".concat(funcName, "(int index) {\n      vec2 uv = uvFromFlat(").concat(tNumR, ", ").concat(tNumC, ", index + ").concat(offset, ");\n      return sampleTexture(").concat(texName, ", uv);\n    }\n  ");
	}
	function getPackedSampler2D(inputInfo, enableShapeUniforms) {
	  var shape = inputInfo.shapeInfo.logicalShape;
	  var texName = inputInfo.name;
	  var funcName = 'get' + texName.charAt(0).toUpperCase() + texName.slice(1);
	  var texShape = inputInfo.shapeInfo.texShape;
	  var texNumR = texShape[0];
	  var texNumC = texShape[1];
	  var glsl = getGlslDifferences();
	  if (texShape != null && arraysEqual(shape, texShape)) {
	    if (enableShapeUniforms) {
	      return "\n      vec4 ".concat(funcName, "(int row, int col) {\n        vec2 uv = (vec2(col, row) + halfCR) / vec2(").concat(texName, "TexShape[1], ").concat(texName, "TexShape[0]);\n\n        return ").concat(glsl.texture2D, "(").concat(texName, ", uv);\n      }\n    ");
	    }
	    return "\n      vec4 ".concat(funcName, "(int row, int col) {\n        vec2 uv = (vec2(col, row) + halfCR) / vec2(").concat(texNumC, ".0, ").concat(texNumR, ".0);\n\n        return ").concat(glsl.texture2D, "(").concat(texName, ", uv);\n      }\n    ");
	  }
	  if (enableShapeUniforms) {
	    return "\n    vec4 ".concat(funcName, "(int row, int col) {\n      ivec2 packedTexShape = ivec2(ceil(float(").concat(texName, "TexShape[0]) / 2.0), ceil(float(").concat(texName, "TexShape[1]) / 2.0));\n      int valuesPerRow = int(ceil(float(").concat(texName, "Shape[1]) / 2.0));\n      vec2 uv = packedUVfrom2D(valuesPerRow, packedTexShape[0], packedTexShape[1], row, col);\n      return ").concat(glsl.texture2D, "(").concat(texName, ", uv);\n    }\n  ");
	  }
	  var packedTexShape = [Math.ceil(texShape[0] / 2), Math.ceil(texShape[1] / 2)];
	  var valuesPerRow = Math.ceil(shape[1] / 2);
	  return "\n    vec4 ".concat(funcName, "(int row, int col) {\n      vec2 uv = packedUVfrom2D(").concat(valuesPerRow, ", ").concat(packedTexShape[0], ", ").concat(packedTexShape[1], ", row, col);\n      return ").concat(glsl.texture2D, "(").concat(texName, ", uv);\n    }\n  ");
	}
	function getSampler2D(inputInfo, enableShapeUniforms) {
	  var shape = inputInfo.shapeInfo.logicalShape;
	  var texName = inputInfo.name;
	  var funcName = 'get' + texName.charAt(0).toUpperCase() + texName.slice(1);
	  var texShape = inputInfo.shapeInfo.texShape;
	  if (texShape != null && arraysEqual(shape, texShape)) {
	    if (enableShapeUniforms) {
	      return "\n      float ".concat(funcName, "(int row, int col) {\n        vec2 uv = (vec2(col, row) + halfCR) / vec2(").concat(texName, "TexShape[1], ").concat(texName, "TexShape[0]);\n        return sampleTexture(").concat(texName, ", uv);\n      }\n    ");
	    }
	    var _texNumR = texShape[0];
	    var _texNumC = texShape[1];
	    return "\n    float ".concat(funcName, "(int row, int col) {\n      vec2 uv = (vec2(col, row) + halfCR) / vec2(").concat(_texNumC, ".0, ").concat(_texNumR, ".0);\n      return sampleTexture(").concat(texName, ", uv);\n    }\n  ");
	  }
	  var _util$squeezeShape = squeezeShape(shape),
	    newShape = _util$squeezeShape.newShape,
	    keptDims = _util$squeezeShape.keptDims;
	  var squeezedShape = newShape;
	  if (squeezedShape.length < shape.length) {
	    var newInputInfo = squeezeInputInfo(inputInfo, squeezedShape);
	    var params = ['row', 'col'];
	    return "\n      ".concat(getSamplerFromInInfo(newInputInfo, enableShapeUniforms), "\n      float ").concat(funcName, "(int row, int col) {\n        return ").concat(funcName, "(").concat(getSqueezedParams(params, keptDims), ");\n      }\n    ");
	  }
	  if (inputInfo.shapeInfo.isUniform) {
	    // Uniform arrays will be less than 65505 (no risk of float16 overflow).
	    return "\n      float ".concat(funcName, "(int row, int col) {\n        int index = round(dot(vec2(row, col), vec2(").concat(shape[1], ", 1)));\n        ").concat(getUniformSampler(inputInfo), "\n      }\n    ");
	  }
	  var texNumR = texShape[0];
	  var texNumC = texShape[1];
	  var offset = getFlatOffsetUniformName(texName);
	  if (texNumC === 1) {
	    // index is used directly as physical (no risk of float16 overflow).
	    if (enableShapeUniforms) {
	      return "\n      float ".concat(funcName, "(int row, int col) {\n        float index = dot(vec3(row, col, ").concat(offset, "), vec3(").concat(texName, "Shape[1], 1, 1));\n        vec2 uv = vec2(0.5, (index + 0.5) / float(").concat(texName, "TexShape[0]));\n        return sampleTexture(").concat(texName, ", uv);\n      }\n    ");
	    }
	    return "\n    float ".concat(funcName, "(int row, int col) {\n      float index = dot(vec3(row, col, ").concat(offset, "), vec3(").concat(shape[1], ", 1, 1));\n      vec2 uv = vec2(0.5, (index + 0.5) / ").concat(texNumR, ".0);\n      return sampleTexture(").concat(texName, ", uv);\n    }\n  ");
	  }
	  if (texNumR === 1) {
	    // index is used directly as physical (no risk of float16 overflow).
	    if (enableShapeUniforms) {
	      return "\n      float ".concat(funcName, "(int row, int col) {\n        float index = dot(vec3(row, col, ").concat(offset, "), vec3(").concat(texName, "Shape[1], 1, 1));\n        vec2 uv = vec2((index + 0.5) / float(").concat(texName, "TexShape[1]), 0.5);\n        return sampleTexture(").concat(texName, ", uv);\n      }\n    ");
	    }
	    return "\n    float ".concat(funcName, "(int row, int col) {\n      float index = dot(vec3(row, col, ").concat(offset, "), vec3(").concat(shape[1], ", 1, 1));\n      vec2 uv = vec2((index + 0.5) / ").concat(texNumC, ".0, 0.5);\n      return sampleTexture(").concat(texName, ", uv);\n    }\n  ");
	  }
	  if (enableShapeUniforms) {
	    return "\n      float ".concat(funcName, "(int row, int col) {\n        // Explicitly use integer operations as dot() only works on floats.\n        int index = row * ").concat(texName, "Shape[1] + col + ").concat(offset, ";\n        vec2 uv = uvFromFlat(").concat(texName, "TexShape[0], ").concat(texName, "TexShape[1], index);\n        return sampleTexture(").concat(texName, ", uv);\n      }\n    ");
	  }
	  return "\n  float ".concat(funcName, "(int row, int col) {\n    // Explicitly use integer operations as dot() only works on floats.\n    int index = row * ").concat(shape[1], " + col + ").concat(offset, ";\n    vec2 uv = uvFromFlat(").concat(texNumR, ", ").concat(texNumC, ", index);\n    return sampleTexture(").concat(texName, ", uv);\n  }\n");
	}
	function getPackedSampler3D(inputInfo, enableShapeUniforms) {
	  var shape = inputInfo.shapeInfo.logicalShape;
	  var texName = inputInfo.name;
	  var funcName = 'get' + texName.charAt(0).toUpperCase() + texName.slice(1);
	  var texShape = inputInfo.shapeInfo.texShape;
	  var packedTexShape = [Math.ceil(texShape[0] / 2), Math.ceil(texShape[1] / 2)];
	  if (shape[0] === 1) {
	    var squeezedShape = shape.slice(1);
	    var keptDims = [1, 2];
	    var newInputInfo = squeezeInputInfo(inputInfo, squeezedShape);
	    var params = ['b', 'row', 'col'];
	    return "\n        ".concat(getPackedSamplerFromInInfo(newInputInfo, enableShapeUniforms), "\n        vec4 ").concat(funcName, "(int b, int row, int col) {\n          return ").concat(funcName, "(").concat(getSqueezedParams(params, keptDims), ");\n        }\n      ");
	  }
	  var glsl = getGlslDifferences();
	  if (enableShapeUniforms) {
	    return "\n    vec4 ".concat(funcName, "(int b, int row, int col) {\n      ivec2 packedTexShape = ivec2(ceil(float(").concat(texName, "TexShape[0]) / 2.0), ceil(float(").concat(texName, "TexShape[1]) / 2.0));\n      int valuesPerRow = int(ceil(float(").concat(texName, "Shape[2]) / 2.0));\n      int texelsInBatch = valuesPerRow * int(ceil(float(").concat(texName, "Shape[1]) / 2.0));\n      vec2 uv = packedUVfrom3D(\n        packedTexShape[0], packedTexShape[1], texelsInBatch, valuesPerRow, b, row, col);\n      return ").concat(glsl.texture2D, "(").concat(texName, ", uv);\n    }\n  ");
	  }
	  var texNumR = packedTexShape[0];
	  var texNumC = packedTexShape[1];
	  var valuesPerRow = Math.ceil(shape[2] / 2);
	  var texelsInBatch = valuesPerRow * Math.ceil(shape[1] / 2);
	  return "\n    vec4 ".concat(funcName, "(int b, int row, int col) {\n      vec2 uv = packedUVfrom3D(\n        ").concat(texNumR, ", ").concat(texNumC, ", ").concat(texelsInBatch, ", ").concat(valuesPerRow, ", b, row, col);\n      return ").concat(glsl.texture2D, "(").concat(texName, ", uv);\n    }\n  ");
	}
	function getSampler3D(inputInfo, enableShapeUniforms) {
	  var shape = inputInfo.shapeInfo.logicalShape;
	  var texName = inputInfo.name;
	  var funcName = 'get' + texName.charAt(0).toUpperCase() + texName.slice(1);
	  var stride0 = shape[1] * shape[2];
	  var stride1 = shape[2];
	  var _util$squeezeShape2 = squeezeShape(shape),
	    newShape = _util$squeezeShape2.newShape,
	    keptDims = _util$squeezeShape2.keptDims;
	  var squeezedShape = newShape;
	  if (squeezedShape.length < shape.length) {
	    var newInputInfo = squeezeInputInfo(inputInfo, squeezedShape);
	    var params = ['row', 'col', 'depth'];
	    return "\n        ".concat(getSamplerFromInInfo(newInputInfo, enableShapeUniforms), "\n        float ").concat(funcName, "(int row, int col, int depth) {\n          return ").concat(funcName, "(").concat(getSqueezedParams(params, keptDims), ");\n        }\n      ");
	  }
	  if (inputInfo.shapeInfo.isUniform) {
	    // Uniform arrays will be less than 65505 (no risk of float16 overflow).
	    return "\n      float ".concat(funcName, "(int row, int col, int depth) {\n        int index = round(dot(vec3(row, col, depth),\n                          vec3(").concat(stride0, ", ").concat(stride1, ", 1)));\n        ").concat(getUniformSampler(inputInfo), "\n      }\n    ");
	  }
	  var texShape = inputInfo.shapeInfo.texShape;
	  var texNumR = texShape[0];
	  var texNumC = texShape[1];
	  var flatOffset = inputInfo.shapeInfo.flatOffset;
	  if (texNumC === stride0 && flatOffset == null) {
	    // texC is used directly as physical (no risk of float16 overflow).
	    if (enableShapeUniforms) {
	      return "\n      float ".concat(funcName, "(int row, int col, int depth) {\n        int stride1 = ").concat(texName, "Shape[2];\n        float texR = float(row);\n        float texC = dot(vec2(col, depth), vec2(stride1, 1));\n        vec2 uv = (vec2(texC, texR) + halfCR) /\n                   vec2(").concat(texName, "TexShape[1], ").concat(texName, "TexShape[0]);\n        return sampleTexture(").concat(texName, ", uv);\n      }\n    ");
	    }
	    return "\n        float ".concat(funcName, "(int row, int col, int depth) {\n          float texR = float(row);\n          float texC = dot(vec2(col, depth), vec2(").concat(stride1, ", 1));\n          vec2 uv = (vec2(texC, texR) + halfCR) /\n                     vec2(").concat(texNumC, ".0, ").concat(texNumR, ".0);\n          return sampleTexture(").concat(texName, ", uv);\n        }\n      ");
	  }
	  if (texNumC === stride1 && flatOffset == null) {
	    // texR is used directly as physical (no risk of float16 overflow).
	    if (enableShapeUniforms) {
	      return "\n      float ".concat(funcName, "(int row, int col, int depth) {\n        float texR = dot(vec2(row, col), vec2(").concat(texName, "Shape[1], 1));\n        float texC = float(depth);\n        vec2 uv = (vec2(texC, texR) + halfCR) / vec2(").concat(texName, "TexShape[1], ").concat(texName, "TexShape[0]);\n        return sampleTexture(").concat(texName, ", uv);\n      }\n    ");
	    }
	    return "\n    float ".concat(funcName, "(int row, int col, int depth) {\n      float texR = dot(vec2(row, col), vec2(").concat(shape[1], ", 1));\n      float texC = float(depth);\n      vec2 uv = (vec2(texC, texR) + halfCR) / vec2(").concat(texNumC, ".0, ").concat(texNumR, ".0);\n      return sampleTexture(").concat(texName, ", uv);\n    }\n  ");
	  }
	  var offset = getFlatOffsetUniformName(texName);
	  if (enableShapeUniforms) {
	    return "\n    float ".concat(funcName, "(int row, int col, int depth) {\n      // Explicitly use integer operations as dot() only works on floats.\n      int stride0 = ").concat(texName, "Shape[1] * ").concat(texName, "Shape[2];\n      int stride1 = ").concat(texName, "Shape[2];\n      int index = row * stride0 + col * stride1 + depth + ").concat(offset, ";\n      vec2 uv = uvFromFlat(").concat(texName, "TexShape[0], ").concat(texName, "TexShape[1], index);\n      return sampleTexture(").concat(texName, ", uv);\n    }\n    ");
	  }
	  return "\n      float ".concat(funcName, "(int row, int col, int depth) {\n        // Explicitly use integer operations as dot() only works on floats.\n        int index = row * ").concat(stride0, " + col * ").concat(stride1, " + depth + ").concat(offset, ";\n        vec2 uv = uvFromFlat(").concat(texNumR, ", ").concat(texNumC, ", index);\n        return sampleTexture(").concat(texName, ", uv);\n      }\n  ");
	}
	function getPackedSamplerND(inputInfo, enableShapeUniforms) {
	  var texName = inputInfo.name;
	  var funcName = 'get' + texName.charAt(0).toUpperCase() + texName.slice(1);
	  var glsl = getGlslDifferences();
	  if (enableShapeUniforms) {
	    // TODO: support 5d and 6d
	    return "\n    vec4 ".concat(funcName, "(int b2, int b, int row, int col) {\n      int valuesPerRow = int(ceil(float(").concat(texName, "Shape[3]) / 2.0));\n      int texelsInBatch = valuesPerRow * int(ceil(float(").concat(texName, "Shape[2]) / 2.0));\n      int index = b * texelsInBatch + (row / 2) * valuesPerRow + (col / 2);\n      texelsInBatch *= ").concat(texName, "Shape[1];\n      index = b2 * texelsInBatch + index;\n      ivec2 packedTexShape = ivec2(ceil(float(").concat(texName, "TexShape[0]) / 2.0), ceil(float(").concat(texName, "TexShape[1]) / 2.0));\n      int texR = index / packedTexShape[1];\n      int texC = index - texR * packedTexShape[1];\n      vec2 uv = (vec2(texC, texR) + halfCR) / vec2(packedTexShape[1], packedTexShape[0]); return ").concat(glsl.texture2D, "(").concat(texName, ", uv);\n    }\n  ");
	  }
	  var shape = inputInfo.shapeInfo.logicalShape;
	  var rank = shape.length;
	  var texShape = inputInfo.shapeInfo.texShape;
	  var packedTexShape = [Math.ceil(texShape[0] / 2), Math.ceil(texShape[1] / 2)];
	  var texNumR = packedTexShape[0];
	  var texNumC = packedTexShape[1];
	  var valuesPerRow = Math.ceil(shape[rank - 1] / 2);
	  var texelsInBatch = valuesPerRow * Math.ceil(shape[rank - 2] / 2);
	  var params = "int b, int row, int col";
	  var index = "b * ".concat(texelsInBatch, " + (row / 2) * ").concat(valuesPerRow, " + (col / 2)");
	  for (var b = 2; b < rank - 1; b++) {
	    params = "int b".concat(b, ", ") + params;
	    texelsInBatch *= shape[rank - b - 1];
	    index = "b".concat(b, " * ").concat(texelsInBatch, " + ") + index;
	  }
	  return "\n    vec4 ".concat(funcName, "(").concat(params, ") {\n      int index = ").concat(index, ";\n      int texR = index / ").concat(texNumC, ";\n      int texC = index - texR * ").concat(texNumC, ";\n      vec2 uv = (vec2(texC, texR) + halfCR) / vec2(").concat(texNumC, ", ").concat(texNumR, ");\n      return ").concat(glsl.texture2D, "(").concat(texName, ", uv);\n    }\n  ");
	}
	function getSampler4D(inputInfo, enableShapeUniforms) {
	  var shape = inputInfo.shapeInfo.logicalShape;
	  var texName = inputInfo.name;
	  var funcName = 'get' + texName.charAt(0).toUpperCase() + texName.slice(1);
	  var stride2 = shape[3];
	  var stride1 = shape[2] * stride2;
	  var stride0 = shape[1] * stride1;
	  var _util$squeezeShape3 = squeezeShape(shape),
	    newShape = _util$squeezeShape3.newShape,
	    keptDims = _util$squeezeShape3.keptDims;
	  if (newShape.length < shape.length) {
	    var newInputInfo = squeezeInputInfo(inputInfo, newShape);
	    var params = ['row', 'col', 'depth', 'depth2'];
	    return "\n      ".concat(getSamplerFromInInfo(newInputInfo, enableShapeUniforms), "\n      float ").concat(funcName, "(int row, int col, int depth, int depth2) {\n        return ").concat(funcName, "(").concat(getSqueezedParams(params, keptDims), ");\n      }\n    ");
	  }
	  if (inputInfo.shapeInfo.isUniform) {
	    // Uniform arrays will be less than 65505 (no risk of float16 overflow).
	    return "\n      float ".concat(funcName, "(int row, int col, int depth, int depth2) {\n        int index = round(dot(vec4(row, col, depth, depth2),\n                          vec4(").concat(stride0, ", ").concat(stride1, ", ").concat(stride2, ", 1)));\n        ").concat(getUniformSampler(inputInfo), "\n      }\n    ");
	  }
	  var flatOffset = inputInfo.shapeInfo.flatOffset;
	  var texShape = inputInfo.shapeInfo.texShape;
	  var texNumR = texShape[0];
	  var texNumC = texShape[1];
	  var stride2Str = "int stride2 = ".concat(texName, "Shape[3];");
	  var stride1Str = "int stride1 = ".concat(texName, "Shape[2] * stride2;");
	  var stride0Str = "int stride0 = ".concat(texName, "Shape[1] * stride1;");
	  if (texNumC === stride0 && flatOffset == null) {
	    // texC is used directly as physical (no risk of float16 overflow).
	    if (enableShapeUniforms) {
	      return "\n      float ".concat(funcName, "(int row, int col, int depth, int depth2) {\n        ").concat(stride2Str, "\n        ").concat(stride1Str, "\n        float texR = float(row);\n        float texC =\n            dot(vec3(col, depth, depth2),\n                vec3(stride1, stride2, 1));\n        vec2 uv = (vec2(texC, texR) + halfCR) /\n                   vec2(").concat(texName, "TexShape[1], ").concat(texName, "TexShape[0]);\n        return sampleTexture(").concat(texName, ", uv);\n      }\n    ");
	    }
	    return "\n      float ".concat(funcName, "(int row, int col, int depth, int depth2) {\n        float texR = float(row);\n        float texC =\n            dot(vec3(col, depth, depth2),\n                vec3(").concat(stride1, ", ").concat(stride2, ", 1));\n        vec2 uv = (vec2(texC, texR) + halfCR) /\n                   vec2(").concat(texNumC, ".0, ").concat(texNumR, ".0);\n        return sampleTexture(").concat(texName, ", uv);\n      }\n    ");
	  }
	  if (texNumC === stride2 && flatOffset == null) {
	    // texR is used directly as physical (no risk of float16 overflow).
	    if (enableShapeUniforms) {
	      return "\n      float ".concat(funcName, "(int row, int col, int depth, int depth2) {\n        float texR = dot(vec3(row, col, depth),\n                         vec3(").concat(texName, "Shape[1] * ").concat(texName, "Shape[2], ").concat(texName, "Shape[2], 1));\n        float texC = float(depth2);\n        vec2 uv = (vec2(texC, texR) + halfCR) /\n                  vec2(").concat(texName, "TexShape[1], ").concat(texName, "TexShape[0]);\n        return sampleTexture(").concat(texName, ", uv);\n      }\n    ");
	    }
	    return "\n      float ".concat(funcName, "(int row, int col, int depth, int depth2) {\n        float texR = dot(vec3(row, col, depth),\n                         vec3(").concat(shape[1] * shape[2], ", ").concat(shape[2], ", 1));\n        float texC = float(depth2);\n        vec2 uv = (vec2(texC, texR) + halfCR) /\n                  vec2(").concat(texNumC, ".0, ").concat(texNumR, ".0);\n        return sampleTexture(").concat(texName, ", uv);\n      }\n    ");
	  }
	  var offset = getFlatOffsetUniformName(texName);
	  if (enableShapeUniforms) {
	    return "\n    float ".concat(funcName, "(int row, int col, int depth, int depth2) {\n      // Explicitly use integer operations as dot() only works on floats.\n      ").concat(stride2Str, "\n      ").concat(stride1Str, "\n      ").concat(stride0Str, "\n      int index = row * stride0 + col * stride1 +\n          depth * stride2 + depth2;\n      vec2 uv = uvFromFlat(").concat(texName, "TexShape[0], ").concat(texName, "TexShape[1], index + ").concat(offset, ");\n      return sampleTexture(").concat(texName, ", uv);\n    }\n  ");
	  }
	  return "\n    float ".concat(funcName, "(int row, int col, int depth, int depth2) {\n      // Explicitly use integer operations as dot() only works on floats.\n      int index = row * ").concat(stride0, " + col * ").concat(stride1, " +\n          depth * ").concat(stride2, " + depth2;\n      vec2 uv = uvFromFlat(").concat(texNumR, ", ").concat(texNumC, ", index + ").concat(offset, ");\n      return sampleTexture(").concat(texName, ", uv);\n    }\n  ");
	}
	function getSampler5D(inputInfo) {
	  var shape = inputInfo.shapeInfo.logicalShape;
	  var texName = inputInfo.name;
	  var funcName = 'get' + texName.charAt(0).toUpperCase() + texName.slice(1);
	  var stride3 = shape[4];
	  var stride2 = shape[3] * stride3;
	  var stride1 = shape[2] * stride2;
	  var stride0 = shape[1] * stride1;
	  var _util$squeezeShape4 = squeezeShape(shape),
	    newShape = _util$squeezeShape4.newShape,
	    keptDims = _util$squeezeShape4.keptDims;
	  if (newShape.length < shape.length) {
	    var newInputInfo = squeezeInputInfo(inputInfo, newShape);
	    var params = ['row', 'col', 'depth', 'depth2', 'depth3'];
	    return "\n      ".concat(getSamplerFromInInfo(newInputInfo), "\n      float ").concat(funcName, "(int row, int col, int depth, int depth2, int depth3) {\n        return ").concat(funcName, "(").concat(getSqueezedParams(params, keptDims), ");\n      }\n    ");
	  }
	  if (inputInfo.shapeInfo.isUniform) {
	    // Uniform arrays will be less than 65505 (no risk of float16 overflow).
	    return "\n      float ".concat(funcName, "(int row, int col, int depth, int depth2, int depth3) {\n        float index = dot(\n          vec4(row, col, depth, depth2),\n          vec4(").concat(stride0, ", ").concat(stride1, ", ").concat(stride2, ", ").concat(stride3, ")) +\n          depth3;\n        ").concat(getUniformSampler(inputInfo), "\n      }\n    ");
	  }
	  var flatOffset = inputInfo.shapeInfo.flatOffset;
	  var texShape = inputInfo.shapeInfo.texShape;
	  var texNumR = texShape[0];
	  var texNumC = texShape[1];
	  if (texNumC === stride0 && flatOffset == null) {
	    // texC is used directly as physical (no risk of float16 overflow).
	    return "\n      float ".concat(funcName, "(int row, int col, int depth, int depth2, int depth3) {\n        int texR = row;\n        float texC = dot(vec4(col, depth, depth2, depth3),\n                         vec4(").concat(stride1, ", ").concat(stride2, ", ").concat(stride3, ", 1));\n        vec2 uv = (vec2(texC, texR) + halfCR) /\n                   vec2(").concat(texNumC, ".0, ").concat(texNumR, ".0);\n        return sampleTexture(").concat(texName, ", uv);\n      }\n    ");
	  }
	  if (texNumC === stride3 && flatOffset == null) {
	    // texR is used directly as physical (no risk of float16 overflow).
	    return "\n      float ".concat(funcName, "(int row, int col, int depth, int depth2, int depth3) {\n        float texR = dot(\n          vec4(row, col, depth, depth2),\n          vec4(").concat(shape[1] * shape[2] * shape[3], ",\n               ").concat(shape[2] * shape[3], ", ").concat(shape[3], ", 1));\n        int texC = depth3;\n        vec2 uv = (vec2(texC, texR) + halfCR) /\n                  vec2(").concat(texNumC, ".0, ").concat(texNumR, ".0);\n        return sampleTexture(").concat(texName, ", uv);\n      }\n    ");
	  }
	  var offset = getFlatOffsetUniformName(texName);
	  return "\n    float ".concat(funcName, "(int row, int col, int depth, int depth2, int depth3) {\n      // Explicitly use integer operations as dot() only works on floats.\n      int index = row * ").concat(stride0, " + col * ").concat(stride1, " + depth * ").concat(stride2, " +\n          depth2 * ").concat(stride3, " + depth3 + ").concat(offset, ";\n      vec2 uv = uvFromFlat(").concat(texNumR, ", ").concat(texNumC, ", index);\n      return sampleTexture(").concat(texName, ", uv);\n    }\n  ");
	}
	function getSampler6D(inputInfo) {
	  var shape = inputInfo.shapeInfo.logicalShape;
	  var texName = inputInfo.name;
	  var funcName = 'get' + texName.charAt(0).toUpperCase() + texName.slice(1);
	  var _util$squeezeShape5 = squeezeShape(shape),
	    newShape = _util$squeezeShape5.newShape,
	    keptDims = _util$squeezeShape5.keptDims;
	  if (newShape.length < shape.length) {
	    var newInputInfo = squeezeInputInfo(inputInfo, newShape);
	    var params = ['row', 'col', 'depth', 'depth2', 'depth3', 'depth4'];
	    return "\n      ".concat(getSamplerFromInInfo(newInputInfo), "\n      float ").concat(funcName, "(int row, int col, int depth,\n                    int depth2, int depth3, int depth4) {\n        return ").concat(funcName, "(").concat(getSqueezedParams(params, keptDims), ");\n      }\n    ");
	  }
	  var stride4 = shape[5];
	  var stride3 = shape[4] * stride4;
	  var stride2 = shape[3] * stride3;
	  var stride1 = shape[2] * stride2;
	  var stride0 = shape[1] * stride1;
	  if (inputInfo.shapeInfo.isUniform) {
	    // Uniform arrays will be less than 65505 (no risk of float16 overflow).
	    return "\n      float ".concat(funcName, "(int row, int col, int depth,\n                  int depth2, int depth3, int depth4) {\n        int index = round(dot(\n          vec4(row, col, depth, depth2),\n          vec4(").concat(stride0, ", ").concat(stride1, ", ").concat(stride2, ", ").concat(stride3, ")) +\n          dot(\n            vec2(depth3, depth4),\n            vec2(").concat(stride4, ", 1)));\n        ").concat(getUniformSampler(inputInfo), "\n      }\n    ");
	  }
	  var flatOffset = inputInfo.shapeInfo.flatOffset;
	  var texShape = inputInfo.shapeInfo.texShape;
	  var texNumR = texShape[0];
	  var texNumC = texShape[1];
	  if (texNumC === stride0 && flatOffset == null) {
	    // texC is used directly as physical (no risk of float16 overflow).
	    return "\n      float ".concat(funcName, "(int row, int col, int depth,\n                    int depth2, int depth3, int depth4) {\n        int texR = row;\n        float texC = dot(vec4(col, depth, depth2, depth3),\n          vec4(").concat(stride1, ", ").concat(stride2, ", ").concat(stride3, ", ").concat(stride4, ")) +\n               float(depth4);\n        vec2 uv = (vec2(texC, texR) + halfCR) /\n                   vec2(").concat(texNumC, ".0, ").concat(texNumR, ".0);\n        return sampleTexture(").concat(texName, ", uv);\n      }\n    ");
	  }
	  if (texNumC === stride4 && flatOffset == null) {
	    // texR is used directly as physical (no risk of float16 overflow).
	    return "\n      float ".concat(funcName, "(int row, int col, int depth,\n                    int depth2, int depth3, int depth4) {\n        float texR = dot(vec4(row, col, depth, depth2),\n          vec4(").concat(shape[1] * shape[2] * shape[3] * shape[4], ",\n               ").concat(shape[2] * shape[3] * shape[4], ",\n               ").concat(shape[3] * shape[4], ",\n               ").concat(shape[4], ")) + float(depth3);\n        int texC = depth4;\n        vec2 uv = (vec2(texC, texR) + halfCR) /\n                  vec2(").concat(texNumC, ".0, ").concat(texNumR, ".0);\n        return sampleTexture(").concat(texName, ", uv);\n      }\n    ");
	  }
	  var offset = getFlatOffsetUniformName(texName);
	  return "\n    float ".concat(funcName, "(int row, int col, int depth,\n                  int depth2, int depth3, int depth4) {\n      // Explicitly use integer operations as dot() only works on floats.\n      int index = row * ").concat(stride0, " + col * ").concat(stride1, " + depth * ").concat(stride2, " +\n          depth2 * ").concat(stride3, " + depth3 * ").concat(stride4, " + depth4 + ").concat(offset, ";\n      vec2 uv = uvFromFlat(").concat(texNumR, ", ").concat(texNumC, ", index);\n      return sampleTexture(").concat(texName, ", uv);\n    }\n  ");
	}
	function getUniformSampler(inputInfo) {
	  var texName = inputInfo.name;
	  var inSize = sizeFromShape(inputInfo.shapeInfo.logicalShape);
	  if (inSize < 2) {
	    return "return ".concat(texName, ";");
	  }
	  return "\n    for (int i = 0; i < ".concat(inSize, "; i++) {\n      if (i == index) {\n        return ").concat(texName, "[i];\n      }\n    }\n  ");
	}
	function getPackedSamplerAtOutputCoords(inputInfo, outShapeInfo) {
	  var texName = inputInfo.name;
	  var texFuncSnippet = texName.charAt(0).toUpperCase() + texName.slice(1);
	  var funcName = 'get' + texFuncSnippet + 'AtOutCoords';
	  var inRank = inputInfo.shapeInfo.logicalShape.length;
	  var outRank = outShapeInfo.logicalShape.length;
	  var broadcastDims = getBroadcastDims(inputInfo.shapeInfo.logicalShape, outShapeInfo.logicalShape);
	  var type = getCoordsDataType(outRank);
	  var rankDiff = outRank - inRank;
	  var coordsSnippet;
	  var fields = ['x', 'y', 'z', 'w', 'u', 'v'];
	  if (inRank === 0) {
	    coordsSnippet = '';
	  } else if (outRank < 2 && broadcastDims.length >= 1) {
	    coordsSnippet = 'coords = 0;';
	  } else {
	    coordsSnippet = broadcastDims.map(function (d) {
	      return "coords.".concat(fields[d + rankDiff], " = 0;");
	    }).join('\n');
	  }
	  var unpackedCoordsSnippet = '';
	  if (outRank < 2 && inRank > 0) {
	    unpackedCoordsSnippet = 'coords';
	  } else {
	    unpackedCoordsSnippet = inputInfo.shapeInfo.logicalShape.map(function (s, i) {
	      return "coords.".concat(fields[i + rankDiff]);
	    }).join(', ');
	  }
	  var output = "return outputValue;";
	  var inSize = sizeFromShape(inputInfo.shapeInfo.logicalShape);
	  var isInputScalar = inSize === 1;
	  var outSize = sizeFromShape(outShapeInfo.logicalShape);
	  var isOutputScalar = outSize === 1;
	  if (inRank === 1 && !isInputScalar && !isOutputScalar) {
	    output = "\n      return vec4(outputValue.xy, outputValue.xy);\n    ";
	  } else if (isInputScalar && !isOutputScalar) {
	    if (outRank === 1) {
	      output = "\n        return vec4(outputValue.x, outputValue.x, 0., 0.);\n      ";
	    } else {
	      output = "\n        return vec4(outputValue.x);\n      ";
	    }
	  } else if (broadcastDims.length) {
	    var rows = inRank - 2;
	    var cols = inRank - 1;
	    if (broadcastDims.indexOf(rows) > -1 && broadcastDims.indexOf(cols) > -1) {
	      output = "return vec4(outputValue.x);";
	    } else if (broadcastDims.indexOf(rows) > -1) {
	      output = "return vec4(outputValue.x, outputValue.y, " + "outputValue.x, outputValue.y);";
	    } else if (broadcastDims.indexOf(cols) > -1) {
	      output = "return vec4(outputValue.xx, outputValue.zz);";
	    }
	  }
	  return "\n    vec4 ".concat(funcName, "() {\n      ").concat(type, " coords = getOutputCoords();\n      ").concat(coordsSnippet, "\n      vec4 outputValue = get").concat(texFuncSnippet, "(").concat(unpackedCoordsSnippet, ");\n      ").concat(output, "\n    }\n  ");
	}
	function getSamplerAtOutputCoords(inputInfo, outShapeInfo) {
	  var texName = inputInfo.name;
	  var texFuncSnippet = texName.charAt(0).toUpperCase() + texName.slice(1);
	  var funcName = 'get' + texFuncSnippet + 'AtOutCoords';
	  var outTexShape = outShapeInfo.texShape;
	  var inTexShape = inputInfo.shapeInfo.texShape;
	  var inRank = inputInfo.shapeInfo.logicalShape.length;
	  var outRank = outShapeInfo.logicalShape.length;
	  if (!inputInfo.shapeInfo.isUniform && inRank === outRank && inputInfo.shapeInfo.flatOffset == null && arraysEqual(inTexShape, outTexShape)) {
	    return "\n      float ".concat(funcName, "() {\n        return sampleTexture(").concat(texName, ", resultUV);\n      }\n    ");
	  }
	  var type = getCoordsDataType(outRank);
	  var broadcastDims = getBroadcastDims(inputInfo.shapeInfo.logicalShape, outShapeInfo.logicalShape);
	  var rankDiff = outRank - inRank;
	  var coordsSnippet;
	  var fields = ['x', 'y', 'z', 'w', 'u', 'v'];
	  if (inRank === 0) {
	    coordsSnippet = '';
	  } else if (outRank < 2 && broadcastDims.length >= 1) {
	    coordsSnippet = 'coords = 0;';
	  } else {
	    coordsSnippet = broadcastDims.map(function (d) {
	      return "coords.".concat(fields[d + rankDiff], " = 0;");
	    }).join('\n');
	  }
	  var unpackedCoordsSnippet = '';
	  if (outRank < 2 && inRank > 0) {
	    unpackedCoordsSnippet = 'coords';
	  } else {
	    unpackedCoordsSnippet = inputInfo.shapeInfo.logicalShape.map(function (s, i) {
	      return "coords.".concat(fields[i + rankDiff]);
	    }).join(', ');
	  }
	  return "\n    float ".concat(funcName, "() {\n      ").concat(type, " coords = getOutputCoords();\n      ").concat(coordsSnippet, "\n      return get").concat(texFuncSnippet, "(").concat(unpackedCoordsSnippet, ");\n    }\n  ");
	}
	function getCoordsDataType(rank) {
	  if (rank <= 1) {
	    return 'int';
	  } else if (rank === 2) {
	    return 'ivec2';
	  } else if (rank === 3) {
	    return 'ivec3';
	  } else if (rank === 4) {
	    return 'ivec4';
	  } else if (rank === 5) {
	    return 'ivec5';
	  } else if (rank === 6) {
	    return 'ivec6';
	  } else {
	    throw Error("GPU for rank ".concat(rank, " is not yet supported"));
	  }
	}
	function getUniformInfoFromShape(isPacked, shape, texShape) {
	  var _util$squeezeShape6 = squeezeShape(shape),
	    newShape = _util$squeezeShape6.newShape,
	    keptDims = _util$squeezeShape6.keptDims;
	  var rank = shape.length;
	  var useSqueezePackedShape = isPacked && rank === 3 && shape[0] === 1;
	  var squeezeShape$1 = useSqueezePackedShape ? shape.slice(1) : newShape;
	  var useSqueezeShape = !isPacked && rank > 1 && !arraysEqual(shape, texShape) && newShape.length < rank || useSqueezePackedShape;
	  var uniformShape = useSqueezeShape ? squeezeShape$1 : shape;
	  return {
	    useSqueezeShape: useSqueezeShape,
	    uniformShape: uniformShape,
	    keptDims: keptDims
	  };
	}
	/** Returns a new input info (a copy) that has a squeezed logical shape. */
	function squeezeInputInfo(inInfo, squeezedShape) {
	  // Deep copy.
	  var newInputInfo = JSON.parse(JSON.stringify(inInfo));
	  newInputInfo.shapeInfo.logicalShape = squeezedShape;
	  return newInputInfo;
	}
	function getSqueezedParams(params, keptDims) {
	  return keptDims.map(function (d) {
	    return params[d];
	  }).join(', ');
	}

	function compileProgram(gpgpu, program, inputs, output) {
	  var inputInfos = inputs.map(function (input, i) {
	    var shapeInfo = {
	      logicalShape: input.shape,
	      texShape: input.isUniform ? null : input.texData.texShape,
	      isUniform: input.isUniform,
	      isPacked: input.isUniform ? false : input.texData.isPacked,
	      flatOffset: null
	    };
	    if (input.texData != null && input.texData.slice != null && input.texData.slice.flatOffset > 0) {
	      shapeInfo.flatOffset = input.texData.slice.flatOffset;
	    }
	    return {
	      name: program.variableNames[i],
	      shapeInfo: shapeInfo
	    };
	  });
	  var inShapeInfos = inputInfos.map(function (x) {
	    return x.shapeInfo;
	  });
	  var outShapeInfo = {
	    logicalShape: output.shape,
	    texShape: output.texData.texShape,
	    isUniform: false,
	    isPacked: output.texData.isPacked,
	    flatOffset: null
	  };
	  var source = makeShader(inputInfos, outShapeInfo, program);
	  var fragmentShader = createFragmentShader(gpgpu.gl, source);
	  var webGLProgram = gpgpu.createProgram(fragmentShader);
	  if (!env().get('ENGINE_COMPILE_ONLY')) {
	    gpgpu.buildVao(webGLProgram);
	    return Object.assign({
	      program: program,
	      fragmentShader: fragmentShader,
	      source: source,
	      webGLProgram: webGLProgram,
	      inShapeInfos: inShapeInfos,
	      outShapeInfo: outShapeInfo
	    }, getUniformLocations(gpgpu, program, webGLProgram));
	  } else {
	    return {
	      program: program,
	      fragmentShader: fragmentShader,
	      source: source,
	      webGLProgram: webGLProgram,
	      inShapeInfos: inShapeInfos,
	      outShapeInfo: outShapeInfo,
	      variablesLocations: null,
	      customUniformLocations: null,
	      infLoc: null,
	      nanLoc: null,
	      outShapeLocation: null,
	      outShapeStridesLocation: null,
	      outTexShapeLocation: null
	    };
	  }
	}
	function getUniformLocations(gpgpu, program, webGLProgram) {
	  var variablesLocations = [];
	  var customUniformLocations = [];
	  var outShapeLocation;
	  var outTexShapeLocation;
	  var outShapeStridesLocation;
	  var infLoc = null;
	  var nanLoc = null;
	  // Add special uniforms (NAN, INFINITY)
	  nanLoc = gpgpu.getUniformLocation(webGLProgram, 'NAN', false);
	  if (env().getNumber('WEBGL_VERSION') === 1) {
	    infLoc = gpgpu.getUniformLocation(webGLProgram, 'INFINITY', false);
	  }
	  // Add user-defined uniforms
	  var shouldThrow = false;
	  var _iterator = _createForOfIteratorHelper(program.variableNames),
	    _step;
	  try {
	    for (_iterator.s(); !(_step = _iterator.n()).done;) {
	      var varName = _step.value;
	      var varLocs = {
	        name: varName,
	        uniform: gpgpu.getUniformLocation(webGLProgram, varName, shouldThrow),
	        offset: gpgpu.getUniformLocation(webGLProgram, "offset".concat(varName), shouldThrow)
	      };
	      if (program.enableShapeUniforms) {
	        varLocs.shape = gpgpu.getUniformLocation(webGLProgram, "".concat(varName, "Shape"), shouldThrow);
	        varLocs.texShape = gpgpu.getUniformLocation(webGLProgram, "".concat(varName, "TexShape"), shouldThrow);
	      }
	      variablesLocations.push(varLocs);
	    }
	  } catch (err) {
	    _iterator.e(err);
	  } finally {
	    _iterator.f();
	  }
	  if (program.enableShapeUniforms) {
	    outShapeLocation = gpgpu.getUniformLocation(webGLProgram, 'outShape', shouldThrow);
	    outShapeStridesLocation = gpgpu.getUniformLocation(webGLProgram, 'outShapeStrides', shouldThrow);
	    outTexShapeLocation = gpgpu.getUniformLocation(webGLProgram, 'outTexShape', shouldThrow);
	  }
	  if (program.customUniforms) {
	    var _iterator2 = _createForOfIteratorHelper(program.customUniforms),
	      _step2;
	    try {
	      for (_iterator2.s(); !(_step2 = _iterator2.n()).done;) {
	        var d = _step2.value;
	        customUniformLocations.push(gpgpu.getUniformLocation(webGLProgram, d.name, shouldThrow));
	      }
	    } catch (err) {
	      _iterator2.e(err);
	    } finally {
	      _iterator2.f();
	    }
	  }
	  return {
	    variablesLocations: variablesLocations,
	    customUniformLocations: customUniformLocations,
	    infLoc: infLoc,
	    nanLoc: nanLoc,
	    outShapeLocation: outShapeLocation,
	    outShapeStridesLocation: outShapeStridesLocation,
	    outTexShapeLocation: outTexShapeLocation
	  };
	}
	function validateBinaryAndProgram(shapeInfos, inputs) {
	  if (shapeInfos.length !== inputs.length) {
	    throw Error("Binary was compiled with ".concat(shapeInfos.length, " inputs, but ") + "was executed with ".concat(inputs.length, " inputs"));
	  }
	  shapeInfos.forEach(function (s, i) {
	    var shapeA = s.logicalShape;
	    var input = inputs[i];
	    var shapeB = input.shape;
	    if (!arraysEqual(shapeA, shapeB)) {
	      throw Error("Binary was compiled with different shapes than " + "the current args. Shapes ".concat(shapeA, " and ").concat(shapeB, " must match"));
	    }
	    // The input is uploaded as uniform.
	    if (s.isUniform && input.isUniform) {
	      return;
	    }
	    var texShapeA = s.texShape;
	    var texShapeB = input.isUniform ? null : input.texData.texShape;
	    if (!arraysEqual(texShapeA, texShapeB)) {
	      throw Error("Binary was compiled with different texture shapes than the" + " current args. Shape ".concat(texShapeA, " and ").concat(texShapeB, " must match"));
	    }
	  });
	}
	function runProgram(gpgpu, binary, inputs, output, customUniformValues) {
	  if (!binary.program.enableShapeUniforms) {
	    validateBinaryAndProgram(binary.inShapeInfos, inputs);
	    validateBinaryAndProgram([binary.outShapeInfo], [output]);
	  }
	  var outTex = output.texData.texture;
	  var outTexShape = output.texData.texShape;
	  if (output.texData.isPacked) {
	    gpgpu.setOutputPackedMatrixTexture(outTex.texture, outTexShape[0], outTexShape[1]);
	  } else {
	    gpgpu.setOutputMatrixTexture(outTex.texture, outTexShape[0], outTexShape[1]);
	  }
	  gpgpu.setProgram(binary.webGLProgram);
	  gpgpu.bindVertexArray(binary.webGLProgram.vao);
	  // Set special uniforms (NAN, INFINITY)
	  if (env().getNumber('WEBGL_VERSION') === 1) {
	    if (binary.infLoc !== null) {
	      gpgpu.gl.uniform1f(binary.infLoc, Infinity);
	    }
	  }
	  if (binary.nanLoc !== null) {
	    gpgpu.gl.uniform1f(binary.nanLoc, NaN);
	  }
	  // Set user-defined inputs
	  for (var i = 0; i < inputs.length; ++i) {
	    var input = inputs[i];
	    var _binary$variablesLoca = binary.variablesLocations[i],
	      varLoc = _binary$variablesLoca.uniform,
	      varOffsetLoc = _binary$variablesLoca.offset,
	      varShapeLoc = _binary$variablesLoca.shape,
	      varTexShapeLoc = _binary$variablesLoca.texShape;
	    if (varShapeLoc) {
	      var _shader_compiler$getU = getUniformInfoFromShape(binary.program.packedInputs, input.shape, input.texData.texShape),
	        uniformShape = _shader_compiler$getU.uniformShape;
	      switch (uniformShape.length) {
	        case 1:
	          gpgpu.gl.uniform1iv(varShapeLoc, new Int32Array(uniformShape));
	          break;
	        case 2:
	          gpgpu.gl.uniform2iv(varShapeLoc, new Int32Array(uniformShape));
	          break;
	        case 3:
	          gpgpu.gl.uniform3iv(varShapeLoc, new Int32Array(uniformShape));
	          break;
	        case 4:
	          gpgpu.gl.uniform4iv(varShapeLoc, new Int32Array(uniformShape));
	          break;
	        default:
	          break;
	      }
	    }
	    if (varTexShapeLoc) {
	      gpgpu.gl.uniform2i(varTexShapeLoc, input.texData.texShape[0], input.texData.texShape[1]);
	    }
	    if (varLoc == null) {
	      // The compiler inferred that this variable is not used in this shader.
	      continue;
	    }
	    if (input.isUniform) {
	      // Upload the values of the tensor as uniform.
	      if (sizeFromShape(input.shape) < 2) {
	        gpgpu.gl.uniform1f(varLoc, input.uniformValues[0]);
	      } else {
	        var vals = input.uniformValues;
	        if (!(vals instanceof Float32Array)) {
	          vals = new Float32Array(vals);
	        }
	        gpgpu.gl.uniform1fv(varLoc, vals);
	      }
	      continue;
	    }
	    // If the input was sliced, upload the flat offset index.
	    if (input.texData.slice != null && varOffsetLoc != null) {
	      gpgpu.gl.uniform1i(varOffsetLoc, input.texData.slice.flatOffset);
	    }
	    gpgpu.setInputMatrixTexture(input.texData.texture.texture, varLoc, i);
	  }
	  var outShapeLoc = binary.outShapeLocation;
	  if (outShapeLoc) {
	    switch (output.shape.length) {
	      case 1:
	        gpgpu.gl.uniform1iv(outShapeLoc, new Int32Array(output.shape));
	        break;
	      case 2:
	        gpgpu.gl.uniform2iv(outShapeLoc, new Int32Array(output.shape));
	        break;
	      case 3:
	        gpgpu.gl.uniform3iv(outShapeLoc, new Int32Array(output.shape));
	        break;
	      case 4:
	        gpgpu.gl.uniform4iv(outShapeLoc, new Int32Array(output.shape));
	        break;
	      default:
	        break;
	    }
	  }
	  if (binary.outShapeStridesLocation) {
	    var strides = computeStrides(output.shape);
	    switch (output.shape.length) {
	      case 2:
	        gpgpu.gl.uniform1iv(binary.outShapeStridesLocation, new Int32Array(strides));
	        break;
	      case 3:
	        gpgpu.gl.uniform2iv(binary.outShapeStridesLocation, new Int32Array(strides));
	        break;
	      case 4:
	        gpgpu.gl.uniform3iv(binary.outShapeStridesLocation, new Int32Array(strides));
	        break;
	      default:
	        break;
	    }
	  }
	  if (binary.outTexShapeLocation) {
	    gpgpu.gl.uniform2i(binary.outTexShapeLocation, output.texData.texShape[0], output.texData.texShape[1]);
	  }
	  if (binary.program.customUniforms && customUniformValues) {
	    for (var _i = 0; _i < binary.program.customUniforms.length; ++_i) {
	      var d = binary.program.customUniforms[_i];
	      var customLoc = binary.customUniformLocations[_i];
	      var customValue = customUniformValues[_i];
	      if (d.type === 'float') {
	        gpgpu.gl.uniform1fv(customLoc, customValue);
	      } else if (d.type === 'vec2') {
	        gpgpu.gl.uniform2fv(customLoc, customValue);
	      } else if (d.type === 'vec3') {
	        gpgpu.gl.uniform3fv(customLoc, customValue);
	      } else if (d.type === 'vec4') {
	        gpgpu.gl.uniform4fv(customLoc, customValue);
	      } else if (d.type === 'int') {
	        gpgpu.gl.uniform1iv(customLoc, customValue);
	      } else if (d.type === 'ivec2') {
	        gpgpu.gl.uniform2iv(customLoc, customValue);
	      } else if (d.type === 'ivec3') {
	        gpgpu.gl.uniform3iv(customLoc, customValue);
	      } else if (d.type === 'ivec4') {
	        gpgpu.gl.uniform4iv(customLoc, customValue);
	      } else {
	        throw Error("uniform type ".concat(d.type, " is not supported yet."));
	      }
	    }
	  }
	  gpgpu.executeProgram();
	}
	function makeShaderKey(program, inputs, output) {
	  var keyInputs = '';
	  inputs.concat(output).forEach(function (x) {
	    var hasOffset = x.texData != null && x.texData.slice != null && x.texData.slice.flatOffset > 0;
	    // TODO: Remove the condition of !x.isUniform.
	    if (program.enableShapeUniforms && !x.isUniform) {
	      var xTexShape = x.texData.texShape;
	      var _shader_compiler$getU2 = getUniformInfoFromShape(program.packedInputs, x.shape, xTexShape),
	        useSqueezeShape = _shader_compiler$getU2.useSqueezeShape,
	        uniformShape = _shader_compiler$getU2.uniformShape,
	        keptDims = _shader_compiler$getU2.keptDims;
	      var rank1 = '',
	        rank2 = '',
	        rank34 = '';
	      if (uniformShape.length === 1 && program.packedInputs) {
	        var packedTexShape = [Math.ceil(xTexShape[0] / 2), Math.ceil(xTexShape[1] / 2)];
	        rank1 = "".concat(packedTexShape[0] > 1, "_").concat(packedTexShape[1] > 1);
	      } else if (uniformShape.length === 2 && !program.packedInputs) {
	        rank2 = "".concat(uniformShape[0] > 1, "_").concat(uniformShape[1] > 1);
	      } else if (uniformShape.length > 2 && !program.packedInputs) {
	        var strides = computeStrides(uniformShape);
	        rank34 = "".concat(strides[0] === xTexShape[1], "_").concat(strides[strides.length - 1] === xTexShape[1]);
	      }
	      var xRank = x.shape.length;
	      var isLogicalShapTexShapeEqual = uniformShape.length === 2 && arraysEqual(x.shape, xTexShape);
	      var isScalar = sizeFromShape(x.shape) === 1;
	      var broadcastDims = getBroadcastDims$1(x.shape, output.shape);
	      var isInOutTexShapeEqual = !program.packedInputs && xRank === output.shape.length && arraysEqual(xTexShape, output.texData.texShape);
	      var isTexShapeGreaterThanOne = program.packedInputs || uniformShape.length > 2 ? '' : "".concat(xTexShape[0] > 1, "_").concat(xTexShape[1] > 1);
	      // These key components are needed due to shader_compiler is embedding
	      // them in the shader.
	      // |xRank| is used to determine the coords length. See
	      // get[Packed]SamplerAtOutputCoords.
	      // |isInOutTexShapeEqual| is used to determine whether going to an
	      // optimization path in getSamplerAtOutputCoords.
	      // |useSqueezeShape| is extracted from squeezeInputInfo of
	      // getSampler[2|3|4]D/getPackedSampler3D.
	      // |isScalar| is extracted from isInputScalar/isOutputScalar in
	      // getPackedSamplerAtOutputCoords.
	      // |broadcastDims| is extracted from get[Packed]SamplerAtOutputCoords.
	      // |isLogicalShapTexShapeEqual| is used in
	      // getOutput[Packed]2DCoords/get[Packed]Sampler2D.
	      // |rank1| is used in getOutputPacked1DCoords.
	      // |rank2| is used in getOutput2DCoords.
	      // |rank34| is used in getSampler3D/getSampler4D.
	      // |isTexShapeGreaterThanOne| are used in
	      // getSampler[Scalar|1D|2D]/getOutput1DCoords.
	      keyInputs += "".concat(xRank, "_").concat(isInOutTexShapeEqual, "_").concat(useSqueezeShape ? keptDims : '', "_").concat(uniformShape.length, "_").concat(isScalar, "_").concat(broadcastDims, "_").concat(isLogicalShapTexShapeEqual, "_").concat(rank1, "_").concat(rank2, "_").concat(rank34, "_").concat(isTexShapeGreaterThanOne, "_").concat(hasOffset);
	    } else {
	      var texShape = x.isUniform ? 'uniform' : x.texData.texShape;
	      keyInputs += "".concat(x.shape, "_").concat(texShape, "_").concat(hasOffset);
	    }
	  });
	  var keyUserCode = program.userCode;
	  var key = program.constructor.name;
	  // Fast string concat. See https://jsperf.com/string-concatenation/14.
	  key += '_' + keyInputs + '_' + keyUserCode + "".concat(env().getNumber('WEBGL_VERSION'));
	  return key;
	}
	function useShapeUniforms(rank) {
	  // TODO: Remove the limitaion of rank <= 4.
	  return env().getBool('WEBGL_USE_SHAPES_UNIFORMS') && rank <= 4;
	}

	var DecodeMatrixProgram = /*#__PURE__*/_createClass(function DecodeMatrixProgram(outputShape) {
	  _classCallCheck(this, DecodeMatrixProgram);
	  this.variableNames = ['A'];
	  this.packedInputs = false;
	  this.packedOutput = true;
	  this.outPackingScheme = PackingScheme.DENSE;
	  this.customUniforms = [{
	    name: 'texShape',
	    type: 'ivec2'
	  }];
	  var glsl = getGlslDifferences();
	  this.outputShape = outputShape;
	  this.enableShapeUniforms = useShapeUniforms(this.outputShape.length);
	  this.userCode = "\n      ivec3 outCoordsFromFlatIndex(int index) {\n        ".concat(this.enableShapeUniforms ? getOutputLogicalCoordinatesFromFlatIndexByUniform(['r', 'c', 'd'], outputShape) : getLogicalCoordinatesFromFlatIndex(['r', 'c', 'd'], outputShape), "\n        return ivec3(r, c, d);\n      }\n\n      void main() {\n        ivec2 resTexRC = ivec2(resultUV.yx * vec2(texShape[0], texShape[1]));\n        int index = 4 * (resTexRC.x * texShape[1] + resTexRC.y);\n\n        vec4 result = vec4(0.);\n\n        for (int i=0; i<4; i++) {\n          int flatIndex = index + i;\n          ivec3 rc = outCoordsFromFlatIndex(flatIndex);\n          result[i] = getA(rc.x, rc.y, rc.z);\n        }\n\n        ").concat(glsl.output, " = result;\n      }\n    ");
	});

	var DecodeMatrixPackedProgram = /*#__PURE__*/_createClass(function DecodeMatrixPackedProgram(outputShape) {
	  _classCallCheck(this, DecodeMatrixPackedProgram);
	  this.variableNames = ['A'];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.outPackingScheme = PackingScheme.DENSE;
	  this.customUniforms = [{
	    name: 'texShape',
	    type: 'ivec2'
	  }];
	  var glsl = getGlslDifferences();
	  this.outputShape = outputShape;
	  this.enableShapeUniforms = useShapeUniforms(this.outputShape.length);
	  this.userCode = "\n      ivec3 outCoordsFromFlatIndex(int index) {\n        ".concat(this.enableShapeUniforms ? getOutputLogicalCoordinatesFromFlatIndexByUniform(['r', 'c', 'd'], outputShape) : getLogicalCoordinatesFromFlatIndex(['r', 'c', 'd'], outputShape), "\n        return ivec3(r, c, d);\n      }\n\n      void main() {\n        ivec2 resTexRC = ivec2(resultUV.yx * vec2(texShape[0], texShape[1]));\n        int index = 4 * (resTexRC.x * texShape[1] + resTexRC.y);\n\n        vec4 result = vec4(0.);\n\n        for (int i=0; i<4; i++) {\n          int flatIndex = index + i;\n          ivec3 rc = outCoordsFromFlatIndex(flatIndex);\n          result[i] = getChannel(getA(rc.x, rc.y, rc.z), vec2(rc.y, rc.z));\n        }\n\n        ").concat(glsl.output, " = result;\n      }\n    ");
	});

	var EncodeFloatProgram = /*#__PURE__*/_createClass(function EncodeFloatProgram(outputShape) {
	  _classCallCheck(this, EncodeFloatProgram);
	  this.variableNames = ['A'];
	  this.outTexUsage = TextureUsage.DOWNLOAD;
	  var glsl = getGlslDifferences();
	  this.outputShape = outputShape;
	  this.userCode = "\n      ".concat(ENCODE_FLOAT_SNIPPET, "\n\n      void main() {\n        float x = getAAtOutCoords();\n        ").concat(glsl.output, " = encode_float(x);\n      }\n    ");
	});

	var EncodeFloatPackedProgram = /*#__PURE__*/_createClass(function EncodeFloatPackedProgram(outputShape) {
	  _classCallCheck(this, EncodeFloatPackedProgram);
	  this.variableNames = ['A'];
	  this.packedInputs = true;
	  this.packedOutput = false;
	  this.outTexUsage = TextureUsage.DOWNLOAD;
	  var glsl = getGlslDifferences();
	  this.outputShape = outputShape;
	  this.userCode = "\n      ".concat(ENCODE_FLOAT_SNIPPET, "\n\n      void main() {\n        ivec3 coords = getOutputCoords();\n        float x = getChannel(getAAtOutCoords(), vec2(coords.y, coords.z));\n        ").concat(glsl.output, " = encode_float(x);\n      }\n    ");
	});

	var CHANNEL_CHAR_TO_INDEX_MAP = {
	  'R': 0,
	  'G': 1,
	  'B': 2,
	  'A': 3
	};
	var EncodeMatrixProgram = /*#__PURE__*/_createClass(function EncodeMatrixProgram(outputShape) {
	  var inputIsUnsignedByte = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
	  var usedChannels = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'RGBA';
	  _classCallCheck(this, EncodeMatrixProgram);
	  this.variableNames = ['A'];
	  this.customUniforms = [{
	    name: 'texShape',
	    type: 'ivec2'
	  }];
	  var glsl = getGlslDifferences();
	  this.outputShape = outputShape;
	  this.enableShapeUniforms = useShapeUniforms(this.outputShape.length);
	  var output = "result";
	  if (inputIsUnsignedByte) {
	    output = "floor(result * 255. + 0.5)";
	  }
	  var mainLoop = '';
	  for (var usedChannelIndex = 0; usedChannelIndex < usedChannels.length; usedChannelIndex++) {
	    var curChannel = usedChannels[usedChannelIndex];
	    mainLoop += "\n          if(offset == ".concat(usedChannelIndex, ") {\n            result = values[").concat(CHANNEL_CHAR_TO_INDEX_MAP[curChannel], "];\n          }");
	  }
	  this.userCode = "\n      ".concat(this.enableShapeUniforms ? getFlatIndexFrom3DOutput() : getFlatIndexFrom3D(outputShape), "\n\n      void main() {\n        ivec3 coords = getOutputCoords();\n        int flatIndex = getFlatIndex(coords);\n        float result = 0.;\n        int offset = imod(flatIndex, ").concat(usedChannels.length, ");\n\n        flatIndex = idiv(flatIndex, ").concat(usedChannels.length, ", 1.);\n\n        int r = flatIndex / texShape[1];\n        if (r < texShape[0]) {\n          int c = imod(flatIndex, texShape[1]);\n          vec2 uv = (vec2(c, r) + halfCR) / vec2(texShape[1], texShape[0]);\n          vec4 values = ").concat(glsl.texture2D, "(A, uv);\n          ").concat(mainLoop, "\n        }\n        ").concat(glsl.output, " = vec4(").concat(output, ", 0., 0., 0.);\n      }\n    ");
	});

	/*
	This is how the shader encodes a tensor with shape = [2, 3, 5]
	(indices are [batch, row, col]).

	000|001   002|003   004|xxx   020|021   022|023   024|xxx
	-------   -------   -------   -------   -------   -------
	010|011   012|013   014|xxx   xxx|xxx   xxx|xxx   xxx|xxx

	100|101   102|103   104|xxx   120|121   122|123   124|xxx
	-------   -------   -------   -------   -------   -------
	110|111   112|113   114|xxx   xxx|xxx   xxx|xxx   xxx|xxx

	Single texels contain only values from the same batch, and from adjacent rows
	and columns.
	 */
	var EncodeMatrixPackedProgram = /*#__PURE__*/_createClass(function EncodeMatrixPackedProgram(outputShape) {
	  var inputIsUnsignedByte = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
	  _classCallCheck(this, EncodeMatrixPackedProgram);
	  this.variableNames = ['A'];
	  this.packedInputs = false;
	  this.packedOutput = true;
	  this.customUniforms = [{
	    name: 'texShape',
	    type: 'ivec2'
	  }];
	  var glsl = getGlslDifferences();
	  this.outputShape = outputShape;
	  this.enableShapeUniforms = useShapeUniforms(this.outputShape.length);
	  var mainLoop = '';
	  var output = 'result';
	  if (inputIsUnsignedByte) {
	    output = 'floor(result * 255. + 0.5)';
	  }
	  for (var row = 0; row <= 1; row++) {
	    for (var col = 0; col <= 1; col++) {
	      var channel = row * 2 + col;
	      mainLoop += "\n          localCoords = coords;\n          if(localCoords[2] + ".concat(col, " < ").concat(this.enableShapeUniforms ? 'outShape[2]' : "".concat(outputShape[2]), ") {\n          localCoords[2] += ").concat(col, ";\n          if (localCoords[1] + ").concat(row, " < ").concat(this.enableShapeUniforms ? 'outShape[1]' : "".concat(outputShape[1]), ") {\n            localCoords[1] += ").concat(row, ";\n\n            flatIndex = getFlatIndex(localCoords);\n            offset = imod(flatIndex, 4);\n\n            flatIndex = idiv(flatIndex, 4, 1.);\n\n            int r = flatIndex / texShape[1];\n            int c = imod(flatIndex, texShape[1]);\n            vec2 uv = (vec2(c, r) + halfCR) / vec2(texShape[1], texShape[0]);\n            values = ").concat(glsl.texture2D, "(A, uv);\n\n            if (offset == 0) {\n              result[").concat(channel, "] = values[0];\n            } else if (offset == 1) {\n              result[").concat(channel, "] = values[1];\n            } else if (offset == 2) {\n              result[").concat(channel, "] = values[2];\n            } else {\n              result[").concat(channel, "] = values[3];\n            }\n          }\n        }\n        ");
	    }
	  }
	  this.userCode = "\n        ".concat(this.enableShapeUniforms ? getFlatIndexFrom3DOutput() : getFlatIndexFrom3D(outputShape), "\n\n        void main() {\n          ivec3 coords = getOutputCoords();\n\n          vec4 result = vec4(0.);\n          int flatIndex, r, c, offset;\n          ivec3 localCoords;\n          vec2 uv;\n          vec4 values;\n\n          ").concat(mainLoop, "\n\n          ").concat(glsl.output, " = ").concat(output, ";\n        }\n    ");
	});

	function createVertexShader(gl) {
	  var glsl = getGlslDifferences();
	  var vertexShaderSource = "".concat(glsl.version, "\n    precision highp float;\n    ").concat(glsl.attribute, " vec3 clipSpacePos;\n    ").concat(glsl.attribute, " vec2 uv;\n    ").concat(glsl.varyingVs, " vec2 resultUV;\n\n    void main() {\n      gl_Position = vec4(clipSpacePos, 1);\n      resultUV = uv;\n    }");
	  return createVertexShader$1(gl, vertexShaderSource);
	}
	function createVertexBuffer(gl) {
	  // [x y z u v] * [upper-left, lower-left, upper-right, lower-right]
	  var vertexArray = new Float32Array([-1, 1, 0, 0, 1, -1, -1, 0, 0, 0, 1, 1, 0, 1, 1, 1, -1, 0, 1, 0]);
	  return createStaticVertexBuffer(gl, vertexArray);
	}
	function createIndexBuffer(gl) {
	  // OpenGL (and WebGL) have "CCW == front" winding
	  var triangleVertexIndices = new Uint16Array([0, 1, 2, 2, 1, 3]);
	  return createStaticIndexBuffer(gl, triangleVertexIndices);
	}
	function createAndConfigureTexture(gl, width, height, internalFormat, textureFormat, textureType) {
	  validateTextureSize(width, height);
	  var texture = createTexture(gl);
	  var tex2d = gl.TEXTURE_2D;
	  callAndCheck(gl, function () {
	    return gl.bindTexture(tex2d, texture);
	  });
	  callAndCheck(gl, function () {
	    return gl.texParameteri(tex2d, gl.TEXTURE_WRAP_S, gl.CLAMP_TO_EDGE);
	  });
	  callAndCheck(gl, function () {
	    return gl.texParameteri(tex2d, gl.TEXTURE_WRAP_T, gl.CLAMP_TO_EDGE);
	  });
	  callAndCheck(gl, function () {
	    return gl.texParameteri(tex2d, gl.TEXTURE_MIN_FILTER, gl.NEAREST);
	  });
	  callAndCheck(gl, function () {
	    return gl.texParameteri(tex2d, gl.TEXTURE_MAG_FILTER, gl.NEAREST);
	  });
	  if (env().getNumber('WEBGL_VERSION') === 1) {
	    callAndCheck(gl, function () {
	      return gl.texImage2D(tex2d, 0, internalFormat, width, height, 0, textureFormat, textureType, null);
	    });
	  } else {
	    callAndCheck(gl, function () {
	      return gl.texStorage2D(tex2d, 1, internalFormat, width, height);
	    });
	  }
	  callAndCheck(gl, function () {
	    return gl.bindTexture(gl.TEXTURE_2D, null);
	  });
	  return {
	    texture: texture,
	    texShape: [height, width]
	  };
	}
	function getInternalFormatForFloat32MatrixTexture(textureConfig) {
	  return textureConfig.internalFormatFloat;
	}
	function createFloat32MatrixTexture(gl, rows, columns, textureConfig) {
	  var _tex_util$getUnpacked = getUnpackedMatrixTextureShapeWidthHeight(rows, columns),
	    _tex_util$getUnpacked2 = _slicedToArray(_tex_util$getUnpacked, 2),
	    width = _tex_util$getUnpacked2[0],
	    height = _tex_util$getUnpacked2[1];
	  return createAndConfigureTexture(gl, width, height, getInternalFormatForFloat32MatrixTexture(textureConfig), textureConfig.textureFormatFloat, gl.FLOAT);
	}
	function getInternalFormatForFloat16MatrixTexture(textureConfig) {
	  return textureConfig.internalFormatHalfFloat;
	}
	function createFloat16MatrixTexture(gl, rows, columns, textureConfig) {
	  var _tex_util$getUnpacked3 = getUnpackedMatrixTextureShapeWidthHeight(rows, columns),
	    _tex_util$getUnpacked4 = _slicedToArray(_tex_util$getUnpacked3, 2),
	    width = _tex_util$getUnpacked4[0],
	    height = _tex_util$getUnpacked4[1];
	  return createAndConfigureTexture(gl, width, height, getInternalFormatForFloat16MatrixTexture(textureConfig), textureConfig.textureFormatFloat, textureConfig.textureTypeHalfFloat);
	}
	function getInternalFormatForUnsignedBytesMatrixTexture(textureConfig) {
	  return textureConfig.downloadTextureFormat;
	}
	function createUnsignedBytesMatrixTexture(gl, rows, columns, textureConfig) {
	  var _tex_util$getUnpacked5 = getUnpackedMatrixTextureShapeWidthHeight(rows, columns),
	    _tex_util$getUnpacked6 = _slicedToArray(_tex_util$getUnpacked5, 2),
	    width = _tex_util$getUnpacked6[0],
	    height = _tex_util$getUnpacked6[1];
	  return createAndConfigureTexture(gl, width, height, getInternalFormatForUnsignedBytesMatrixTexture(textureConfig), gl.RGBA, gl.UNSIGNED_BYTE);
	}
	function getInternalFormatForPackedMatrixTexture(textureConfig) {
	  return textureConfig.internalFormatPackedFloat;
	}
	function createPackedMatrixTexture(gl, rows, columns, textureConfig) {
	  var _tex_util$getPackedMa = getPackedMatrixTextureShapeWidthHeight(rows, columns),
	    _tex_util$getPackedMa2 = _slicedToArray(_tex_util$getPackedMa, 2),
	    width = _tex_util$getPackedMa2[0],
	    height = _tex_util$getPackedMa2[1];
	  return createAndConfigureTexture(gl, width, height, getInternalFormatForPackedMatrixTexture(textureConfig), gl.RGBA, gl.FLOAT);
	}
	function getInternalFormatForFloat16PackedMatrixTexture(textureConfig) {
	  return textureConfig.internalFormatPackedHalfFloat;
	}
	function createFloat16PackedMatrixTexture(gl, rows, columns, textureConfig) {
	  var _tex_util$getPackedMa3 = getPackedMatrixTextureShapeWidthHeight(rows, columns),
	    _tex_util$getPackedMa4 = _slicedToArray(_tex_util$getPackedMa3, 2),
	    width = _tex_util$getPackedMa4[0],
	    height = _tex_util$getPackedMa4[1];
	  return createAndConfigureTexture(gl, width, height, getInternalFormatForFloat16PackedMatrixTexture(textureConfig), gl.RGBA, textureConfig.textureTypeHalfFloat);
	}
	function bindVertexProgramAttributeStreams(gl, program, vertexBuffer) {
	  var posOffset = 0; // x is the first buffer element
	  var uvOffset = 3 * 4; // uv comes after [x y z]
	  var stride = 3 * 4 + 2 * 4; // xyz + uv, each entry is 4-byte float.
	  callAndCheck(gl, function () {
	    return gl.bindBuffer(gl.ARRAY_BUFFER, vertexBuffer);
	  });
	  var success = bindVertexBufferToProgramAttribute(gl, program, 'clipSpacePos', vertexBuffer, 3, stride, posOffset);
	  return success && bindVertexBufferToProgramAttribute(gl, program, 'uv', vertexBuffer, 2, stride, uvOffset);
	}
	function uploadDenseMatrixToTexture(gl, texture, width, height, data, textureConfig) {
	  callAndCheck(gl, function () {
	    return gl.bindTexture(gl.TEXTURE_2D, texture);
	  });
	  var dataForUpload, texelDataType, internalFormat;
	  if (data instanceof Uint8Array) {
	    dataForUpload = new Uint8Array(width * height * 4);
	    texelDataType = gl.UNSIGNED_BYTE;
	    internalFormat = gl.RGBA;
	  } else {
	    dataForUpload = new Float32Array(width * height * 4);
	    texelDataType = gl.FLOAT;
	    internalFormat = textureConfig.internalFormatPackedFloat;
	  }
	  dataForUpload.set(data);
	  if (env().getNumber('WEBGL_VERSION') === 2) {
	    callAndCheck(gl, function () {
	      return gl.texSubImage2D(gl.TEXTURE_2D, 0, 0, 0, width, height, gl.RGBA, texelDataType, dataForUpload);
	    });
	  } else {
	    callAndCheck(gl, function () {
	      return gl.texImage2D(gl.TEXTURE_2D, 0, internalFormat, width, height, 0, gl.RGBA, texelDataType, dataForUpload);
	    });
	  }
	  callAndCheck(gl, function () {
	    return gl.bindTexture(gl.TEXTURE_2D, null);
	  });
	}
	function uploadPixelDataToTexture(gl, texture, pixels) {
	  callAndCheck(gl, function () {
	    return gl.bindTexture(gl.TEXTURE_2D, texture);
	  });
	  if (pixels.data instanceof Uint8Array) {
	    if (env().getNumber('WEBGL_VERSION') === 2) {
	      callAndCheck(gl, function () {
	        return gl.texSubImage2D(gl.TEXTURE_2D, 0, 0, 0, pixels.width, pixels.height, gl.RGBA, gl.UNSIGNED_BYTE, pixels.data);
	      });
	    } else {
	      callAndCheck(gl, function () {
	        return gl.texImage2D(gl.TEXTURE_2D, 0, gl.RGBA, pixels.width, pixels.height, 0, gl.RGBA, gl.UNSIGNED_BYTE, pixels.data);
	      });
	    }
	  } else {
	    if (env().getNumber('WEBGL_VERSION') === 2) {
	      callAndCheck(gl, function () {
	        return gl.texSubImage2D(gl.TEXTURE_2D, 0, 0, 0, gl.RGBA, gl.UNSIGNED_BYTE, pixels);
	      });
	    } else {
	      callAndCheck(gl, function () {
	        return gl.texImage2D(gl.TEXTURE_2D, 0, gl.RGBA, gl.RGBA, gl.UNSIGNED_BYTE, pixels);
	      });
	    }
	  }
	  callAndCheck(gl, function () {
	    return gl.bindTexture(gl.TEXTURE_2D, null);
	  });
	}
	function createBufferFromOutputTexture(gl2, rows, columns, textureConfig) {
	  // Create and bind the buffer.
	  var buffer = gl2.createBuffer();
	  callAndCheck(gl2, function () {
	    return gl2.bindBuffer(gl2.PIXEL_PACK_BUFFER, buffer);
	  });
	  // Initialize the buffer to the size of the texture in bytes.
	  var bytesPerFloat = 4;
	  var valuesPerTexel = 4;
	  var bufferSizeBytes = bytesPerFloat * valuesPerTexel * rows * columns;
	  callAndCheck(gl2, function () {
	    return gl2.bufferData(gl2.PIXEL_PACK_BUFFER, bufferSizeBytes, gl2.STREAM_READ);
	  });
	  // Enqueue a command on the GPU command queue to copy of texture into the
	  // buffer.
	  callAndCheck(gl2, function () {
	    return gl2.readPixels(0, 0, columns, rows, gl2.RGBA, gl2.FLOAT, 0);
	  });
	  callAndCheck(gl2, function () {
	    return gl2.bindBuffer(gl2.PIXEL_PACK_BUFFER, null);
	  });
	  return buffer;
	}
	function downloadFloat32MatrixFromBuffer(gl, buffer, size) {
	  var gl2 = gl;
	  var downloadTarget = new Float32Array(size);
	  gl2.bindBuffer(gl2.PIXEL_PACK_BUFFER, buffer);
	  gl2.getBufferSubData(gl2.PIXEL_PACK_BUFFER, 0, downloadTarget);
	  gl2.bindBuffer(gl2.PIXEL_PACK_BUFFER, null);
	  return downloadTarget;
	}
	function downloadByteEncodedFloatMatrixFromOutputTexture(gl, rows, columns, textureConfig) {
	  var _tex_util$getUnpacked7 = getUnpackedMatrixTextureShapeWidthHeight(rows, columns),
	    _tex_util$getUnpacked8 = _slicedToArray(_tex_util$getUnpacked7, 2),
	    w = _tex_util$getUnpacked8[0],
	    h = _tex_util$getUnpacked8[1];
	  var numChannels = 4;
	  var downloadTarget = new Uint8Array(getUnpackedArraySizeFromMatrixSize(rows * columns, numChannels));
	  callAndCheck(gl, function () {
	    return gl.readPixels(0, 0, w, h, textureConfig.downloadTextureFormat, gl.UNSIGNED_BYTE, downloadTarget);
	  });
	  // By wrapping the buffer in a Float32Array, we use native browser IEEE 754
	  // decoding of the 4 bytes that back each 32 bit float.
	  return new Float32Array(downloadTarget.buffer);
	}
	function downloadPackedMatrixFromBuffer(gl, buffer, batch, rows, cols, physicalRows, physicalCols, textureConfig) {
	  var gl2 = gl;
	  var downloadTarget = new Float32Array(getPackedRGBAArraySizeFromMatrixShape(physicalRows, physicalCols));
	  gl2.bindBuffer(gl2.PIXEL_PACK_BUFFER, buffer);
	  gl2.getBufferSubData(gl2.PIXEL_PACK_BUFFER, 0, downloadTarget);
	  gl2.bindBuffer(gl2.PIXEL_PACK_BUFFER, null);
	  return downloadTarget;
	}
	function downloadMatrixFromPackedOutputTexture(gl, physicalRows, physicalCols) {
	  var packedRGBA = new Float32Array(physicalRows * physicalCols * 4);
	  callAndCheck(gl, function () {
	    return gl.readPixels(0, 0, physicalCols, physicalRows, gl.RGBA, gl.FLOAT, packedRGBA);
	  });
	  return packedRGBA;
	}

	var gpgpu_util = {
		__proto__: null,
		bindVertexProgramAttributeStreams: bindVertexProgramAttributeStreams,
		createBufferFromOutputTexture: createBufferFromOutputTexture,
		createFloat16MatrixTexture: createFloat16MatrixTexture,
		createFloat16PackedMatrixTexture: createFloat16PackedMatrixTexture,
		createFloat32MatrixTexture: createFloat32MatrixTexture,
		createIndexBuffer: createIndexBuffer,
		createPackedMatrixTexture: createPackedMatrixTexture,
		createUnsignedBytesMatrixTexture: createUnsignedBytesMatrixTexture,
		createVertexBuffer: createVertexBuffer,
		createVertexShader: createVertexShader,
		downloadByteEncodedFloatMatrixFromOutputTexture: downloadByteEncodedFloatMatrixFromOutputTexture,
		downloadFloat32MatrixFromBuffer: downloadFloat32MatrixFromBuffer,
		downloadMatrixFromPackedOutputTexture: downloadMatrixFromPackedOutputTexture,
		downloadPackedMatrixFromBuffer: downloadPackedMatrixFromBuffer,
		getInternalFormatForFloat16MatrixTexture: getInternalFormatForFloat16MatrixTexture,
		getInternalFormatForFloat16PackedMatrixTexture: getInternalFormatForFloat16PackedMatrixTexture,
		getInternalFormatForFloat32MatrixTexture: getInternalFormatForFloat32MatrixTexture,
		getInternalFormatForPackedMatrixTexture: getInternalFormatForPackedMatrixTexture,
		getInternalFormatForUnsignedBytesMatrixTexture: getInternalFormatForUnsignedBytesMatrixTexture,
		uploadDenseMatrixToTexture: uploadDenseMatrixToTexture,
		uploadPixelDataToTexture: uploadPixelDataToTexture
	};

	var GPGPUContext = /*#__PURE__*/function () {
	  function GPGPUContext(gl) {
	    _classCallCheck(this, GPGPUContext);
	    this.outputTexture = null;
	    this.program = null;
	    this.disposed = false;
	    this.itemsToPoll = [];
	    var glVersion = env().getNumber('WEBGL_VERSION');
	    if (gl != null) {
	      this.gl = gl;
	      setWebGLContext(glVersion, gl);
	    } else {
	      this.gl = getWebGLContext(glVersion);
	    }
	    gl = this.gl;
	    if (env().getNumber('WEBGL_VERSION') === 2) {
	      var gl2 = gl;
	      this.createVertexArray = function () {
	        return callAndCheck(gl2, function () {
	          return gl2.createVertexArray();
	        });
	      };
	      this.bindVertexArray = function (vao) {
	        return callAndCheck(gl2, function () {
	          return gl2.bindVertexArray(vao);
	        });
	      };
	      this.deleteVertexArray = function (vao) {
	        return callAndCheck(gl2, function () {
	          return gl2.deleteVertexArray(vao);
	        });
	      };
	      this.getVertexArray = function () {
	        return callAndCheck(gl2, function () {
	          return gl2.getParameter(gl2.VERTEX_ARRAY_BINDING);
	        });
	      };
	    } else if (gl != null) {
	      var ext = gl.getExtension('OES_vertex_array_object');
	      if (ext == null) {
	        throw new Error('All WebGL1 implementations are expected to offer' + ' OES_vertex_array_object.');
	      }
	      this.createVertexArray = function () {
	        return callAndCheck(gl, function () {
	          return ext.createVertexArrayOES();
	        });
	      };
	      this.bindVertexArray = function (vao) {
	        return callAndCheck(gl, function () {
	          return ext.bindVertexArrayOES(vao);
	        });
	      };
	      this.deleteVertexArray = function (vao) {
	        return callAndCheck(gl, function () {
	          return ext.deleteVertexArrayOES(vao);
	        });
	      };
	      this.getVertexArray = function () {
	        return callAndCheck(gl, function () {
	          return gl.getParameter(ext.VERTEX_ARRAY_BINDING_OES);
	        });
	      };
	    }
	    // WebGL 2.0 enables texture floats without an extension.
	    var COLOR_BUFFER_FLOAT = 'WEBGL_color_buffer_float';
	    var COLOR_BUFFER_HALF_FLOAT = 'EXT_color_buffer_half_float';
	    this.parallelCompilationExtension = this.gl.getExtension('KHR_parallel_shader_compile');
	    if (env().getNumber('WEBGL_VERSION') === 1) {
	      var TEXTURE_FLOAT = 'OES_texture_float';
	      var TEXTURE_HALF_FLOAT = 'OES_texture_half_float';
	      this.textureFloatExtension = getExtensionOrThrow(this.gl, TEXTURE_FLOAT);
	      if (hasExtension(this.gl, TEXTURE_HALF_FLOAT)) {
	        this.textureHalfFloatExtension = getExtensionOrThrow(this.gl, TEXTURE_HALF_FLOAT);
	      } else if (env().get('WEBGL_FORCE_F16_TEXTURES')) {
	        throw new Error('GL context does not support half float textures, yet the ' + 'environment flag WEBGL_FORCE_F16_TEXTURES is set to true.');
	      }
	      this.colorBufferFloatExtension = this.gl.getExtension(COLOR_BUFFER_FLOAT);
	      if (hasExtension(this.gl, COLOR_BUFFER_HALF_FLOAT)) {
	        this.colorBufferHalfFloatExtension = getExtensionOrThrow(this.gl, COLOR_BUFFER_HALF_FLOAT);
	      } else if (env().get('WEBGL_FORCE_F16_TEXTURES')) {
	        throw new Error('GL context does not support color renderable half floats, yet ' + 'the environment flag WEBGL_FORCE_F16_TEXTURES is set to true.');
	      }
	    } else {
	      COLOR_BUFFER_FLOAT = 'EXT_color_buffer_float';
	      if (hasExtension(this.gl, COLOR_BUFFER_FLOAT)) {
	        this.colorBufferFloatExtension = this.gl.getExtension(COLOR_BUFFER_FLOAT);
	      } else if (hasExtension(this.gl, COLOR_BUFFER_HALF_FLOAT)) {
	        this.colorBufferHalfFloatExtension = this.gl.getExtension(COLOR_BUFFER_HALF_FLOAT);
	      } else {
	        throw new Error('GL context does not support color renderable floats');
	      }
	    }
	    this.vertexBuffer = createVertexBuffer(this.gl);
	    this.indexBuffer = createIndexBuffer(this.gl);
	    this.framebuffer = createFramebuffer(this.gl);
	    this.textureConfig = getTextureConfig(this.gl, this.textureHalfFloatExtension);
	  }
	  _createClass(GPGPUContext, [{
	    key: "debug",
	    get: function get() {
	      return env().getBool('DEBUG');
	    }
	  }, {
	    key: "dispose",
	    value: function dispose() {
	      var _this = this;
	      if (this.disposed) {
	        return;
	      }
	      if (this.program != null) {
	        console.warn('Disposing a GPGPUContext that still has a bound WebGLProgram.' + ' This is probably a resource leak, delete the program with ' + 'GPGPUContext.deleteProgram before disposing.');
	      }
	      if (this.outputTexture != null) {
	        console.warn('Disposing a GPGPUContext that still has a bound output matrix ' + 'texture.  This is probably a resource leak, delete the output ' + 'matrix texture with GPGPUContext.deleteMatrixTexture before ' + 'disposing.');
	      }
	      var gl = this.gl;
	      callAndCheck(gl, function () {
	        return gl.finish();
	      });
	      callAndCheck(gl, function () {
	        return gl.bindFramebuffer(gl.FRAMEBUFFER, null);
	      });
	      callAndCheck(gl, function () {
	        return gl.deleteFramebuffer(_this.framebuffer);
	      });
	      callAndCheck(gl, function () {
	        return gl.bindBuffer(gl.ARRAY_BUFFER, null);
	      });
	      callAndCheck(gl, function () {
	        return gl.bindBuffer(gl.ELEMENT_ARRAY_BUFFER, null);
	      });
	      callAndCheck(gl, function () {
	        return gl.deleteBuffer(_this.indexBuffer);
	      });
	      this.disposed = true;
	    }
	  }, {
	    key: "createFloat32MatrixTexture",
	    value: function createFloat32MatrixTexture$1(rows, columns) {
	      this.throwIfDisposed();
	      return createFloat32MatrixTexture(this.gl, rows, columns, this.textureConfig);
	    }
	  }, {
	    key: "createFloat16MatrixTexture",
	    value: function createFloat16MatrixTexture$1(rows, columns) {
	      this.throwIfDisposed();
	      return createFloat16MatrixTexture(this.gl, rows, columns, this.textureConfig);
	    }
	  }, {
	    key: "createUnsignedBytesMatrixTexture",
	    value: function createUnsignedBytesMatrixTexture$1(rows, columns) {
	      this.throwIfDisposed();
	      return createUnsignedBytesMatrixTexture(this.gl, rows, columns, this.textureConfig);
	    }
	  }, {
	    key: "uploadPixelDataToTexture",
	    value: function uploadPixelDataToTexture$1(texture, pixels) {
	      this.throwIfDisposed();
	      uploadPixelDataToTexture(this.gl, texture, pixels);
	    }
	  }, {
	    key: "uploadDenseMatrixToTexture",
	    value: function uploadDenseMatrixToTexture$1(texture, width, height, data) {
	      this.throwIfDisposed();
	      uploadDenseMatrixToTexture(this.gl, texture, width, height, data, this.textureConfig);
	    }
	  }, {
	    key: "createFloat16PackedMatrixTexture",
	    value: function createFloat16PackedMatrixTexture$1(rows, columns) {
	      this.throwIfDisposed();
	      return createFloat16PackedMatrixTexture(this.gl, rows, columns, this.textureConfig);
	    }
	  }, {
	    key: "createPackedMatrixTexture",
	    value: function createPackedMatrixTexture$1(rows, columns) {
	      this.throwIfDisposed();
	      return createPackedMatrixTexture(this.gl, rows, columns, this.textureConfig);
	    }
	  }, {
	    key: "deleteMatrixTexture",
	    value: function deleteMatrixTexture(texture) {
	      var _this2 = this;
	      this.throwIfDisposed();
	      if (this.outputTexture === texture) {
	        unbindColorTextureFromFramebuffer(this.gl, this.framebuffer);
	        this.outputTexture = null;
	      }
	      callAndCheck(this.gl, function () {
	        return _this2.gl.deleteTexture(texture);
	      });
	    }
	  }, {
	    key: "downloadByteEncodedFloatMatrixFromOutputTexture",
	    value: function downloadByteEncodedFloatMatrixFromOutputTexture$1(texture, rows, columns) {
	      var _this3 = this;
	      return this.downloadMatrixDriver(texture, function () {
	        return downloadByteEncodedFloatMatrixFromOutputTexture(_this3.gl, rows, columns, _this3.textureConfig);
	      });
	    }
	  }, {
	    key: "downloadPackedMatrixFromBuffer",
	    value: function downloadPackedMatrixFromBuffer$1(buffer, batch, rows, columns, physicalRows, physicalCols) {
	      return downloadPackedMatrixFromBuffer(this.gl, buffer, batch, rows, columns, physicalRows, physicalCols, this.textureConfig);
	    }
	  }, {
	    key: "downloadFloat32MatrixFromBuffer",
	    value: function downloadFloat32MatrixFromBuffer$1(buffer, size) {
	      return downloadFloat32MatrixFromBuffer(this.gl, buffer, size);
	    }
	  }, {
	    key: "createBufferFromTexture",
	    value: function createBufferFromTexture(texture, rows, columns) {
	      this.bindTextureToFrameBuffer(texture);
	      var result = createBufferFromOutputTexture(this.gl, rows, columns, this.textureConfig);
	      this.unbindTextureToFrameBuffer();
	      return result;
	    }
	  }, {
	    key: "createAndWaitForFence",
	    value: function createAndWaitForFence() {
	      var fenceContext = this.createFence(this.gl);
	      return this.pollFence(fenceContext);
	    }
	  }, {
	    key: "createFence",
	    value: function createFence(gl) {
	      var _this4 = this;
	      var query;
	      var isFencePassed;
	      if (env().getBool('WEBGL_FENCE_API_ENABLED')) {
	        var gl2 = gl;
	        var sync = gl2.fenceSync(gl2.SYNC_GPU_COMMANDS_COMPLETE, 0);
	        gl.flush();
	        isFencePassed = function isFencePassed() {
	          var status = gl2.clientWaitSync(sync, 0, 0);
	          return status === gl2.ALREADY_SIGNALED || status === gl2.CONDITION_SATISFIED;
	        };
	        query = sync;
	      } else if (env().getNumber('WEBGL_DISJOINT_QUERY_TIMER_EXTENSION_VERSION') > 0) {
	        query = this.beginQuery();
	        this.endQuery();
	        isFencePassed = function isFencePassed() {
	          return _this4.isQueryAvailable(query, env().getNumber('WEBGL_DISJOINT_QUERY_TIMER_EXTENSION_VERSION'));
	        };
	      } else {
	        // If we have no way to fence, return true immediately. This will fire in
	        // WebGL 1.0 when there is no disjoint query timer. In this case, because
	        // the fence passes immediately, we'll immediately ask for a download of
	        // the texture, which will cause the UI thread to hang.
	        isFencePassed = function isFencePassed() {
	          return true;
	        };
	      }
	      return {
	        query: query,
	        isFencePassed: isFencePassed
	      };
	    }
	  }, {
	    key: "downloadMatrixFromPackedTexture",
	    value: function downloadMatrixFromPackedTexture(texture, physicalRows, physicalCols) {
	      var _this5 = this;
	      return this.downloadMatrixDriver(texture, function () {
	        return downloadMatrixFromPackedOutputTexture(_this5.gl, physicalRows, physicalCols);
	      });
	    }
	  }, {
	    key: "createProgram",
	    value: function createProgram$1(fragmentShader) {
	      var _this6 = this;
	      this.throwIfDisposed();
	      var gl = this.gl;
	      if (this.vertexShader == null) {
	        this.vertexShader = createVertexShader(gl);
	      }
	      var program = createProgram(gl);
	      callAndCheck(gl, function () {
	        return gl.attachShader(program, _this6.vertexShader);
	      });
	      callAndCheck(gl, function () {
	        return gl.attachShader(program, fragmentShader);
	      });
	      linkProgram(gl, program);
	      var program2 = Object.assign(program, {
	        vao: this.createVertexArray()
	      });
	      if (this.debug) {
	        validateProgram(gl, program2);
	      }
	      return program2;
	    }
	  }, {
	    key: "buildVao",
	    value: function buildVao(program) {
	      var _this7 = this;
	      this.setProgram(program);
	      this.bindVertexArray(program.vao);
	      var gl = this.gl;
	      // Bind index buffer, and vertex buffers based on program attrib
	      // locations.
	      callAndCheck(gl, function () {
	        return gl.bindBuffer(gl.ELEMENT_ARRAY_BUFFER, _this7.indexBuffer);
	      });
	      bindVertexProgramAttributeStreams(gl, program, this.vertexBuffer);
	    }
	  }, {
	    key: "deleteProgram",
	    value: function deleteProgram(program) {
	      var _this8 = this;
	      this.throwIfDisposed();
	      if (program === this.program) {
	        this.program = null;
	      }
	      if (program != null) {
	        callAndCheck(this.gl, function () {
	          return _this8.gl.deleteProgram(program);
	        });
	        this.deleteVertexArray(program.vao);
	      }
	    }
	  }, {
	    key: "setProgram",
	    value: function setProgram(program) {
	      var _this9 = this;
	      this.throwIfDisposed();
	      this.program = program;
	      if (this.program != null) {
	        if (this.debug) {
	          validateProgram(this.gl, this.program);
	        }
	      }
	      callAndCheck(this.gl, function () {
	        return _this9.gl.useProgram(program);
	      });
	    }
	  }, {
	    key: "getUniformLocation",
	    value: function getUniformLocation(program, uniformName) {
	      var shouldThrow = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
	      this.throwIfDisposed();
	      if (shouldThrow) {
	        return getProgramUniformLocationOrThrow(this.gl, program, uniformName);
	      } else {
	        return getProgramUniformLocation(this.gl, program, uniformName);
	      }
	    }
	  }, {
	    key: "getAttributeLocation",
	    value: function getAttributeLocation(program, attribute) {
	      var _this10 = this;
	      this.throwIfDisposed();
	      return callAndCheck(this.gl, function () {
	        return _this10.gl.getAttribLocation(program, attribute);
	      });
	    }
	  }, {
	    key: "getUniformLocationNoThrow",
	    value: function getUniformLocationNoThrow(program, uniformName) {
	      this.throwIfDisposed();
	      return this.gl.getUniformLocation(program, uniformName);
	    }
	  }, {
	    key: "setInputMatrixTexture",
	    value: function setInputMatrixTexture(inputMatrixTexture, uniformLocation, textureUnit) {
	      this.throwIfDisposed();
	      this.throwIfNoProgram();
	      bindTextureToProgramUniformSampler(this.gl, inputMatrixTexture, uniformLocation, textureUnit);
	    }
	  }, {
	    key: "setOutputMatrixTexture",
	    value: function setOutputMatrixTexture(outputMatrixTexture, rows, columns) {
	      this.setOutputMatrixTextureDriver(outputMatrixTexture, columns, rows);
	    }
	  }, {
	    key: "setOutputPackedMatrixTexture",
	    value: function setOutputPackedMatrixTexture(outputPackedMatrixTexture, rows, columns) {
	      this.throwIfDisposed();
	      var _tex_util$getPackedMa = getPackedMatrixTextureShapeWidthHeight(rows, columns),
	        _tex_util$getPackedMa2 = _slicedToArray(_tex_util$getPackedMa, 2),
	        width = _tex_util$getPackedMa2[0],
	        height = _tex_util$getPackedMa2[1];
	      this.setOutputMatrixTextureDriver(outputPackedMatrixTexture, width, height);
	    }
	  }, {
	    key: "setOutputMatrixWriteRegion",
	    value: function setOutputMatrixWriteRegion(startRow, numRows, startColumn, numColumns) {
	      this.setOutputMatrixWriteRegionDriver(startColumn, startRow, numColumns, numRows);
	    }
	  }, {
	    key: "setOutputPackedMatrixWriteRegion",
	    value: function setOutputPackedMatrixWriteRegion(startRow, numRows, startColumn, numColumns) {
	      throw new Error('setOutputPackedMatrixWriteRegion not implemented.');
	    }
	  }, {
	    key: "debugValidate",
	    value: function debugValidate() {
	      if (this.program != null) {
	        validateProgram(this.gl, this.program);
	      }
	      validateFramebuffer(this.gl);
	    }
	  }, {
	    key: "executeProgram",
	    value: function executeProgram() {
	      this.throwIfDisposed();
	      this.throwIfNoProgram();
	      var gl = this.gl;
	      if (this.debug) {
	        var boundVao = this.getVertexArray();
	        console.assert(boundVao === this.program.vao, 'VAO changed between setProgram and executeProgram!');
	        this.debugValidate();
	      }
	      callAndCheck(gl, function () {
	        return gl.drawElements(gl.TRIANGLES, 6, gl.UNSIGNED_SHORT, 0);
	      });
	    }
	  }, {
	    key: "blockUntilAllProgramsCompleted",
	    value: function blockUntilAllProgramsCompleted() {
	      var _this11 = this;
	      this.throwIfDisposed();
	      callAndCheck(this.gl, function () {
	        return _this11.gl.finish();
	      });
	    }
	  }, {
	    key: "getQueryTimerExtension",
	    value: function getQueryTimerExtension() {
	      if (this.disjointQueryTimerExtension == null) {
	        this.disjointQueryTimerExtension = getExtensionOrThrow(this.gl, env().getNumber('WEBGL_DISJOINT_QUERY_TIMER_EXTENSION_VERSION') === 2 ? 'EXT_disjoint_timer_query_webgl2' : 'EXT_disjoint_timer_query');
	      }
	      return this.disjointQueryTimerExtension;
	    }
	  }, {
	    key: "getQueryTimerExtensionWebGL2",
	    value: function getQueryTimerExtensionWebGL2() {
	      return this.getQueryTimerExtension();
	    }
	  }, {
	    key: "getQueryTimerExtensionWebGL1",
	    value: function getQueryTimerExtensionWebGL1() {
	      return this.getQueryTimerExtension();
	    }
	  }, {
	    key: "beginQuery",
	    value: function beginQuery() {
	      if (env().getNumber('WEBGL_DISJOINT_QUERY_TIMER_EXTENSION_VERSION') === 2) {
	        var gl2 = this.gl;
	        var _ext = this.getQueryTimerExtensionWebGL2();
	        var _query = gl2.createQuery();
	        gl2.beginQuery(_ext.TIME_ELAPSED_EXT, _query);
	        return _query;
	      }
	      var ext = this.getQueryTimerExtensionWebGL1();
	      var query = ext.createQueryEXT();
	      ext.beginQueryEXT(ext.TIME_ELAPSED_EXT, query);
	      return query;
	    }
	  }, {
	    key: "endQuery",
	    value: function endQuery() {
	      if (env().getNumber('WEBGL_DISJOINT_QUERY_TIMER_EXTENSION_VERSION') === 2) {
	        var gl2 = this.gl;
	        var _ext2 = this.getQueryTimerExtensionWebGL2();
	        gl2.endQuery(_ext2.TIME_ELAPSED_EXT);
	        return;
	      }
	      var ext = this.getQueryTimerExtensionWebGL1();
	      ext.endQueryEXT(ext.TIME_ELAPSED_EXT);
	    }
	  }, {
	    key: "waitForQueryAndGetTime",
	    value: function () {
	      var _waitForQueryAndGetTime = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(query) {
	        var _this12 = this;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              _context.next = 2;
	              return repeatedTry(function () {
	                return _this12.disposed ||
	                // while testing contexts are created / disposed
	                // in rapid succession, so without this check we
	                // may poll for the query timer indefinitely
	                _this12.isQueryAvailable(query, env().getNumber('WEBGL_DISJOINT_QUERY_TIMER_EXTENSION_VERSION'));
	              });
	            case 2:
	              return _context.abrupt("return", this.getQueryTime(query, env().getNumber('WEBGL_DISJOINT_QUERY_TIMER_EXTENSION_VERSION')));
	            case 3:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function waitForQueryAndGetTime(_x) {
	        return _waitForQueryAndGetTime.apply(this, arguments);
	      }
	      return waitForQueryAndGetTime;
	    }()
	  }, {
	    key: "getQueryTime",
	    value: function getQueryTime(query, queryTimerVersion) {
	      if (queryTimerVersion === 0) {
	        return null;
	      }
	      if (queryTimerVersion === 2) {
	        var gl2 = this.gl;
	        var timeElapsedNanos = gl2.getQueryParameter(query, gl2.QUERY_RESULT);
	        // Return milliseconds.
	        return timeElapsedNanos / 1000000;
	      } else {
	        var ext = this.getQueryTimerExtensionWebGL1();
	        var _timeElapsedNanos = ext.getQueryObjectEXT(query, ext.QUERY_RESULT_EXT);
	        // Return milliseconds.
	        return _timeElapsedNanos / 1000000;
	      }
	    }
	  }, {
	    key: "isQueryAvailable",
	    value: function isQueryAvailable(query, queryTimerVersion) {
	      if (queryTimerVersion === 0) {
	        return true;
	      }
	      if (queryTimerVersion === 2) {
	        var gl2 = this.gl;
	        var ext = this.getQueryTimerExtensionWebGL2();
	        var available = gl2.getQueryParameter(query, gl2.QUERY_RESULT_AVAILABLE);
	        if (this.disjoint == null) {
	          this.disjoint = this.gl.getParameter(ext.GPU_DISJOINT_EXT);
	        }
	        return available && !this.disjoint;
	      } else {
	        var _ext3 = this.getQueryTimerExtensionWebGL1();
	        var _available = _ext3.getQueryObjectEXT(query, _ext3.QUERY_RESULT_AVAILABLE_EXT);
	        if (this.disjoint == null) {
	          this.disjoint = this.gl.getParameter(_ext3.GPU_DISJOINT_EXT);
	        }
	        return _available && !this.disjoint;
	      }
	    }
	  }, {
	    key: "pollFence",
	    value: function pollFence(fenceContext) {
	      var _this13 = this;
	      return new Promise(function (resolve) {
	        _this13.addItemToPoll(function () {
	          return fenceContext.isFencePassed();
	        }, function () {
	          return resolve();
	        });
	      });
	    }
	  }, {
	    key: "pollItems",
	    value: function pollItems() {
	      // Find the last query that has finished.
	      var index = linearSearchLastTrue(this.itemsToPoll.map(function (x) {
	        return x.isDoneFn;
	      }));
	      for (var i = 0; i <= index; ++i) {
	        var resolveFn = this.itemsToPoll[i].resolveFn;
	        resolveFn();
	      }
	      this.itemsToPoll = this.itemsToPoll.slice(index + 1);
	    }
	  }, {
	    key: "addItemToPoll",
	    value: function addItemToPoll(isDoneFn, resolveFn) {
	      var _this14 = this;
	      this.itemsToPoll.push({
	        isDoneFn: isDoneFn,
	        resolveFn: resolveFn
	      });
	      if (this.itemsToPoll.length > 1) {
	        // We already have a running loop that polls.
	        return;
	      }
	      // Start a new loop that polls.
	      var scheduleFn = undefined;
	      if ('setTimeoutCustom' in env().platform) {
	        scheduleFn = env().platform.setTimeoutCustom.bind(env().platform);
	      }
	      repeatedTry(function () {
	        _this14.pollItems();
	        // End the loop if no more items to poll.
	        return _this14.itemsToPoll.length === 0;
	      }, function () {
	        return 0;
	      }, null, scheduleFn);
	    }
	  }, {
	    key: "bindTextureToFrameBuffer",
	    value: function bindTextureToFrameBuffer(texture) {
	      this.throwIfDisposed();
	      bindColorTextureToFramebuffer(this.gl, texture, this.framebuffer);
	      if (this.debug) {
	        validateFramebuffer(this.gl);
	      }
	    }
	  }, {
	    key: "unbindTextureToFrameBuffer",
	    value: function unbindTextureToFrameBuffer() {
	      if (this.outputTexture != null) {
	        bindColorTextureToFramebuffer(this.gl, this.outputTexture, this.framebuffer);
	        if (this.debug) {
	          validateFramebuffer(this.gl);
	        }
	      } else {
	        unbindColorTextureFromFramebuffer(this.gl, this.framebuffer);
	      }
	    }
	  }, {
	    key: "downloadMatrixDriver",
	    value: function downloadMatrixDriver(texture, downloadAndDecode) {
	      this.bindTextureToFrameBuffer(texture);
	      var result = downloadAndDecode();
	      this.unbindTextureToFrameBuffer();
	      return result;
	    }
	  }, {
	    key: "setOutputMatrixTextureDriver",
	    value: function setOutputMatrixTextureDriver(outputMatrixTextureMaybePacked, width, height) {
	      this.throwIfDisposed();
	      var gl = this.gl;
	      bindColorTextureToFramebuffer(gl, outputMatrixTextureMaybePacked, this.framebuffer);
	      if (this.debug) {
	        validateFramebuffer(gl);
	      }
	      this.outputTexture = outputMatrixTextureMaybePacked;
	      callAndCheck(gl, function () {
	        return gl.viewport(0, 0, width, height);
	      });
	      callAndCheck(gl, function () {
	        return gl.scissor(0, 0, width, height);
	      });
	    }
	  }, {
	    key: "setOutputMatrixWriteRegionDriver",
	    value: function setOutputMatrixWriteRegionDriver(x, y, width, height) {
	      var _this15 = this;
	      this.throwIfDisposed();
	      callAndCheck(this.gl, function () {
	        return _this15.gl.scissor(x, y, width, height);
	      });
	    }
	  }, {
	    key: "throwIfDisposed",
	    value: function throwIfDisposed() {
	      if (this.disposed) {
	        throw new Error('Attempted to use disposed GPGPUContext.');
	      }
	    }
	  }, {
	    key: "throwIfNoProgram",
	    value: function throwIfNoProgram() {
	      if (this.program == null) {
	        throw new Error('No GPU program is currently set.');
	      }
	    }
	  }]);
	  return GPGPUContext;
	}();
	/**
	 * Finds the index of the last true element using linear search.
	 * Note: We can't do binary search because Chrome expects us to explicitly
	 * test all fences before download:
	 * https://github.com/tensorflow/tfjs/issues/1145
	 */
	function linearSearchLastTrue(arr) {
	  var i = 0;
	  for (; i < arr.length; ++i) {
	    var isDone = arr[i]();
	    if (!isDone) {
	      break;
	    }
	  }
	  return i - 1;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var addImplCPU = addImpl,
	  bincountImplCPU = bincountImpl,
	  bincountReduceImplCPU = bincountReduceImpl,
	  bitwiseAndImplCPU = bitwiseAndImpl,
	  castImplCPU = castImpl,
	  ceilImplCPU = ceilImpl,
	  concatImplCPU = concatImpl$1,
	  equalImplCPU = equalImpl,
	  expImplCPU = expImpl,
	  expm1ImplCPU = expm1Impl,
	  floorImplCPU = floorImpl,
	  gatherNdImplCPU = gatherNdImpl,
	  gatherV2ImplCPU = gatherV2Impl,
	  greaterImplCPU = greaterImpl,
	  greaterEqualImplCPU = greaterEqualImpl,
	  lessImplCPU = lessImpl,
	  lessEqualImplCPU = lessEqualImpl,
	  linSpaceImplCPU = linSpaceImpl,
	  logImplCPU = logImpl,
	  maxImplCPU = maxImpl$1,
	  maximumImplCPU = maximumImpl,
	  minimumImplCPU = minimumImpl,
	  multiplyImplCPU = multiplyImpl,
	  negImplCPU = negImpl,
	  notEqualImplCPU = notEqualImpl,
	  prodImplCPU = prodImpl,
	  raggedGatherImplCPU = raggedGatherImpl,
	  raggedRangeImplCPU = raggedRangeImpl,
	  raggedTensorToTensorImplCPU = raggedTensorToTensorImpl,
	  rangeImplCPU = rangeImpl,
	  rsqrtImplCPU = rsqrtImpl,
	  scatterImplCPU = scatterImpl,
	  sigmoidImplCPU = sigmoidImpl,
	  simpleAbsImplCPU = simpleAbsImpl,
	  sliceImplCPU = sliceImpl,
	  sparseFillEmptyRowsImplCPU = sparseFillEmptyRowsImpl,
	  sparseReshapeImplCPU = sparseReshapeImpl,
	  sparseSegmentReductionImplCPU = sparseSegmentReductionImpl,
	  sqrtImplCPU = sqrtImpl,
	  staticRegexReplaceImplCPU = staticRegexReplaceImpl,
	  stridedSliceImplCPU = stridedSliceImpl,
	  stringNGramsImplCPU = stringNGramsImpl,
	  stringSplitImplCPU = stringSplitImpl,
	  stringToHashBucketFastImplCPU = stringToHashBucketFastImpl,
	  subImplCPU = subImpl,
	  tileImplCPU = tileImpl,
	  topKImplCPU = topKImpl,
	  transposeImplCPU = transposeImpl$1,
	  uniqueImplCPU = uniqueImpl;

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function getVecChannels(name, rank) {
	  return ['x', 'y', 'z', 'w', 'u', 'v'].slice(0, rank).map(function (d) {
	    return "".concat(name, ".").concat(d);
	  });
	}
	function getChannels(name, rank) {
	  if (rank === 1) {
	    return [name];
	  }
	  return getVecChannels(name, rank);
	}
	function getSourceCoords$2(rank, dims) {
	  if (rank === 1) {
	    return 'rc';
	  }
	  var coords = '';
	  for (var i = 0; i < rank; i++) {
	    coords += dims[i];
	    if (i < rank - 1) {
	      coords += ',';
	    }
	  }
	  return coords;
	}

	var PackProgram = /*#__PURE__*/function () {
	  function PackProgram(outputShape) {
	    _classCallCheck(this, PackProgram);
	    this.variableNames = ['A'];
	    this.packedInputs = false;
	    this.packedOutput = true;
	    // Only input / output 3D tensors.
	    this.outputShape = outputShape;
	    this.rank = outputShape.length;
	    this.enableShapeUniforms = useShapeUniforms(this.outputShape.length);
	    if (this.rank === 0) {
	      this.userCode = "\n        void main() {\n          setOutput(vec4(getA(), 0., 0., 0.));\n        }\n      ";
	    } else {
	      var channels = getChannels('rc', this.rank);
	      var dtype = getCoordsDataType(this.rank);
	      var outOfBoundsCondition = this.getOutOfBoundsCondition(channels);
	      var setup = this.getSetup(channels);
	      var output = this.getOutput(channels);
	      this.userCode = "\n        void main() {\n          ".concat(dtype, " rc = getOutputCoords();\n\n          if(").concat(outOfBoundsCondition, ") {\n            setOutput(vec4(0));\n          } else {\n            ").concat(setup, "\n\n            setOutput(vec4(").concat(output, "));\n          }\n        }\n      ");
	    }
	  }
	  _createClass(PackProgram, [{
	    key: "getSourceCoordsArr",
	    value: function getSourceCoordsArr(dims) {
	      var coords = [];
	      for (var row = 0; row <= 1; row++) {
	        for (var col = 0; col <= 1; col++) {
	          var coord = "".concat(row === 0 ? 'r' : 'rp1', ", ").concat(col === 0 ? 'c' : 'cp1');
	          for (var d = 2; d < this.rank; d++) {
	            coord = "".concat(dims[dims.length - 1 - d], ",") + coord;
	          }
	          coords.push(coord);
	        }
	      }
	      return coords;
	    }
	  }, {
	    key: "getOutOfBoundsCondition",
	    value: function getOutOfBoundsCondition(dims) {
	      if (this.rank === 1) {
	        return "rc > ".concat(this.enableShapeUniforms ? 'outShape' : this.outputShape[0]);
	      }
	      var cond = '';
	      for (var i = this.rank - 2; i < this.rank; i++) {
	        cond += "".concat(dims[i], " >= ").concat(this.enableShapeUniforms ? "outShape[".concat(i, "]") : this.outputShape[i]);
	        if (i < this.rank - 1) {
	          cond += '||';
	        }
	      }
	      return cond;
	    }
	  }, {
	    key: "getSetup",
	    value: function getSetup(dims) {
	      if (this.rank === 1) {
	        return '';
	      }
	      var innerDims = dims.slice(-2);
	      var col = this.enableShapeUniforms ? "outShape[".concat(this.rank, " - 1]") : this.outputShape[this.rank - 1];
	      var row = this.enableShapeUniforms ? "outShape[".concat(this.rank, " - 2]") : this.outputShape[this.rank - 2];
	      return "\n      int r = ".concat(innerDims[0], ";\n      int c = ").concat(innerDims[1], ";\n      int rp1 = r + 1;\n      int cp1 = c + 1;\n\n      bool cEdge = cp1 >= ").concat(col, ";\n      bool rEdge = rp1 >= ").concat(row, ";\n    ");
	    }
	  }, {
	    key: "getOutput",
	    value: function getOutput(dims) {
	      var sourceCoords = this.getSourceCoordsArr(dims);
	      if (this.rank === 1) {
	        var outShape = this.enableShapeUniforms ? 'outShape' : this.outputShape[0];
	        return "getA(rc), (rc + 1 >= ".concat(outShape, " ? 0. : getA(rc + 1)), 0, 0");
	      }
	      return "getA(".concat(sourceCoords[0], "),\n            cEdge ? 0. : getA(").concat(sourceCoords[1], "),\n            rEdge ? 0. : getA(").concat(sourceCoords[2], "),\n            rEdge || cEdge ? 0. : getA(").concat(sourceCoords[3], ")");
	    }
	  }]);
	  return PackProgram;
	}();

	var ReshapePackedProgram = /*#__PURE__*/_createClass(function ReshapePackedProgram(outputShape, inputShape) {
	  _classCallCheck(this, ReshapePackedProgram);
	  this.variableNames = ['A'];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.customUniforms = [{
	    name: 'inputShape',
	    type: 'ivec3'
	  }];
	  this.outputShape = outputShape;
	  this.enableShapeUniforms = useShapeUniforms(this.outputShape.length);
	  var mainLoop = "";
	  for (var i = 0; i < 4; i++) {
	    var thisRC = "thisRC = rc;";
	    if (i % 2 === 1) {
	      thisRC += "thisRC.z += 1;";
	    }
	    if (i > 1) {
	      thisRC += "thisRC.y += 1;";
	    }
	    mainLoop += "\n        ".concat(thisRC, "\n        ").concat(i > 0 ? "if(thisRC.y < rows && thisRC.z < cols){" : '', "\n          int flatIndex = getFlatIndex(thisRC);\n\n          ivec3 inputRC = inputCoordsFromReshapedOutCoords(flatIndex);\n          vec2 inputRCInnerDims = vec2(float(inputRC.y),float(inputRC.z));\n\n          result[").concat(i, "] =\n            getChannel(getA(inputRC.x, inputRC.y, inputRC.z), inputRCInnerDims);\n        ").concat(i > 0 ? '}' : '', "\n      ");
	  }
	  this.userCode = "\n      ".concat(getReshapedInputCoords(inputShape, this.enableShapeUniforms), "\n      ").concat(this.enableShapeUniforms ? getFlatIndexFrom3DOutput() : getFlatIndexFrom3D(outputShape), "\n\n      void main() {\n        ivec3 rc = getOutputCoords();\n\n        vec4 result = vec4(0.);\n\n        ivec3 thisRC;\n        int rows = ").concat(this.enableShapeUniforms ? 'outShape[1]' : outputShape[1], ";\n        int cols = ").concat(this.enableShapeUniforms ? 'outShape[2]' : outputShape[2], ";\n\n        ").concat(mainLoop, "\n\n        setOutput(result);\n      }\n    ");
	});
	function getReshapedInputCoords(shape, enableShapeUniforms) {
	  var coordsFromIndexSnippet = enableShapeUniforms ? getLogicalCoordinatesFromFlatIndexByUniform(['r', 'c', 'd'], 'inputShape') : getLogicalCoordinatesFromFlatIndex(['r', 'c', 'd'], shape);
	  return "\n    ivec3 inputCoordsFromReshapedOutCoords(int index) {\n      ".concat(coordsFromIndexSnippet, "\n      return ivec3(r, c, d);\n    }\n  ");
	}

	var TextureManager = /*#__PURE__*/function () {
	  function TextureManager(gpgpu) {
	    _classCallCheck(this, TextureManager);
	    this.gpgpu = gpgpu;
	    this.numUsedTextures = 0;
	    this.numFreeTextures = 0;
	    this._numBytesAllocated = 0;
	    // Number of bytes that have been allocated and available for reuse.
	    this._numBytesFree = 0;
	    this.freeTextures = {};
	    this.usedTextures = {};
	    this.logEnabled = false;
	  }
	  _createClass(TextureManager, [{
	    key: "acquireTexture",
	    value: function acquireTexture(shapeRC, usage, isPacked) {
	      var physicalTexType = getPhysicalFromLogicalTextureType(usage, isPacked);
	      var shapeKey = getKeyFromTextureShape(shapeRC, physicalTexType, isPacked);
	      if (!(shapeKey in this.freeTextures)) {
	        this.freeTextures[shapeKey] = [];
	      }
	      if (!(shapeKey in this.usedTextures)) {
	        this.usedTextures[shapeKey] = [];
	      }
	      var texBytes = computeBytes(shapeRC, physicalTexType, this.gpgpu.gl, this.gpgpu.textureConfig, isPacked);
	      if (this.freeTextures[shapeKey].length > 0) {
	        this.numFreeTextures--;
	        this.numUsedTextures++;
	        this._numBytesFree -= texBytes;
	        this.log();
	        var _newTexture = this.freeTextures[shapeKey].pop();
	        this.usedTextures[shapeKey].push(_newTexture);
	        return _newTexture;
	      }
	      var newTexture;
	      if (physicalTexType === PhysicalTextureType.PACKED_2X2_FLOAT32) {
	        newTexture = this.gpgpu.createPackedMatrixTexture(shapeRC[0], shapeRC[1]);
	      } else if (physicalTexType === PhysicalTextureType.PACKED_2X2_FLOAT16) {
	        newTexture = this.gpgpu.createFloat16PackedMatrixTexture(shapeRC[0], shapeRC[1]);
	      } else if (physicalTexType === PhysicalTextureType.UNPACKED_FLOAT32) {
	        newTexture = this.gpgpu.createFloat32MatrixTexture(shapeRC[0], shapeRC[1]);
	      } else if (physicalTexType === PhysicalTextureType.UNPACKED_FLOAT16) {
	        newTexture = this.gpgpu.createFloat16MatrixTexture(shapeRC[0], shapeRC[1]);
	      } else if (physicalTexType === PhysicalTextureType.PACKED_4X1_UNSIGNED_BYTE) {
	        newTexture = this.gpgpu.createUnsignedBytesMatrixTexture(shapeRC[0], shapeRC[1]);
	      }
	      this.usedTextures[shapeKey].push(newTexture);
	      this.numUsedTextures++;
	      this._numBytesAllocated += texBytes;
	      this.log();
	      return newTexture;
	    }
	  }, {
	    key: "releaseTexture",
	    value: function releaseTexture(texture, shape, logicalTexType, isPacked) {
	      if (this.freeTextures == null) {
	        // Already disposed.
	        return;
	      }
	      var physicalTexType = getPhysicalFromLogicalTextureType(logicalTexType, isPacked);
	      var shapeKey = getKeyFromTextureShape(shape, physicalTexType, isPacked);
	      if (!(shapeKey in this.freeTextures)) {
	        this.freeTextures[shapeKey] = [];
	      }
	      var texBytes = computeBytes(shape, physicalTexType, this.gpgpu.gl, this.gpgpu.textureConfig, isPacked);
	      var deleteTexThreshold = env().getNumber('WEBGL_DELETE_TEXTURE_THRESHOLD');
	      if (deleteTexThreshold !== -1 && this._numBytesAllocated > deleteTexThreshold) {
	        this.gpgpu.deleteMatrixTexture(texture.texture);
	        this._numBytesAllocated -= texBytes;
	      } else {
	        this.freeTextures[shapeKey].push(texture);
	        this.numFreeTextures++;
	        this._numBytesFree += texBytes;
	      }
	      this.numUsedTextures--;
	      var texList = this.usedTextures[shapeKey];
	      var texIndex = texList && texList.indexOf(texture);
	      if (texIndex == null || texIndex < 0) {
	        throw new Error('Cannot release a texture that was never provided by this ' + 'texture manager');
	      }
	      texList[texIndex] = texList[texList.length - 1];
	      texList.pop();
	      this.log();
	    }
	  }, {
	    key: "log",
	    value: function log() {
	      if (!this.logEnabled) {
	        return;
	      }
	      var total = this.numFreeTextures + this.numUsedTextures;
	      console.log('Free/Used', "".concat(this.numFreeTextures, " / ").concat(this.numUsedTextures), "(".concat(total, ")"));
	      var freeRatio = this._numBytesFree / this._numBytesAllocated;
	      console.log("Bytes allocated: ".concat(this._numBytesAllocated));
	      console.log("Bytes unused: ".concat(this._numBytesFree, " (").concat(Math.round(100 * freeRatio), "%)"));
	    }
	  }, {
	    key: "numBytesAllocated",
	    get: function get() {
	      return this._numBytesAllocated;
	    }
	  }, {
	    key: "numBytesFree",
	    get: function get() {
	      return this._numBytesFree;
	    }
	  }, {
	    key: "getNumUsedTextures",
	    value: function getNumUsedTextures() {
	      return this.numUsedTextures;
	    }
	  }, {
	    key: "getNumFreeTextures",
	    value: function getNumFreeTextures() {
	      return this.numFreeTextures;
	    }
	  }, {
	    key: "dispose",
	    value: function dispose() {
	      var _this = this;
	      if (this.freeTextures == null) {
	        // Already disposed.
	        return;
	      }
	      for (var texShape in this.freeTextures) {
	        this.freeTextures[texShape].forEach(function (tex) {
	          _this.gpgpu.deleteMatrixTexture(tex.texture);
	        });
	      }
	      for (var _texShape in this.usedTextures) {
	        this.usedTextures[_texShape].forEach(function (tex) {
	          _this.gpgpu.deleteMatrixTexture(tex.texture);
	        });
	      }
	      // TODO: Assign non-null value (empty object) to textures after disposed.
	      this.freeTextures = null;
	      this.usedTextures = null;
	      this.numUsedTextures = 0;
	      this.numFreeTextures = 0;
	      this._numBytesAllocated = 0;
	      this._numBytesFree = 0;
	    }
	  }]);
	  return TextureManager;
	}();
	function numBytesForInternalFormat(gl, internalFormat) {
	  // tslint:disable-next-line:no-any
	  var glany = gl;
	  if (internalFormat === glany.R32F) {
	    return 4;
	  } else if (internalFormat === glany.R16F) {
	    return 2;
	  } else if (internalFormat === glany.RGBA32F) {
	    return 16;
	  } else if (internalFormat === gl.RGBA) {
	    return 16;
	  } else if (internalFormat === glany.RGBA16F) {
	    return 8;
	  } else if (internalFormat === glany.RGBA8) {
	    return 4;
	  }
	  throw new Error("Unknown internal format ".concat(internalFormat));
	}
	function computeBytes(shape, physicalTexType, gl, textureConfig, isPacked) {
	  // It is not possible to infer packed status from the texture type because
	  // depending on the textureConfig, different  texture types may resolve to the
	  // same internal format (e.g. in WebGL1, the internal format for
	  // UNPACKED_FLOAT16 textures is gl.RGBA). Therefore we pass in `isPacked`
	  // explicitly.
	  var internalFormat = internalFormatForPhysicalTexType(physicalTexType, textureConfig);
	  var numElements;
	  if (isPacked) {
	    var _getPackedMatrixTextu = getPackedMatrixTextureShapeWidthHeight(shape[0], shape[1]),
	      _getPackedMatrixTextu2 = _slicedToArray(_getPackedMatrixTextu, 2),
	      packedWidth = _getPackedMatrixTextu2[0],
	      packedHeight = _getPackedMatrixTextu2[1];
	    numElements = packedWidth * packedHeight;
	  } else {
	    var _getUnpackedMatrixTex = getUnpackedMatrixTextureShapeWidthHeight(shape[0], shape[1]),
	      _getUnpackedMatrixTex2 = _slicedToArray(_getUnpackedMatrixTex, 2),
	      width = _getUnpackedMatrixTex2[0],
	      height = _getUnpackedMatrixTex2[1];
	    numElements = width * height;
	  }
	  var bytesPerElement = numBytesForInternalFormat(gl, internalFormat);
	  return numElements * bytesPerElement;
	}
	function internalFormatForPhysicalTexType(physicalTexType, textureConfig) {
	  switch (physicalTexType) {
	    case PhysicalTextureType.PACKED_2X2_FLOAT32:
	      return getInternalFormatForPackedMatrixTexture(textureConfig);
	    case PhysicalTextureType.PACKED_2X2_FLOAT16:
	      return getInternalFormatForFloat16PackedMatrixTexture(textureConfig);
	    case PhysicalTextureType.UNPACKED_FLOAT32:
	      return getInternalFormatForFloat32MatrixTexture(textureConfig);
	    case PhysicalTextureType.UNPACKED_FLOAT16:
	      return getInternalFormatForFloat16MatrixTexture(textureConfig);
	    case PhysicalTextureType.PACKED_4X1_UNSIGNED_BYTE:
	      return getInternalFormatForUnsignedBytesMatrixTexture(textureConfig);
	    default:
	      throw new Error("Unknown physical texture type ".concat(physicalTexType));
	  }
	}
	function getPhysicalTextureForRendering(isPacked) {
	  if (env().getBool('WEBGL_RENDER_FLOAT32_ENABLED')) {
	    if (isPacked) {
	      return PhysicalTextureType.PACKED_2X2_FLOAT32;
	    }
	    return PhysicalTextureType.UNPACKED_FLOAT32;
	  }
	  if (isPacked) {
	    return PhysicalTextureType.PACKED_2X2_FLOAT16;
	  }
	  return PhysicalTextureType.UNPACKED_FLOAT16;
	}
	function getPhysicalFromLogicalTextureType(logicalTexType, isPacked) {
	  if (logicalTexType === TextureUsage.UPLOAD) {
	    return PhysicalTextureType.PACKED_2X2_FLOAT32;
	  } else if (logicalTexType === TextureUsage.RENDER || logicalTexType == null) {
	    return getPhysicalTextureForRendering(isPacked);
	  } else if (logicalTexType === TextureUsage.DOWNLOAD || logicalTexType === TextureUsage.PIXELS) {
	    return PhysicalTextureType.PACKED_4X1_UNSIGNED_BYTE;
	  }
	  throw new Error("Unknown logical texture type ".concat(logicalTexType));
	}
	function getKeyFromTextureShape(shapeRowsCol, physicalTexType, isPacked) {
	  return "".concat(shapeRowsCol[0], "_").concat(shapeRowsCol[1], "_").concat(physicalTexType, "_").concat(isPacked);
	}

	var UnaryOpProgram = /*#__PURE__*/_createClass(function UnaryOpProgram(aShape, opSnippet) {
	  _classCallCheck(this, UnaryOpProgram);
	  this.variableNames = ['A'];
	  this.outputShape = aShape;
	  this.enableShapeUniforms = useShapeUniforms(this.outputShape.length);
	  this.userCode = "\n      float unaryOperation(float x) {\n        ".concat(opSnippet, "\n      }\n\n      void main() {\n        float x = getAAtOutCoords();\n        float y = unaryOperation(x);\n\n        setOutput(y);\n      }\n    ");
	});
	var CHECK_NAN_SNIPPET$1 = "if (isnan(x)) return x;";
	var LINEAR$1 = "return x;";
	var ABS$1 = "return abs(x);";
	function STEP() {
	  var alpha = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0.0;
	  return CHECK_NAN_SNIPPET$1 + "\n    return x > 0.0 ? 1.0 : float(".concat(alpha, ");\n  ");
	}
	var ELU$2 = "return (x >= 0.0) ? x : (exp(x) - 1.0);";
	var RELU$2 = CHECK_NAN_SNIPPET$1 + "\n  return (x < 0.0) ? 0.0 : x;\n";
	var RELU6$2 = CHECK_NAN_SNIPPET$1 + "\n  return (x < 0.0) ? 0.0 : min(6.0, x);\n";
	var CLONE = 'return x;';
	var SIGMOID$2 = "return 1.0 / (1.0 + exp(-1.0 * x));";

	var LINEAR = "return x;";
	var ELU$1 = "\n  vec4 result;\n\n  result.r = (x.r >= 0.0) ? x.r : (exp(x.r) - 1.0);\n  result.g = (x.g >= 0.0) ? x.g : (exp(x.g) - 1.0);\n  result.b = (x.b >= 0.0) ? x.b : (exp(x.b) - 1.0);\n  result.a = (x.a >= 0.0) ? x.a : (exp(x.a) - 1.0);\n\n  return result;\n";
	var RELU$1 = "\n  vec4 result = x * vec4(greaterThanEqual(x, vec4(0.0)));\n  bvec4 isNaN = isnan(x);\n\n  result.r = isNaN.r ? x.r : result.r;\n  result.g = isNaN.g ? x.g : result.g;\n  result.b = isNaN.b ? x.b : result.b;\n  result.a = isNaN.a ? x.a : result.a;\n\n  return result;\n";
	var RELU6$1 = "\n  vec4 result = min(x, vec4(6.)) * vec4(greaterThanEqual(x, vec4(0.0)));\n  bvec4 isNaN = isnan(x);\n\n  result.r = isNaN.r ? x.r : result.r;\n  result.g = isNaN.g ? x.g : result.g;\n  result.b = isNaN.b ? x.b : result.b;\n  result.a = isNaN.a ? x.a : result.a;\n\n  return result;\n";
	var SIGMOID$1 = "return 1.0 / (1.0 + exp(-1.0 * x));";
	var UnaryOpPackedProgram = /*#__PURE__*/_createClass(function UnaryOpPackedProgram(aShape, opSnippet) {
	  _classCallCheck(this, UnaryOpPackedProgram);
	  this.variableNames = ['A'];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.outputShape = aShape;
	  this.enableShapeUniforms = useShapeUniforms(this.outputShape.length);
	  this.userCode = "\n      vec4 unaryOperation(vec4 x) {\n        ".concat(opSnippet, "\n      }\n\n      void main() {\n        vec4 x = getAAtOutCoords();\n        vec4 y = unaryOperation(x);\n\n        setOutput(y);\n      }\n    ");
	});

	var UnpackProgram = /*#__PURE__*/_createClass(function UnpackProgram(outputShape) {
	  _classCallCheck(this, UnpackProgram);
	  this.variableNames = ['A'];
	  this.packedInputs = true;
	  this.packedOutput = false;
	  this.outputShape = outputShape;
	  this.enableShapeUniforms = useShapeUniforms(this.outputShape.length);
	  var rank = outputShape.length;
	  var channels = getChannels('rc', rank);
	  var dtype = getCoordsDataType(rank);
	  var sourceCoords = getSourceCoords$2(rank, channels);
	  var innerDims = channels.slice(-2);
	  var coords = rank <= 1 ? 'rc' : "vec2(".concat(innerDims.join(','), ")");
	  this.userCode = "\n      void main() {\n        ".concat(dtype, " rc = getOutputCoords();\n        vec4 packedInput = getA(").concat(sourceCoords, ");\n\n        setOutput(getChannel(packedInput, ").concat(coords, "));\n      }\n    ");
	});

	var whereImpl = whereImpl$2;
	var EPSILON_FLOAT32 = 1e-7;
	var EPSILON_FLOAT16 = 1e-4;
	var binaryCaches = {};
	function getBinaryCache(webGLVersion) {
	  if (webGLVersion in binaryCaches) {
	    return binaryCaches[webGLVersion];
	  }
	  binaryCaches[webGLVersion] = {};
	  return binaryCaches[webGLVersion];
	}
	// Empirically determined constant used to determine size threshold for handing
	// off execution to the CPU.
	var CPU_HANDOFF_SIZE_THRESHOLD = env().getNumber('CPU_HANDOFF_SIZE_THRESHOLD');
	// Empirically determined constant used to decide the number of MB on GPU
	// before we warn about high memory use. The MB are this constant * screen area
	// * dpi / 1024 / 1024.
	var BEFORE_PAGING_CONSTANT = 600;
	function numMBBeforeWarning() {
	  if (env().global.screen == null) {
	    return 1024; // 1 GB.
	  }

	  return env().global.screen.height * env().global.screen.width * window.devicePixelRatio * BEFORE_PAGING_CONSTANT / 1024 / 1024;
	}
	var MathBackendWebGL = /*#__PURE__*/function (_KernelBackend) {
	  _inherits(MathBackendWebGL, _KernelBackend);
	  var _super = _createSuper(MathBackendWebGL);
	  function MathBackendWebGL(gpuResource) {
	    var _this;
	    _classCallCheck(this, MathBackendWebGL);
	    _this = _super.call(this);
	    // Maps data ids that have a pending read operation, to list of subscribers.
	    _this.pendingRead = new WeakMap();
	    // List of data ids that are scheduled for disposal, but are waiting on a
	    // pending read operation.
	    _this.pendingDisposal = new WeakSet();
	    // Used to count the number of 'shallow' sliced tensors that point to the
	    // same data id.
	    _this.dataRefCount = new WeakMap();
	    _this.numBytesInGPU = 0;
	    // Accumulated time spent (including blocking) in uploading data to webgl.
	    _this.uploadWaitMs = 0;
	    // Accumulated time spent (including blocking in downloading data from webgl.
	    _this.downloadWaitMs = 0;
	    // record the last manual GL Flush time.
	    _this.lastGlFlushTime = 0;
	    _this.warnedAboutMemory = false;
	    _this.pendingDeletes = 0;
	    _this.disposed = false;
	    if (!env().getBool('HAS_WEBGL')) {
	      throw new Error('WebGL is not supported on this device');
	    }
	    var newGPGPU;
	    if (gpuResource != null) {
	      if (gpuResource instanceof GPGPUContext) {
	        newGPGPU = gpuResource;
	      } else {
	        var gl = getWebGLContext(env().getNumber('WEBGL_VERSION'), gpuResource);
	        newGPGPU = new GPGPUContext(gl);
	      }
	      _this.binaryCache = {};
	      _this.gpgpuCreatedLocally = false;
	    } else {
	      var _gl = getWebGLContext(env().getNumber('WEBGL_VERSION'));
	      newGPGPU = new GPGPUContext(_gl);
	      _this.binaryCache = getBinaryCache(env().getNumber('WEBGL_VERSION'));
	      _this.gpgpuCreatedLocally = true;
	    }
	    _this.gpgpu = newGPGPU;
	    _this.canvas = _this.gpgpu.gl.canvas;
	    _this.textureManager = new TextureManager(_this.gpgpu);
	    _this.numMBBeforeWarning = numMBBeforeWarning();
	    _this.texData = new DataStorage(_assertThisInitialized(_this), engine());
	    return _this;
	  }
	  _createClass(MathBackendWebGL, [{
	    key: "nextDataId",
	    value: function nextDataId() {
	      return MathBackendWebGL.nextDataId++;
	    }
	  }, {
	    key: "numDataIds",
	    value: function numDataIds() {
	      return this.texData.numDataIds() - this.pendingDeletes;
	    }
	    // Writes a new entry to the data store with a WebGL texture, and registers it
	    // to the texture manager.
	  }, {
	    key: "writeTexture",
	    value: function writeTexture(texture, shape, dtype, texHeight, texWidth, channels) {
	      // Temporarily create an tensor info to make the texture compatible with
	      // the runWebGLProgram's input.
	      var input = this.makeTensorInfo(shape, dtype);
	      var inData = this.texData.get(input.dataId);
	      // Even though the input texture could be unpacked or dense packed, it is
	      // always considered as unpacked for EncodeMatrixProgram.
	      inData.isPacked = false;
	      // Bind texture to the input tensor.
	      inData.texture = {
	        texture: texture,
	        texShape: [texHeight, texWidth]
	      };
	      inData.texShape = [texHeight, texWidth];
	      var shapeAs3D = getShapeAs3D(shape);
	      var program = new EncodeMatrixProgram(shapeAs3D, false /* isByteArray */, channels);
	      var output = this.runWebGLProgram(program, [input], dtype, [[texHeight, texWidth]]);
	      output.shape = shape;
	      // Unbind the texture from the input tensor to avoid the texture being
	      // released.
	      inData.texture = null;
	      this.disposeIntermediateTensorInfo(input);
	      return output.dataId;
	    }
	  }, {
	    key: "write",
	    value: function write(values, shape, dtype) {
	      if (env().getBool('WEBGL_CHECK_NUMERICAL_PROBLEMS') || env().getBool('DEBUG')) {
	        this.checkNumericalProblems(values);
	      }
	      if (dtype === 'complex64' && values != null) {
	        throw new Error("Cannot write to a complex64 dtype. " + "Please use tf.complex(real, imag).");
	      }
	      var dataId = {
	        id: this.nextDataId()
	      };
	      this.texData.set(dataId, {
	        shape: shape,
	        dtype: dtype,
	        values: values,
	        usage: TextureUsage.UPLOAD,
	        refCount: 1
	      });
	      return dataId;
	    }
	    /** Return refCount of a `TensorData`. */
	  }, {
	    key: "refCount",
	    value: function refCount(dataId) {
	      if (this.texData.has(dataId)) {
	        var tensorData = this.texData.get(dataId);
	        return tensorData.refCount;
	      }
	      return 0;
	    }
	    /** Increase refCount of a `TextureData`. */
	  }, {
	    key: "incRef",
	    value: function incRef(dataId) {
	      var texData = this.texData.get(dataId);
	      texData.refCount++;
	    }
	    /** Decrease refCount of a `TextureData`. */
	  }, {
	    key: "decRef",
	    value: function decRef(dataId) {
	      if (this.texData.has(dataId)) {
	        var texData = this.texData.get(dataId);
	        texData.refCount--;
	      }
	    }
	  }, {
	    key: "move",
	    value: function move(dataId, values, shape, dtype, refCount) {
	      if (env().getBool('DEBUG')) {
	        this.checkNumericalProblems(values);
	      }
	      if (dtype === 'complex64') {
	        throw new Error("Cannot write to a complex64 dtype. " + "Please use tf.complex(real, imag).");
	      }
	      this.texData.set(dataId, {
	        shape: shape,
	        dtype: dtype,
	        values: values,
	        usage: TextureUsage.UPLOAD,
	        refCount: refCount
	      });
	    }
	  }, {
	    key: "disposeIntermediateTensorInfo",
	    value: function disposeIntermediateTensorInfo(tensorInfo) {
	      this.disposeData(tensorInfo.dataId);
	    }
	  }, {
	    key: "readSync",
	    value: function readSync(dataId) {
	      var texData = this.texData.get(dataId);
	      var values = texData.values,
	        dtype = texData.dtype,
	        complexTensorInfos = texData.complexTensorInfos,
	        slice = texData.slice,
	        shape = texData.shape,
	        isPacked = texData.isPacked;
	      // The presence of `slice` indicates this tensor is a shallow slice of a
	      // different tensor, and is using that original tensor's texture. Run
	      // `clone` in order to copy that texture and read from it.
	      if (slice != null) {
	        var program;
	        if (isPacked) {
	          program = new UnaryOpPackedProgram(shape, CLONE);
	        } else {
	          program = new UnaryOpProgram(shape, CLONE);
	        }
	        var res = this.runWebGLProgram(program, [{
	          dataId: dataId,
	          shape: shape,
	          dtype: dtype
	        }], dtype);
	        var data = this.readSync(res.dataId);
	        this.disposeIntermediateTensorInfo(res);
	        return data;
	      }
	      if (values != null) {
	        return this.convertAndCacheOnCPU(dataId);
	      }
	      if (dtype === 'string') {
	        return values;
	      }
	      var shouldTimeProgram = this.activeTimers != null;
	      var start;
	      if (shouldTimeProgram) {
	        start = now();
	      }
	      var result;
	      if (dtype === 'complex64') {
	        var realValues = this.readSync(complexTensorInfos.real.dataId);
	        var imagValues = this.readSync(complexTensorInfos.imag.dataId);
	        result = mergeRealAndImagArrays(realValues, imagValues);
	      } else {
	        result = this.getValuesFromTexture(dataId);
	      }
	      if (shouldTimeProgram) {
	        this.downloadWaitMs += now() - start;
	      }
	      return this.convertAndCacheOnCPU(dataId, result);
	    }
	  }, {
	    key: "read",
	    value: function () {
	      var _read = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee(dataId) {
	        var _subscribers, texData, values, shape, slice, dtype, complexTensorInfos, isPacked, program, res, data, buffer, tmpDownloadTarget, _this$gpgpu, tmpData, vals, ps, realValues, imagValues, size, gl, dTypeVals, subscribers;
	        return _regeneratorRuntime().wrap(function _callee$(_context) {
	          while (1) switch (_context.prev = _context.next) {
	            case 0:
	              if (!this.pendingRead.has(dataId)) {
	                _context.next = 3;
	                break;
	              }
	              _subscribers = this.pendingRead.get(dataId);
	              return _context.abrupt("return", new Promise(function (resolve) {
	                return _subscribers.push(resolve);
	              }));
	            case 3:
	              texData = this.texData.get(dataId);
	              values = texData.values, shape = texData.shape, slice = texData.slice, dtype = texData.dtype, complexTensorInfos = texData.complexTensorInfos, isPacked = texData.isPacked; // The presence of `slice` indicates this tensor is a shallow slice of a
	              // different tensor, and is using that original tensor's texture. Run
	              // `clone` in order to copy that texture and read from it.
	              if (!(slice != null)) {
	                _context.next = 11;
	                break;
	              }
	              if (isPacked) {
	                program = new UnaryOpPackedProgram(shape, CLONE);
	              } else {
	                program = new UnaryOpProgram(shape, CLONE);
	              }
	              res = this.runWebGLProgram(program, [{
	                dataId: dataId,
	                shape: shape,
	                dtype: dtype
	              }], dtype);
	              data = this.read(res.dataId);
	              this.disposeIntermediateTensorInfo(res);
	              return _context.abrupt("return", data);
	            case 11:
	              if (!(values != null)) {
	                _context.next = 13;
	                break;
	              }
	              return _context.abrupt("return", this.convertAndCacheOnCPU(dataId));
	            case 13:
	              if (!env().getBool('DEBUG')) {
	                _context.next = 16;
	                break;
	              }
	              if (!(!env().getBool('WEBGL_DOWNLOAD_FLOAT_ENABLED') && env().getNumber('WEBGL_VERSION') === 2)) {
	                _context.next = 16;
	                break;
	              }
	              throw new Error("tensor.data() with WEBGL_DOWNLOAD_FLOAT_ENABLED=false and " + "WEBGL_VERSION=2 not yet supported.");
	            case 16:
	              buffer = null;
	              if (dtype !== 'complex64' && env().get('WEBGL_BUFFER_SUPPORTED')) {
	                // Possibly copy the texture into a buffer before inserting a fence.
	                tmpDownloadTarget = this.decode(dataId);
	                tmpData = this.texData.get(tmpDownloadTarget.dataId);
	                buffer = (_this$gpgpu = this.gpgpu).createBufferFromTexture.apply(_this$gpgpu, [tmpData.texture.texture].concat(_toConsumableArray(getDenseTexShape(shape))));
	              }
	              this.pendingRead.set(dataId, []);
	              if (!(dtype !== 'complex64')) {
	                _context.next = 22;
	                break;
	              }
	              _context.next = 22;
	              return this.gpgpu.createAndWaitForFence();
	            case 22:
	              if (!(dtype === 'complex64')) {
	                _context.next = 31;
	                break;
	              }
	              _context.next = 25;
	              return Promise.all([this.read(complexTensorInfos.real.dataId), this.read(complexTensorInfos.imag.dataId)]);
	            case 25:
	              ps = _context.sent;
	              realValues = ps[0];
	              imagValues = ps[1];
	              vals = mergeRealAndImagArrays(realValues, imagValues);
	              _context.next = 32;
	              break;
	            case 31:
	              if (buffer == null) {
	                vals = this.getValuesFromTexture(dataId);
	              } else {
	                size = sizeFromShape(shape);
	                vals = this.gpgpu.downloadFloat32MatrixFromBuffer(buffer, size);
	              }
	            case 32:
	              if (tmpDownloadTarget != null) {
	                this.disposeIntermediateTensorInfo(tmpDownloadTarget);
	              }
	              if (buffer != null) {
	                gl = this.gpgpu.gl;
	                callAndCheck(gl, function () {
	                  return gl.deleteBuffer(buffer);
	                });
	              }
	              dTypeVals = this.convertAndCacheOnCPU(dataId, vals);
	              subscribers = this.pendingRead.get(dataId);
	              this.pendingRead.delete(dataId);
	              // Notify all pending reads.
	              subscribers.forEach(function (resolve) {
	                return resolve(dTypeVals);
	              });
	              if (this.pendingDisposal.has(dataId)) {
	                this.pendingDisposal.delete(dataId);
	                if (this.disposeData(dataId)) {
	                  engine().removeDataId(dataId, this);
	                }
	                this.pendingDeletes--;
	              }
	              return _context.abrupt("return", dTypeVals);
	            case 40:
	            case "end":
	              return _context.stop();
	          }
	        }, _callee, this);
	      }));
	      function read(_x) {
	        return _read.apply(this, arguments);
	      }
	      return read;
	    }()
	    /**
	     * Read tensor to a new texture that is densely packed for ease of use.
	     * @param dataId The source tensor.
	     * @param options
	     *     customTexShape: Optional. If set, will use the user defined texture
	     *     shape to create the texture.
	     */
	  }, {
	    key: "readToGPU",
	    value: function readToGPU(dataId) {
	      var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
	      var texData = this.texData.get(dataId);
	      var values = texData.values,
	        shape = texData.shape,
	        slice = texData.slice,
	        dtype = texData.dtype,
	        isPacked = texData.isPacked,
	        texture = texData.texture;
	      if (dtype === 'complex64') {
	        throw new Error('Does not support reading texture for complex64 dtype.');
	      }
	      // The presence of `slice` indicates this tensor is a shallow slice of a
	      // different tensor, and is using that original tensor's texture. Run
	      // `clone` in order to copy that texture and read from it.
	      if (slice != null) {
	        var program;
	        if (isPacked) {
	          program = new UnaryOpPackedProgram(shape, CLONE);
	        } else {
	          program = new UnaryOpProgram(shape, CLONE);
	        }
	        var res = this.runWebGLProgram(program, [{
	          dataId: dataId,
	          shape: shape,
	          dtype: dtype
	        }], dtype);
	        var gpuResouorce = this.readToGPU(res, options);
	        this.disposeIntermediateTensorInfo(res);
	        return gpuResouorce;
	      }
	      if (texture == null) {
	        if (values != null) {
	          throw new Error('Data is not on GPU but on CPU.');
	        } else {
	          throw new Error('There is no data on GPU or CPU.');
	        }
	      }
	      // Decode the texture so that it is stored densely (using four channels).
	      var tmpTarget = this.decode(dataId, options.customTexShape);
	      // Make engine track this tensor, so that we can dispose it later.
	      var tensorRef = engine().makeTensorFromTensorInfo(tmpTarget);
	      var tmpData = this.texData.get(tmpTarget.dataId);
	      return Object.assign({
	        tensorRef: tensorRef
	      }, tmpData.texture);
	    }
	  }, {
	    key: "bufferSync",
	    value: function bufferSync(t) {
	      var data = this.readSync(t.dataId);
	      if (t.dtype === 'string') {
	        try {
	          // Decode the bytes into string.
	          var strings = data.map(function (d) {
	            return decodeString(d);
	          });
	          return buffer(t.shape, t.dtype, strings);
	        } catch (_a) {
	          throw new Error('Failed to decode encoded string bytes into utf-8');
	        }
	      }
	      return buffer(t.shape, t.dtype, data);
	    }
	  }, {
	    key: "checkNumericalProblems",
	    value: function checkNumericalProblems(values) {
	      if (values == null) {
	        return;
	      }
	      for (var i = 0; i < values.length; i++) {
	        var num = values[i];
	        if (!canBeRepresented(num)) {
	          if (env().getBool('WEBGL_RENDER_FLOAT32_CAPABLE')) {
	            throw Error("The value ".concat(num, " cannot be represented with your ") + "current settings. Consider enabling float32 rendering: " + "'tf.env().set('WEBGL_RENDER_FLOAT32_ENABLED', true);'");
	          }
	          throw Error("The value ".concat(num, " cannot be represented on this device."));
	        }
	      }
	    }
	  }, {
	    key: "getValuesFromTexture",
	    value: function getValuesFromTexture(dataId) {
	      var _this$texData$get = this.texData.get(dataId),
	        shape = _this$texData$get.shape,
	        dtype = _this$texData$get.dtype,
	        isPacked = _this$texData$get.isPacked;
	      var size = sizeFromShape(shape);
	      if (env().getBool('WEBGL_DOWNLOAD_FLOAT_ENABLED')) {
	        var _this$gpgpu2;
	        var tmpTarget = this.decode(dataId);
	        var _tmpData = this.texData.get(tmpTarget.dataId);
	        var _vals = (_this$gpgpu2 = this.gpgpu).downloadMatrixFromPackedTexture.apply(_this$gpgpu2, [_tmpData.texture.texture].concat(_toConsumableArray(getDenseTexShape(shape)))).subarray(0, size);
	        this.disposeIntermediateTensorInfo(tmpTarget);
	        return _vals;
	      }
	      var shouldUsePackedProgram = env().getBool('WEBGL_PACK') && isPacked === true;
	      var outputShape = shouldUsePackedProgram ? getShapeAs3D(shape) : shape;
	      var program = shouldUsePackedProgram ? new EncodeFloatPackedProgram(outputShape) : new EncodeFloatProgram(outputShape);
	      var output = this.runWebGLProgram(program, [{
	        shape: outputShape,
	        dtype: dtype,
	        dataId: dataId
	      }], 'float32');
	      var tmpData = this.texData.get(output.dataId);
	      var vals = this.gpgpu.downloadByteEncodedFloatMatrixFromOutputTexture(tmpData.texture.texture, tmpData.texShape[0], tmpData.texShape[1]).subarray(0, size);
	      this.disposeIntermediateTensorInfo(output);
	      return vals;
	    }
	  }, {
	    key: "timerAvailable",
	    value: function timerAvailable() {
	      return env().getNumber('WEBGL_DISJOINT_QUERY_TIMER_EXTENSION_RELIABLE') > 0;
	    }
	  }, {
	    key: "time",
	    value: function time(f) {
	      var _this2 = this;
	      var oldActiveTimers = this.activeTimers;
	      var newActiveTimers = [];
	      var outerMostTime = false;
	      if (this.programTimersStack == null) {
	        this.programTimersStack = newActiveTimers;
	        outerMostTime = true;
	      } else {
	        this.activeTimers.push(newActiveTimers);
	      }
	      this.activeTimers = newActiveTimers;
	      f();
	      // needing to split these up because util.flatten only accepts certain types
	      var flattenedActiveTimerQueries = flatten$2(this.activeTimers.map(function (d) {
	        return d.query;
	      })).filter(function (d) {
	        return d != null;
	      });
	      var flattenedActiveTimerNames = flatten$2(this.activeTimers.map(function (d) {
	        return d.name;
	      })).filter(function (d) {
	        return d != null;
	      });
	      this.activeTimers = oldActiveTimers;
	      if (outerMostTime) {
	        this.programTimersStack = null;
	      }
	      var res = {
	        uploadWaitMs: this.uploadWaitMs,
	        downloadWaitMs: this.downloadWaitMs,
	        kernelMs: null,
	        wallMs: null // will be filled by the engine
	      };

	      return _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee2() {
	        var kernelMs;
	        return _regeneratorRuntime().wrap(function _callee2$(_context2) {
	          while (1) switch (_context2.prev = _context2.next) {
	            case 0:
	              if (!(env().getNumber('WEBGL_DISJOINT_QUERY_TIMER_EXTENSION_RELIABLE') > 0)) {
	                _context2.next = 8;
	                break;
	              }
	              _context2.next = 3;
	              return Promise.all(flattenedActiveTimerQueries);
	            case 3:
	              kernelMs = _context2.sent;
	              res['kernelMs'] = sum$4(kernelMs);
	              res['getExtraProfileInfo'] = function () {
	                return kernelMs.map(function (d, i) {
	                  return {
	                    name: flattenedActiveTimerNames[i],
	                    ms: d
	                  };
	                }).map(function (d) {
	                  return "".concat(d.name, ": ").concat(d.ms);
	                }).join(', ');
	              };
	              _context2.next = 9;
	              break;
	            case 8:
	              res['kernelMs'] = {
	                error: 'WebGL query timers are not supported in this environment.'
	              };
	            case 9:
	              _this2.uploadWaitMs = 0;
	              _this2.downloadWaitMs = 0;
	              return _context2.abrupt("return", res);
	            case 12:
	            case "end":
	              return _context2.stop();
	          }
	        }, _callee2);
	      }))();
	    }
	  }, {
	    key: "memory",
	    value: function memory() {
	      return {
	        unreliable: false,
	        numBytesInGPU: this.numBytesInGPU,
	        numBytesInGPUAllocated: this.textureManager.numBytesAllocated,
	        numBytesInGPUFree: this.textureManager.numBytesFree
	      };
	    }
	  }, {
	    key: "startTimer",
	    value: function startTimer() {
	      if (env().getNumber('WEBGL_DISJOINT_QUERY_TIMER_EXTENSION_RELIABLE') > 0) {
	        return this.gpgpu.beginQuery();
	      }
	      return {
	        startMs: now(),
	        endMs: null
	      };
	    }
	  }, {
	    key: "endTimer",
	    value: function endTimer(query) {
	      if (env().getNumber('WEBGL_DISJOINT_QUERY_TIMER_EXTENSION_RELIABLE') > 0) {
	        this.gpgpu.endQuery();
	        return query;
	      }
	      query.endMs = now();
	      return query;
	    }
	  }, {
	    key: "getQueryTime",
	    value: function () {
	      var _getQueryTime = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee3(query) {
	        var timerQuery;
	        return _regeneratorRuntime().wrap(function _callee3$(_context3) {
	          while (1) switch (_context3.prev = _context3.next) {
	            case 0:
	              if (!(env().getNumber('WEBGL_DISJOINT_QUERY_TIMER_EXTENSION_RELIABLE') > 0)) {
	                _context3.next = 2;
	                break;
	              }
	              return _context3.abrupt("return", this.gpgpu.waitForQueryAndGetTime(query));
	            case 2:
	              timerQuery = query;
	              return _context3.abrupt("return", timerQuery.endMs - timerQuery.startMs);
	            case 4:
	            case "end":
	              return _context3.stop();
	          }
	        }, _callee3, this);
	      }));
	      function getQueryTime(_x2) {
	        return _getQueryTime.apply(this, arguments);
	      }
	      return getQueryTime;
	    }()
	    /**
	     * Decrease the RefCount on the dataId and dispose the memory if the dataId
	     * has 0 refCount. If there are pending read on the data, the disposal would
	     * added to the pending delete queue. Return true if the dataId is removed
	     * from backend or the backend does not contain the dataId, false if the
	     * dataId is not removed. Memory may or may not be released even when dataId
	     * is removed, which also depends on dataRefCount, see `releaseGPU`.
	     * @param dataId
	     * @oaram force Optional, remove the data regardless of refCount
	     */
	  }, {
	    key: "disposeData",
	    value: function disposeData(dataId) {
	      var force = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
	      if (this.pendingDisposal.has(dataId)) {
	        return false;
	      }
	      // No-op if already disposed.
	      if (!this.texData.has(dataId)) {
	        return true;
	      }
	      // if force flag is set, change refCount to 0, this would ensure disposal
	      // when added to the pendingDisposal queue. Memory may or may not be
	      // released, which also depends on dataRefCount, see `releaseGPU`.
	      if (force) {
	        this.texData.get(dataId).refCount = 0;
	      } else {
	        this.texData.get(dataId).refCount--;
	      }
	      if (!force && this.texData.get(dataId).refCount > 0) {
	        return false;
	      }
	      if (this.pendingRead.has(dataId)) {
	        this.pendingDisposal.add(dataId);
	        this.pendingDeletes++;
	        return false;
	      }
	      this.releaseGPUData(dataId);
	      var _this$texData$get2 = this.texData.get(dataId),
	        complexTensorInfos = _this$texData$get2.complexTensorInfos;
	      if (complexTensorInfos != null) {
	        this.disposeData(complexTensorInfos.real.dataId, force);
	        this.disposeData(complexTensorInfos.imag.dataId, force);
	      }
	      this.texData.delete(dataId);
	      return true;
	    }
	  }, {
	    key: "releaseGPUData",
	    value: function releaseGPUData(dataId) {
	      var _this$texData$get3 = this.texData.get(dataId),
	        texture = _this$texData$get3.texture,
	        dtype = _this$texData$get3.dtype,
	        texShape = _this$texData$get3.texShape,
	        usage = _this$texData$get3.usage,
	        isPacked = _this$texData$get3.isPacked,
	        slice = _this$texData$get3.slice;
	      var key = slice && slice.origDataId || dataId;
	      var refCount = this.dataRefCount.get(key);
	      if (refCount > 1) {
	        this.dataRefCount.set(key, refCount - 1);
	      } else {
	        this.dataRefCount.delete(key);
	        if (texture != null) {
	          this.numBytesInGPU -= this.computeBytes(texShape, dtype);
	          this.textureManager.releaseTexture(texture, texShape, usage, isPacked);
	        }
	      }
	      var texData = this.texData.get(dataId);
	      texData.texture = null;
	      texData.texShape = null;
	      texData.isPacked = false;
	      texData.slice = null;
	    }
	  }, {
	    key: "getTexture",
	    value: function getTexture(dataId) {
	      this.uploadToGPU(dataId);
	      return this.texData.get(dataId).texture.texture;
	    }
	    /**
	     * Returns internal information for the specific data bucket. Used in unit
	     * tests.
	     */
	  }, {
	    key: "getDataInfo",
	    value: function getDataInfo(dataId) {
	      return this.texData.get(dataId);
	    }
	    /*
	    Tests whether all the inputs to an op are small and on the CPU. This heuristic
	    determines when it would be faster to execute a kernel on the CPU. WebGL
	    kernels opt into running this check and forwarding when appropriate.
	    TODO(https://github.com/tensorflow/tfjs/issues/872): Develop a more
	    sustainable strategy for optimizing backend execution of ops.
	     */
	  }, {
	    key: "shouldExecuteOnCPU",
	    value: function shouldExecuteOnCPU(inputs) {
	      var _this3 = this;
	      var sizeThreshold = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : CPU_HANDOFF_SIZE_THRESHOLD;
	      return env().getBool('WEBGL_CPU_FORWARD') && inputs.every(function (input) {
	        return _this3.texData.get(input.dataId).texture == null && sizeFromShape(input.shape) < sizeThreshold;
	      });
	    }
	  }, {
	    key: "getGPGPUContext",
	    value: function getGPGPUContext() {
	      return this.gpgpu;
	    }
	  }, {
	    key: "where",
	    value: function where(condition) {
	      warn('tf.where() in webgl locks the UI thread. ' + 'Call tf.whereAsync() instead');
	      var condVals = condition.dataSync();
	      return whereImpl(condition.shape, condVals);
	    }
	  }, {
	    key: "packedUnaryOp",
	    value: function packedUnaryOp(x, op, dtype) {
	      var program = new UnaryOpPackedProgram(x.shape, op);
	      var outInfo = this.compileAndRun(program, [x], dtype);
	      return engine().makeTensorFromTensorInfo(outInfo);
	    }
	    // TODO(msoulanille) remove this once the backend has been modularized
	    // a copy is needed here to break a circular dependency.
	    // Also remove the op from unary_op.
	  }, {
	    key: "abs",
	    value: function abs(x) {
	      // TODO: handle cases when x is complex.
	      if (this.shouldExecuteOnCPU([x]) && x.dtype !== 'complex64') {
	        var outValues = simpleAbsImplCPU(this.texData.get(x.dataId).values);
	        return this.makeOutput(x.shape, x.dtype, outValues);
	      }
	      if (env().getBool('WEBGL_PACK_UNARY_OPERATIONS')) {
	        return this.packedUnaryOp(x, ABS$1, x.dtype);
	      }
	      var program = new UnaryOpProgram(x.shape, ABS$1);
	      var outInfo = this.compileAndRun(program, [x]);
	      return engine().makeTensorFromTensorInfo(outInfo);
	    }
	  }, {
	    key: "makeTensorInfo",
	    value: function makeTensorInfo(shape, dtype, values) {
	      var dataId;
	      if (dtype === 'string' && values != null && values.length > 0 && isString(values[0])) {
	        var encodedValues = values.map(function (d) {
	          return encodeString(d);
	        });
	        dataId = this.write(encodedValues, shape, dtype);
	      } else {
	        dataId = this.write(values, shape, dtype);
	      }
	      this.texData.get(dataId).usage = null;
	      return {
	        dataId: dataId,
	        shape: shape,
	        dtype: dtype
	      };
	    }
	  }, {
	    key: "makeOutput",
	    value: function makeOutput(shape, dtype, values) {
	      return engine().makeTensorFromTensorInfo(this.makeTensorInfo(shape, dtype, values), this);
	    }
	  }, {
	    key: "unpackTensor",
	    value: function unpackTensor(input) {
	      var program = new UnpackProgram(input.shape);
	      return this.runWebGLProgram(program, [input], input.dtype);
	    }
	  }, {
	    key: "packTensor",
	    value: function packTensor(input) {
	      var program = new PackProgram(input.shape);
	      var preventEagerUnpackingOutput = true;
	      return this.runWebGLProgram(program, [input], input.dtype, null /* customUniformValues */, preventEagerUnpackingOutput);
	    }
	  }, {
	    key: "packedReshape",
	    value: function packedReshape(input, afterShape) {
	      var input3DShape = [getBatchDim(input.shape)].concat(_toConsumableArray(getRowsCols(input.shape)));
	      var input3D = {
	        dtype: input.dtype,
	        shape: input3DShape,
	        dataId: input.dataId
	      };
	      var afterShapeAs3D = [getBatchDim(afterShape)].concat(_toConsumableArray(getRowsCols(afterShape)));
	      var program = new ReshapePackedProgram(afterShapeAs3D, input3DShape);
	      var preventEagerUnpackingOfOutput = true;
	      var customValues = [input3DShape];
	      var output = this.runWebGLProgram(program, [input3D], input.dtype, customValues, preventEagerUnpackingOfOutput);
	      return {
	        dataId: output.dataId,
	        shape: afterShape,
	        dtype: output.dtype
	      };
	    }
	  }, {
	    key: "decode",
	    value: function decode(dataId, customTexShape) {
	      var texData = this.texData.get(dataId);
	      var isPacked = texData.isPacked,
	        shape = texData.shape,
	        dtype = texData.dtype;
	      if (customTexShape != null) {
	        var size = sizeFromShape(shape);
	        var texSize = customTexShape[0] * customTexShape[1] * 4;
	        assert$1(size <= texSize, function () {
	          return 'customTexShape is too small. ' + 'Row * Column * 4 should be equal or larger than the ' + 'size of the tensor data.';
	        });
	      }
	      var shapeAs3D = getShapeAs3D(shape);
	      var program;
	      if (isPacked) {
	        program = new DecodeMatrixPackedProgram(shapeAs3D);
	      } else {
	        program = new DecodeMatrixProgram(shapeAs3D);
	      }
	      var preventEagerUnpackingOfOutput = true;
	      var customValues = [customTexShape != null ? customTexShape : getDenseTexShape(shapeAs3D)];
	      var out = this.runWebGLProgram(program, [{
	        shape: shapeAs3D,
	        dtype: dtype,
	        dataId: dataId
	      }], dtype, customValues, preventEagerUnpackingOfOutput, customTexShape);
	      return {
	        dtype: dtype,
	        shape: shape,
	        dataId: out.dataId
	      };
	    }
	  }, {
	    key: "runWebGLProgram",
	    value: function runWebGLProgram(program, inputs, outputDtype, customUniformValues) {
	      var _this4 = this;
	      var preventEagerUnpackingOfOutput = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
	      var customTexShape = arguments.length > 5 ? arguments[5] : undefined;
	      var output = this.makeTensorInfo(program.outputShape, outputDtype);
	      var outData = this.texData.get(output.dataId);
	      if (program.packedOutput) {
	        outData.isPacked = true;
	      }
	      if (program.outPackingScheme === PackingScheme.DENSE) {
	        var texelShape = customTexShape != null ? customTexShape : getDenseTexShape(program.outputShape);
	        // For a densely packed output, we explicitly set texShape
	        // so it doesn't get assigned later according to our typical packing
	        // scheme wherein a single texel can only contain values from adjacent
	        // rows/cols.
	        outData.texShape = texelShape.map(function (d) {
	          return d * 2;
	        });
	      }
	      if (program.outTexUsage != null) {
	        outData.usage = program.outTexUsage;
	      }
	      if (sizeFromShape(output.shape) === 0) {
	        // Short-circuit the computation since the result is empty (has 0 in its
	        // shape).
	        outData.values = getTypedArrayFromDType(output.dtype, 0);
	        return output;
	      }
	      var dataToDispose = [];
	      var inputsData = inputs.map(function (input) {
	        if (input.dtype === 'complex64') {
	          throw new Error("GPGPUProgram does not support complex64 input. For complex64 " + "dtypes, please separate the program into real and imaginary " + "parts.");
	        }
	        var texData = _this4.texData.get(input.dataId);
	        if (texData.texture == null) {
	          if (!program.packedInputs && sizeFromShape(input.shape) <= env().getNumber('WEBGL_SIZE_UPLOAD_UNIFORM')) {
	            // Upload small tensors that live on the CPU as uniforms, not as
	            // textures. Do this only when the environment supports 32bit floats
	            // due to problems when comparing 16bit floats with 32bit floats.
	            // TODO(https://github.com/tensorflow/tfjs/issues/821): Make it
	            // possible for packed shaders to sample from uniforms.
	            return {
	              shape: input.shape,
	              texData: null,
	              isUniform: true,
	              uniformValues: texData.values
	            };
	          }
	          // This ensures that if a packed program's inputs have not yet been
	          // uploaded to the GPU, they get uploaded as packed right off the bat.
	          if (program.packedInputs) {
	            texData.isPacked = true;
	            texData.shape = input.shape;
	          }
	        }
	        _this4.uploadToGPU(input.dataId);
	        if (!!texData.isPacked !== !!program.packedInputs) {
	          input = texData.isPacked ? _this4.unpackTensor(input) : _this4.packTensor(input);
	          dataToDispose.push(input);
	          texData = _this4.texData.get(input.dataId);
	        } else if (texData.isPacked && !isReshapeFree(texData.shape, input.shape)) {
	          // This is a special case where a texture exists for a tensor
	          // but the shapes are incompatible (due to packing constraints) because
	          // the tensor did not have a chance to go through the packed reshape
	          // shader. This only happens when we reshape the *same* tensor to form
	          // *distinct* inputs to an op, e.g. dotting a vector with itself. This
	          // case will disappear once packed uploading is the default.
	          var savedInput = input;
	          var targetShape = input.shape;
	          input.shape = texData.shape;
	          input = _this4.packedReshape(input, targetShape);
	          dataToDispose.push(input);
	          texData = _this4.texData.get(input.dataId);
	          savedInput.shape = targetShape;
	        }
	        return {
	          shape: input.shape,
	          texData: texData,
	          isUniform: false
	        };
	      });
	      this.uploadToGPU(output.dataId);
	      var outputData = {
	        shape: output.shape,
	        texData: outData,
	        isUniform: false
	      };
	      var key = makeShaderKey(program, inputsData, outputData);
	      var binary = this.getAndSaveBinary(key, function () {
	        return compileProgram(_this4.gpgpu, program, inputsData, outputData);
	      });
	      var shouldTimeProgram = this.activeTimers != null;
	      var query;
	      if (shouldTimeProgram) {
	        query = this.startTimer();
	      }
	      if (!env().get('ENGINE_COMPILE_ONLY')) {
	        runProgram(this.gpgpu, binary, inputsData, outputData, customUniformValues);
	      }
	      dataToDispose.forEach(function (info) {
	        return _this4.disposeIntermediateTensorInfo(info);
	      });
	      if (shouldTimeProgram) {
	        query = this.endTimer(query);
	        this.activeTimers.push({
	          name: program.constructor.name,
	          query: this.getQueryTime(query)
	        });
	      }
	      var glFlushThreshold = env().getNumber('WEBGL_FLUSH_THRESHOLD');
	      // Manually GL flush requested
	      if (glFlushThreshold > 0) {
	        var time = now();
	        if (time - this.lastGlFlushTime > glFlushThreshold) {
	          this.gpgpu.gl.flush();
	          this.lastGlFlushTime = time;
	        }
	      }
	      if (!env().getBool('WEBGL_LAZILY_UNPACK') && outData.isPacked && preventEagerUnpackingOfOutput === false) {
	        var unpacked = this.unpackTensor(output);
	        this.disposeIntermediateTensorInfo(output);
	        return unpacked;
	      }
	      return output;
	    }
	  }, {
	    key: "compileAndRun",
	    value: function compileAndRun(program, inputs, outputDtype, customUniformValues) {
	      var preventEagerUnpackingOfOutput = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
	      outputDtype = outputDtype || inputs[0].dtype;
	      var outInfo = this.runWebGLProgram(program, inputs, outputDtype, customUniformValues, preventEagerUnpackingOfOutput);
	      return outInfo;
	    }
	  }, {
	    key: "getAndSaveBinary",
	    value: function getAndSaveBinary(key, getBinary) {
	      if (!(key in this.binaryCache)) {
	        this.binaryCache[key] = getBinary();
	      }
	      return this.binaryCache[key];
	    }
	  }, {
	    key: "getTextureManager",
	    value: function getTextureManager() {
	      return this.textureManager;
	    }
	  }, {
	    key: "dispose",
	    value: function dispose() {
	      var _this5 = this;
	      if (this.disposed) {
	        return;
	      }
	      // Avoid disposing the compiled webgl programs during unit testing because
	      // it slows down test execution.
	      if (!env().getBool('IS_TEST')) {
	        var allKeys = Object.keys(this.binaryCache);
	        allKeys.forEach(function (key) {
	          _this5.gpgpu.deleteProgram(_this5.binaryCache[key].webGLProgram);
	          delete _this5.binaryCache[key];
	        });
	      }
	      this.textureManager.dispose();
	      if (this.canvas != null && typeof HTMLCanvasElement !== 'undefined' && this.canvas instanceof HTMLCanvasElement) {
	        this.canvas.remove();
	      } else {
	        this.canvas = null;
	      }
	      if (this.gpgpuCreatedLocally) {
	        this.gpgpu.program = null;
	        this.gpgpu.dispose();
	      }
	      this.disposed = true;
	    }
	  }, {
	    key: "floatPrecision",
	    value: function floatPrecision() {
	      var _this6 = this;
	      if (this.floatPrecisionValue == null) {
	        this.floatPrecisionValue = tidy(function () {
	          if (!env().get('WEBGL_RENDER_FLOAT32_ENABLED')) {
	            // Momentarily switching DEBUG flag to false so we don't throw an
	            // error trying to upload a small value.
	            var debugFlag = env().getBool('DEBUG');
	            env().set('DEBUG', false);
	            var underflowCheckValue = _this6.abs(scalar(1e-8)).dataSync()[0];
	            env().set('DEBUG', debugFlag);
	            if (underflowCheckValue > 0) {
	              return 32;
	            }
	          }
	          return 16;
	        });
	      }
	      return this.floatPrecisionValue;
	    }
	    /** Returns the smallest representable number.  */
	  }, {
	    key: "epsilon",
	    value: function epsilon() {
	      return this.floatPrecision() === 32 ? EPSILON_FLOAT32 : EPSILON_FLOAT16;
	    }
	  }, {
	    key: "uploadToGPU",
	    value: function uploadToGPU(dataId) {
	      var texData = this.texData.get(dataId);
	      var shape = texData.shape,
	        dtype = texData.dtype,
	        values = texData.values,
	        texture = texData.texture,
	        usage = texData.usage,
	        isPacked = texData.isPacked;
	      if (texture != null) {
	        // Array is already on GPU. No-op.
	        return;
	      }
	      var shouldTimeProgram = this.activeTimers != null;
	      var start;
	      if (shouldTimeProgram) {
	        start = now();
	      }
	      var texShape = texData.texShape;
	      if (texShape == null) {
	        // This texShape may not be the final texture shape. For packed or dense
	        // textures, the texShape will be changed when textures are created.
	        texShape = getTextureShapeFromLogicalShape(shape, isPacked);
	        texData.texShape = texShape;
	      }
	      if (values != null) {
	        var shapeAs3D = getShapeAs3D(shape);
	        var program;
	        var width = texShape[1],
	          height = texShape[0];
	        var isByteArray = values instanceof Uint8Array || values instanceof Uint8ClampedArray;
	        // texture for float array is PhysicalTextureType.PACKED_2X2_FLOAT32, we
	        // need to make sure the upload uses the same packed size
	        if (isPacked || !isByteArray) {
	          var _tex_util$getPackedMa = getPackedMatrixTextureShapeWidthHeight(texShape[0], texShape[1]);
	          var _tex_util$getPackedMa2 = _slicedToArray(_tex_util$getPackedMa, 2);
	          width = _tex_util$getPackedMa2[0];
	          height = _tex_util$getPackedMa2[1];
	        }
	        if (isPacked) {
	          program = new EncodeMatrixPackedProgram(shapeAs3D, isByteArray);
	        } else {
	          program = new EncodeMatrixProgram(shapeAs3D, isByteArray);
	        }
	        // TexShape for float array needs to be the original shape, which byte
	        // array needs to be packed size. This allow the data upload shape to be
	        // matched with texture creation logic.
	        var tempDenseInputTexShape = isByteArray ? [height, width] : texShape;
	        var tempDenseInputHandle = this.makeTensorInfo(tempDenseInputTexShape, dtype);
	        var tempDenseInputTexData = this.texData.get(tempDenseInputHandle.dataId);
	        if (isByteArray) {
	          tempDenseInputTexData.usage = TextureUsage.PIXELS;
	        } else {
	          tempDenseInputTexData.usage = TextureUsage.UPLOAD;
	        }
	        tempDenseInputTexData.texShape = tempDenseInputTexShape;
	        this.gpgpu.uploadDenseMatrixToTexture(this.getTexture(tempDenseInputHandle.dataId), width, height, values);
	        var customValues = [[height, width]];
	        // We want the output to remain packed regardless of the value of
	        // WEBGL_PACK.
	        var preventEagerUnpacking = true;
	        var encodedOutputTarget = this.runWebGLProgram(program, [tempDenseInputHandle], dtype, customValues, preventEagerUnpacking);
	        // Have the original texture assume the identity of the encoded output.
	        var outputTexData = this.texData.get(encodedOutputTarget.dataId);
	        texData.texShape = outputTexData.texShape;
	        texData.isPacked = outputTexData.isPacked;
	        texData.usage = outputTexData.usage;
	        if (!env().get('ENGINE_COMPILE_ONLY')) {
	          texData.texture = outputTexData.texture;
	          // Once uploaded, don't store the values on cpu.
	          texData.values = null;
	          this.texData.delete(encodedOutputTarget.dataId);
	        } else {
	          this.disposeData(encodedOutputTarget.dataId);
	        }
	        this.disposeIntermediateTensorInfo(tempDenseInputHandle);
	        if (shouldTimeProgram) {
	          this.uploadWaitMs += now() - start;
	        }
	      } else {
	        var newTexture = this.acquireTexture(texShape, usage, dtype, isPacked);
	        texData.texture = newTexture;
	      }
	    }
	  }, {
	    key: "convertAndCacheOnCPU",
	    value: function convertAndCacheOnCPU(dataId, float32Values) {
	      var texData = this.texData.get(dataId);
	      var dtype = texData.dtype;
	      if (float32Values != null) {
	        texData.values = float32ToTypedArray(float32Values, dtype);
	      }
	      return texData.values;
	    }
	  }, {
	    key: "acquireTexture",
	    value: function acquireTexture(texShape, texType, dtype, isPacked) {
	      this.numBytesInGPU += this.computeBytes(texShape, dtype);
	      if (!this.warnedAboutMemory && this.numBytesInGPU > this.numMBBeforeWarning * 1024 * 1024) {
	        var mb = (this.numBytesInGPU / 1024 / 1024).toFixed(2);
	        this.warnedAboutMemory = true;
	        console.warn("High memory usage in GPU: ".concat(mb, " MB, ") + "most likely due to a memory leak");
	      }
	      return this.textureManager.acquireTexture(texShape, texType, isPacked);
	    }
	  }, {
	    key: "computeBytes",
	    value: function computeBytes(shape, dtype) {
	      return shape[0] * shape[1] * bytesPerElement(dtype);
	    }
	  }, {
	    key: "checkCompileCompletion",
	    value: function checkCompileCompletion() {
	      for (var _i = 0, _Object$entries = Object.entries(this.binaryCache); _i < _Object$entries.length; _i++) {
	        var _Object$entries$_i = _slicedToArray(_Object$entries[_i], 2),
	          binary = _Object$entries$_i[1];
	        this.checkCompletion_(binary);
	      }
	    }
	  }, {
	    key: "checkCompileCompletionAsync",
	    value: function () {
	      var _checkCompileCompletionAsync = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee4() {
	        var _this7 = this;
	        var ps, _i2, _Object$entries2, _Object$entries2$_i, binary, _loop, _i3, _Object$entries3;
	        return _regeneratorRuntime().wrap(function _callee4$(_context5) {
	          while (1) switch (_context5.prev = _context5.next) {
	            case 0:
	              ps = [];
	              if (!this.gpgpu.parallelCompilationExtension) {
	                _context5.next = 6;
	                break;
	              }
	              for (_i2 = 0, _Object$entries2 = Object.entries(this.binaryCache); _i2 < _Object$entries2.length; _i2++) {
	                _Object$entries2$_i = _slicedToArray(_Object$entries2[_i2], 2), binary = _Object$entries2$_i[1];
	                ps.push(this.checkCompletionAsync_(binary));
	              }
	              return _context5.abrupt("return", Promise.all(ps));
	            case 6:
	              _loop = /*#__PURE__*/_regeneratorRuntime().mark(function _loop() {
	                var _Object$entries3$_i, binary, p;
	                return _regeneratorRuntime().wrap(function _loop$(_context4) {
	                  while (1) switch (_context4.prev = _context4.next) {
	                    case 0:
	                      _Object$entries3$_i = _slicedToArray(_Object$entries3[_i3], 2), binary = _Object$entries3$_i[1];
	                      p = new Promise(function (resolve) {
	                        try {
	                          _this7.checkCompletion_(binary);
	                          resolve(true);
	                        } catch (error) {
	                          throw error;
	                        }
	                      });
	                      ps.push(p);
	                    case 3:
	                    case "end":
	                      return _context4.stop();
	                  }
	                }, _loop);
	              });
	              _i3 = 0, _Object$entries3 = Object.entries(this.binaryCache);
	            case 8:
	              if (!(_i3 < _Object$entries3.length)) {
	                _context5.next = 13;
	                break;
	              }
	              return _context5.delegateYield(_loop(), "t0", 10);
	            case 10:
	              _i3++;
	              _context5.next = 8;
	              break;
	            case 13:
	              return _context5.abrupt("return", Promise.all(ps));
	            case 14:
	            case "end":
	              return _context5.stop();
	          }
	        }, _callee4, this);
	      }));
	      function checkCompileCompletionAsync() {
	        return _checkCompileCompletionAsync.apply(this, arguments);
	      }
	      return checkCompileCompletionAsync;
	    }()
	  }, {
	    key: "checkCompletionAsync_",
	    value: function () {
	      var _checkCompletionAsync_ = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime().mark(function _callee5(binary) {
	        return _regeneratorRuntime().wrap(function _callee5$(_context6) {
	          while (1) switch (_context6.prev = _context6.next) {
	            case 0:
	              if (!this.gpgpu.gl.getProgramParameter(binary.webGLProgram, this.gpgpu.parallelCompilationExtension.COMPLETION_STATUS_KHR)) {
	                _context6.next = 4;
	                break;
	              }
	              return _context6.abrupt("return", this.checkCompletion_(binary));
	            case 4:
	              _context6.next = 6;
	              return nextFrame();
	            case 6:
	              return _context6.abrupt("return", this.checkCompletionAsync_(binary));
	            case 7:
	            case "end":
	              return _context6.stop();
	          }
	        }, _callee5, this);
	      }));
	      function checkCompletionAsync_(_x3) {
	        return _checkCompletionAsync_.apply(this, arguments);
	      }
	      return checkCompletionAsync_;
	    }()
	  }, {
	    key: "checkCompletion_",
	    value: function checkCompletion_(binary) {
	      if (this.gpgpu.gl.getProgramParameter(binary.webGLProgram, this.gpgpu.gl.LINK_STATUS) === false) {
	        console.log(this.gpgpu.gl.getProgramInfoLog(binary.webGLProgram));
	        if (this.gpgpu.gl.getShaderParameter(binary.fragmentShader, this.gpgpu.gl.COMPILE_STATUS) === false) {
	          logShaderSourceAndInfoLog(binary.source, this.gpgpu.gl.getShaderInfoLog(binary.fragmentShader));
	          throw new Error('Failed to compile fragment shader.');
	        }
	        throw new Error('Failed to link vertex and fragment shaders.');
	      }
	      return true;
	    }
	  }, {
	    key: "getUniformLocations",
	    value: function getUniformLocations$1() {
	      for (var _i4 = 0, _Object$values = Object.values(this.binaryCache); _i4 < _Object$values.length; _i4++) {
	        var binary = _Object$values[_i4];
	        // TODO: Iterating through all binaries to build VAOs is supposed to be in
	        // a seperate function, like 'setVaos'. However, to avoid breaking changes
	        // for the users using parallel compile feature now, buildVao is silently
	        // added here.
	        this.gpgpu.buildVao(binary.webGLProgram);
	        var _getUniformLocations2 = getUniformLocations(this.gpgpu, binary.program, binary.webGLProgram),
	          variablesLocations = _getUniformLocations2.variablesLocations,
	          customUniformLocations = _getUniformLocations2.customUniformLocations,
	          infLoc = _getUniformLocations2.infLoc,
	          nanLoc = _getUniformLocations2.nanLoc,
	          outShapeLocation = _getUniformLocations2.outShapeLocation,
	          outShapeStridesLocation = _getUniformLocations2.outShapeStridesLocation,
	          outTexShapeLocation = _getUniformLocations2.outTexShapeLocation;
	        binary.variablesLocations = variablesLocations;
	        binary.customUniformLocations = customUniformLocations;
	        binary.infLoc = infLoc;
	        binary.nanLoc = nanLoc;
	        binary.outShapeLocation = outShapeLocation;
	        binary.outShapeStridesLocation = outShapeStridesLocation;
	        binary.outTexShapeLocation = outTexShapeLocation;
	      }
	    }
	    /**
	     * Create a TF.js tensor out of an existing WebGL texture. A new texture will
	     * be created.
	     */
	  }, {
	    key: "createTensorFromGPUData",
	    value: function createTensorFromGPUData(values, shape, dtype) {
	      values.channels = values.channels || 'RGBA';
	      var texture = values.texture,
	        height = values.height,
	        width = values.width,
	        channels = values.channels;
	      var backend = engine().backend;
	      // Have to throw an error, otherwise WebGL just warns and returns wrong
	      // values.
	      if (!backend.gpgpu.gl.isTexture(texture)) {
	        throw new Error("The texture is invalid. Also, please make sure the texture and " + "the TFJS WebGL backend are using the same canvas. If you want to " + "use your own custom canvas, you have to create and use the custom " + "TFJS WebGL backend created from the canvas through " + "'new tf.MathBackendWebGL(customCanvas)'.");
	      }
	      var dataId = backend.writeTexture(texture, shape, dtype, height, width, channels);
	      return engine().makeTensorFromDataId(dataId, shape, dtype, backend);
	    }
	  }]);
	  return MathBackendWebGL;
	}(KernelBackend);
	MathBackendWebGL.nextDataId = 0;
	function float32ToTypedArray(a, dtype) {
	  if (dtype === 'float32' || dtype === 'complex64') {
	    return a;
	  } else if (dtype === 'int32' || dtype === 'bool') {
	    var result = dtype === 'int32' ? new Int32Array(a.length) : new Uint8Array(a.length);
	    for (var i = 0; i < result.length; ++i) {
	      result[i] = Math.round(a[i]);
	    }
	    return result;
	  } else {
	    throw new Error("Unknown dtype ".concat(dtype));
	  }
	}

	/** @license See the LICENSE file. */
	// This code is auto-generated, do not modify this file!
	var version$2 = '4.22.0';

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * Enforce use of half precision textures if available on the platform.
	 *
	 * @doc {heading: 'Environment', namespace: 'webgl'}
	 */
	function forceHalfFloat() {
	  env().set('WEBGL_FORCE_F16_TEXTURES', true);
	}

	/**
	 * @license
	 * Copyright 2020 Google Inc. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	if (isBrowser()) {
	  registerBackend('webgl', function () {
	    return new MathBackendWebGL();
	  }, 2 /* priority */);
	}
	var webgl = {
	  forceHalfFloat: forceHalfFloat
	};

	var CHECK_NAN_SNIPPET = "\n  if (isnan(a)) return a;\n  if (isnan(b)) return b;\n";
	var SQUARED_DIFFERENCE$1 = 'return (a - b) * (a - b);';
	var BinaryOpProgram = /*#__PURE__*/_createClass(function BinaryOpProgram(op, aShape, bShape) {
	  _classCallCheck(this, BinaryOpProgram);
	  this.variableNames = ['A', 'B'];
	  this.outputShape = assertAndGetBroadcastShape(aShape, bShape);
	  this.enableShapeUniforms = useShapeUniforms(this.outputShape.length);
	  this.userCode = "\n      float binaryOperation(float a, float b) {\n        ".concat(op, "\n      }\n\n      void main() {\n        float a = getAAtOutCoords();\n        float b = getBAtOutCoords();\n        setOutput(binaryOperation(a, b));\n      }\n    ");
	});

	var CHECK_NAN_SNIPPET_PACKED = "\n  result.r = isNaN.r ? NAN : result.r;\n  result.g = isNaN.g ? NAN : result.g;\n  result.b = isNaN.b ? NAN : result.b;\n  result.a = isNaN.a ? NAN : result.a;\n";
	var ELU_DER$1 = "\n  vec4 bGTEZero = vec4(greaterThanEqual(b, vec4(0.)));\n  return (bGTEZero * a) + ((vec4(1.0) - bGTEZero) * (a * (b + vec4(1.0))));\n";
	var NOT_EQUAL$1 = "\n  return vec4(notEqual(a, b));\n";
	var BinaryOpPackedProgram = /*#__PURE__*/_createClass(function BinaryOpPackedProgram(op, aShape, bShape) {
	  var checkOutOfBounds = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  _classCallCheck(this, BinaryOpPackedProgram);
	  this.variableNames = ['A', 'B'];
	  this.supportsBroadcasting = true;
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.outputShape = assertAndGetBroadcastShape(aShape, bShape);
	  var rank = this.outputShape.length;
	  this.enableShapeUniforms = useShapeUniforms(rank);
	  var checkOutOfBoundsString = '';
	  if (checkOutOfBounds) {
	    if (rank === 0 || sizeFromShape(this.outputShape) === 1) {
	      checkOutOfBoundsString = "\n          result.y = 0.;\n          result.z = 0.;\n          result.w = 0.;\n        ";
	    } else {
	      var dtype = getCoordsDataType(rank);
	      checkOutOfBoundsString = "\n          ".concat(dtype, " coords = getOutputCoords();\n        ");
	      if (rank === 1) {
	        if (this.enableShapeUniforms) {
	          checkOutOfBoundsString += "\n            result.y = (coords + 1) >= outShape ? 0. : result.y;\n            result.z = 0.;\n            result.w = 0.;\n          ";
	        } else {
	          checkOutOfBoundsString += "\n            result.y = (coords + 1) >= ".concat(this.outputShape[0], " ? 0. : result.y;\n            result.z = 0.;\n            result.w = 0.;\n          ");
	        }
	      } else {
	        var channels = getChannels('coords', rank);
	        if (this.enableShapeUniforms) {
	          checkOutOfBoundsString += "\n            bool nextRowOutOfBounds =\n              (".concat(channels[rank - 2], " + 1) >= outShape[").concat(rank, " - 2];\n            bool nextColOutOfBounds =\n              (").concat(channels[rank - 1], " + 1) >= outShape[").concat(rank, " - 1];\n            result.y = nextColOutOfBounds ? 0. : result.y;\n            result.z = nextRowOutOfBounds ? 0. : result.z;\n            result.w = nextColOutOfBounds || nextRowOutOfBounds ? 0. : result.w;\n          ");
	        } else {
	          checkOutOfBoundsString += "\n            bool nextRowOutOfBounds =\n              (".concat(channels[rank - 2], " + 1) >= ").concat(this.outputShape[rank - 2], ";\n            bool nextColOutOfBounds =\n              (").concat(channels[rank - 1], " + 1) >= ").concat(this.outputShape[rank - 1], ";\n            result.y = nextColOutOfBounds ? 0. : result.y;\n            result.z = nextRowOutOfBounds ? 0. : result.z;\n            result.w = nextColOutOfBounds || nextRowOutOfBounds ? 0. : result.w;\n          ");
	        }
	      }
	    }
	  }
	  this.userCode = "\n      vec4 binaryOperation(vec4 a, vec4 b) {\n        ".concat(op, "\n      }\n\n      void main() {\n        vec4 a = getAAtOutCoords();\n        vec4 b = getBAtOutCoords();\n\n        vec4 result = binaryOperation(a, b);\n        ").concat(checkOutOfBoundsString, "\n\n        setOutput(result);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function identity(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var x = inputs.x;
	  backend.incRef(x.dataId);
	  return {
	    dataId: x.dataId,
	    shape: x.shape,
	    dtype: x.dtype
	  };
	}
	var identityConfig = {
	  kernelName: Identity$1,
	  backendName: 'webgl',
	  kernelFunc: identity
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	/**
	 * In WebGL data is stored in GPU textures which can't be efficiently copied, so
	 * complex tensors share data with their real and imaginary components. Complex
	 * tensors' reference to the components is tracked by refCount on the individual
	 * component. The refCounts are increased by the identity call.
	 *
	 * When a complex tensor is disposed, it will reduce the refCount on the
	 * components by calling disposeData on each.
	 */
	function complex(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var real = inputs.real,
	    imag = inputs.imag;
	  var complexInfo = backend.makeTensorInfo(real.shape, 'complex64');
	  var complex = backend.texData.get(complexInfo.dataId);
	  var realTensorInfo = identity({
	    inputs: {
	      x: real
	    },
	    backend: backend
	  });
	  var imagTensorInfo = identity({
	    inputs: {
	      x: imag
	    },
	    backend: backend
	  });
	  complex.complexTensorInfos = {
	    real: realTensorInfo,
	    imag: imagTensorInfo
	  };
	  return complexInfo;
	}
	var complexConfig = {
	  kernelName: Complex,
	  backendName: 'webgl',
	  kernelFunc: complex
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var LEAKYRELU = "return (a < 0.) ? b * a : a;";
	var LEAKYRELU_PACKED = "\n  vec4 aLessThanZero = vec4(lessThan(a, vec4(0.)));\n  return (aLessThanZero * (b * a)) + ((vec4(1.0) - aLessThanZero) * a);\n";
	function leakyRelu(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var alpha = attrs.alpha;
	  var $alpha = backend.makeTensorInfo([], 'float32', createScalarValue(alpha, 'float32'));
	  var program = env().getBool('WEBGL_PACK_BINARY_OPERATIONS') ? new BinaryOpPackedProgram(LEAKYRELU_PACKED, x.shape, $alpha.shape) : new BinaryOpProgram(LEAKYRELU, x.shape, $alpha.shape);
	  var result = backend.runWebGLProgram(program, [x, $alpha], 'float32');
	  backend.disposeIntermediateTensorInfo($alpha);
	  return result;
	}
	var leakyReluConfig = {
	  kernelName: LeakyRelu,
	  backendName: 'webgl',
	  kernelFunc: leakyRelu
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var PRELU = "return (a < 0.) ? b * a : a;";
	var PRELU_PACKED = "\n  vec4 aLessThanZero = vec4(lessThan(a, vec4(0.)));\n  return (aLessThanZero * (b * a)) + ((vec4(1.0) - aLessThanZero) * a);\n";
	function prelu(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var x = inputs.x,
	    alpha = inputs.alpha;
	  var program = env().getBool('WEBGL_PACK_BINARY_OPERATIONS') ? new BinaryOpPackedProgram(PRELU_PACKED, x.shape, alpha.shape) : new BinaryOpProgram(PRELU, x.shape, alpha.shape);
	  return backend.runWebGLProgram(program, [x, alpha], 'float32');
	}
	var preluConfig = {
	  kernelName: Prelu,
	  backendName: 'webgl',
	  kernelFunc: prelu
	};

	var CHECK_NAN_SNIPPET_UNARY = "if (isnan(x)) return x;";
	/**
	 * Template that creates a `KernelFunc` for unary ops.
	 * @param opSnippet Op snippet to create `UnaryOpProgram`.
	 * @param packedOpSnippet Op snippet to create `UnaryOpPackedProgram`.
	 * @param dtype Optional. If set, the result has this dtype. Otherwise, the
	 *     result has the same dtype as the first input. This is mainly used in
	 *     comparison kernels, such as Equal, Less, Greater, etc.
	 */
	function unaryKernelFunc(_ref) {
	  var opSnippet = _ref.opSnippet,
	    packedOpSnippet = _ref.packedOpSnippet,
	    cpuKernelImpl = _ref.cpuKernelImpl,
	    dtype = _ref.dtype;
	  return function (_ref2) {
	    var inputs = _ref2.inputs,
	      backend = _ref2.backend;
	    var x = inputs.x;
	    var webglBackend = backend;
	    var $dtype = dtype || x.dtype;
	    if (webglBackend.shouldExecuteOnCPU([x]) && cpuKernelImpl != null) {
	      var xData = webglBackend.texData.get(x.dataId);
	      var outValues = cpuKernelImpl(xData.values, $dtype);
	      return webglBackend.makeTensorInfo(x.shape, $dtype, outValues);
	    }
	    var shouldUsePackedProgram = env().getBool('WEBGL_PACK_UNARY_OPERATIONS') && packedOpSnippet != null;
	    var program;
	    if (shouldUsePackedProgram) {
	      program = new UnaryOpPackedProgram(x.shape, packedOpSnippet);
	    } else {
	      program = new UnaryOpProgram(x.shape, opSnippet);
	    }
	    return webglBackend.runWebGLProgram(program, [x], $dtype);
	  };
	}
	/**
	 * Template that creates a `KernelFunc` for binary ops.
	 * @param opSnippet Op snippet to create `BinaryOpProgram`.
	 * @param packedOpSnippet Op snippet to create `BinaryOpPackedProgram`.
	 * @param checkOutOfBoundsForPackedProgram Whether to set checkOutOfBounds=true
	 *     when creating BinaryOpPackedProgram.
	 * @param dtype Optional. If set, the result has this dtype. Otherwise, the
	 *     result has the same dtype as the first input. This is mainly used in
	 *     comparison kernels, such as Equal, Less, Greater, etc.
	 */
	function binaryKernelFunc(_ref3) {
	  var opSnippet = _ref3.opSnippet,
	    packedOpSnippet = _ref3.packedOpSnippet,
	    _ref3$checkOutOfBound = _ref3.checkOutOfBounds,
	    checkOutOfBounds = _ref3$checkOutOfBound === void 0 ? false : _ref3$checkOutOfBound,
	    _ref3$supportsComplex = _ref3.supportsComplex,
	    supportsComplex = _ref3$supportsComplex === void 0 ? false : _ref3$supportsComplex,
	    cpuKernelImpl = _ref3.cpuKernelImpl,
	    dtype = _ref3.dtype;
	  return function (_ref4) {
	    var inputs = _ref4.inputs,
	      backend = _ref4.backend;
	    var a = inputs.a,
	      b = inputs.b;
	    var webglBackend = backend;
	    if (supportsComplex && a.dtype === 'complex64') {
	      var aData = webglBackend.texData.get(a.dataId);
	      var bData = webglBackend.texData.get(b.dataId);
	      var _map = [[aData.complexTensorInfos.real, bData.complexTensorInfos.real], [aData.complexTensorInfos.imag, bData.complexTensorInfos.imag]].map(function (complexParts) {
	          var _complexParts = _slicedToArray(complexParts, 2),
	            aPart = _complexParts[0],
	            bPart = _complexParts[1];
	          var aHandle = {
	            dataId: aPart.dataId,
	            dtype: aPart.dtype,
	            shape: a.shape
	          };
	          var bHandle = {
	            dataId: bPart.dataId,
	            dtype: bPart.dtype,
	            shape: b.shape
	          };
	          var program = new BinaryOpProgram(opSnippet, a.shape, b.shape);
	          return webglBackend.runWebGLProgram(program, [aHandle, bHandle], upcastType(aPart.dtype, bPart.dtype));
	        }),
	        _map2 = _slicedToArray(_map, 2),
	        real = _map2[0],
	        imag = _map2[1];
	      var complexOutput = complex({
	        inputs: {
	          real: real,
	          imag: imag
	        },
	        backend: webglBackend
	      });
	      webglBackend.disposeIntermediateTensorInfo(real);
	      webglBackend.disposeIntermediateTensorInfo(imag);
	      // TODO(annxingyuan): Implement CPU forwarding for complex inputs.
	      return complexOutput;
	    }
	    var $dtype = dtype || upcastType(a.dtype, b.dtype);
	    if ((a.dtype === 'string' || b.dtype === 'string' || webglBackend.shouldExecuteOnCPU([a, b])) && cpuKernelImpl != null) {
	      var aVals = webglBackend.texData.get(a.dataId).values;
	      var bVals = webglBackend.texData.get(b.dataId).values;
	      var decodedAVals = a.dtype === 'string' ?
	      // tslint:disable-next-line: no-any
	      fromUint8ToStringArray(aVals) : aVals;
	      var decodedBVals = a.dtype === 'string' ?
	      // tslint:disable-next-line: no-any
	      fromUint8ToStringArray(bVals) : bVals;
	      var _cpuKernelImpl = cpuKernelImpl(a.shape, b.shape, decodedAVals, decodedBVals, $dtype),
	        _cpuKernelImpl2 = _slicedToArray(_cpuKernelImpl, 2),
	        outValues = _cpuKernelImpl2[0],
	        outShape = _cpuKernelImpl2[1];
	      var out = webglBackend.makeTensorInfo(outShape, $dtype);
	      var outData = webglBackend.texData.get(out.dataId);
	      outData.values = outValues;
	      return out;
	    }
	    var shouldUsePackedProgram = env().getBool('WEBGL_PACK_BINARY_OPERATIONS') && packedOpSnippet != null;
	    var program;
	    if (shouldUsePackedProgram) {
	      program = new BinaryOpPackedProgram(packedOpSnippet, a.shape, b.shape, checkOutOfBounds);
	    } else {
	      program = new BinaryOpProgram(opSnippet, a.shape, b.shape);
	    }
	    return webglBackend.runWebGLProgram(program, [a, b], $dtype);
	  };
	}
	function mapActivationToShaderProgram(activation) {
	  var packed = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
	  if (activation === 'linear') {
	    if (packed) {
	      return LINEAR;
	    }
	    return LINEAR$1;
	  } else if (activation === 'relu') {
	    if (packed) {
	      return RELU$1;
	    }
	    return RELU$2;
	  } else if (activation === 'elu') {
	    if (packed) {
	      return ELU$1;
	    }
	    return ELU$2;
	  } else if (activation === 'relu6') {
	    if (packed) {
	      return RELU6$1;
	    }
	    return RELU6$2;
	  } else if (activation === 'prelu') {
	    if (packed) {
	      return PRELU_PACKED;
	    }
	    return PRELU;
	  } else if (activation === 'leakyrelu') {
	    if (packed) {
	      return LEAKYRELU_PACKED;
	    }
	    return LEAKYRELU;
	  } else if (activation === 'sigmoid') {
	    if (packed) {
	      return SIGMOID$1;
	    }
	    return SIGMOID$2;
	  }
	  throw new Error("Activation ".concat(activation, " has not been implemented for the WebGL backend."));
	}

	var MatMulPackedProgram = /*#__PURE__*/_createClass(function MatMulPackedProgram(aShape, bShape, outputShape) {
	  var transposeA = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var transposeB = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
	  var addBias = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : false;
	  var activation = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : null;
	  var hasPreluActivation = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : false;
	  var hasLeakyreluActivation = arguments.length > 8 && arguments[8] !== undefined ? arguments[8] : false;
	  _classCallCheck(this, MatMulPackedProgram);
	  this.variableNames = ['matrixA', 'matrixB'];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.outputShape = outputShape;
	  this.enableShapeUniforms = useShapeUniforms(this.outputShape.length);
	  var sharedDim = transposeA ? aShape[1] : aShape[2];
	  var sharedDimensionPacked = Math.ceil(sharedDim / 2);
	  var aSample = transposeA ? 'i * 2, rc.y' : 'rc.y, i * 2';
	  var bSample = transposeB ? 'rc.z, i * 2' : 'i * 2, rc.z';
	  var aSwizzle = transposeA ? ['a.xxyy', 'a.zzww'] : ['a.xxzz', 'a.yyww'];
	  var bSwizzle = transposeB ? ['b.xzxz', 'b.ywyw'] : ['b.xyxy', 'b.zwzw'];
	  var activationSnippet = '',
	    applyActivationSnippet = '';
	  if (activation) {
	    if (hasPreluActivation) {
	      activationSnippet = "vec4 activation(vec4 a) {\n          vec4 b = getPreluActivationWeightsAtOutCoords();\n          ".concat(activation, "\n        }");
	    } else if (hasLeakyreluActivation) {
	      activationSnippet = "vec4 activation(vec4 a) {\n          vec4 b = getLeakyreluAlphaAtOutCoords();\n          ".concat(activation, "\n        }");
	    } else {
	      activationSnippet = "vec4 activation(vec4 x) {\n          ".concat(activation, "\n        }");
	    }
	    applyActivationSnippet = "result = activation(result);";
	  }
	  var addBiasSnippet = addBias ? 'result += getBiasAtOutCoords();' : '';
	  if (addBias) {
	    this.variableNames.push('bias');
	  }
	  if (hasPreluActivation) {
	    this.variableNames.push('preluActivationWeights');
	  }
	  if (hasLeakyreluActivation) {
	    this.variableNames.push('leakyreluAlpha');
	  }
	  var batchASnippet = 'rc.x';
	  var batchBSnippet = 'rc.x';
	  if (aShape[0] < bShape[0]) {
	    batchASnippet = "imod(rc.x, ".concat(aShape[0], ")");
	  } else if (bShape[0] < aShape[0]) {
	    batchBSnippet = "imod(rc.x, ".concat(bShape[0], ")");
	  }
	  this.userCode = "\n      ".concat(activationSnippet, "\n      // Don't use uniform for sharedDimensionPacked for performance.\n      const float sharedDimension = ").concat(sharedDimensionPacked, ".0;\n\n      vec4 dot2x2ARowBCol(ivec3 rc) {\n        vec4 result = vec4(0);\n        int batchA = ").concat(batchASnippet, ";\n        int batchB = ").concat(batchBSnippet, ";\n        for (int i = 0; i < ").concat(sharedDimensionPacked, "; i++) {\n          vec4 a = getMatrixA(batchA, ").concat(aSample, ");\n          vec4 b = getMatrixB(batchB, ").concat(bSample, ");\n\n          // These swizzled products need to be separately added.\n          // See: https://github.com/tensorflow/tfjs/issues/1735\n          result += (").concat(aSwizzle[0], " * ").concat(bSwizzle[0], ");\n          result += (").concat(aSwizzle[1], " * ").concat(bSwizzle[1], ");\n        }\n        return result;\n      }\n\n      void main() {\n        ivec3 rc = getOutputCoords();\n        vec4 result = dot2x2ARowBCol(rc);\n\n        ").concat(addBiasSnippet, "\n\n        ").concat(applyActivationSnippet, "\n\n        setOutput(result);\n      }\n    ");
	});

	// (Ar + Ai)(Br + Bi) =
	// ArBr + ArBi + AiBr + AiBi = ArBr - AB + ArBi + AiBr
	// Yr = ArBr - AB
	// Yi = ArBi + AiBr
	var COMPLEX_MULTIPLY = {
	  REAL: 'return areal * breal - aimag * bimag;',
	  IMAG: 'return areal * bimag + aimag * breal;'
	};
	var BinaryOpComplexProgram = /*#__PURE__*/_createClass(function BinaryOpComplexProgram(op, aShape, bShape) {
	  _classCallCheck(this, BinaryOpComplexProgram);
	  this.variableNames = ['AReal', 'AImag', 'BReal', 'BImag'];
	  this.outputShape = assertAndGetBroadcastShape(aShape, bShape);
	  this.userCode = "\n      float binaryOpComplex(\n          float areal, float aimag, float breal, float bimag) {\n        ".concat(op, "\n      }\n\n      void main() {\n        float areal = getARealAtOutCoords();\n        float aimag = getAImagAtOutCoords();\n        float breal = getBRealAtOutCoords();\n        float bimag = getBImagAtOutCoords();\n        setOutput(binaryOpComplex(areal, aimag, breal, bimag));\n      }\n    ");
	});

	var MUL = 'return a * b;';
	function multiply(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var a = inputs.a,
	    b = inputs.b;
	  var dtype = upcastType(a.dtype, b.dtype);
	  if (a.dtype === 'complex64') {
	    var aData = backend.texData.get(a.dataId);
	    var bData = backend.texData.get(b.dataId);
	    var realProgram = new BinaryOpComplexProgram(COMPLEX_MULTIPLY.REAL, a.shape, b.shape);
	    var imagProgram = new BinaryOpComplexProgram(COMPLEX_MULTIPLY.IMAG, a.shape, b.shape);
	    var _inputs = [{
	      dataId: aData.complexTensorInfos.real.dataId,
	      dtype: aData.complexTensorInfos.real.dtype,
	      shape: a.shape
	    }, {
	      dataId: aData.complexTensorInfos.imag.dataId,
	      dtype: aData.complexTensorInfos.imag.dtype,
	      shape: a.shape
	    }, {
	      dataId: bData.complexTensorInfos.real.dataId,
	      dtype: bData.complexTensorInfos.real.dtype,
	      shape: b.shape
	    }, {
	      dataId: bData.complexTensorInfos.imag.dataId,
	      dtype: bData.complexTensorInfos.imag.dtype,
	      shape: b.shape
	    }];
	    var realPart = backend.runWebGLProgram(realProgram, _inputs, 'float32');
	    var imagPart = backend.runWebGLProgram(imagProgram, _inputs, 'float32');
	    var complexOutput = complex({
	      inputs: {
	        real: realPart,
	        imag: imagPart
	      },
	      backend: backend
	    });
	    backend.disposeIntermediateTensorInfo(realPart);
	    backend.disposeIntermediateTensorInfo(imagPart);
	    // TODO(annxingyuan): CPU forwarding for complex inputs.
	    return complexOutput;
	  }
	  if (backend.shouldExecuteOnCPU([a, b])) {
	    var _aData = backend.texData.get(a.dataId);
	    var _bData = backend.texData.get(b.dataId);
	    var _cpuMultiply = multiplyImplCPU(a.shape, b.shape, _aData.values, _bData.values, dtype),
	      _cpuMultiply2 = _slicedToArray(_cpuMultiply, 2),
	      outValues = _cpuMultiply2[0],
	      outShape = _cpuMultiply2[1];
	    var out = backend.makeTensorInfo(outShape, dtype);
	    var outData = backend.texData.get(out.dataId);
	    outData.values = outValues;
	    return out;
	  }
	  var program;
	  if (env().getBool('WEBGL_PACK_BINARY_OPERATIONS')) {
	    program = new BinaryOpPackedProgram(MUL, a.shape, b.shape);
	  } else {
	    program = new BinaryOpProgram(MUL, a.shape, b.shape);
	  }
	  return backend.runWebGLProgram(program, [a, b], dtype);
	}
	var multiplyConfig = {
	  kernelName: Multiply$1,
	  backendName: 'webgl',
	  kernelFunc: multiply
	};

	function packedReshape(input, afterShape, backend) {
	  var input3DShape = [getBatchDim(input.shape)].concat(_toConsumableArray(getRowsCols(input.shape)));
	  var input3D = {
	    dtype: input.dtype,
	    shape: input3DShape,
	    dataId: input.dataId
	  };
	  var afterShapeAs3D = [getBatchDim(afterShape)].concat(_toConsumableArray(getRowsCols(afterShape)));
	  var program = new ReshapePackedProgram(afterShapeAs3D, input3DShape);
	  var preventEagerUnpackingOfOutput = true;
	  var customValues = [input3DShape];
	  var output = backend.runWebGLProgram(program, [input3D], input.dtype, customValues, preventEagerUnpackingOfOutput);
	  return {
	    dataId: output.dataId,
	    shape: afterShape,
	    dtype: output.dtype
	  };
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function reshape(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var shape = attrs.shape;
	  var webglBackend = backend;
	  var xSize = sizeFromShape(x.shape);
	  var $shape = inferFromImplicitShape(shape, xSize);
	  var $xSize = sizeFromShape($shape);
	  assert$1(xSize === $xSize, function () {
	    return "The new shape (".concat($shape, ") has ").concat($xSize, " elements and the old ") + "shape (".concat(x.shape, ") has ").concat(xSize, " elements. The new shape and old ") + "shape must have the same number of elements.";
	  });
	  var xTexData = webglBackend.texData.get(x.dataId);
	  if (xTexData.isPacked && !isReshapeFree(x.shape, $shape) && !(xTexData.texture !== null && isReshapeFree(xTexData.shape, $shape))) {
	    return packedReshape(x, $shape, webglBackend);
	  }
	  webglBackend.incRef(x.dataId);
	  return {
	    dataId: x.dataId,
	    shape: $shape,
	    dtype: x.dtype
	  };
	}
	var reshapeConfig = {
	  kernelName: Reshape$1,
	  backendName: 'webgl',
	  kernelFunc: reshape
	};

	var MeanProgram = /*#__PURE__*/_createClass(function MeanProgram(reduceInfo, divisor) {
	  _classCallCheck(this, MeanProgram);
	  this.variableNames = ['x'];
	  var windowSize = reduceInfo.windowSize,
	    batchSize = reduceInfo.batchSize,
	    inSize = reduceInfo.inSize,
	    outSize = reduceInfo.outSize;
	  this.outputShape = [batchSize, outSize];
	  var windowSizeNearestVec4 = Math.floor(windowSize / 4) * 4;
	  var windowSizeVec4Remainder = windowSize % 4;
	  var updateSnippet = "sumValue += dot(values, ones);";
	  if (divisor != null) {
	    var denominator = 1 / divisor;
	    updateSnippet = "sumValue += dot(values * ".concat(isInt(denominator) ? denominator.toPrecision(2) : denominator, ", ones);");
	  }
	  var checkOutOfBounds = '';
	  if (inSize % windowSize > 0) {
	    checkOutOfBounds = "\n        if (inIdx < 0 || inIdx >= ".concat(inSize, ") {\n          return 0.0;\n        }\n      ");
	  }
	  this.userCode = "\n      const vec4 ones = vec4(1.0, 1.0, 1.0, 1.0);\n\n      float getValue(int batch, int inIdx) {\n        ".concat(checkOutOfBounds, "\n        return getX(batch, inIdx);\n      }\n\n      void main() {\n        ivec2 coords = getOutputCoords();\n        int batch = coords[0];\n        int outIdx = coords[1];\n        int inOffset = outIdx * ").concat(windowSize, ";\n\n        float sumValue = 0.0;\n\n        for (int i = 0; i < ").concat(windowSizeNearestVec4, "; i += 4) {\n          int inIdx = inOffset + i;\n          vec4 values = vec4(\n            getValue(batch, inIdx),\n            getValue(batch, inIdx + 1),\n            getValue(batch, inIdx + 2),\n            getValue(batch, inIdx + 3)\n          );\n\n          ").concat(updateSnippet, "\n        }\n\n        int inIdx = inOffset + ").concat(windowSizeNearestVec4, ";\n        if (").concat(windowSizeVec4Remainder === 1, ") {\n          vec4 values = vec4(getValue(batch, inIdx), 0.0, 0.0, 0.0);\n\n          ").concat(updateSnippet, "\n        } else if (").concat(windowSizeVec4Remainder === 2, ") {\n          vec4 values = vec4(\n            getValue(batch, inIdx),\n            getValue(batch, inIdx + 1), 0.0, 0.0);\n\n          ").concat(updateSnippet, "\n        } else if (").concat(windowSizeVec4Remainder === 3, ") {\n          vec4 values = vec4(\n            getValue(batch, inIdx),\n            getValue(batch, inIdx + 1),\n            getValue(batch, inIdx + 2), 0.0);\n\n          ").concat(updateSnippet, "\n        }\n        setOutput(sumValue);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ReduceProgram = /*#__PURE__*/_createClass(function ReduceProgram(reduceInfo, reduceType) {
	  _classCallCheck(this, ReduceProgram);
	  this.variableNames = ['x'];
	  var windowSize = reduceInfo.windowSize,
	    batchSize = reduceInfo.batchSize,
	    inSize = reduceInfo.inSize,
	    outSize = reduceInfo.outSize;
	  this.outputShape = [batchSize, outSize];
	  var initializationValue = '0.0';
	  var compareOp = "";
	  if (reduceType === 'prod') {
	    initializationValue = '1.0';
	  } else if (reduceType === 'min') {
	    // WebGL on Firefox Linux can't compile 1/0 so we do 1/eps.
	    initializationValue = '1.0 / 1e-20';
	    compareOp = "min";
	  } else if (reduceType === 'max') {
	    // WebGL on Firefox Linux can't compile 1/0 so we do 1/eps.
	    initializationValue = '-1.0 / 1e-20';
	    compareOp = "max";
	  }
	  var returnValue = "".concat(reduceType, "(").concat(reduceType, "(").concat(reduceType, "(") + 'minMaxValue[0], minMaxValue[1]), minMaxValue[2]), minMaxValue[3])';
	  if (reduceType === 'sum') {
	    returnValue = "sumValue";
	  } else if (reduceType === 'prod') {
	    returnValue = "prodValue";
	  } else if (reduceType === 'all') {
	    returnValue = "allValue";
	  } else if (reduceType === 'any') {
	    returnValue = "anyValue";
	  }
	  var windowSizeNearestVec4 = Math.floor(windowSize / 4) * 4;
	  var windowSizeVec4Remainder = windowSize % 4;
	  var updateSnippet = "\n      if (".concat(reduceType === 'sum', ") {\n        sumValue += dot(values, ones);\n      } else if (").concat(reduceType === 'prod', ") {\n        vec2 tmp = vec2(values[0], values[1]) * vec2(values[2], values[3]);\n        prodValue *= tmp[0] * tmp[1];\n      } else {\n        minMaxValue = ").concat(compareOp, "(values, minMaxValue);\n        if (").concat(reduceType === 'min', " || ").concat(reduceType === 'max', ") {\n          minMaxValue = ").concat(compareOp, "(values, minMaxValue);\n          bvec4 isNaN = isnan(values);\n          if (isNaN.r || isNaN.g || isNaN.b || isNaN.a) {\n            minMaxValue = vec4(NAN);\n          }\n        }\n      }\n    ");
	  var vecType = "vec4";
	  if (reduceType === 'all') {
	    initializationValue = '1.0';
	    updateSnippet = "\n        bool reducedAllValue = all(values);\n        float floatedReducedAllValue = float(reducedAllValue);\n        allValue = float(allValue >= 1.0 && floatedReducedAllValue >= 1.0);\n      ";
	    vecType = "bvec4";
	  } else if (reduceType === 'any') {
	    initializationValue = '0.0';
	    updateSnippet = "\n        bool reducedAnyValue = any(values);\n        float floatedReducedAnyValue = float(reducedAnyValue);\n        anyValue = float(anyValue >= 1.0 || floatedReducedAnyValue >= 1.0);\n      ";
	    vecType = "bvec4";
	  }
	  var checkOutOfBounds = '';
	  if (inSize % windowSize > 0) {
	    checkOutOfBounds = "\n        if (inIdx < 0 || inIdx >= ".concat(inSize, ") {\n          return initializationValue;\n        }\n      ");
	  }
	  this.userCode = "\n      const float initializationValue = ".concat(initializationValue, ";\n      const vec4 ones = vec4(1.0, 1.0, 1.0, 1.0);\n\n      float getValue(int batch, int inIdx) {\n        ").concat(checkOutOfBounds, "\n        return getX(batch, inIdx);\n      }\n\n      void main() {\n        ivec2 coords = getOutputCoords();\n        int batch = coords[0];\n        int outIdx = coords[1];\n        int inOffset = outIdx * ").concat(windowSize, ";\n\n        vec4 minMaxValue = vec4(").concat(initializationValue, ");\n        float prodValue = 1.0;\n        float sumValue = 0.0;\n        float allValue = 1.0;\n        float anyValue = 0.0;\n\n        for (int i = 0; i < ").concat(windowSizeNearestVec4, "; i += 4) {\n          int inIdx = inOffset + i;\n          ").concat(vecType, " values = ").concat(vecType, "(\n            getValue(batch, inIdx),\n            getValue(batch, inIdx + 1),\n            getValue(batch, inIdx + 2),\n            getValue(batch, inIdx + 3)\n          );\n\n          ").concat(updateSnippet, "\n        }\n\n        int inIdx = inOffset + ").concat(windowSizeNearestVec4, ";\n        if (").concat(windowSizeVec4Remainder === 1, ") {\n          ").concat(vecType, " values = ").concat(vecType, "(\n            getValue(batch, inIdx),\n            initializationValue,\n            initializationValue,\n            initializationValue\n          );\n\n          ").concat(updateSnippet, "\n        } else if (").concat(windowSizeVec4Remainder === 2, ") {\n          ").concat(vecType, " values = ").concat(vecType, "(\n            getValue(batch, inIdx),\n            getValue(batch, inIdx + 1),\n            initializationValue,\n            initializationValue\n          );\n\n          ").concat(updateSnippet, "\n        } else if (").concat(windowSizeVec4Remainder === 3, ") {\n          ").concat(vecType, " values = ").concat(vecType, "(\n            getValue(batch, inIdx),\n            getValue(batch, inIdx + 1),\n            getValue(batch, inIdx + 2),\n            initializationValue\n          );\n\n          ").concat(updateSnippet, "\n        }\n        setOutput(").concat(returnValue, ");\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	// Returns an array of configuration objects that describe each stage of the
	// reduction.
	function getReductionStages(inShape) {
	  var stages = [];
	  while (stages.length === 0 || stages[stages.length - 1].outSize !== 1) {
	    var outSize = stages.length ? stages[stages.length - 1].outSize : inShape[1];
	    var windowSize = computeOptimalWindowSize(outSize);
	    stages.push({
	      inSize: outSize,
	      windowSize: windowSize,
	      outSize: Math.ceil(outSize / windowSize)
	    });
	  }
	  return stages;
	}
	function reduce(x, dtype, reductionType, backend) {
	  var reductionStages = getReductionStages(x.shape);
	  var result = x;
	  for (var i = 0; i < reductionStages.length; i++) {
	    var _reductionStages$i = reductionStages[i],
	      inSize = _reductionStages$i.inSize,
	      windowSize = _reductionStages$i.windowSize,
	      outSize = _reductionStages$i.outSize;
	    var program = void 0;
	    var previousResult = void 0;
	    if (reductionType === 'mean') {
	      program = i === 0 ? new MeanProgram({
	        windowSize: windowSize,
	        inSize: inSize,
	        batchSize: x.shape[0],
	        outSize: outSize
	      }, inSize) : new MeanProgram({
	        windowSize: windowSize,
	        inSize: inSize,
	        batchSize: x.shape[0],
	        outSize: outSize
	      });
	    } else {
	      program = new ReduceProgram({
	        windowSize: windowSize,
	        inSize: inSize,
	        batchSize: x.shape[0],
	        outSize: outSize
	      }, reductionType);
	    }
	    previousResult = result;
	    result = backend.runWebGLProgram(program, [result], dtype);
	    if (previousResult.dataId !== x.dataId) {
	      backend.disposeIntermediateTensorInfo(previousResult);
	    }
	  }
	  return result;
	}

	var TransposeProgram = /*#__PURE__*/_createClass(function TransposeProgram(aShape, newDim) {
	  _classCallCheck(this, TransposeProgram);
	  this.variableNames = ['A'];
	  var outputShape = new Array(aShape.length);
	  for (var i = 0; i < outputShape.length; i++) {
	    outputShape[i] = aShape[newDim[i]];
	  }
	  this.outputShape = outputShape;
	  this.rank = outputShape.length;
	  var dtype = getCoordsDataType(this.rank);
	  var switched = getSwitchedCoords(newDim);
	  this.userCode = "\n    void main() {\n      ".concat(dtype, " resRC = getOutputCoords();\n      setOutput(getA(").concat(switched, "));\n    }\n    ");
	});
	function getSwitchedCoords(newDim) {
	  var rank = newDim.length;
	  if (rank > 6) {
	    throw Error("Transpose for rank ".concat(rank, " is not yet supported"));
	  }
	  var originalOrder = ['resRC.x', 'resRC.y', 'resRC.z', 'resRC.w', 'resRC.u', 'resRC.v'];
	  var switchedCoords = new Array(rank);
	  for (var i = 0; i < newDim.length; i++) {
	    switchedCoords[newDim[i]] = originalOrder[i];
	  }
	  return switchedCoords.join();
	}

	var TransposePackedProgram = /*#__PURE__*/_createClass(function TransposePackedProgram(aShape, newDim) {
	  _classCallCheck(this, TransposePackedProgram);
	  this.variableNames = ['A'];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  var outputShape = new Array(aShape.length);
	  for (var i = 0; i < outputShape.length; i++) {
	    outputShape[i] = aShape[newDim[i]];
	  }
	  this.outputShape = outputShape;
	  this.rank = outputShape.length;
	  if (this.rank > 6) {
	    throw Error("Packed transpose for rank ".concat(this.rank, " is not yet supported."));
	  }
	  var dtype = getCoordsDataType(this.rank);
	  var outputOrder = getVecChannels('rc', this.rank);
	  var switchedOrder = new Array(this.rank);
	  for (var _i = 0; _i < newDim.length; _i++) {
	    switchedOrder[newDim[_i]] = outputOrder[_i];
	  }
	  var innerDims = "vec2(".concat(switchedOrder.slice(-2).join(), ")");
	  var nextColumn = "++".concat(outputOrder[this.rank - 1], " < ").concat(outputShape[this.rank - 1]);
	  var getc = "getChannel(getA(".concat(switchedOrder.join(), "), ").concat(innerDims, ")");
	  this.userCode = "\n    void main() {\n      ".concat(dtype, " rc = getOutputCoords();\n      vec4 result = vec4(0.);\n      result[0] = ").concat(getc, ";\n      if(").concat(nextColumn, ") {\n        result[1] = ").concat(getc, ";\n      }\n      --").concat(outputOrder[this.rank - 1], ";\n      if(++").concat(outputOrder[this.rank - 2], " < ").concat(outputShape[this.rank - 2], ") {\n        result[2] = ").concat(getc, ";\n        if(").concat(nextColumn, ") {\n          result[3] = ").concat(getc, ";\n        }\n      }\n      setOutput(result);\n    }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function transposeImpl(x, perm, backend) {
	  var program = env().getBool('WEBGL_PACK_ARRAY_OPERATIONS') ? new TransposePackedProgram(x.shape, perm) : new TransposeProgram(x.shape, perm);
	  return backend.runWebGLProgram(program, [x], x.dtype);
	}

	function sumImpl(x, axis, keepDims, backend) {
	  var reductionIndices = axis;
	  var xRank = x.shape.length;
	  var origAxes = parseAxisParam(reductionIndices, x.shape);
	  var axes = origAxes;
	  var permutedAxes = getAxesPermutation(axes, xRank);
	  var sumInputIsTransposed = permutedAxes != null;
	  var sumInput = x;
	  if (sumInputIsTransposed) {
	    sumInput = transposeImpl(x, permutedAxes, backend);
	    axes = getInnerMostAxes(axes.length, xRank);
	  }
	  assertAxesAreInnerMostDims('sum', axes, xRank);
	  var _backend_util$compute = computeOutAndReduceShapes(sumInput.shape, axes),
	    _backend_util$compute2 = _slicedToArray(_backend_util$compute, 2),
	    sumOutShape = _backend_util$compute2[0],
	    reduceShape = _backend_util$compute2[1];
	  var outShape = sumOutShape;
	  if (keepDims) {
	    // rather than reshape at the end, set the target shape here.
	    outShape = expandShapeToKeepDim(sumOutShape, origAxes);
	  }
	  var inSize = sizeFromShape(reduceShape);
	  var xSize = sizeFromShape(x.shape);
	  var batchSize = xSize / inSize;
	  var reshapedInput = reshape({
	    inputs: {
	      x: sumInput
	    },
	    attrs: {
	      shape: [batchSize, inSize]
	    },
	    backend: backend
	  });
	  var outType = sumOutType(x.dtype);
	  var reduced = reduce(reshapedInput, outType, 'sum', backend);
	  var out = reshape({
	    inputs: {
	      x: reduced
	    },
	    attrs: {
	      shape: outShape
	    },
	    backend: backend
	  });
	  backend.disposeIntermediateTensorInfo(reshapedInput);
	  backend.disposeIntermediateTensorInfo(reduced);
	  if (sumInputIsTransposed) {
	    backend.disposeIntermediateTensorInfo(sumInput);
	  }
	  return out;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function sum(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis,
	    keepDims = attrs.keepDims;
	  return sumImpl(x, axis, keepDims, backend);
	}
	var sumConfig = {
	  kernelName: Sum,
	  backendName: 'webgl',
	  kernelFunc: sum
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function transpose(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var perm = attrs.perm;
	  var webglBackend = backend;
	  var xRank = x.shape.length;
	  var newShape = new Array(xRank);
	  for (var i = 0; i < newShape.length; i++) {
	    newShape[i] = x.shape[perm[i]];
	  }
	  var out;
	  if (webglBackend.shouldExecuteOnCPU([x])) {
	    var xTexData = webglBackend.texData.get(x.dataId);
	    var values = xTexData.values;
	    var outValues = transposeImplCPU(values, x.shape, x.dtype, perm, newShape);
	    out = webglBackend.makeTensorInfo(newShape, x.dtype);
	    var outData = webglBackend.texData.get(out.dataId);
	    outData.values = outValues;
	  } else {
	    out = transposeImpl(x, perm, webglBackend);
	  }
	  return out;
	}
	var transposeConfig = {
	  kernelName: Transpose,
	  backendName: 'webgl',
	  kernelFunc: transpose
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	// Empirically determined minimal shared dimension in matmul before we forward
	// to a.mul(b).sum() in order to take advantage of GPU parallelism. See
	// https://github.com/tensorflow/tfjs-core/pull/1379 for benchmarks.
	var MATMUL_SHARED_DIM_THRESHOLD = 1000;
	function batchMatMulImpl(_ref) {
	  var a = _ref.a,
	    b = _ref.b,
	    transposeA = _ref.transposeA,
	    transposeB = _ref.transposeB,
	    backend = _ref.backend,
	    _ref$bias = _ref.bias,
	    bias = _ref$bias === void 0 ? null : _ref$bias,
	    _ref$preluActivationW = _ref.preluActivationWeights,
	    preluActivationWeights = _ref$preluActivationW === void 0 ? null : _ref$preluActivationW,
	    _ref$leakyreluAlpha = _ref.leakyreluAlpha,
	    leakyreluAlpha = _ref$leakyreluAlpha === void 0 ? 0 : _ref$leakyreluAlpha,
	    _ref$activation = _ref.activation,
	    activation = _ref$activation === void 0 ? null : _ref$activation;
	  var aRank = a.shape.length;
	  var bRank = b.shape.length;
	  var innerShapeA = transposeA ? a.shape[aRank - 2] : a.shape[aRank - 1];
	  var innerShapeB = transposeB ? b.shape[bRank - 1] : b.shape[bRank - 2];
	  var outerShapeA = transposeA ? a.shape[aRank - 1] : a.shape[aRank - 2];
	  var outerShapeB = transposeB ? b.shape[bRank - 2] : b.shape[bRank - 1];
	  var outerDimsA = a.shape.slice(0, -2);
	  var outerDimsB = b.shape.slice(0, -2);
	  var batchDimA = sizeFromShape(outerDimsA);
	  var batchDimB = sizeFromShape(outerDimsB);
	  var outShapeOuterDims = assertAndGetBroadcastShape(a.shape.slice(0, -2), b.shape.slice(0, -2));
	  var outShape = outShapeOuterDims.concat([outerShapeA, outerShapeB]);
	  assert$1(innerShapeA === innerShapeB, function () {
	    return "Error in matMul: inner shapes (".concat(innerShapeA, ") and (") + "".concat(innerShapeB, ") of Tensors with shapes ").concat(a.shape, " and ") + "".concat(b.shape, " and transposeA=").concat(transposeA) + " and transposeB=".concat(transposeB, " must match.");
	  });
	  var a3dShape = transposeA ? [batchDimA, innerShapeA, outerShapeA] : [batchDimA, outerShapeA, innerShapeA];
	  var b3dShape = transposeB ? [batchDimB, outerShapeB, innerShapeB] : [batchDimB, innerShapeB, outerShapeB];
	  // The rest of the implementation is designed to operate on rank-3 tensors
	  var a3d = reshape({
	    inputs: {
	      x: a
	    },
	    backend: backend,
	    attrs: {
	      shape: a3dShape
	    }
	  });
	  var b3d = reshape({
	    inputs: {
	      x: b
	    },
	    backend: backend,
	    attrs: {
	      shape: b3dShape
	    }
	  });
	  var intermediates = [a3d, b3d];
	  var batchDim = Math.max(batchDimA, batchDimB);
	  var sharedDim = transposeA ? a3d.shape[1] : a3d.shape[2];
	  var hasBias = bias != null;
	  var hasPreluActivationWeights = preluActivationWeights != null;
	  var hasLeakyreluAlpha = activation === 'leakyrelu';
	  var fusedActivation = activation != null ? mapActivationToShaderProgram(activation, true) : null;
	  var containsFusedOps = hasBias || hasPreluActivationWeights || hasLeakyreluAlpha || fusedActivation != null;
	  var out;
	  // Since the matrices are vectors, it is faster to call mul().sum()
	  // because sum() is O(sqrt(N)) due to divide-and-conquer.
	  if ((outerShapeA === 1 || outerShapeB === 1) && sharedDim > MATMUL_SHARED_DIM_THRESHOLD && containsFusedOps === false) {
	    var aVec = a3d;
	    var bVec = b3d;
	    if (transposeA) {
	      aVec = transpose({
	        inputs: {
	          x: a3d
	        },
	        backend: backend,
	        attrs: {
	          perm: [0, 2, 1]
	        }
	      });
	      intermediates.push(aVec);
	    }
	    if (transposeB) {
	      bVec = transpose({
	        inputs: {
	          x: b3d
	        },
	        backend: backend,
	        attrs: {
	          perm: [0, 2, 1]
	        }
	      });
	      intermediates.push(bVec);
	    }
	    var shouldReshapeA = outerShapeB !== 1;
	    var shouldReshapeB = outerShapeB === 1;
	    var aVec3d = aVec;
	    if (shouldReshapeA) {
	      aVec3d = reshape({
	        inputs: {
	          x: aVec
	        },
	        backend: backend,
	        attrs: {
	          shape: [batchDim, sharedDim, 1]
	        }
	      });
	      intermediates.push(aVec3d);
	    }
	    var axis = outerShapeB === 1 ? 2 : 1;
	    var bVec3d = bVec;
	    if (shouldReshapeB) {
	      bVec3d = reshape({
	        inputs: {
	          x: bVec
	        },
	        backend: backend,
	        attrs: {
	          shape: [batchDim, 1, sharedDim]
	        }
	      });
	      intermediates.push(bVec3d);
	    }
	    var product = multiply({
	      inputs: {
	        a: aVec3d,
	        b: bVec3d
	      },
	      backend: backend
	    });
	    out = sum({
	      inputs: {
	        x: product
	      },
	      backend: backend,
	      attrs: {
	        axis: axis,
	        keepDims: true
	      }
	    });
	    intermediates.push(product);
	  } else {
	    var dtype = upcastType(a.dtype, b.dtype);
	    var program = new MatMulPackedProgram(a3dShape, b3dShape, [batchDim, outerShapeA, outerShapeB], transposeA, transposeB, hasBias, fusedActivation, hasPreluActivationWeights, hasLeakyreluAlpha);
	    var inputs = [a3d, b3d];
	    if (bias != null) {
	      inputs.push(bias);
	    }
	    if (hasPreluActivationWeights) {
	      inputs.push(preluActivationWeights);
	    }
	    if (hasLeakyreluAlpha) {
	      var $leakyreluAlpha = backend.makeTensorInfo([], 'float32', createScalarValue(leakyreluAlpha, 'float32'));
	      inputs.push($leakyreluAlpha);
	      intermediates.push($leakyreluAlpha);
	    }
	    out = backend.runWebGLProgram(program, inputs, dtype);
	  }
	  var outReshaped = reshape({
	    inputs: {
	      x: out
	    },
	    backend: backend,
	    attrs: {
	      shape: outShape
	    }
	  });
	  intermediates.push(out);
	  for (var _i = 0, _intermediates = intermediates; _i < _intermediates.length; _i++) {
	    var i = _intermediates[_i];
	    backend.disposeIntermediateTensorInfo(i);
	  }
	  return outReshaped;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function _fusedMatMul(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var a = inputs.a,
	    b = inputs.b,
	    bias = inputs.bias,
	    preluActivationWeights = inputs.preluActivationWeights;
	  var transposeA = attrs.transposeA,
	    transposeB = attrs.transposeB,
	    activation = attrs.activation,
	    leakyreluAlpha = attrs.leakyreluAlpha;
	  return batchMatMulImpl({
	    a: a,
	    b: b,
	    transposeA: transposeA,
	    transposeB: transposeB,
	    backend: backend,
	    bias: bias,
	    preluActivationWeights: preluActivationWeights,
	    leakyreluAlpha: leakyreluAlpha,
	    activation: activation
	  });
	}
	var _fusedMatMulConfig = {
	  kernelName: _FusedMatMul,
	  backendName: 'webgl',
	  kernelFunc: _fusedMatMul
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ABS = "return abs(x);";
	function abs(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var x = inputs.x;
	  // TODO: handle cases when x is complex. Once the cpu implementation
	  // can handle complex values, refactor to use unaryKernelFunc.
	  if (backend.shouldExecuteOnCPU([x]) && x.dtype !== 'complex64') {
	    var xData = backend.texData.get(x.dataId);
	    var outValues = simpleAbsImplCPU(xData.values);
	    return backend.makeTensorInfo(x.shape, x.dtype, outValues);
	  }
	  var program;
	  if (env().getBool('WEBGL_PACK_UNARY_OPERATIONS')) {
	    program = new UnaryOpPackedProgram(x.shape, ABS);
	  } else {
	    program = new UnaryOpProgram(x.shape, ABS);
	  }
	  return backend.runWebGLProgram(program, [x], x.dtype);
	}
	var absConfig = {
	  kernelName: Abs,
	  backendName: 'webgl',
	  kernelFunc: abs
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ACOS = CHECK_NAN_SNIPPET$1 + "\n  if (abs(x) > 1.) {\n    return NAN;\n  }\n  return acos(x);\n";
	var acos = unaryKernelFunc({
	  opSnippet: ACOS
	});
	var acosConfig = {
	  kernelName: Acos,
	  backendName: 'webgl',
	  kernelFunc: acos
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ACOSH = CHECK_NAN_SNIPPET$1 + "\n  if (x < 1.0) return NAN;\nreturn log(x + sqrt(x * x - 1.0));";
	var acosh = unaryKernelFunc({
	  opSnippet: ACOSH
	});
	var acoshConfig = {
	  kernelName: Acosh,
	  backendName: 'webgl',
	  kernelFunc: acosh
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ADD = 'return a + b;';
	var addKernelFunc = binaryKernelFunc({
	  opSnippet: ADD,
	  packedOpSnippet: ADD,
	  supportsComplex: true,
	  cpuKernelImpl: addImplCPU
	});
	var addConfig = {
	  kernelName: Add$1,
	  backendName: 'webgl',
	  kernelFunc: addKernelFunc
	};

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var AddNProgram = /*#__PURE__*/_createClass(function AddNProgram(outputShape, shapes) {
	  _classCallCheck(this, AddNProgram);
	  this.outputShape = [];
	  this.outputShape = outputShape;
	  this.variableNames = shapes.map(function (_, i) {
	    return "T".concat(i);
	  });
	  var snippets = [];
	  // Get target elements from every input tensor.
	  this.variableNames.forEach(function (variable) {
	    snippets.push("float v".concat(variable, " = get").concat(variable, "AtOutCoords();"));
	  });
	  // Calculate the sum of all elements.
	  var operation = this.variableNames.map(function (variable) {
	    return "v".concat(variable);
	  }).join(' + ');
	  this.userCode = "\n      void main() {\n        ".concat(snippets.join('\n        '), "\n\n        float result = ").concat(operation, ";\n        setOutput(result);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var AddNPackedProgram = /*#__PURE__*/_createClass(function AddNPackedProgram(outputShape, shapes) {
	  _classCallCheck(this, AddNPackedProgram);
	  this.outputShape = [];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.outputShape = outputShape;
	  this.variableNames = shapes.map(function (_, i) {
	    return "T".concat(i);
	  });
	  var snippets = [];
	  // Get target elements from every input tensor.
	  this.variableNames.forEach(function (variable) {
	    snippets.push("vec4 v".concat(variable, " = get").concat(variable, "AtOutCoords();"));
	  });
	  // Calculate the sum of all elements.
	  var operation = this.variableNames.map(function (variable) {
	    return "v".concat(variable);
	  }).join(' + ');
	  this.userCode = "\n      void main() {\n        ".concat(snippets.join('\n        '), "\n\n        vec4 result = ").concat(operation, ";\n        setOutput(result);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function addN(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var tensors = inputs;
	  if (tensors.length === 1) {
	    return identity({
	      inputs: {
	        x: tensors[0]
	      },
	      backend: backend
	    });
	  }
	  // Limit the number of uploaded textures for optimization.
	  if (tensors.length > env().getNumber('WEBGL_MAX_TEXTURES_IN_SHADER')) {
	    var midIndex = Math.floor(tensors.length / 2);
	    var leftSide = addN({
	      inputs: tensors.slice(0, midIndex),
	      backend: backend
	    });
	    var rightSide = addN({
	      inputs: tensors.slice(midIndex),
	      backend: backend
	    });
	    return addN({
	      inputs: [leftSide, rightSide],
	      backend: backend
	    });
	  }
	  var dtype = tensors.map(function (t) {
	    return t.dtype;
	  }).reduce(function (d1, d2) {
	    return upcastType(d1, d2);
	  });
	  var shapes = tensors.map(function (t) {
	    return t.shape;
	  });
	  // We can make sure shapes are identical in op level.
	  var usePackedOp = env().getBool('WEBGL_PACK');
	  var program = usePackedOp ? new AddNPackedProgram(tensors[0].shape, shapes) : new AddNProgram(tensors[0].shape, shapes);
	  return backend.runWebGLProgram(program, tensors, dtype);
	}
	var addNConfig = {
	  kernelName: AddN,
	  backendName: 'webgl',
	  kernelFunc: addN
	};

	function all(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis,
	    keepDims = attrs.keepDims;
	  var xRank = x.shape.length;
	  var origAxes = parseAxisParam(axis, x.shape);
	  var axes = origAxes;
	  var permutedAxes = getAxesPermutation(axes, xRank);
	  var permutedX = x;
	  if (permutedAxes != null) {
	    permutedX = transpose({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        perm: permutedAxes
	      }
	    });
	    axes = getInnerMostAxes(axes.length, xRank);
	  }
	  assertAxesAreInnerMostDims('all', axes, xRank);
	  var _backend_util$compute = computeOutAndReduceShapes(permutedX.shape, axes),
	    _backend_util$compute2 = _slicedToArray(_backend_util$compute, 2),
	    outShape = _backend_util$compute2[0],
	    reduceShape = _backend_util$compute2[1];
	  var inSize = sizeFromShape(reduceShape);
	  var a2D = reshape({
	    inputs: {
	      x: permutedX
	    },
	    backend: backend,
	    attrs: {
	      shape: [-1, inSize]
	    }
	  });
	  var reduced = reduce(a2D, a2D.dtype, 'all', backend);
	  var res;
	  if (keepDims) {
	    var newShape = expandShapeToKeepDim(outShape, origAxes);
	    res = reshape({
	      inputs: {
	        x: reduced
	      },
	      backend: backend,
	      attrs: {
	        shape: newShape
	      }
	    });
	  } else {
	    res = reshape({
	      inputs: {
	        x: reduced
	      },
	      backend: backend,
	      attrs: {
	        shape: outShape
	      }
	    });
	  }
	  backend.disposeIntermediateTensorInfo(a2D);
	  backend.disposeIntermediateTensorInfo(reduced);
	  if (permutedAxes != null) {
	    backend.disposeIntermediateTensorInfo(permutedX);
	  }
	  return res;
	}
	var allConfig = {
	  kernelName: All,
	  backendName: 'webgl',
	  kernelFunc: all
	};

	function any(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis,
	    keepDims = attrs.keepDims;
	  var xRank = x.shape.length;
	  var origAxes = parseAxisParam(axis, x.shape);
	  var axes = origAxes;
	  var permutedAxes = getAxesPermutation(axes, xRank);
	  var permutedX = x;
	  if (permutedAxes != null) {
	    permutedX = transpose({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        perm: permutedAxes
	      }
	    });
	    axes = getInnerMostAxes(axes.length, xRank);
	  }
	  assertAxesAreInnerMostDims('any', axes, xRank);
	  var _backend_util$compute = computeOutAndReduceShapes(permutedX.shape, axes),
	    _backend_util$compute2 = _slicedToArray(_backend_util$compute, 2),
	    outShape = _backend_util$compute2[0],
	    reduceShape = _backend_util$compute2[1];
	  var inSize = sizeFromShape(reduceShape);
	  var a2D = reshape({
	    inputs: {
	      x: permutedX
	    },
	    backend: backend,
	    attrs: {
	      shape: [-1, inSize]
	    }
	  });
	  var reduced = reduce(a2D, a2D.dtype, 'any', backend);
	  var res;
	  if (keepDims) {
	    var newShape = expandShapeToKeepDim(outShape, origAxes);
	    res = reshape({
	      inputs: {
	        x: reduced
	      },
	      backend: backend,
	      attrs: {
	        shape: newShape
	      }
	    });
	  } else {
	    res = reshape({
	      inputs: {
	        x: reduced
	      },
	      backend: backend,
	      attrs: {
	        shape: outShape
	      }
	    });
	  }
	  backend.disposeIntermediateTensorInfo(a2D);
	  backend.disposeIntermediateTensorInfo(reduced);
	  if (permutedAxes != null) {
	    backend.disposeIntermediateTensorInfo(permutedX);
	  }
	  return res;
	}
	var anyConfig = {
	  kernelName: Any,
	  backendName: 'webgl',
	  kernelFunc: any
	};

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ArgMinMaxProgram = /*#__PURE__*/_createClass(function ArgMinMaxProgram(reduceInfo, op, firstPass) {
	  _classCallCheck(this, ArgMinMaxProgram);
	  this.variableNames = ['A'];
	  var windowSize = reduceInfo.windowSize,
	    batchSize = reduceInfo.batchSize,
	    outSize = reduceInfo.outSize;
	  if (!firstPass) {
	    this.variableNames.push('bestIndicesA');
	  }
	  this.outputShape = [batchSize, outSize];
	  var compOp = op === 'max' ? '>' : '<';
	  var indexSnippet = firstPass ? 'inOffset + i;' : 'round(getBestIndicesA(batch, inOffset + i));';
	  this.userCode = "\n      void main() {\n        ivec2 coords = getOutputCoords();\n        int batch = coords[0];\n        int outIdx = coords[1];\n        int inOffset = outIdx * ".concat(windowSize, ";\n\n        int bestIndex = inOffset;\n        float bestValue = getA(batch, bestIndex);\n\n        for (int i = 0; i < ").concat(windowSize, "; i++) {\n          int inIdx = ").concat(indexSnippet, ";\n          float candidate = getA(batch, inIdx);\n          if (candidate ").concat(compOp, " bestValue) {\n            bestValue = candidate;\n            bestIndex = inIdx;\n          }\n        }\n        setOutput(float(bestIndex));\n      }\n    ");
	});

	var ArgMinMaxPackedProgram = /*#__PURE__*/_createClass(function ArgMinMaxPackedProgram(shape, windowSize, op, firstPass) {
	  _classCallCheck(this, ArgMinMaxPackedProgram);
	  this.variableNames = ['A'];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  assert$1(shape.length > 2, function () {
	    return "Packed arg".concat(op.charAt(0).toUpperCase() + op.slice(1), " supports only inputs with rank above 2.");
	  });
	  var inSize = shape[shape.length - 1];
	  var outSize = Math.ceil(inSize / windowSize);
	  this.outputShape = shape.slice(0, -1);
	  if (outSize > 1) {
	    this.outputShape.push(outSize);
	  }
	  if (!firstPass) {
	    this.variableNames.push('bestIndicesA');
	  }
	  var outShape = this.outputShape;
	  var rank = outShape.length;
	  var dtype = getCoordsDataType(rank);
	  var coords = getChannels('coords', rank);
	  var sourceLocSetup;
	  var sourceRank;
	  if (outSize === 1) {
	    sourceRank = rank + 1;
	    var sourceLocDType = getCoordsDataType(sourceRank);
	    sourceLocSetup = "\n        ".concat(sourceLocDType, " sourceLocR = ").concat(sourceLocDType, "(").concat(coords.join(), ", 0);\n        ++").concat(coords[rank - 1], ";\n        ").concat(sourceLocDType, " sourceLocG = ").concat(sourceLocDType, "(").concat(coords.join(), ", 0);\n        ++").concat(coords[rank - 2], ";\n        ").concat(sourceLocDType, " sourceLocA = ").concat(sourceLocDType, "(").concat(coords.join(), ", 0);\n        --").concat(coords[rank - 1], ";\n        ").concat(sourceLocDType, " sourceLocB = ").concat(sourceLocDType, "(").concat(coords.join(), ", 0);\n        --").concat(coords[rank - 2], ";");
	  } else {
	    sourceRank = rank;
	    sourceLocSetup = "\n        ".concat(dtype, " sourceLocR = coords;\n        ++").concat(coords[rank - 1], ";\n        ").concat(dtype, " sourceLocG = coords;\n        ++").concat(coords[rank - 2], ";\n        ").concat(dtype, " sourceLocA = coords;\n        --").concat(coords[rank - 1], ";\n        ").concat(dtype, " sourceLocB = coords;\n        --").concat(coords[rank - 2], ";");
	  }
	  var channels = ['x', 'y', 'z', 'w', 'u', 'v'].slice(0, sourceRank);
	  var inChannel = '.' + channels[sourceRank - 1]; // e.g. ".b" for rank 3.
	  var intChannels = channels.map(function (x) {
	    return 'int ' + x;
	  });
	  var srcRCoords = getChannels('sourceLocR', sourceRank - 1).concat('inIdx.r');
	  var srcGCoords = getChannels('sourceLocG', sourceRank - 1).concat('inIdx.g');
	  var srcBCoords = getChannels('sourceLocB', sourceRank - 1).concat('inIdx.b');
	  var srcACoords = getChannels('sourceLocA', sourceRank - 1).concat('inIdx.a');
	  var compOp = op === 'max' ? 'greaterThan' : 'lessThan';
	  var fetchCandidateIdx = firstPass ? '' : "\n          inIdx = round(vec4(getBestIndicesAChannel(".concat(srcRCoords.join(), "),\n                             getBestIndicesAChannel(").concat(srcGCoords.join(), "),\n                             getBestIndicesAChannel(").concat(srcBCoords.join(), "),\n                             getBestIndicesAChannel(").concat(srcACoords.join(), ")));");
	  var fetchValue = "vec4(\n            getAChannel(".concat(srcRCoords.join(), "),\n            hasNextCol ? getAChannel(").concat(srcGCoords.join(), ") : 0.,\n            hasNextRow ? getAChannel(").concat(srcBCoords.join(), ") : 0.,\n            hasNextRow && hasNextCol ? getAChannel(").concat(srcACoords.join(), ") : 0.)");
	  var getBestIndicesAChannelSnippet = firstPass ? '' : "\n      float getBestIndicesAChannel(".concat(intChannels.join(), ") {\n        return getChannel(getBestIndicesA(").concat(channels.join(), "),\n                                          vec2(").concat(channels.slice(-2).join(), "));\n      }");
	  this.userCode = "\n      float getAChannel(".concat(intChannels.join(), ") {\n        return getChannel(getA(").concat(channels.join(), "),\n                               vec2(").concat(channels.slice(-2).join(), "));\n      }\n      ").concat(getBestIndicesAChannelSnippet, "\n      void main() {\n        ").concat(dtype, " coords = getOutputCoords();\n        bool hasNextCol = ").concat(coords[rank - 1], " < ").concat(outShape[rank - 1] - 1, ";\n        bool hasNextRow = ").concat(coords[rank - 2], " < ").concat(outShape[rank - 2] - 1, ";\n        ").concat(sourceLocSetup, "\n        ivec4 srcIdx = ivec4(sourceLocR").concat(inChannel, ", sourceLocG").concat(inChannel, ",\n          sourceLocB").concat(inChannel, ", sourceLocA").concat(inChannel, ") * ").concat(windowSize, ";\n        ivec4 inIdx = srcIdx;\n        vec4 bestIndex = vec4(inIdx);\n        vec4 bestValue = ").concat(fetchValue, ";\n\n        for (int i = 0; i < ").concat(windowSize, "; i++) {\n          inIdx = srcIdx;\n          ").concat(fetchCandidateIdx, "\n          vec4 candidate = ").concat(fetchValue, ";\n          bvec4 nan = isnan(candidate);\n          bvec4 replace = bvec4(\n            vec4(").concat(compOp, "(candidate, bestValue)) * (vec4(1.0) - vec4(nan)));\n\n          bestValue = vec4(replace.x  ? candidate.x : bestValue.x,\n                           replace.y  ? candidate.y : bestValue.y,\n                           replace.z  ? candidate.z : bestValue.z,\n                           replace.w  ? candidate.w : bestValue.w);\n          bestIndex = mix(bestIndex, vec4(inIdx), vec4(replace));\n          srcIdx++;\n        }\n        setOutput(bestIndex);\n      }\n    ");
	});

	function argReduce(backend, x, reduceType) {
	  var bestIndicesA = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;
	  var batchSize = x.shape[0];
	  var inSize = x.shape[1];
	  if (bestIndicesA != null) {
	    batchSize = bestIndicesA.shape[0];
	    inSize = bestIndicesA.shape[1];
	  }
	  var windowSize = computeOptimalWindowSize(inSize);
	  var reduceInfo = {
	    windowSize: windowSize,
	    inSize: inSize,
	    batchSize: batchSize,
	    outSize: Math.ceil(inSize / windowSize)
	  };
	  var program = new ArgMinMaxProgram(reduceInfo, reduceType, bestIndicesA == null);
	  var inputs = [x];
	  if (bestIndicesA != null) {
	    inputs.push(bestIndicesA);
	  }
	  var output = backend.runWebGLProgram(program, inputs, 'int32');
	  // No need to run another GPGPU program.
	  if (output.shape[1] === 1) {
	    return output;
	  }
	  var result = argReduce(backend, x, reduceType, output);
	  backend.disposeIntermediateTensorInfo(output);
	  return result;
	}
	function argReducePacked(backend, x, reduceType) {
	  var bestIndicesA = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;
	  var inShape = bestIndicesA != null ? bestIndicesA.shape : x.shape;
	  var inSize = inShape[inShape.length - 1];
	  var windowSize = computeOptimalWindowSize(inSize);
	  var program = new ArgMinMaxPackedProgram(inShape, windowSize, reduceType, bestIndicesA == null);
	  var inputs = bestIndicesA == null ? [x] : [x, bestIndicesA];
	  var output = backend.runWebGLProgram(program, inputs, 'int32');
	  if (output.shape.length === x.shape.length) {
	    var result = argReducePacked(backend, x, reduceType, output);
	    backend.disposeIntermediateTensorInfo(output);
	    return result;
	  }
	  return output;
	}
	function argMinMaxReduce(backend, x, axis, reduceType) {
	  var axes = [axis];
	  assertAxesAreInnerMostDims('arg' + reduceType.charAt(0).toUpperCase() + reduceType.slice(1), axes, x.shape.length);
	  if (!env().getBool('WEBGL_PACK_REDUCE') || x.shape.length <= 2) {
	    var intermediateTensorInfos = [];
	    // Eagerly unpack x input since it is passed in to all the shaders which
	    // require unpacked inputs.
	    var xtexData = backend.texData.get(x.dataId);
	    var xIsPacked = xtexData !== null && xtexData.isPacked;
	    var xUnPacked = x;
	    if (xIsPacked) {
	      xUnPacked = backend.unpackTensor(x);
	      intermediateTensorInfos.push(xUnPacked);
	    }
	    var _backend_util$compute = computeOutAndReduceShapes(xUnPacked.shape, axes),
	      _backend_util$compute2 = _slicedToArray(_backend_util$compute, 2),
	      outShape = _backend_util$compute2[0],
	      reduceShape = _backend_util$compute2[1];
	    var inSize = sizeFromShape(reduceShape);
	    var a2D = reshape({
	      inputs: {
	        x: xUnPacked
	      },
	      backend: backend,
	      attrs: {
	        shape: [-1, inSize]
	      }
	    });
	    intermediateTensorInfos.push(a2D);
	    var reduced = argReduce(backend, a2D, reduceType);
	    intermediateTensorInfos.push(reduced);
	    var reshaped = reshape({
	      inputs: {
	        x: reduced
	      },
	      backend: backend,
	      attrs: {
	        shape: outShape
	      }
	    });
	    intermediateTensorInfos.forEach(function (t) {
	      return backend.disposeIntermediateTensorInfo(t);
	    });
	    return reshaped;
	  }
	  return argReducePacked(backend, x, reduceType);
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function argMax(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis;
	  var axes = parseAxisParam(axis, x.shape);
	  var permutedAxes = getAxesPermutation(axes, x.shape.length);
	  var $x = x;
	  var intermediateTensorInfos = [];
	  if (permutedAxes != null) {
	    $x = transpose({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        perm: permutedAxes
	      }
	    });
	    intermediateTensorInfos.push($x);
	    axes = getInnerMostAxes(axes.length, $x.shape.length);
	  }
	  assertAxesAreInnerMostDims('argMax', [axes[0]], $x.shape.length);
	  var out = argMinMaxReduce(backend, $x, axes[0], 'max');
	  intermediateTensorInfos.forEach(function (t) {
	    return backend.disposeIntermediateTensorInfo(t);
	  });
	  return out;
	}
	var argMaxConfig = {
	  kernelName: ArgMax,
	  backendName: 'webgl',
	  kernelFunc: argMax
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function argMin(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis;
	  var axes = parseAxisParam(axis, x.shape);
	  var permutedAxes = getAxesPermutation(axes, x.shape.length);
	  var $x = x;
	  var intermediateTensorInfos = [];
	  if (permutedAxes != null) {
	    $x = transpose({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        perm: permutedAxes
	      }
	    });
	    intermediateTensorInfos.push($x);
	    axes = getInnerMostAxes(axes.length, $x.shape.length);
	  }
	  assertAxesAreInnerMostDims('argMin', [axes[0]], $x.shape.length);
	  var out = argMinMaxReduce(backend, $x, axes[0], 'min');
	  intermediateTensorInfos.forEach(function (t) {
	    return backend.disposeIntermediateTensorInfo(t);
	  });
	  return out;
	}
	var argMinConfig = {
	  kernelName: ArgMin,
	  backendName: 'webgl',
	  kernelFunc: argMin
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ASIN = CHECK_NAN_SNIPPET$1 + "\n  if (abs(x) > 1.) {\n    return NAN;\n  }\n  return asin(x);\n";
	var asin = unaryKernelFunc({
	  opSnippet: ASIN
	});
	var asinConfig = {
	  kernelName: Asin,
	  backendName: 'webgl',
	  kernelFunc: asin
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ASINH = CHECK_NAN_SNIPPET$1 + "return log(x + sqrt(x * x + 1.0));";
	var asinh = unaryKernelFunc({
	  opSnippet: ASINH
	});
	var asinhConfig = {
	  kernelName: Asinh,
	  backendName: 'webgl',
	  kernelFunc: asinh
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ATAN = CHECK_NAN_SNIPPET$1 + "\n  return atan(x);\n";
	var atan = unaryKernelFunc({
	  opSnippet: ATAN
	});
	var atanConfig = {
	  kernelName: Atan,
	  backendName: 'webgl',
	  kernelFunc: atan
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ATAN2 = CHECK_NAN_SNIPPET + "\n  return atan(a, b);\n";
	var ATAN2_PACKED = "\n  vec4 result = atan(a, b);\n  bvec4 isNaNA = isnan(a);\n  bvec4 isNaNB = isnan(b);\n  bvec4 isNaN = bvec4(isNaNA.x || isNaNB.x, isNaNA.y || isNaNB.y, isNaNA.z || isNaNB.z, isNaNA.w || isNaNB.w);\n  " + CHECK_NAN_SNIPPET_PACKED + "\n  return result;\n";
	var atan2 = binaryKernelFunc({
	  opSnippet: ATAN2,
	  packedOpSnippet: ATAN2_PACKED
	});
	var atan2Config = {
	  kernelName: Atan2,
	  backendName: 'webgl',
	  kernelFunc: atan2
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ATANH = CHECK_NAN_SNIPPET$1 + "\n  if ((x < -1.0) || (x > 1.0)) return NAN;\nreturn (log(1.0 + x) - log(1.0 - x)) / 2.0;";
	var atanh = unaryKernelFunc({
	  opSnippet: ATANH
	});
	var atanhConfig = {
	  kernelName: Atanh,
	  backendName: 'webgl',
	  kernelFunc: atanh
	};

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var Pool2DProgram = /*#__PURE__*/_createClass(function Pool2DProgram(convInfo, poolType, computePositions) {
	  var flattenPositions = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var includeBatchInIndex = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
	  _classCallCheck(this, Pool2DProgram);
	  this.variableNames = ['x'];
	  if (poolType === 'avg' && computePositions) {
	    throw new Error('Cannot compute positions for average pool.');
	  }
	  var filterWidth = convInfo.filterWidth;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var dilationHeight = convInfo.dilationHeight;
	  var dilationWidth = convInfo.dilationWidth;
	  var effectiveFilterHeight = convInfo.effectiveFilterHeight;
	  var effectiveFilterWidth = convInfo.effectiveFilterWidth;
	  var padTop = convInfo.padInfo.top;
	  var padLeft = convInfo.padInfo.left;
	  this.outputShape = convInfo.outShape;
	  var isAvgPool = poolType === 'avg';
	  var batchFlattenPositionStr = "((batch  * ".concat(convInfo.inHeight, " + xR) * ").concat(convInfo.inWidth, " + xC) * ").concat(convInfo.inChannels, " + d");
	  var flattenPositionStr = "(xR * ".concat(convInfo.inWidth, " + xC) * ").concat(convInfo.inChannels, " + d");
	  var initializationValue = '0.0';
	  if (!isAvgPool) {
	    // WebGL on Firefox Linux can't compile 1/0 so we do 1/eps.
	    initializationValue = '-1.0 / 1e-20';
	  }
	  if (computePositions) {
	    var _compareOp = '>=';
	    this.userCode = "\n        const ivec2 strides = ivec2(".concat(strideHeight, ", ").concat(strideWidth, ");\n        const ivec2 pads = ivec2(").concat(padTop, ", ").concat(padLeft, ");\n\n        void main() {\n          ivec4 coords = getOutputCoords();\n          int batch = coords[0];\n          int d = coords[3];\n\n          ivec2 xRCCorner = coords.yz * strides - pads;\n          int xRCorner = xRCCorner.x;\n          int xCCorner = xRCCorner.y;\n\n          // max/min x(?, ?, d) to get y(yR, yC, d).\n          // ? = to be determined\n          float minMaxValue = 0.0;\n          float minMaxValueFound = 0.0;\n          int minMaxPosition = 0;\n          float avgValue = 0.0;\n\n          for (int wR = 0; wR < ").concat(effectiveFilterHeight, ";\n              wR += ").concat(dilationHeight, ") {\n            int xR = xRCorner + wR;\n\n            if (xR < 0 || xR >= ").concat(convInfo.inHeight, ") {\n              continue;\n            }\n\n            for (int wC = 0; wC < ").concat(effectiveFilterWidth, ";\n                wC += ").concat(dilationWidth, ") {\n              int xC = xCCorner + wC;\n\n              if (xC < 0 || xC >= ").concat(convInfo.inWidth, ") {\n                continue;\n              }\n\n              float value = getX(batch, xR, xC, d);\n\n              // If a min / max value has already been found, use it. If not,\n              // use the current value.\n              float currMinMaxValue = mix(\n                  value, minMaxValue, minMaxValueFound);\n              if (value ").concat(_compareOp, " currMinMaxValue) {\n                minMaxValue = value;\n                minMaxValueFound = 1.0;\n                minMaxPosition = ").concat(flattenPositions ? includeBatchInIndex ? batchFlattenPositionStr : flattenPositionStr : "wR * ".concat(effectiveFilterWidth, " + wC"), ";\n              }\n            }\n          }\n          setOutput(float(minMaxPosition));\n        }\n      ");
	    return;
	  }
	  var compareOp = 'max';
	  var returnValue = "".concat(poolType, "(").concat(poolType, "(").concat(poolType, "(") + 'minMaxValue[0], minMaxValue[1]), minMaxValue[2]), minMaxValue[3])';
	  if (poolType === 'avg') {
	    returnValue = "avgValue / max(count, 1.0)";
	  }
	  var filterWidthNearestVec4 = Math.floor(filterWidth / 4) * 4;
	  var filterWidthVec4Remainder = filterWidth % 4;
	  var updateSnippet = "\n      if (".concat(isAvgPool, ") {\n        avgValue += dot(values, ones);\n      } else {\n        minMaxValue = ").concat(compareOp, "(values, minMaxValue);\n      }\n    ");
	  this.userCode = "\n      const ivec2 strides = ivec2(".concat(strideHeight, ", ").concat(strideWidth, ");\n      const ivec2 pads = ivec2(").concat(padTop, ", ").concat(padLeft, ");\n      const float initializationValue = ").concat(initializationValue, ";\n      const vec4 ones = vec4(1.0, 1.0, 1.0, 1.0);\n\n      float count = 0.0;\n\n      float getValue(int batch, int xR, int xC, int d) {\n        if (xC < 0 || xC >= ").concat(convInfo.inWidth, ") {\n          return initializationValue;\n        }\n        count += 1.0;\n        return getX(batch, xR, xC, d);\n      }\n\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int batch = coords[0];\n        int d = coords[3];\n\n        ivec2 xRCCorner = coords.yz * strides - pads;\n        int xRCorner = xRCCorner.x;\n        int xCCorner = xRCCorner.y;\n\n        // max/min x(?, ?, d) to get y(yR, yC, d).\n        // ? = to be determined\n        vec4 minMaxValue = vec4(").concat(initializationValue, ");\n        float avgValue = 0.0;\n        count = 0.0;\n\n        for (int wR = 0; wR < ").concat(effectiveFilterHeight, ";\n            wR += ").concat(dilationHeight, ") {\n          int xR = xRCorner + wR;\n\n          if (xR < 0 || xR >= ").concat(convInfo.inHeight, ") {\n            continue;\n          }\n\n          for (int wC = 0; wC < ").concat(filterWidthNearestVec4, "; wC += 4) {\n            int xC = xCCorner + wC * ").concat(dilationWidth, ";\n\n            vec4 values = vec4(\n              getValue(batch, xR, xC, d),\n              getValue(batch, xR, xC + ").concat(dilationWidth, ", d),\n              getValue(batch, xR, xC + 2 * ").concat(dilationWidth, ", d),\n              getValue(batch, xR, xC + 3 * ").concat(dilationWidth, ", d)\n            );\n\n            ").concat(updateSnippet, "\n          }\n\n          int xC = xCCorner + ").concat(filterWidthNearestVec4, ";\n          if (").concat(filterWidthVec4Remainder === 1, ") {\n            vec4 values = vec4(\n              getValue(batch, xR, xC, d),\n              initializationValue,\n              initializationValue,\n              initializationValue\n            );\n\n            ").concat(updateSnippet, "\n          } else if (").concat(filterWidthVec4Remainder === 2, ") {\n            vec4 values = vec4(\n              getValue(batch, xR, xC, d),\n              getValue(batch, xR, xC + ").concat(dilationWidth, ", d),\n              initializationValue,\n              initializationValue\n            );\n\n            ").concat(updateSnippet, "\n          } else if (").concat(filterWidthVec4Remainder === 3, ") {\n            vec4 values = vec4(\n              getValue(batch, xR, xC, d),\n              getValue(batch, xR, xC + ").concat(dilationWidth, ", d),\n              getValue(batch, xR, xC + 2 * ").concat(dilationWidth, ", d),\n              initializationValue\n            );\n\n            ").concat(updateSnippet, "\n          }\n        }\n        setOutput(").concat(returnValue, ");\n      }\n    ");
	});
	var Pool3DProgram = /*#__PURE__*/_createClass(function Pool3DProgram(convInfo, poolType, computePositions) {
	  var flattenPositions = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var includeBatchInIndex = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
	  _classCallCheck(this, Pool3DProgram);
	  this.variableNames = ['x'];
	  if (poolType === 'avg' && computePositions) {
	    throw new Error('Cannot compute positions for average pool.');
	  }
	  var filterWidth = convInfo.filterWidth;
	  var strideDepth = convInfo.strideDepth;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var dilationDepth = convInfo.dilationDepth;
	  var dilationHeight = convInfo.dilationHeight;
	  var dilationWidth = convInfo.dilationWidth;
	  var effectiveFilterDepth = convInfo.effectiveFilterDepth;
	  var effectiveFilterHeight = convInfo.effectiveFilterHeight;
	  var effectiveFilterWidth = convInfo.effectiveFilterWidth;
	  var padFront = convInfo.padInfo.front;
	  var padTop = convInfo.padInfo.top;
	  var padLeft = convInfo.padInfo.left;
	  this.outputShape = convInfo.outShape;
	  var isAvgPool = poolType === 'avg';
	  var initializationValue = '0.0';
	  if (!isAvgPool) {
	    // WebGL on Firefox Linux can't compile 1/0 so we do 1/eps.
	    initializationValue = '-1.0 / 1e-20';
	  }
	  if (computePositions) {
	    var _compareOp2 = '>=';
	    this.userCode = "\n        const ivec3 strides =\n            ivec3(".concat(strideDepth, ", ").concat(strideHeight, ", ").concat(strideWidth, ");\n        const ivec3 pads = ivec3(").concat(padFront, ", ").concat(padTop, ", ").concat(padLeft, ");\n\n        void main() {\n          ivec5 coords = getOutputCoords();\n          int batch = coords.x;\n          int ch = coords.u;\n\n          ivec3 xCorner = ivec3(coords.y, coords.z, coords.w) * strides - pads;\n          int xDCorner = xCorner.x;\n          int xRCorner = xCorner.y;\n          int xCCorner = xCorner.z;\n\n          // max/min x(?, ?, ?, ch) to get y(yD, yR, yC, ch).\n          // ? = to be determined\n          float minMaxValue = 0.0;\n          float minMaxValueFound = 0.0;\n          int minMaxPosition = 0;\n\n          for (int wD = 0; wD < ").concat(effectiveFilterDepth, ";\n              wD += ").concat(dilationDepth, ") {\n            int xD = xDCorner + wD;\n\n            if (xD < 0 || xD >= ").concat(convInfo.inDepth, ") {\n              continue;\n            }\n\n            for (int wR = 0; wR < ").concat(effectiveFilterHeight, ";\n                wR += ").concat(dilationHeight, ") {\n              int xR = xRCorner + wR;\n\n              if (xR < 0 || xR >= ").concat(convInfo.inHeight, ") {\n                continue;\n              }\n\n              for (int wC = 0; wC < ").concat(effectiveFilterWidth, ";\n                  wC += ").concat(dilationWidth, ") {\n                int xC = xCCorner + wC;\n\n                if (xC < 0 || xC >= ").concat(convInfo.inWidth, ") {\n                  continue;\n                }\n\n                float value = getX(batch, xD, xR, xC, ch);\n\n                // If a min / max value has already been found, use it. If not,\n                // use the current value.\n                float currMinMaxValue = mix(\n                    value, minMaxValue, minMaxValueFound);\n                if (value ").concat(_compareOp2, " currMinMaxValue) {\n                  minMaxValue = value;\n                  minMaxValueFound = 1.0;\n                  minMaxPosition = ").concat(flattenPositions ? includeBatchInIndex ? "(((batch * ".concat(convInfo.inDepth, " + xD) * ").concat(convInfo.inHeight, " + xR) * ").concat(convInfo.inWidth, " + xC) * ").concat(convInfo.inChannels, " + ch") : "((xD * ".concat(convInfo.inHeight, " + xR) * ").concat(convInfo.inWidth, " + xC) * ").concat(convInfo.inChannels, " + ch") : "wD * ".concat(effectiveFilterHeight, " * ").concat(effectiveFilterWidth, " +\n                      wR * ").concat(effectiveFilterWidth, " + wC"), ";\n                }\n              }\n            }\n          }\n          setOutput(float(minMaxPosition));\n        }\n      ");
	    return;
	  }
	  var compareOp = 'max';
	  var returnValue = "".concat(poolType, "(").concat(poolType, "(").concat(poolType, "(") + 'minMaxValue[0], minMaxValue[1]), minMaxValue[2]), minMaxValue[3])';
	  if (poolType === 'avg') {
	    // Use `max(count, 1.0)` instead of `count` in case count === 0.0.
	    // If count === 0.0, `avgValue` is always 0.0 and we change `count`'s
	    // value to avoid dividing zero.
	    returnValue = "avgValue / max(count, 1.0)";
	  }
	  var filterWidthNearestVec4 = Math.floor(filterWidth / 4) * 4;
	  var filterWidthVec4Remainder = filterWidth % 4;
	  var updateSnippet = "\n      if (".concat(isAvgPool, ") {\n        avgValue += dot(values, ones);\n      } else {\n        minMaxValue = ").concat(compareOp, "(values, minMaxValue);\n      }\n    ");
	  this.userCode = "\n      const ivec3 strides =\n        ivec3(".concat(strideDepth, ", ").concat(strideHeight, ", ").concat(strideWidth, ");\n      const ivec3 pads = ivec3(").concat(padFront, ", ").concat(padTop, ", ").concat(padLeft, ");\n      const float initializationValue = ").concat(initializationValue, ";\n      const vec4 ones = vec4(1.0, 1.0, 1.0, 1.0);\n\n      float count = 0.0;\n\n      float getValue(int batch, int xD, int xR, int xC, int ch) {\n        if (xC < 0 || xC >= ").concat(convInfo.inWidth, ") {\n          return initializationValue;\n        }\n        count += 1.0;\n        return getX(batch, xD, xR, xC, ch);\n      }\n\n      void main() {\n        ivec5 coords = getOutputCoords();\n        int batch = coords.x;\n        int ch = coords.u;\n\n        ivec3 xCorner = ivec3(coords.y, coords.z, coords.w) * strides - pads;\n        int xDCorner = xCorner.x;\n        int xRCorner = xCorner.y;\n        int xCCorner = xCorner.z;\n\n        // max/min x(?, ?, ?, d) to get y(yD, yR, yC, ch).\n        // ? = to be determined\n        vec4 minMaxValue = vec4(").concat(initializationValue, ");\n        float avgValue = 0.0;\n        count = 0.0;\n\n        for (int wD = 0; wD < ").concat(effectiveFilterDepth, ";\n            wD += ").concat(dilationDepth, ") {\n          int xD = xDCorner + wD;\n\n          if (xD < 0 || xD >= ").concat(convInfo.inDepth, ") {\n            continue;\n          }\n\n          for (int wR = 0; wR < ").concat(effectiveFilterHeight, ";\n            wR += ").concat(dilationHeight, ") {\n            int xR = xRCorner + wR;\n\n            if (xR < 0 || xR >= ").concat(convInfo.inHeight, ") {\n              continue;\n            }\n\n            for (int wC = 0; wC < ").concat(filterWidthNearestVec4, "; wC += 4) {\n              int xC = xCCorner + wC * ").concat(dilationWidth, ";\n\n              vec4 values = vec4(\n                getValue(batch, xD, xR, xC, ch),\n                getValue(batch, xD, xR, xC + ").concat(dilationWidth, ", ch),\n                getValue(batch, xD, xR, xC + 2 * ").concat(dilationWidth, ", ch),\n                getValue(batch, xD, xR, xC + 3 * ").concat(dilationWidth, ", ch)\n              );\n\n              ").concat(updateSnippet, "\n            }\n\n            int xC = xCCorner + ").concat(filterWidthNearestVec4, ";\n            if (").concat(filterWidthVec4Remainder === 1, ") {\n              vec4 values = vec4(\n                getValue(batch, xD, xR, xC, ch),\n                initializationValue,\n                initializationValue,\n                initializationValue\n              );\n\n              ").concat(updateSnippet, "\n            } else if (").concat(filterWidthVec4Remainder === 2, ") {\n              vec4 values = vec4(\n                getValue(batch, xD, xR, xC, ch),\n                getValue(batch, xD, xR, xC + ").concat(dilationWidth, ", ch),\n                initializationValue,\n                initializationValue\n              );\n\n              ").concat(updateSnippet, "\n            } else if (").concat(filterWidthVec4Remainder === 3, ") {\n              vec4 values = vec4(\n                getValue(batch, xD, xR, xC, ch),\n                getValue(batch, xD, xR, xC + ").concat(dilationWidth, ", ch),\n                getValue(batch, xD, xR, xC + 2 * ").concat(dilationWidth, ", ch),\n                initializationValue\n              );\n\n              ").concat(updateSnippet, "\n            }\n          }\n        }\n        setOutput(").concat(returnValue, ");\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function avgPool(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  assertNotComplex(x, 'avgPool');
	  var filterSize = attrs.filterSize,
	    strides = attrs.strides,
	    pad = attrs.pad,
	    dimRoundingMode = attrs.dimRoundingMode;
	  var dilations = 1;
	  assert$1(eitherStridesOrDilationsAreOne(strides, dilations), function () {
	    return 'Error in avgPool: Either strides or dilations must be 1. ' + "Got strides ".concat(strides, " and dilations '").concat(dilations, "'");
	  });
	  var convInfo = computePool2DInfo(x.shape, filterSize, strides, dilations, pad, dimRoundingMode);
	  if (convInfo.filterWidth === 1 && convInfo.filterHeight === 1 && arraysEqual(convInfo.inShape, convInfo.outShape)) {
	    return identity({
	      inputs: {
	        x: x
	      },
	      backend: backend
	    });
	  }
	  var avgPoolProgram = new Pool2DProgram(convInfo, 'avg', false);
	  return backend.runWebGLProgram(avgPoolProgram, [x], 'float32');
	}
	var avgPoolConfig = {
	  kernelName: AvgPool,
	  backendName: 'webgl',
	  kernelFunc: avgPool
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function avgPool3D(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var filterSize = attrs.filterSize,
	    strides = attrs.strides,
	    pad = attrs.pad,
	    dimRoundingMode = attrs.dimRoundingMode,
	    dataFormat = attrs.dataFormat;
	  var dilations = [1, 1, 1];
	  var convInfo = computePool3DInfo(x.shape, filterSize, strides, dilations, pad, dimRoundingMode, dataFormat);
	  var avgPoolProgram = new Pool3DProgram(convInfo, 'avg', false);
	  return backend.runWebGLProgram(avgPoolProgram, [x], 'float32');
	}
	var avgPool3DConfig = {
	  kernelName: AvgPool3D,
	  backendName: 'webgl',
	  kernelFunc: avgPool3D
	};

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var AvgPool2DBackpropProgram = /*#__PURE__*/_createClass(function AvgPool2DBackpropProgram(convInfo) {
	  _classCallCheck(this, AvgPool2DBackpropProgram);
	  this.variableNames = ['dy'];
	  this.outputShape = convInfo.inShape;
	  var filterHeight = convInfo.filterHeight;
	  var filterWidth = convInfo.filterWidth;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var dilationHeight = convInfo.dilationHeight;
	  var dilationWidth = convInfo.dilationWidth;
	  var effectiveFilterHeight = convInfo.effectiveFilterHeight;
	  var effectiveFilterWidth = convInfo.effectiveFilterWidth;
	  var padTop = effectiveFilterHeight - 1 - convInfo.padInfo.top;
	  var padLeft = effectiveFilterWidth - 1 - convInfo.padInfo.left;
	  var avgMultiplier = 1 / (filterHeight * filterWidth);
	  this.userCode = "\n      const ivec2 pads = ivec2(".concat(padTop, ", ").concat(padLeft, ");\n      const float avgMultiplier = float(").concat(avgMultiplier, ");\n\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int b = coords[0];\n        int d = coords[3];\n\n        ivec2 dyRCCorner = coords.yz - pads;\n        int dyRCorner = dyRCCorner.x;\n        int dyCCorner = dyRCCorner.y;\n\n        // Convolve dy(?, ?, d) with pos mask(:, :, d) to get dx(xR, xC, d).\n        // ? = to be determined. : = across all values in that axis.\n        float dotProd = 0.0;\n        for (int wR = 0; wR < ").concat(effectiveFilterHeight, ";\n            wR += ").concat(dilationHeight, ") {\n          float dyR = float(dyRCorner + wR) / ").concat(strideHeight, ".0;\n\n          if (dyR < 0.0 || dyR >= ").concat(convInfo.outHeight, ".0 || fract(dyR) > 0.0) {\n            continue;\n          }\n          int idyR = int(dyR);\n\n          for (int wC = 0; wC < ").concat(effectiveFilterWidth, ";\n            wC+= ").concat(dilationWidth, ") {\n            float dyC = float(dyCCorner + wC) / ").concat(strideWidth, ".0;\n\n            if (dyC < 0.0 || dyC >= ").concat(convInfo.outWidth, ".0 ||\n                fract(dyC) > 0.0) {\n              continue;\n            }\n            int idyC = int(dyC);\n\n            float dyValue = getDy(b, idyR, idyC, d);\n\n            dotProd += dyValue * avgMultiplier;\n          }\n        }\n        setOutput(dotProd);\n      }\n    ");
	});
	var AvgPool3DBackpropProgram = /*#__PURE__*/_createClass(function AvgPool3DBackpropProgram(convInfo) {
	  _classCallCheck(this, AvgPool3DBackpropProgram);
	  this.variableNames = ['dy'];
	  this.outputShape = convInfo.inShape;
	  var filterDepth = convInfo.filterDepth;
	  var filterHeight = convInfo.filterHeight;
	  var filterWidth = convInfo.filterWidth;
	  var strideDepth = convInfo.strideDepth;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var dilationDepth = convInfo.dilationDepth;
	  var dilationHeight = convInfo.dilationHeight;
	  var dilationWidth = convInfo.dilationWidth;
	  var effectiveFilterDepth = convInfo.effectiveFilterDepth;
	  var effectiveFilterHeight = convInfo.effectiveFilterHeight;
	  var effectiveFilterWidth = convInfo.effectiveFilterWidth;
	  var padFront = effectiveFilterDepth - 1 - convInfo.padInfo.front;
	  var padTop = effectiveFilterHeight - 1 - convInfo.padInfo.top;
	  var padLeft = effectiveFilterWidth - 1 - convInfo.padInfo.left;
	  var avgMultiplier = 1 / (filterDepth * filterHeight * filterWidth);
	  this.userCode = "\n      const ivec3 pads = ivec3(".concat(padFront, ", ").concat(padTop, ", ").concat(padLeft, ");\n      const float avgMultiplier = float(").concat(avgMultiplier, ");\n\n      void main() {\n        ivec5 coords = getOutputCoords();\n        int batch = coords.x;\n        int ch = coords.u;\n\n        ivec3 dyCorner = ivec3(coords.y, coords.z, coords.w) - pads;\n        int dyDCorner = dyCorner.x;\n        int dyRCorner = dyCorner.y;\n        int dyCCorner = dyCorner.z;\n\n        // Convolve dy(?, ?, ?, d) with pos mask(:, :, :, ch) to get\n        // dx(xD, xR, xC, ch).\n        // ? = to be determined. : = across all values in that axis.\n        float dotProd = 0.0;\n\n        for (int wD = 0; wD < ").concat(effectiveFilterDepth, ";\n            wD += ").concat(dilationDepth, ") {\n          float dyD = float(dyDCorner + wD) / ").concat(strideDepth, ".0;\n\n          if (dyD < 0.0 || dyD >= ").concat(convInfo.outDepth, ".0 || fract(dyD) > 0.0) {\n            continue;\n          }\n          int idyD = int(dyD);\n\n          for (int wR = 0; wR < ").concat(effectiveFilterHeight, ";\n              wR += ").concat(dilationHeight, ") {\n            float dyR = float(dyRCorner + wR) / ").concat(strideHeight, ".0;\n\n            if (dyR < 0.0 || dyR >= ").concat(convInfo.outHeight, ".0 ||\n                fract(dyR) > 0.0) {\n              continue;\n            }\n            int idyR = int(dyR);\n\n            for (int wC = 0; wC < ").concat(effectiveFilterWidth, ";\n                wC += ").concat(dilationWidth, ") {\n              float dyC = float(dyCCorner + wC) / ").concat(strideWidth, ".0;\n\n              if (dyC < 0.0 || dyC >= ").concat(convInfo.outWidth, ".0 ||\n                  fract(dyC) > 0.0) {\n                continue;\n              }\n              int idyC = int(dyC);\n\n              float dyValue = getDy(batch, idyD, idyR, idyC, ch);\n\n              dotProd += dyValue * avgMultiplier;\n            }\n          }\n        }\n        setOutput(dotProd);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function avgPool3DGrad(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var dy = inputs.dy,
	    input = inputs.input;
	  var x = input;
	  var filterSize = attrs.filterSize,
	    strides = attrs.strides,
	    pad = attrs.pad,
	    dimRoundingMode = attrs.dimRoundingMode;
	  var dilations = [1, 1, 1];
	  var convInfo = computePool3DInfo(x.shape, filterSize, strides, dilations, pad, dimRoundingMode);
	  var avgPoolBackpropProgram = new AvgPool3DBackpropProgram(convInfo);
	  return backend.runWebGLProgram(avgPoolBackpropProgram, [dy], x.dtype);
	}
	var avgPool3DGradConfig = {
	  kernelName: AvgPool3DGrad,
	  backendName: 'webgl',
	  kernelFunc: avgPool3DGrad
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function avgPoolGrad(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var dy = inputs.dy,
	    input = inputs.input;
	  var x = input;
	  assertNotComplex([dy, input], 'avgPoolGrad');
	  var filterSize = attrs.filterSize,
	    strides = attrs.strides,
	    pad = attrs.pad;
	  var convInfo = computePool2DInfo(x.shape, filterSize, strides, 1 /* dilations */, pad);
	  var avgPoolBackpropProgram = new AvgPool2DBackpropProgram(convInfo);
	  return backend.runWebGLProgram(avgPoolBackpropProgram, [dy], x.dtype);
	}
	var avgPoolGradConfig = {
	  kernelName: AvgPoolGrad,
	  backendName: 'webgl',
	  kernelFunc: avgPoolGrad
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function batchMatMul(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var a = inputs.a,
	    b = inputs.b;
	  var transposeA = attrs.transposeA,
	    transposeB = attrs.transposeB;
	  return batchMatMulImpl({
	    a: a,
	    b: b,
	    transposeA: transposeA,
	    transposeB: transposeB,
	    backend: backend
	  });
	}
	var batchMatMulConfig = {
	  kernelName: BatchMatMul,
	  backendName: 'webgl',
	  kernelFunc: batchMatMul
	};

	var BatchNormProgram = /*#__PURE__*/_createClass(function BatchNormProgram(xShape, meanShape, varianceShape, offsetShape, scaleShape, varianceEpsilon) {
	  _classCallCheck(this, BatchNormProgram);
	  this.outputShape = [];
	  this.variableNames = ['x', 'mean', 'variance'];
	  assertAndGetBroadcastShape(xShape, meanShape);
	  assertAndGetBroadcastShape(xShape, varianceShape);
	  var offsetSnippet = '0.0';
	  if (offsetShape != null) {
	    assertAndGetBroadcastShape(xShape, offsetShape);
	    this.variableNames.push('offset');
	    offsetSnippet = 'getOffsetAtOutCoords()';
	  }
	  var scaleSnippet = '1.0';
	  if (scaleShape != null) {
	    assertAndGetBroadcastShape(xShape, scaleShape);
	    this.variableNames.push('scale');
	    scaleSnippet = 'getScaleAtOutCoords()';
	  }
	  this.outputShape = xShape;
	  this.userCode = "\n      void main() {\n        float x = getXAtOutCoords();\n        float mean = getMeanAtOutCoords();\n        float variance = getVarianceAtOutCoords();\n        float offset = ".concat(offsetSnippet, ";\n        float scale = ").concat(scaleSnippet, ";\n        float inv = scale * inversesqrt(variance + float(").concat(varianceEpsilon, "));\n        setOutput(dot(vec3(x, -mean, offset), vec3(inv, inv, 1)));\n      }\n    ");
	});

	var BatchNormPackedProgram = /*#__PURE__*/_createClass(function BatchNormPackedProgram(xShape, meanShape, varianceShape, offsetShape, scaleShape, varianceEpsilon) {
	  _classCallCheck(this, BatchNormPackedProgram);
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.variableNames = ['x', 'mean', 'variance'];
	  assertAndGetBroadcastShape(xShape, meanShape);
	  assertAndGetBroadcastShape(xShape, varianceShape);
	  var offsetSnippet = 'vec4(0.0)';
	  if (offsetShape != null) {
	    assertAndGetBroadcastShape(xShape, offsetShape);
	    this.variableNames.push('offset');
	    offsetSnippet = 'getOffsetAtOutCoords()';
	  }
	  var scaleSnippet = 'vec4(1.0)';
	  if (scaleShape != null) {
	    assertAndGetBroadcastShape(xShape, scaleShape);
	    this.variableNames.push('scale');
	    scaleSnippet = 'getScaleAtOutCoords()';
	  }
	  this.outputShape = xShape;
	  this.userCode = "\n      void main() {\n        vec4 offset = ".concat(offsetSnippet, ";\n        vec4 scale = ").concat(scaleSnippet, ";\n\n        vec4 x = getXAtOutCoords();\n        vec4 mean = getMeanAtOutCoords();\n        vec4 variance = getVarianceAtOutCoords();\n\n        vec4 inv = scale * inversesqrt(variance + vec4(").concat(varianceEpsilon, "));\n\n        setOutput((x - mean) * inv + offset);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var batchNorm = function batchNorm(_ref) {
	  var inputs = _ref.inputs,
	    backend = _ref.backend,
	    attrs = _ref.attrs;
	  var x = inputs.x,
	    mean = inputs.mean,
	    variance = inputs.variance,
	    offset = inputs.offset,
	    scale = inputs.scale;
	  assert$1(mean.shape.length === variance.shape.length, function () {
	    return 'Batch normalization gradient requires mean and variance to have ' + 'equal ranks.';
	  });
	  assert$1(offset == null || mean.shape.length === offset.shape.length, function () {
	    return 'Batch normalization gradient requires mean and offset to have ' + 'equal ranks.';
	  });
	  assert$1(scale == null || mean.shape.length === scale.shape.length, function () {
	    return 'Batch normalization gradient requires mean and scale to have ' + 'equal ranks.';
	  });
	  var varianceEpsilon = attrs.varianceEpsilon;
	  if (varianceEpsilon == null) {
	    varianceEpsilon = 0.001;
	  }
	  var finalInputs = [x, mean, variance];
	  var offsetShape = null;
	  if (offset != null) {
	    offsetShape = offset.shape;
	    finalInputs.push(offset);
	  }
	  var scaleShape = null;
	  if (scale != null) {
	    scaleShape = scale.shape;
	    finalInputs.push(scale);
	  }
	  var program = env().getBool('WEBGL_PACK_NORMALIZATION') ? new BatchNormPackedProgram(x.shape, mean.shape, variance.shape, offsetShape, scaleShape, varianceEpsilon) : new BatchNormProgram(x.shape, mean.shape, variance.shape, offsetShape, scaleShape, varianceEpsilon);
	  var output = backend.runWebGLProgram(program, finalInputs, finalInputs[0].dtype);
	  return output;
	};
	var batchNormConfig = {
	  kernelName: FusedBatchNorm,
	  backendName: 'webgl',
	  kernelFunc: batchNorm
	};

	var SliceProgram = /*#__PURE__*/_createClass(function SliceProgram(destSize) {
	  _classCallCheck(this, SliceProgram);
	  this.variableNames = ['source'];
	  this.outputShape = destSize;
	  this.rank = destSize.length;
	  var dtype = getCoordsDataType(this.rank);
	  this.customUniforms = [{
	    name: 'start',
	    arrayIndex: this.rank,
	    type: 'int'
	  }];
	  var sourceCoords = getCoords$1(this.rank);
	  var body;
	  var coordSum = destSize.map(function (_, i) {
	    return "sourceLoc.".concat(coords[i], " = start[").concat(i, "] + coords.").concat(coords[i], ";");
	  });
	  body = "\n        ".concat(dtype, " sourceLoc;\n        ").concat(dtype, " coords = getOutputCoords();\n        ").concat(coordSum.join('\n'), "\n      ");
	  this.userCode = "\n      void main() {\n        ".concat(body, "\n        setOutput(getSource(").concat(sourceCoords, "));\n      }\n    ");
	});
	var coords = ['x', 'y', 'z', 'w', 'u', 'v'];
	function getCoords$1(rank) {
	  if (rank === 1) {
	    return 'sourceLoc';
	  } else if (rank <= 6) {
	    return coords.slice(0, rank).map(function (x) {
	      return 'sourceLoc.' + x;
	    }).join(',');
	  } else {
	    throw Error("Slicing for rank ".concat(rank, " is not yet supported"));
	  }
	}

	var SlicePackedProgram = /*#__PURE__*/_createClass(function SlicePackedProgram(destSize) {
	  _classCallCheck(this, SlicePackedProgram);
	  this.variableNames = ['source'];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.outputShape = destSize;
	  this.rank = destSize.length;
	  this.customUniforms = [{
	    name: 'start',
	    arrayIndex: this.rank,
	    type: 'int'
	  }];
	  var dtype = getCoordsDataType(this.rank);
	  var coords = getChannels('coords', this.rank);
	  var sourceLoc = getChannels('sourceLoc', this.rank);
	  var innerDims = this.rank === 1 ? 'sourceLoc' : "vec2(".concat(sourceLoc.slice(-2).join(), ")");
	  var getChannel = "getChannel(getSource(".concat(sourceLoc.join(), "), ").concat(innerDims, ")");
	  var upperRow = "\n      result.x = ".concat(getChannel, ";\n      if (++").concat(coords[this.rank - 1], " < ").concat(destSize[this.rank - 1], ") {\n        ++").concat(sourceLoc[this.rank - 1], ";\n        result.y = ").concat(getChannel, ";\n        --").concat(sourceLoc[this.rank - 1], ";\n      }\n    ");
	  var lowerRow = this.rank === 1 ? '' : "\n      --".concat(coords[this.rank - 1], ";\n      if (++").concat(coords[this.rank - 2], " < ").concat(destSize[this.rank - 2], ") {\n        ++").concat(sourceLoc[this.rank - 2], ";\n        result.z = ").concat(getChannel, ";\n        if (++").concat(coords[this.rank - 1], " < ").concat(destSize[this.rank - 1], ") {\n          ++").concat(sourceLoc[this.rank - 1], ";\n          result.w = ").concat(getChannel, ";\n        }\n      }\n    ");
	  var sourceLocSetup = this.rank <= 4 ? "sourceLoc = coords +\n            ".concat(dtype, "(").concat(destSize.map(function (_, i) {
	    return "start[".concat(i, "]");
	  }).join(), ");") : destSize.map(function (_, i) {
	    return "".concat(sourceLoc[i], " = ").concat(coords[i], " + start[").concat(i, "];");
	  }).join('\n');
	  this.userCode = "\n      void main() {\n        ".concat(dtype, " coords = getOutputCoords();\n        ").concat(dtype, " sourceLoc;\n        ").concat(sourceLocSetup, "\n        vec4 result = vec4(0.);\n        ").concat(upperRow, "\n        ").concat(lowerRow, "\n        setOutput(result);\n      }\n    ");
	});

	function shallowSlice(x, begin, size, backend) {
	  var xTexData = backend.texData.get(x.dataId);
	  var t = backend.makeTensorInfo(size, x.dtype);
	  var newTexData = backend.texData.get(t.dataId);
	  // Copy texture data from the original tensor.
	  Object.assign(newTexData, xTexData);
	  newTexData.refCount = 1;
	  newTexData.shape = size;
	  newTexData.dtype = x.dtype;
	  var flatOffset = computeFlatOffset(begin, computeStrides(x.shape));
	  if (xTexData.slice) {
	    // We are slicing an already sliced tensor, so we have to accumulate
	    // the offset.
	    flatOffset += xTexData.slice.flatOffset;
	  }
	  newTexData.slice = {
	    flatOffset: flatOffset,
	    // Point to the original dataId, which is used to do ref counting.
	    origDataId: xTexData.slice && xTexData.slice.origDataId || x.dataId
	  };
	  // Increase the ref count for that data bucket.
	  var refCount = backend.dataRefCount.get(newTexData.slice.origDataId) || 1;
	  backend.dataRefCount.set(newTexData.slice.origDataId, refCount + 1);
	  return t;
	}
	function slice(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var begin = attrs.begin,
	    size = attrs.size;
	  var _slice_util$parseSlic = parseSliceParams(x, begin, size),
	    _slice_util$parseSlic2 = _slicedToArray(_slice_util$parseSlic, 2),
	    $begin = _slice_util$parseSlic2[0],
	    $size = _slice_util$parseSlic2[1];
	  assertParamsValid(x, $begin, $size);
	  if (sizeFromShape($size) === 0) {
	    return backend.makeTensorInfo($size, x.dtype, []);
	  }
	  // Run on cpu if dtype is string. For string, the backend represents it
	  // as Uint8Array[], where each Uint8Array is a character. Given that the
	  // computation is only on the outer array, uploading the whole data onto
	  // gpu is wasteful. Also, currently webgl doesn't have a design to
	  // upload and retrieve Uint8Array[] between cpu and gpu. Therefore, we
	  // just run the kernel on cpu if dtype is string.
	  if (backend.shouldExecuteOnCPU([x]) || x.dtype === 'string') {
	    var xTexData = backend.texData.get(x.dataId);
	    var outValues = sliceImplCPU(xTexData.values, $begin, $size, x.shape, x.dtype);
	    return backend.makeTensorInfo($size, x.dtype, outValues);
	  }
	  var _backend$texData$get = backend.texData.get(x.dataId),
	    isPacked = _backend$texData$get.isPacked;
	  var isContinous = isSliceContinous(x.shape, $begin, $size);
	  if (isPacked || !isContinous) {
	    var program = env().getBool('WEBGL_PACK_ARRAY_OPERATIONS') ? new SlicePackedProgram($size) : new SliceProgram($size);
	    var customValues = [$begin];
	    return backend.runWebGLProgram(program, [x], x.dtype, customValues);
	  }
	  backend.uploadToGPU(x.dataId);
	  return shallowSlice(x, $begin, $size, backend);
	}
	var sliceConfig = {
	  kernelName: Slice,
	  backendName: 'webgl',
	  kernelFunc: slice
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var batchToSpaceND = function batchToSpaceND(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var blockShape = attrs.blockShape,
	    crops = attrs.crops;
	  assert$1(x.shape.length <= 4, function () {
	    return 'batchToSpaceND for rank > 4 with a WebGL backend not ' + 'implemented yet';
	  });
	  var prod = blockShape.reduce(function (a, b) {
	    return a * b;
	  });
	  var reshaped = getReshaped(x.shape, blockShape, prod);
	  var permuted = getPermuted(reshaped.length, blockShape.length);
	  var reshapedPermuted = getReshapedPermuted(x.shape, blockShape, prod);
	  var sliceBeginCoords = getSliceBeginCoords(crops, blockShape.length);
	  var sliceSize = getSliceSize(reshapedPermuted, crops, blockShape.length);
	  var toDispose = [];
	  var reshapedIntermediate = reshape({
	    inputs: {
	      x: x
	    },
	    backend: backend,
	    attrs: {
	      shape: reshaped
	    }
	  });
	  var transposedIntermediate = transpose({
	    inputs: {
	      x: reshapedIntermediate
	    },
	    backend: backend,
	    attrs: {
	      perm: permuted
	    }
	  });
	  var reshapedIntermediate2 = reshape({
	    inputs: {
	      x: transposedIntermediate
	    },
	    backend: backend,
	    attrs: {
	      shape: reshapedPermuted
	    }
	  });
	  var sliced = slice({
	    inputs: {
	      x: reshapedIntermediate2
	    },
	    backend: backend,
	    attrs: {
	      begin: sliceBeginCoords,
	      size: sliceSize
	    }
	  });
	  toDispose.push(reshapedIntermediate);
	  toDispose.push(transposedIntermediate);
	  toDispose.push(reshapedIntermediate2);
	  toDispose.forEach(function (t) {
	    return backend.disposeIntermediateTensorInfo(t);
	  });
	  return sliced;
	};
	var batchToSpaceNDConfig = {
	  kernelName: BatchToSpaceND,
	  backendName: 'webgl',
	  kernelFunc: batchToSpaceND
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function bincount(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    weights = inputs.weights;
	  var size = attrs.size;
	  var xVals = backend.readSync(x.dataId);
	  var weightsVals = backend.readSync(weights.dataId);
	  var outVals = bincountImplCPU(xVals, weightsVals, weights.dtype, weights.shape, size);
	  return backend.makeTensorInfo([size], weights.dtype, outVals);
	}
	var bincountConfig = {
	  kernelName: Bincount,
	  backendName: 'webgl',
	  kernelFunc: bincount
	};

	var BITWISEAND = "\n  int r = int(a.r) & int(b.r);\n  int g = int(a.g) & int(b.g);\n  int rb = int(a.b) & int(b.b);\n  int ra = int(a.a) & int(b.a);\n  return vec4(r, g, rb, ra);\n";
	var BITWISEAND_UNPACKED = "\n  return float(int(a.r) & int(b.r));\n";
	function bitwiseAnd(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var a = inputs.a,
	    b = inputs.b;
	  var shouldUsePackedProgram = env().getBool('WEBGL_PACK_BINARY_OPERATIONS');
	  var versionNumber = env().getNumber('WEBGL_VERSION');
	  // The type of a and b are ensured to be `int32` in core, therefore no need to
	  // consider other type situations.
	  if (backend.shouldExecuteOnCPU([a, b]) || versionNumber === 1) {
	    var aVals = backend.texData.get(a.dataId).values;
	    var bVals = backend.texData.get(b.dataId).values;
	    var _cpuBitwiseAnd = bitwiseAndImplCPU(a.shape, b.shape, aVals, bVals, a.dtype),
	      _cpuBitwiseAnd2 = _slicedToArray(_cpuBitwiseAnd, 2),
	      outValues = _cpuBitwiseAnd2[0],
	      outShape = _cpuBitwiseAnd2[1];
	    var out = backend.makeTensorInfo(outShape, a.dtype);
	    var outData = backend.texData.get(out.dataId);
	    outData.values = outValues;
	    return out;
	  }
	  var program;
	  if (shouldUsePackedProgram) {
	    program = new BinaryOpPackedProgram(BITWISEAND, a.shape, b.shape, false);
	  } else {
	    program = new BinaryOpProgram(BITWISEAND_UNPACKED, a.shape, b.shape);
	  }
	  return backend.runWebGLProgram(program, [a, b], a.dtype);
	}
	var bitwiseAndConfig = {
	  kernelName: BitwiseAnd,
	  backendName: 'webgl',
	  kernelFunc: bitwiseAnd
	};

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function broadcastArgs(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var s0 = inputs.s0,
	    s1 = inputs.s1;
	  var s0Vals = backend.readSync(s0.dataId);
	  var s1Vals = backend.readSync(s1.dataId);
	  var broadcastShape = assertAndGetBroadcastShape(Array.from(s0Vals), Array.from(s1Vals));
	  return backend.makeTensorInfo([broadcastShape.length], 'int32', Int32Array.from(broadcastShape));
	}
	var broadcastArgsConfig = {
	  kernelName: BroadcastArgs,
	  backendName: 'webgl',
	  kernelFunc: broadcastArgs
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var NOT_EQUAL = "return float(a != b);";
	var notEqual = binaryKernelFunc({
	  opSnippet: NOT_EQUAL,
	  cpuKernelImpl: notEqualImplCPU,
	  dtype: 'bool'
	});
	var notEqualConfig = {
	  kernelName: NotEqual,
	  backendName: 'webgl',
	  kernelFunc: notEqual
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function real(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var input = inputs.input;
	  var inputData = backend.texData.get(input.dataId);
	  return identity({
	    inputs: {
	      x: inputData.complexTensorInfos.real
	    },
	    backend: backend
	  });
	}
	var realConfig = {
	  kernelName: Real,
	  backendName: 'webgl',
	  kernelFunc: real
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var TO_INT = "return float(int(x));";
	function int(input, backend) {
	  var program = new UnaryOpProgram(input.shape, TO_INT);
	  var output = backend.runWebGLProgram(program, [input], 'int32');
	  return {
	    dataId: output.dataId,
	    shape: output.shape,
	    dtype: output.dtype
	  };
	}

	function cast(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var dtype = attrs.dtype;
	  // Casting to complex64.
	  if (dtype === 'complex64') {
	    if (x.dtype === 'complex64') {
	      return identity({
	        inputs: {
	          x: x
	        },
	        backend: backend
	      });
	    }
	    // TODO(annxingyuan): Import kernel function once zeros is modularized.
	    var zerosTensor = zeros$2(x.shape);
	    var floatX = cast({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        dtype: 'float32'
	      }
	    });
	    var result = complex({
	      inputs: {
	        real: floatX,
	        imag: zerosTensor
	      },
	      backend: backend
	    });
	    zerosTensor.dispose();
	    backend.disposeIntermediateTensorInfo(floatX);
	    return result;
	  }
	  // Casting from complex64
	  if (x.dtype === 'complex64') {
	    var realPart = real({
	      inputs: {
	        input: x
	      },
	      backend: backend
	    });
	    var _result = cast({
	      inputs: {
	        x: realPart
	      },
	      backend: backend,
	      attrs: {
	        dtype: dtype
	      }
	    });
	    backend.disposeIntermediateTensorInfo(realPart);
	    return _result;
	  }
	  if (!hasEncodingLoss(x.dtype, dtype)) {
	    // We don't change the underlying data, since we cast to higher
	    // precision.
	    var _result2 = identity({
	      inputs: {
	        x: x
	      },
	      backend: backend
	    });
	    return {
	      dataId: _result2.dataId,
	      shape: _result2.shape,
	      dtype: dtype
	    };
	  }
	  if (backend.shouldExecuteOnCPU([x])) {
	    var values = backend.texData.get(x.dataId).values;
	    var _castImplCPU = castImplCPU(values, x.shape, x.dtype, dtype),
	      _castImplCPU2 = _slicedToArray(_castImplCPU, 3),
	      resultShape = _castImplCPU2[0],
	      resultType = _castImplCPU2[1],
	      resultData = _castImplCPU2[2];
	    return backend.makeTensorInfo(resultShape, resultType, resultData);
	  }
	  if (dtype === 'int32') {
	    return int(x, backend);
	  }
	  if (dtype === 'bool') {
	    var zerosTensorInfo = backend.makeTensorInfo([], 'bool', getTypedArrayFromDType('bool', 1));
	    var binaryInputs = {
	      a: x,
	      b: zerosTensorInfo
	    };
	    var _result3 = notEqual({
	      inputs: binaryInputs,
	      backend: backend
	    });
	    backend.disposeIntermediateTensorInfo(zerosTensorInfo);
	    return _result3;
	  }
	  throw new Error("Error in Cast: failed to cast ".concat(x.dtype, " to ").concat(dtype));
	}
	var castConfig = {
	  kernelName: Cast,
	  backendName: 'webgl',
	  kernelFunc: cast
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var CEIL = "return ceil(x);";
	var ceil = unaryKernelFunc({
	  opSnippet: CEIL,
	  packedOpSnippet: CEIL,
	  cpuKernelImpl: ceilImplCPU
	});
	var ceilConfig = {
	  kernelName: Ceil,
	  backendName: 'webgl',
	  kernelFunc: ceil
	};

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ClipProgram = /*#__PURE__*/_createClass(function ClipProgram(aShape) {
	  _classCallCheck(this, ClipProgram);
	  this.variableNames = ['A'];
	  this.customUniforms = [{
	    name: 'minVal',
	    type: 'float'
	  }, {
	    name: 'maxVal',
	    type: 'float'
	  }];
	  this.outputShape = aShape;
	  this.userCode = "\n\n      void main() {\n        float value = getAAtOutCoords();\n        if (isnan(value)) {\n          setOutput(value);\n          return;\n        }\n\n        setOutput(clamp(value, minVal, maxVal));\n      }\n    ";
	});

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ClipPackedProgram = /*#__PURE__*/_createClass(function ClipPackedProgram(aShape) {
	  _classCallCheck(this, ClipPackedProgram);
	  this.variableNames = ['A'];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.customUniforms = [{
	    name: 'minVal',
	    type: 'float'
	  }, {
	    name: 'maxVal',
	    type: 'float'
	  }];
	  this.outputShape = aShape;
	  this.userCode = "\n      void main() {\n        vec4 value = getAAtOutCoords();\n\n        if (any(isnan(value))) {\n          setOutput(value);\n          return;\n        }\n\n        setOutput(clamp(value, vec4(minVal), vec4(maxVal)));\n      }\n    ";
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function clipByValue(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var clipValueMin = attrs.clipValueMin,
	    clipValueMax = attrs.clipValueMax;
	  var program;
	  if (env().getBool('WEBGL_PACK_CLIP')) {
	    program = new ClipPackedProgram(x.shape);
	  } else {
	    program = new ClipProgram(x.shape);
	  }
	  var customValues = [[clipValueMin], [clipValueMax]];
	  return backend.runWebGLProgram(program, [x], x.dtype, customValues);
	}
	var clipByValueConfig = {
	  kernelName: ClipByValue,
	  backendName: 'webgl',
	  kernelFunc: clipByValue
	};

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ComplexAbsProgram = /*#__PURE__*/_createClass(function ComplexAbsProgram(shape) {
	  _classCallCheck(this, ComplexAbsProgram);
	  this.variableNames = ['real', 'imag'];
	  this.outputShape = shape;
	  this.userCode = "\n      void main() {\n        float re = abs(getRealAtOutCoords());\n        float im = abs(getImagAtOutCoords());\n        float mx = max(re, im);\n\n        // sadly the length function in glsl is not underflow-safe\n        // (at least not on Intel GPUs). So the safe solution is\n        // to ensure underflow-safety in all cases.\n        setOutput(\n          mx == 0.0 ? 0.0 : mx * length(vec2(1, min(re, im)/mx))\n        );\n      }\n    ";
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	// Returns a TensorInfo with the complex shape and the dataId of the
	// underlying part. We need to do this because a reshaped complex tensor is
	// not reflected in its parts.
	function makeComplexComponentTensorInfo(complexTensor, complexPart) {
	  return {
	    dataId: complexPart.dataId,
	    dtype: complexPart.dtype,
	    shape: complexTensor.shape
	  };
	}
	function complexAbs(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var x = inputs.x;
	  var xData = backend.texData.get(x.dataId);
	  var program = new ComplexAbsProgram(x.shape);
	  var programInputs = [makeComplexComponentTensorInfo(x, xData.complexTensorInfos.real), makeComplexComponentTensorInfo(x, xData.complexTensorInfos.imag)];
	  return backend.runWebGLProgram(program, programInputs, programInputs[0].dtype);
	}
	var complexAbsConfig = {
	  kernelName: ComplexAbs,
	  backendName: 'webgl',
	  kernelFunc: complexAbs
	};

	var ConcatProgram = /*#__PURE__*/_createClass(
	// Concats 2d tensors along axis=1. See comments in MathBackendWebGL.concat().
	function ConcatProgram(shapes) {
	  _classCallCheck(this, ConcatProgram);
	  this.outputShape = [];
	  this.outputShape = computeOutShape$1(shapes, 1 /* axis */);
	  this.variableNames = shapes.map(function (_, i) {
	    return "T".concat(i);
	  });
	  var offsets = new Array(shapes.length - 1);
	  offsets[0] = shapes[0][1];
	  for (var i = 1; i < offsets.length; i++) {
	    offsets[i] = offsets[i - 1] + shapes[i][1];
	  }
	  var snippets = ["if (yC < ".concat(offsets[0], ") setOutput(getT0(yR, yC));")];
	  for (var _i = 1; _i < offsets.length; _i++) {
	    var shift = offsets[_i - 1];
	    snippets.push("else if (yC < ".concat(offsets[_i], ") ") + "setOutput(getT".concat(_i, "(yR, yC-").concat(shift, "));"));
	  }
	  var lastIndex = offsets.length;
	  var lastShift = offsets[offsets.length - 1];
	  snippets.push("else setOutput(getT".concat(lastIndex, "(yR, yC-").concat(lastShift, "));"));
	  this.userCode = "\n      void main() {\n        ivec2 coords = getOutputCoords();\n        int yR = coords.x;\n        int yC = coords.y;\n\n        ".concat(snippets.join('\n        '), "\n      }\n    ");
	});

	var ConcatPackedProgram = /*#__PURE__*/_createClass(function ConcatPackedProgram(shapes, axis) {
	  _classCallCheck(this, ConcatPackedProgram);
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.outputShape = [];
	  this.outputShape = computeOutShape$1(shapes, axis);
	  var shape = this.outputShape;
	  var rank = shape.length;
	  var dtype = getCoordsDataType(rank);
	  var coords = getChannels('coords', rank);
	  var channels = ['x', 'y', 'z', 'w', 'u', 'v'].slice(0, rank);
	  this.variableNames = shapes.map(function (_, i) {
	    return "T".concat(i);
	  });
	  var offsets = new Array(shapes.length - 1);
	  offsets[0] = shapes[0][axis];
	  for (var i = 1; i < offsets.length; i++) {
	    offsets[i] = offsets[i - 1] + shapes[i][axis];
	  }
	  var channel = channels[axis];
	  var lastChannels = channels.slice(-2);
	  var allChannels = channels.join();
	  var getValueSnippet = "if (".concat(channel, " < ").concat(offsets[0], ") {\n        return getChannel(\n            getT0(").concat(allChannels, "), vec2(").concat(lastChannels.join(), "));\n        }");
	  for (var _i = 1; _i < offsets.length; _i++) {
	    var _shift = offsets[_i - 1];
	    // Note: the >= comparison below may seem unnecessary given the check
	    // above but is needed to workaround branch execution issues on some
	    // devices. It makes all the conditions exclusive without relying on
	    // execution order.
	    getValueSnippet += "\n        if (".concat(channel, " < ").concat(offsets[_i], "  && ").concat(channel, " >= ").concat(offsets[_i - 1], ") {\n          return getChannel(\n            getT").concat(_i, "(").concat(shiftedChannels(channels, channel, _shift), "),\n            vec2(").concat(shiftedChannels(lastChannels, channel, _shift), "));\n        }");
	  }
	  var lastIndex = offsets.length;
	  var shift = offsets[offsets.length - 1];
	  getValueSnippet += "\n        return getChannel(\n          getT".concat(lastIndex, "(").concat(shiftedChannels(channels, channel, shift), "),\n          vec2(").concat(shiftedChannels(lastChannels, channel, shift), "));");
	  this.userCode = "\n      float getValue(".concat(channels.map(function (x) {
	    return 'int ' + x;
	  }), ") {\n        ").concat(getValueSnippet, "\n      }\n\n      void main() {\n        ").concat(dtype, " coords = getOutputCoords();\n        vec4 result = vec4(getValue(").concat(coords, "), 0., 0., 0.);\n\n        ").concat(coords[rank - 1], " = ").concat(coords[rank - 1], " + 1;\n        if (").concat(coords[rank - 1], " < ").concat(shape[rank - 1], ") {\n          result.g = getValue(").concat(coords, ");\n        }\n\n        ").concat(coords[rank - 2], " = ").concat(coords[rank - 2], " + 1;\n        if (").concat(coords[rank - 2], " < ").concat(shape[rank - 2], ") {\n          result.a = getValue(").concat(coords, ");\n        }\n\n        ").concat(coords[rank - 1], " = ").concat(coords[rank - 1], " - 1;\n        if (").concat(coords[rank - 2], " < ").concat(shape[rank - 2], " &&\n            ").concat(coords[rank - 1], " < ").concat(shape[rank - 1], ") {\n          result.b = getValue(").concat(coords, ");\n        }\n        setOutput(result);\n      }\n    ");
	});
	/**
	 * Return an expression for coordinates into a vector where a given channel
	 * will be offset by [shift].
	 *
	 * @param channels the channels to consider
	 * @param channel the channel we want shifted
	 * @param shift  the amount to subtract from the channel.
	 *
	 * @returns a string of the form 'x, y-[shift], z' where any one channel can
	 * have the shift applied.
	 */
	function shiftedChannels(channels, channel, shift) {
	  var channelIdx = channels.indexOf(channel);
	  var res = channels.map(function (c, idx) {
	    if (idx === channelIdx) {
	      return "".concat(c, " - ").concat(shift);
	    } else {
	      return c;
	    }
	  });
	  return res.join();
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function imag(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var input = inputs.input;
	  var inputData = backend.texData.get(input.dataId);
	  return identity({
	    inputs: {
	      x: inputData.complexTensorInfos.imag
	    },
	    backend: backend
	  });
	}
	var imagConfig = {
	  kernelName: Imag,
	  backendName: 'webgl',
	  kernelFunc: imag
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function concatImpl(inputs, axis, backend) {
	  var dtype = inputs[0].dtype;
	  if (dtype === 'complex64') {
	    var reals = inputs.map(function (t) {
	      return real({
	        inputs: {
	          input: t
	        },
	        backend: backend
	      });
	    });
	    var imags = inputs.map(function (t) {
	      return imag({
	        inputs: {
	          input: t
	        },
	        backend: backend
	      });
	    });
	    var realConcated = concatImpl(reals, axis, backend);
	    var imagConcated = concatImpl(imags, axis, backend);
	    var _result = complex({
	      inputs: {
	        real: realConcated,
	        imag: imagConcated
	      },
	      backend: backend
	    });
	    reals.forEach(function (r) {
	      return backend.disposeIntermediateTensorInfo(r);
	    });
	    imags.forEach(function (i) {
	      return backend.disposeIntermediateTensorInfo(i);
	    });
	    backend.disposeIntermediateTensorInfo(realConcated);
	    backend.disposeIntermediateTensorInfo(imagConcated);
	    return _result;
	  }
	  var runOnCpu = backend.shouldExecuteOnCPU(inputs);
	  // Run on cpu if dtype is string. For string, the backend represents it
	  // as Uint8Array[], where each Uint8Array is a character. Given that the
	  // computation is only on the outer array, uploading the whole data onto
	  // gpu is wasteful. Also, currently webgl doesn't have a design to
	  // upload and retrieve Uint8Array[] between cpu and gpu. Therefore, we
	  // just run the kernel on cpu if dtype is string.
	  if (dtype === 'string') {
	    runOnCpu = true;
	  }
	  if (runOnCpu) {
	    // Any concat of n-dimensional tensors across any axis can be reduced to
	    // a concatenation of two-dimensional tensors across the axis 1 by first
	    // partitioning the axes of the original tensors into those less than the
	    // axis to be concatenated and the rest. Then reshape the tensors
	    // into a two-dimensional tensor by collapsing these two sets of axes and
	    // concatenate the resulting matrices across the axis 1, finally reshaping
	    // the result to have the proper shape.
	    var _tensors2D = inputs.map(function (t) {
	      var innerSize = sizeFromShape(t.shape.slice(axis));
	      var shape = [-1, innerSize];
	      return reshape({
	        inputs: {
	          x: t
	        },
	        backend: backend,
	        attrs: {
	          shape: shape
	        }
	      });
	    });
	    var inputsValShapes = _tensors2D.map(function (t) {
	      return {
	        vals: backend.readSync(t.dataId),
	        shape: t.shape
	      };
	    });
	    // Concats 2d tensors along axis=1.
	    var _outShape = computeOutShape$1(_tensors2D.map(function (t) {
	      return t.shape;
	    }), 1 /* axis */);
	    var simplyConcat = _tensors2D[0].shape[0] === 1;
	    var outVals = concatImplCPU(inputsValShapes, _outShape, dtype, simplyConcat);
	    var finalOutShape = computeOutShape$1(inputs.map(function (t) {
	      return t.shape;
	    }), axis);
	    var outInfo = backend.makeTensorInfo(finalOutShape, dtype, outVals);
	    _tensors2D.forEach(function (t) {
	      return backend.disposeIntermediateTensorInfo(t);
	    });
	    return outInfo;
	  }
	  // Keep only non-empty tensors (ignore tensors with 0 in their shape).
	  var $inputs = inputs.filter(function (t) {
	    return sizeFromShape(t.shape) > 0;
	  });
	  var shouldPack = env().getBool('WEBGL_PACK_ARRAY_OPERATIONS') && $inputs[0].shape.length > 1;
	  if ($inputs.length === 1) {
	    // Clone tensor.
	    var _program = shouldPack ? new UnaryOpProgram(inputs[0].shape, CLONE) : new UnaryOpPackedProgram(inputs[0].shape, CLONE);
	    return backend.runWebGLProgram(_program, inputs, dtype);
	  }
	  var maxTexturesInShader = env().getNumber('WEBGL_MAX_TEXTURES_IN_SHADER');
	  if ($inputs.length > maxTexturesInShader) {
	    var reducedInputs = [];
	    for (var i = 0; i < $inputs.length; i += maxTexturesInShader) {
	      var subArray = $inputs.slice(i, i + maxTexturesInShader);
	      reducedInputs.push(concatImpl(subArray, axis, backend));
	    }
	    var _result2 = concatImpl(reducedInputs, axis, backend);
	    for (var _i = 0, _reducedInputs = reducedInputs; _i < _reducedInputs.length; _i++) {
	      var _i2 = _reducedInputs[_i];
	      backend.disposeIntermediateTensorInfo(_i2);
	    }
	    return _result2;
	  }
	  if (shouldPack) {
	    var _program2 = new ConcatPackedProgram($inputs.map(function (t) {
	      return t.shape;
	    }), axis);
	    return backend.runWebGLProgram(_program2, $inputs, dtype);
	  }
	  var _computeTensors2D = computeTensors2D($inputs, axis, backend),
	    tensors2D = _computeTensors2D.tensors2D,
	    outShape = _computeTensors2D.outShape;
	  var program = new ConcatProgram(tensors2D.map(function (t) {
	    return t.shape;
	  }));
	  var result = backend.runWebGLProgram(program, tensors2D, dtype);
	  tensors2D.forEach(function (r) {
	    return backend.disposeIntermediateTensorInfo(r);
	  });
	  var reshapedResult = reshape({
	    inputs: {
	      x: result
	    },
	    attrs: {
	      shape: outShape
	    },
	    backend: backend
	  });
	  backend.disposeIntermediateTensorInfo(result);
	  return reshapedResult;
	}
	function computeTensors2D(inputs, axis, backend) {
	  // Any concat of n-dimensional tensors across any axis can be reduced to
	  // a concatenation of two-dimensional tensors across the axis 1 by first
	  // partitioning the axes of the original tensors into those less than the
	  // axis to be concatenated and the rest. Then reshape the tensors
	  // into a two-dimensional tensor by collapsing these two sets of axes and
	  // concatenate the resulting matrices across the axis 1, finally reshaping
	  // the result to have the proper shape.
	  var outShape = computeOutShape$1(inputs.map(function (t) {
	    return t.shape;
	  }), axis);
	  var tensors2D = inputs.map(function (x) {
	    return reshape({
	      inputs: {
	        x: x
	      },
	      attrs: {
	        shape: [-1, sizeFromShape(x.shape.slice(axis))]
	      },
	      backend: backend
	    });
	  });
	  return {
	    tensors2D: tensors2D,
	    outShape: outShape
	  };
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function concat(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var axis = attrs.axis;
	  var $axis = parseAxisParam(axis, inputs[0].shape)[0];
	  var shapes = inputs.map(function (t) {
	    return t.shape;
	  });
	  assertParamsConsistent(shapes, $axis);
	  var outShape = computeOutShape$1(inputs.map(function (t) {
	    return t.shape;
	  }), $axis);
	  if (sizeFromShape(outShape) === 0) {
	    return backend.makeTensorInfo(outShape, inputs[0].dtype, []);
	  }
	  // Keep only non-empty tensors (ignore tensors with 0 in their shape).
	  var $inputs = inputs.filter(function (t) {
	    return sizeFromShape(t.shape) > 0;
	  });
	  if ($inputs.length === 1) {
	    return identity({
	      inputs: {
	        x: $inputs[0]
	      },
	      backend: backend
	    });
	  }
	  return concatImpl($inputs, $axis, backend);
	}
	var concatConfig = {
	  kernelName: Concat,
	  backendName: 'webgl',
	  kernelFunc: concat
	};

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var Conv2DProgram = /*#__PURE__*/_createClass(function Conv2DProgram(convInfo) {
	  var addBias = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
	  var activation = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
	  var hasPreluActivationWeights = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var hasLeakyreluAlpha = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
	  _classCallCheck(this, Conv2DProgram);
	  this.variableNames = ['x', 'W'];
	  this.outputShape = convInfo.outShape;
	  var padTop = convInfo.padInfo.top;
	  var padLeft = convInfo.padInfo.left;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var dilationHeight = convInfo.dilationHeight;
	  var dilationWidth = convInfo.dilationWidth;
	  var filterHeight = convInfo.filterHeight;
	  var filterWidth = convInfo.filterWidth;
	  var inputDepthNearestVec4 = Math.floor(convInfo.inChannels / 4) * 4;
	  var inputDepthVec4Remainder = convInfo.inChannels % 4;
	  var isChannelsLast = convInfo.dataFormat === 'channelsLast';
	  var rowDim = isChannelsLast ? 1 : 2;
	  var colDim = isChannelsLast ? 2 : 3;
	  var channelDim = isChannelsLast ? 3 : 1;
	  var activationSnippet = '',
	    applyActivationSnippet = '';
	  if (activation) {
	    if (hasPreluActivationWeights) {
	      activationSnippet = "float activation(float a) {\n          float b = getPreluActivationWeightsAtOutCoords();\n          ".concat(activation, "\n        }");
	    } else if (hasLeakyreluAlpha) {
	      activationSnippet = "float activation(float a) {\n          float b = getLeakyreluAlphaAtOutCoords();\n          ".concat(activation, "\n        }");
	    } else {
	      activationSnippet = "\n          float activation(float x) {\n            ".concat(activation, "\n          }\n        ");
	    }
	    applyActivationSnippet = "result = activation(result);";
	  }
	  var addBiasSnippet = addBias ? 'result += getBiasAtOutCoords();' : '';
	  if (addBias) {
	    this.variableNames.push('bias');
	  }
	  if (hasPreluActivationWeights) {
	    this.variableNames.push('preluActivationWeights');
	  }
	  if (hasLeakyreluAlpha) {
	    this.variableNames.push('leakyreluAlpha');
	  }
	  this.userCode = "\n      ".concat(activationSnippet, "\n\n      const ivec2 strides = ivec2(").concat(strideHeight, ", ").concat(strideWidth, ");\n      const ivec2 pads = ivec2(").concat(padTop, ", ").concat(padLeft, ");\n\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int batch = coords[0];\n        int d2 = coords[").concat(channelDim, "];\n\n        ivec2 xRCCorner =\n            ivec2(coords[").concat(rowDim, "], coords[").concat(colDim, "]) * strides - pads;\n        int xRCorner = xRCCorner.x;\n        int xCCorner = xRCCorner.y;\n\n        // Convolve x(?, ?, d1) with w(:, :, d1, d2) to get y(yR, yC, d2).\n        // ? = to be determined. : = across all values in that axis.\n        float dotProd = 0.0;\n        for (int wR = 0; wR < ").concat(filterHeight, "; wR++) {\n          int xR = xRCorner + wR * ").concat(dilationHeight, ";\n\n          if (xR < 0 || xR >= ").concat(convInfo.inHeight, ") {\n            continue;\n          }\n\n          for (int wC = 0; wC < ").concat(filterWidth, "; wC++) {\n            int xC = xCCorner + wC * ").concat(dilationWidth, ";\n\n            if (xC < 0 || xC >= ").concat(convInfo.inWidth, ") {\n              continue;\n            }\n\n            for (int d1 = 0; d1 < ").concat(inputDepthNearestVec4, "; d1 += 4) {\n              vec4 wValues = vec4(\n                getW(wR, wC, d1, d2),\n                getW(wR, wC, d1 + 1, d2),\n                getW(wR, wC, d1 + 2, d2),\n                getW(wR, wC, d1 + 3, d2)\n              );\n\n              if (").concat(isChannelsLast, ") {\n                vec4 xValues = vec4(\n                  getX(batch, xR, xC, d1),\n                  getX(batch, xR, xC, d1 + 1),\n                  getX(batch, xR, xC, d1 + 2),\n                  getX(batch, xR, xC, d1 + 3)\n                );\n                dotProd += dot(xValues, wValues);\n              } else {\n                vec4 xValues = vec4(\n                  getX(batch, d1, xR, xC),\n                  getX(batch, d1 + 1, xR, xC),\n                  getX(batch, d1 + 2, xR, xC),\n                  getX(batch, d1 + 3, xR, xC)\n                );\n                dotProd += dot(xValues, wValues);\n              }\n            }\n\n            if (").concat(inputDepthVec4Remainder === 1, ") {\n\n              if (").concat(isChannelsLast, ") {\n                dotProd +=\n                    getX(batch, xR, xC, ").concat(inputDepthNearestVec4, ") *\n                    getW(wR, wC, ").concat(inputDepthNearestVec4, ", d2);\n              } else {\n                dotProd +=\n                    getX(batch, ").concat(inputDepthNearestVec4, ", xR, xC) *\n                    getW(wR, wC, ").concat(inputDepthNearestVec4, ", d2);\n              }\n\n            } else if (").concat(inputDepthVec4Remainder === 2, ") {\n              vec2 wValues = vec2(\n                getW(wR, wC, ").concat(inputDepthNearestVec4, ", d2),\n                getW(wR, wC, ").concat(inputDepthNearestVec4, " + 1, d2)\n              );\n\n              if (").concat(isChannelsLast, ") {\n                vec2 xValues = vec2(\n                  getX(batch, xR, xC, ").concat(inputDepthNearestVec4, "),\n                  getX(batch, xR, xC, ").concat(inputDepthNearestVec4, " + 1)\n                );\n                dotProd += dot(xValues, wValues);\n              } else {\n                vec2 xValues = vec2(\n                  getX(batch, ").concat(inputDepthNearestVec4, ", xR, xC),\n                  getX(batch, ").concat(inputDepthNearestVec4, " + 1, xR, xC)\n                );\n                dotProd += dot(xValues, wValues);\n              }\n\n            } else if (").concat(inputDepthVec4Remainder === 3, ") {\n              vec3 wValues = vec3(\n                getW(wR, wC, ").concat(inputDepthNearestVec4, ", d2),\n                getW(wR, wC, ").concat(inputDepthNearestVec4, " + 1, d2),\n                getW(wR, wC, ").concat(inputDepthNearestVec4, " + 2, d2)\n              );\n\n              if (").concat(isChannelsLast, ") {\n                vec3 xValues = vec3(\n                  getX(batch, xR, xC, ").concat(inputDepthNearestVec4, "),\n                  getX(batch, xR, xC, ").concat(inputDepthNearestVec4, " + 1),\n                  getX(batch, xR, xC, ").concat(inputDepthNearestVec4, " + 2)\n                );\n                dotProd += dot(xValues, wValues);\n              } else {\n                vec3 xValues = vec3(\n                  getX(batch, ").concat(inputDepthNearestVec4, ", xR, xC),\n                  getX(batch, ").concat(inputDepthNearestVec4, " + 1, xR, xC),\n                  getX(batch, ").concat(inputDepthNearestVec4, " + 2, xR, xC)\n                );\n                dotProd += dot(xValues, wValues);\n              }\n\n            }\n          }\n        }\n\n        float result = dotProd;\n        ").concat(addBiasSnippet, "\n        ").concat(applyActivationSnippet, "\n        setOutput(result);\n      }\n    ");
	});
	var Conv3DProgram = /*#__PURE__*/_createClass(function Conv3DProgram(convInfo) {
	  _classCallCheck(this, Conv3DProgram);
	  this.variableNames = ['x', 'W'];
	  this.outputShape = convInfo.outShape;
	  var padFront = convInfo.padInfo.front;
	  var padTop = convInfo.padInfo.top;
	  var padLeft = convInfo.padInfo.left;
	  var strideDepth = convInfo.strideDepth;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var dilationDepth = convInfo.dilationDepth;
	  var dilationHeight = convInfo.dilationHeight;
	  var dilationWidth = convInfo.dilationWidth;
	  var filterDepth = convInfo.filterDepth;
	  var filterHeight = convInfo.filterHeight;
	  var filterWidth = convInfo.filterWidth;
	  var inputDepthNearestVec4 = Math.floor(convInfo.inChannels / 4) * 4;
	  var inputDepthVec4Remainder = convInfo.inChannels % 4;
	  this.userCode = "\n      const ivec3 strides = ivec3(".concat(strideDepth, ", ").concat(strideHeight, ", ").concat(strideWidth, ");\n      const ivec3 pads = ivec3(").concat(padFront, ", ").concat(padTop, ", ").concat(padLeft, ");\n\n      void main() {\n        ivec5 coords = getOutputCoords();\n        int batch = coords.x;\n        int d2 = coords.u;\n\n        ivec3 xFRCCorner = ivec3(coords.y, coords.z, coords.w) * strides - pads;\n        int xFCorner = xFRCCorner.x;\n        int xRCorner = xFRCCorner.y;\n        int xCCorner = xFRCCorner.z;\n\n        // Convolve x(?, ?, ?, d1) with w(:, :, :, d1, d2) to get\n        // y(yF, yR, yC, d2). ? = to be determined. : = across all\n        // values in that axis.\n        float dotProd = 0.0;\n        for (int wF = 0; wF < ").concat(filterDepth, "; wF++) {\n          int xF = xFCorner + wF * ").concat(dilationDepth, ";\n\n          if (xF < 0 || xF >= ").concat(convInfo.inDepth, ") {\n            continue;\n          }\n\n          for (int wR = 0; wR < ").concat(filterHeight, "; wR++) {\n            int xR = xRCorner + wR * ").concat(dilationHeight, ";\n\n            if (xR < 0 || xR >= ").concat(convInfo.inHeight, ") {\n              continue;\n            }\n\n            for (int wC = 0; wC < ").concat(filterWidth, "; wC++) {\n              int xC = xCCorner + wC * ").concat(dilationWidth, ";\n\n              if (xC < 0 || xC >= ").concat(convInfo.inWidth, ") {\n                continue;\n              }\n\n              for (int d1 = 0; d1 < ").concat(inputDepthNearestVec4, "; d1 += 4) {\n                vec4 xValues = vec4(\n                  getX(batch, xF, xR, xC, d1),\n                  getX(batch, xF, xR, xC, d1 + 1),\n                  getX(batch, xF, xR, xC, d1 + 2),\n                  getX(batch, xF, xR, xC, d1 + 3)\n                );\n                vec4 wValues = vec4(\n                  getW(wF, wR, wC, d1, d2),\n                  getW(wF, wR, wC, d1 + 1, d2),\n                  getW(wF, wR, wC, d1 + 2, d2),\n                  getW(wF, wR, wC, d1 + 3, d2)\n                );\n\n                dotProd += dot(xValues, wValues);\n              }\n\n              if (").concat(inputDepthVec4Remainder === 1, ") {\n                dotProd +=\n                  getX(batch, xF, xR, xC, ").concat(inputDepthNearestVec4, ") *\n                  getW(wF, wR, wC, ").concat(inputDepthNearestVec4, ", d2);\n              } else if (").concat(inputDepthVec4Remainder === 2, ") {\n                vec2 xValues = vec2(\n                  getX(batch, xF, xR, xC, ").concat(inputDepthNearestVec4, "),\n                  getX(batch, xF, xR, xC, ").concat(inputDepthNearestVec4, " + 1)\n                );\n                vec2 wValues = vec2(\n                  getW(wF, wR, wC, ").concat(inputDepthNearestVec4, ", d2),\n                  getW(wF, wR, wC, ").concat(inputDepthNearestVec4, " + 1, d2)\n                );\n                dotProd += dot(xValues, wValues);\n              } else if (").concat(inputDepthVec4Remainder === 3, ") {\n                vec3 xValues = vec3(\n                  getX(batch, xF, xR, xC, ").concat(inputDepthNearestVec4, "),\n                  getX(batch, xF, xR, xC, ").concat(inputDepthNearestVec4, " + 1),\n                  getX(batch, xF, xR, xC, ").concat(inputDepthNearestVec4, " + 2)\n                );\n                vec3 wValues = vec3(\n                  getW(wF, wR, wC, ").concat(inputDepthNearestVec4, ", d2),\n                  getW(wF, wR, wC, ").concat(inputDepthNearestVec4, " + 1, d2),\n                  getW(wF, wR, wC, ").concat(inputDepthNearestVec4, " + 2, d2)\n                );\n                dotProd += dot(xValues, wValues);\n              }\n            }\n          }\n        }\n        setOutput(dotProd);\n      }\n    ");
	});

	var Conv2DPackedProgram = /*#__PURE__*/_createClass(function Conv2DPackedProgram(convInfo) {
	  var addBias = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
	  var activation = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
	  var hasPreluActivation = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var hasLeakyReluAlpha = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
	  _classCallCheck(this, Conv2DPackedProgram);
	  this.variableNames = ['x', 'W'];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.customUniforms = [{
	    name: 'pads',
	    type: 'ivec2'
	  }, {
	    name: 'strides',
	    type: 'ivec2'
	  }, {
	    name: 'dilations',
	    type: 'ivec2'
	  }, {
	    name: 'inDims',
	    type: 'ivec2'
	  }];
	  this.outputShape = convInfo.outShape;
	  this.enableShapeUniforms = useShapeUniforms(this.outputShape.length);
	  var padLeft = convInfo.padInfo.left;
	  var strideWidth = convInfo.strideWidth;
	  var dilationWidth = convInfo.dilationWidth;
	  var filterHeight = convInfo.filterHeight;
	  var filterWidth = convInfo.filterWidth;
	  var texelsAcross = filterWidth;
	  var mainLoop = "\n       int xR; int xC; int xCOffset;\n       vec4 wTexel; vec4 previous; vec4 final;";
	  for (var c = 0; c < filterWidth; c++) {
	    mainLoop += "\n           vec4 xTexelC".concat(c * 2, ";\n           int xTexelC").concat(c * 2, "Ready;\n           vec4 xTexelC").concat(c * 2 + 1, ";\n           int xTexelC").concat(c * 2 + 1, "Ready;\n           vec4 xC").concat(c, ";");
	  }
	  /**
	   * This vectorized implementation works by gathering the values needed for
	   * each output channel's dot product into vec4's and then multiplying them
	   * all together (this happens in the final double for-loop below). Most of
	   * the main loop consists of constructing these vec4's with the minimum
	   * number of texture2D calls, which means making use of all four returned
	   * values from a texture2D call at once.
	   */
	  mainLoop += "\n     for (int r = 0; r < ".concat(filterHeight, "; r++) {\n      for (int d1 = 0; d1 < ").concat(convInfo.inChannels, "; d1 += 2) {\n       ");
	  for (var _c = 0; _c < filterWidth; _c++) {
	    mainLoop += "\n           xTexelC".concat(_c * 2, " = vec4(0.0);\n           xTexelC").concat(_c * 2, "Ready = 0;\n           xTexelC").concat(_c * 2 + 1, " = vec4(0.0);\n           xTexelC").concat(_c * 2 + 1, "Ready = 0;\n           xC").concat(_c, " = vec4(0.0);");
	  }
	  mainLoop += "\n         xR = xRCorner + r * dilations[0];\n         if (xR >=0 && xR < inDims[0]) {\n       ";
	  for (var texelC = 0; texelC < (texelsAcross + 1) / 2; texelC++) {
	    var colIndex = texelC * 2;
	    mainLoop += "\n           xC = xCCorner + ".concat(colIndex * dilationWidth, ";\n           ");
	    if (strideWidth === 1) {
	      if (colIndex < filterWidth) {
	        // If padding is odd, the outer texels have to be composed.
	        if (padLeft % 2 === 1) {
	          // TODO: Ensure vec4 previous does not result in redundant sample,
	          // and avoid setting xTexelRC's that exceed the boundary in the
	          // first place rather than resetting them to vec4(0)).
	          // To compute xCOffset:
	          // - If padding is odd, we must add 1 to ensure we ask for an
	          // even-numbered row.
	          // - We subtract 2 to access the previous texel.
	          mainLoop += "\n                 xCOffset = xC + 1;\n                 if (xCOffset >= 0 && xCOffset < inDims[1] && xTexelC".concat(colIndex, "Ready == 0) {\n                   xTexelC").concat(colIndex, " = getX(batch, xR, xCOffset, d1);\n\n                   // Need to manually clear unused channels in case\n                   // we're reading from recycled texture.\n                   if (xCOffset + 1 >= inDims[1]) {\n                     xTexelC").concat(colIndex, ".zw = vec2(0.0);\n                   }\n                   xTexelC").concat(colIndex, "Ready = 1;\n                 }\n               ");
	          // This texel has been read in previous iteration if the dilation
	          // is 1.
	          if (dilationWidth === 1 && colIndex > 0) {
	            mainLoop += "\n                 xC".concat(colIndex, " = vec4(xTexelC").concat(colIndex - 2, ".zw, xTexelC").concat(colIndex, ".xy);\n                 ");
	          } else {
	            mainLoop += "\n                   xCOffset = xC + 1 - 2;\n\n                   if (xCOffset >= 0 && xCOffset < inDims[1]) {\n                     previous = getX(batch, xR, xCOffset, d1);\n\n                     // Need to manually clear unused channels in case\n                     // we're reading from recycled texture.\n                     if (xCOffset + 1 >= inDims[1]) {\n                       previous.zw = vec2(0.0);\n                     }\n\n                     xC".concat(colIndex, " = vec4(previous.zw, xTexelC").concat(colIndex, ".xy);\n                   } else {\n                     xC").concat(colIndex, " = vec4(0.0, 0.0, xTexelC").concat(colIndex, ".xy);\n                   }\n                   ");
	          }
	        } else {
	          // Padding is even, so xRC corresponds to a single texel.
	          mainLoop += "\n                 if (xC >= 0 && xC < inDims[1] && xTexelC".concat(colIndex, "Ready == 0) {\n                   xTexelC").concat(colIndex, " = getX(batch, xR, xC, d1);\n                   if (xC + 1 >= inDims[1]) {\n                     xTexelC").concat(colIndex, ".zw = vec2(0.0);\n                   }\n                   xTexelC").concat(colIndex, "Ready = 1;\n                 }\n\n                 xC").concat(colIndex, " = xTexelC").concat(colIndex, ";\n                 ");
	        }
	        if (colIndex + 1 < filterWidth) {
	          // If dilation is even, the second entry should match the first
	          // (either both are composed or both are single samples). But if
	          // dilation is odd, then the second entry should be the opposite
	          // of the first (if the first is composed, the second is a single
	          // sample, and vice versa.)
	          var nextTexelOffset = padLeft % 2 === 0 ? nearestLargerEven(dilationWidth) : dilationWidth;
	          if (dilationWidth % 2 === 0 && padLeft % 2 === 1 || dilationWidth % 2 !== 0 && padLeft % 2 !== 1) {
	            mainLoop += "\n                   xCOffset = xC + imod(pads[1], 2) + ".concat(nextTexelOffset, ";\n\n                   if (xCOffset >= 0 && xCOffset < inDims[1] && xTexelC").concat(colIndex + 1, "Ready == 0) {\n                     xTexelC").concat(colIndex + 1, " = getX(batch, xR, xCOffset, d1);\n\n                     // Need to manually clear unused channels in case\n                     // we're reading from recycled texture.\n                     if (xCOffset + 1 >= inDims[1]) {\n                       xTexelC").concat(colIndex + 1, ".zw = vec2(0.0);\n                     }\n                     xTexelC").concat(colIndex + 1, "Ready = 1;\n                   }\n                   ");
	            // If dilation > 1 then the xRC's will not be able to share any
	            // values, so each xRC will require two unique calls to getX.
	            if (dilationWidth > 1) {
	              mainLoop += "\n                     xCOffset -= 2;\n                     if (xCOffset >= 0 && xCOffset < inDims[1]) {\n                      previous = getX(batch, xR, xCOffset, d1);\n                      xC".concat(colIndex + 1, " = vec4(previous.zw, xTexelC").concat(colIndex + 1, ".xy);\n                     } else {\n                      xC").concat(colIndex + 1, " = vec4(0.0, 0.0, xTexelC").concat(colIndex + 1, ".xy);\n                     }\n                     ");
	            } else {
	              mainLoop += "\n                     xC".concat(colIndex + 1, " = vec4(xTexelC").concat(colIndex, ".zw, xTexelC").concat(colIndex + 1, ".xy);\n                     ");
	            }
	          } else {
	            // If dilation is 1 and padding is odd, we have already read the
	            // texel when constructing the previous x value. Here we can
	            // simply skip the texture read.
	            if (nextTexelOffset === 1) {
	              mainLoop += "\n                     xC".concat(colIndex + 1, " = xTexelC").concat(colIndex, ";\n                     ");
	            } else {
	              mainLoop += "\n                     xCOffset = xC + ".concat(nextTexelOffset, ";\n\n                     if (xCOffset >= 0 && xCOffset < inDims[1] && xTexelC").concat(colIndex + 1, "Ready == 0) {\n                       xTexelC").concat(colIndex + 1, " = getX(batch, xR, xCOffset, d1);\n                       if (xCOffset + 1 >= inDims[1]) {\n                         xTexelC").concat(colIndex + 1, ".zw = vec2(0.0);\n                       }\n                       xTexelC").concat(colIndex + 1, "Ready = 1;\n                     }\n\n                     xC").concat(colIndex + 1, " = xTexelC").concat(colIndex + 1, ";\n                     ");
	            }
	          }
	        }
	      }
	    } else {
	      // stride === 2
	      if (colIndex < filterWidth) {
	        // Depending on whether padLeft is even or odd, we want either the
	        // xy or zw channels from X texels for xC${colIndex}. If padLeft is
	        // even, xC${colIndex +1} is simply the zw channels of texels we've
	        // already sampled. But if padLeft is odd, xC{$c + 1}.zw will
	        // need to come from the xy channels of a new texel, hence the `
	        // vec4
	        // final` initialized below.
	        if (padLeft % 2 === 1) {
	          mainLoop += "\n                 xCOffset = xC + 1 - strides[1];\n                 if(xCOffset >= 0 && xCOffset < inDims[1] && xTexelC".concat(colIndex, "Ready == 0) {\n                   xTexelC").concat(colIndex, " = getX(batch, xR, xCOffset, d1);\n                   // Need to manually clear unused channels in case\n                   // we're reading from recycled texture.\n                   if (xCOffset + 1 >= inDims[1]) {\n                     xTexelC").concat(colIndex, ".zw = vec2(0.0);\n                   }\n                   xTexelC").concat(colIndex, "Ready = 1;\n                 }\n\n                 if(xC + 1 >= 0 && xC + 1 < inDims[1] && xTexelC").concat(colIndex + 1, "Ready == 0) {\n                   xTexelC").concat(colIndex + 1, " = getX(batch, xR, xC + 1, d1);\n                   // Need to manually clear unused channels in case\n                   // we're reading from recycled texture.\n                   if (xC + 2 >= inDims[1]) {\n                     xTexelC").concat(colIndex + 1, ".zw = vec2(0.0);\n                   }\n                   xTexelC").concat(colIndex + 1, "Ready = 1;\n                 }\n\n                 xC").concat(colIndex, " = vec4(xTexelC").concat(colIndex, ".zw, xTexelC").concat(colIndex + 1, ".zw);\n               ");
	          if (colIndex + 1 < filterWidth) {
	            mainLoop += "\n                   final = vec4(0.0);\n                   xCOffset = xC + 1 + strides[1];\n                   if(xCOffset >= 0 && xCOffset < inDims[1]) {\n                     final = getX(batch, xR, xCOffset, d1);\n                   }\n                   xC".concat(colIndex + 1, " = vec4(xTexelC").concat(colIndex + 1, ".xy, final.xy);\n                 ");
	          }
	        } else {
	          mainLoop += "\n                 if(xC >= 0 && xC < inDims[1] && xTexelC".concat(colIndex, "Ready == 0) {\n                   xTexelC").concat(colIndex, " = getX(batch, xR, xC, d1);\n                   if (xC + 1 >= inDims[1]) {\n                     xTexelC").concat(colIndex, ".zw = vec2(0.0);\n                   }\n                   xTexelC").concat(colIndex, "Ready = 1;\n                 }\n\n                 xCOffset = xC + strides[1];\n                 if(xCOffset >= 0 && xCOffset < inDims[1] && xTexelC").concat(colIndex + 1, "Ready == 0) {\n                   xTexelC").concat(colIndex + 1, " = getX(batch, xR, xCOffset, d1);\n                   if (xCOffset + 1 >= inDims[1]) {\n                     xTexelC").concat(colIndex + 1, ".zw = vec2(0.);\n                   }\n                   xTexelC").concat(colIndex + 1, "Ready = 1;\n                 }\n\n                 xC").concat(colIndex, " = vec4(\n                   xTexelC").concat(colIndex, ".xy, xTexelC").concat(colIndex + 1, ".xy);\n               ");
	          if (colIndex + 1 < filterWidth) {
	            mainLoop += "\n                   xC".concat(colIndex + 1, " = vec4(xTexelC").concat(colIndex, ".zw, xTexelC").concat(colIndex + 1, ".zw);\n                 ");
	          }
	        }
	      }
	    }
	    // localize the dotProd accumulation within the loop, the theory is for
	    // GPU with limited cache, accumulate sum across large amount of
	    // veriables will cause lots of cache misses. (i.e. 5x5 filter will have
	    // 50 variables)
	    if (colIndex < filterWidth) {
	      mainLoop += "\n             wTexel = getW(r, ".concat(colIndex, ", d1, d2);\n             dotProd += xC").concat(colIndex, ".xxzz * vec4(wTexel.xy, wTexel.xy);\n             if(d1 + 1 < ").concat(convInfo.inChannels, ") {\n               dotProd += xC").concat(colIndex, ".yyww * vec4(wTexel.zw, wTexel.zw);\n             }\n           ");
	      if (colIndex + 1 < filterWidth) {
	        mainLoop += "\n               wTexel = getW(r, ".concat(colIndex + 1, ", d1, d2);\n               dotProd += xC").concat(colIndex + 1, ".xxzz * vec4(wTexel.xy, wTexel.xy);\n               if(d1 + 1 < ").concat(convInfo.inChannels, ") {\n                 dotProd += xC").concat(colIndex + 1, ".yyww * vec4(wTexel.zw, wTexel.zw);\n               }\n             ");
	      }
	    }
	  }
	  mainLoop += "\n     }\n   ";
	  mainLoop += "\n     }\n   ";
	  mainLoop += "\n     }\n   ";
	  var activationSnippet = '',
	    applyActivationSnippet = '';
	  if (activation) {
	    if (hasPreluActivation) {
	      activationSnippet = "vec4 activation(vec4 a) {\n           vec4 b = getPreluActivationWeightsAtOutCoords();\n           ".concat(activation, "\n         }");
	    } else if (hasLeakyReluAlpha) {
	      activationSnippet = "vec4 activation(vec4 a) {\n           vec4 b = getLeakyreluAlphaAtOutCoords();\n           ".concat(activation, "\n         }");
	    } else {
	      activationSnippet = "vec4 activation(vec4 x) {\n           ".concat(activation, "\n         }");
	    }
	    applyActivationSnippet = "result = activation(result);";
	  }
	  var addBiasSnippet = addBias ? 'result += getBiasAtOutCoords();' : '';
	  if (addBias) {
	    this.variableNames.push('bias');
	  }
	  if (hasPreluActivation) {
	    this.variableNames.push('preluActivationWeights');
	  }
	  if (hasLeakyReluAlpha) {
	    this.variableNames.push('leakyreluAlpha');
	  }
	  this.userCode = "\n       ".concat(activationSnippet, "\n\n       void main() {\n         ivec4 coords = getOutputCoords();\n         int batch = coords.x;\n         ivec2 xRCCorner = coords.yz * strides - pads;\n         int d2 = coords.w;\n         int xRCorner = xRCCorner.x;\n         int xCCorner = xRCCorner.y;\n\n         //intialize dotProd with a small epsilon seems to reduce GPU accuracy loss.\n         vec4 dotProd = vec4(0.000000000000001);\n\n         ").concat(mainLoop, "\n\n         vec4 result = dotProd - vec4(0.000000000000001);\n         ").concat(addBiasSnippet, "\n         ").concat(applyActivationSnippet, "\n         setOutput(result);\n       }\n     ");
	});

	var Im2ColPackedProgram = /*#__PURE__*/_createClass(function Im2ColPackedProgram(outputShape, convInfo) {
	  _classCallCheck(this, Im2ColPackedProgram);
	  this.variableNames = ['A'];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.customUniforms = [{
	    name: 'inputShape',
	    type: 'ivec4'
	  }, {
	    name: 'pad',
	    type: 'ivec2'
	  }, {
	    name: 'stride',
	    type: 'ivec2'
	  }, {
	    name: 'dilation',
	    type: 'ivec2'
	  }, {
	    name: 'inChannels',
	    type: 'int'
	  }, {
	    name: 'itemsPerBlockRow',
	    type: 'int'
	  }, {
	    name: 'outWidth',
	    type: 'int'
	  }];
	  this.outputShape = outputShape;
	  this.enableShapeUniforms = useShapeUniforms(this.outputShape.length);
	  var dataFormat = convInfo.dataFormat;
	  var glsl = getGlslDifferences();
	  var isChannelsLast = dataFormat === 'channelsLast';
	  var rowDim = isChannelsLast ? 1 : 2;
	  var colDim = isChannelsLast ? 2 : 3;
	  var boundsCheckingSnippet = this.enableShapeUniforms ? 'if(blockIndex < outShape[2] && pos < outShape[1]) {' : "if(blockIndex < ".concat(outputShape[2], " && pos < ").concat(outputShape[1], ") {");
	  var unrolled = "";
	  for (var row = 0; row <= 1; row++) {
	    for (var col = 0; col <= 1; col++) {
	      unrolled += "\n          blockIndex = rc.z + ".concat(col, ";\n          pos = rc.y + ").concat(row, ";\n\n          ").concat(boundsCheckingSnippet, "\n            offsetY = int(blockIndex / outWidth) * stride[0] - pad[0];\n            d0 = offsetY + dilation[0] * (pos / itemsPerBlockRow);\n\n            if(d0 < inputShape[").concat(rowDim, "] && d0 >= 0) {\n              // Use custom imod instead mod. On Intel GPU, mod may generate\n              // unexpected value.\n              // https://github.com/tensorflow/tfjs/issues/5447\n              offsetX = imod(blockIndex, outWidth) * stride[1] - pad[1];\n              d1 = offsetX + dilation[1] * (imod(pos, itemsPerBlockRow) /\n                  inChannels);\n\n              if(d1 < inputShape[").concat(colDim, "] && d1 >= 0) {\n\n                ch = imod(pos, inChannels);\n\n                if (").concat(isChannelsLast, ") {\n                  innerDims = vec2(d1, ch);\n                  result[").concat(row * 2 + col, "] = getChannel(\n                    getA(rc.x, d0, int(innerDims.x),\n                    int(innerDims.y)), innerDims);\n                } else {\n                  innerDims = vec2(d0, d1);\n                  result[").concat(row * 2 + col, "] = getChannel(\n                    getA(rc.x, ch, int(innerDims.x),\n                    int(innerDims.y)), innerDims);\n                }\n              }\n            }\n          }\n        ");
	    }
	  }
	  this.userCode = "\n      void main() {\n        ivec3 rc = getOutputCoords();\n\n        vec4 result = vec4(0);\n\n        int blockIndex, pos, offsetY, d0, offsetX, d1, ch;\n        vec2 innerDims;\n\n        ".concat(unrolled, "\n\n        ").concat(glsl.output, " = result;\n      }\n    ");
	});

	// Both conv2dByMatMul and conv2dWithIm2Row fuse height and width into one
	// dimension to compute batchMatMul, so bias and activation weights are also
	// supposed to fuse the two dimensions into one.
	//
	// This function computes the target shape for fusing height and width
	// dimensions. Returning null means the shape is already compatible.
	//
	// Even though the bias is not supposed to be a 3-D or a 4-D (including
	// batch) tensor and PReLU activiation weights is not supposed to be a 4-D
	// tensor, we still need to support them, because we haven't disabled
	// them for NHWC format.
	// https://github.com/tensorflow/tfjs/blob/b53bd47e880367ae57493f0ea628abaf08db2d5d/tfjs-core/src/ops/fused/conv2d.ts#L181-L196
	function getShapeForBatchMatMul(shape, isChannelsLast) {
	  var length = shape.length;
	  if (length >= 3) {
	    return isChannelsLast ? [].concat(_toConsumableArray(shape.slice(0, -3)), [shape[length - 3] * shape[length - 2] /* height * width */, shape[length - 1] /* channel */]) : [].concat(_toConsumableArray(shape.slice(0, -3)), [shape[length - 3] /* channel */, shape[length - 2] * shape[length - 1] /* height * width */]);
	  } else if (!isChannelsLast && length === 1 && shape[0] > 1) {
	    return [shape[0], 1];
	  } else {
	    return null;
	  }
	}
	// For 1x1 kernels that iterate through every point in the input, convolution
	// can be expressed as matrix multiplication (without need for memory
	// remapping).
	function conv2dByMatMul(_ref) {
	  var x = _ref.x,
	    filter = _ref.filter,
	    convInfo = _ref.convInfo,
	    backend = _ref.backend,
	    _ref$bias = _ref.bias,
	    bias = _ref$bias === void 0 ? null : _ref$bias,
	    _ref$preluActivationW = _ref.preluActivationWeights,
	    preluActivationWeights = _ref$preluActivationW === void 0 ? null : _ref$preluActivationW,
	    _ref$leakyreluAlpha = _ref.leakyreluAlpha,
	    leakyreluAlpha = _ref$leakyreluAlpha === void 0 ? 0 : _ref$leakyreluAlpha,
	    _ref$activation = _ref.activation,
	    activation = _ref$activation === void 0 ? null : _ref$activation;
	  // Reshapes conv2D input to 2D tensors, uses matMul and then reshape the
	  // result from 2D to 4D.
	  var xShape = x.shape;
	  var xTexData = backend.texData.get(x.dataId);
	  var sharedMatMulDim = convInfo.inChannels;
	  var outerShapeX = xShape[0] * xShape[1] * xShape[2];
	  var outerShapeFilter = convInfo.outChannels;
	  var isChannelsLast = convInfo.dataFormat === 'channelsLast';
	  var transposeA = false;
	  var transposeB = false;
	  var out;
	  var intermediates = [];
	  if (preluActivationWeights != null) {
	    var targetShape = getShapeForBatchMatMul(preluActivationWeights.shape, isChannelsLast);
	    if (targetShape != null) {
	      preluActivationWeights = reshape({
	        inputs: {
	          x: preluActivationWeights
	        },
	        backend: backend,
	        attrs: {
	          shape: targetShape
	        }
	      });
	      intermediates.push(preluActivationWeights);
	    }
	  }
	  if (bias != null) {
	    var _targetShape = getShapeForBatchMatMul(bias.shape, isChannelsLast);
	    if (_targetShape != null) {
	      bias = reshape({
	        inputs: {
	          x: bias
	        },
	        backend: backend,
	        attrs: {
	          shape: _targetShape
	        }
	      });
	      intermediates.push(bias);
	    }
	  }
	  // TODO: Once reduction ops are packed, batchMatMul will always be packed
	  // and we can remove this condition.
	  var batchMatMulWillBeUnpacked = (outerShapeX === 1 || outerShapeFilter === 1) && sharedMatMulDim > MATMUL_SHARED_DIM_THRESHOLD;
	  // The algorithm in the if condition assumes (1) the output will be packed,
	  // (2) x is packed, (3) x isChannelsLast, (4)  x's packed texture is already
	  // on GPU, (5) col is odd, (6) the width, height and inChannels are the same
	  // for xTexData.shape and xShape.
	  var canOptimize = !batchMatMulWillBeUnpacked && xTexData.isPacked && isChannelsLast && xTexData.texture != null && xShape[2] % 2 !== 0 && arraysEqual(xTexData.shape.slice(-3), xShape.slice(-3));
	  if (canOptimize) {
	    // We avoid expensive packed 2x2 reshape by padding col count to next,
	    // even number. When col is odd, the result of packed batchMatMul is
	    // the same (has the same texture layout and and values in the texture) as
	    // it is for next even col. We make the odd-cols tensor to look like
	    // even-cols tensor before the operation and, after the batchMatMul,
	    // fix the even-cols result to have odd number of cols.
	    var _targetShape2 = xShape[0] * xShape[1] * (xShape[2] + 1);
	    var xReshaped = {
	      dataId: x.dataId,
	      shape: [1, _targetShape2, convInfo.inChannels],
	      dtype: x.dtype
	    };
	    // xTexData.shape gets referenced from GPGPUBinary.inShapeInfos.
	    // Decrementing col count, after batchMatMul->...->compileProgram leads to
	    // invalid col count within the reference in GPGPUBinary.inShapeInfos.
	    // Alternative fix would be to provide a copy to GPGPUBinary.inShapeInfos
	    // in compileProgram method, but that would affect compilation of all
	    // programs - instead, provide a copy here, with even col count, before
	    // calling batchMatMul->...->compileProgram and after that, the original
	    // xTexData.shape is restored.
	    var originalXTexDataShape = xTexData.shape;
	    xTexData.shape = xTexData.shape.slice();
	    xTexData.shape[xTexData.shape.length - 2]++;
	    assert$1(isReshapeFree(xTexData.shape, xReshaped.shape), function () {
	      return "packed reshape ".concat(xTexData.shape, " to ").concat(xReshaped.shape, " isn't free");
	    });
	    var filterReshaped = reshape({
	      inputs: {
	        x: filter
	      },
	      backend: backend,
	      attrs: {
	        shape: [1, convInfo.inChannels, convInfo.outChannels]
	      }
	    });
	    intermediates.push(filterReshaped);
	    var pointwiseConv = batchMatMulImpl({
	      a: xReshaped,
	      b: filterReshaped,
	      backend: backend,
	      transposeA: transposeA,
	      transposeB: transposeB,
	      bias: bias,
	      activation: activation,
	      preluActivationWeights: preluActivationWeights,
	      leakyreluAlpha: leakyreluAlpha
	    });
	    var pointwiseConvTexData = backend.texData.get(pointwiseConv.dataId);
	    assert$1(pointwiseConvTexData.isPacked, function () {
	      return 'batchMatMul result is expected to be packed';
	    });
	    // Restore the input shape to original.
	    xTexData.shape = originalXTexDataShape;
	    // Set the output shape - there is no need for expensive reshape as data
	    // layout is already correct.
	    pointwiseConvTexData.shape = convInfo.outShape;
	    out = identity({
	      inputs: {
	        x: pointwiseConv
	      },
	      backend: backend
	    });
	    out.shape = convInfo.outShape;
	    intermediates.push(pointwiseConv);
	  } else {
	    var numCols = convInfo.outHeight * convInfo.outWidth;
	    var _xReshaped = reshape({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        shape: isChannelsLast ? [convInfo.batchSize, numCols, convInfo.inChannels] : [convInfo.batchSize, convInfo.inChannels, numCols]
	      }
	    });
	    var _filterReshaped = reshape({
	      inputs: {
	        x: filter
	      },
	      backend: backend,
	      attrs: {
	        shape: [1, convInfo.inChannels, convInfo.outChannels]
	      }
	    });
	    var result = batchMatMulImpl({
	      a: isChannelsLast ? _xReshaped : _filterReshaped,
	      b: isChannelsLast ? _filterReshaped : _xReshaped,
	      transposeA: !isChannelsLast,
	      transposeB: transposeB,
	      backend: backend,
	      bias: bias,
	      activation: activation,
	      preluActivationWeights: preluActivationWeights,
	      leakyreluAlpha: leakyreluAlpha
	    });
	    out = reshape({
	      inputs: {
	        x: result
	      },
	      backend: backend,
	      attrs: {
	        shape: convInfo.outShape
	      }
	    });
	    intermediates.push(_xReshaped);
	    intermediates.push(_filterReshaped);
	    intermediates.push(result);
	  }
	  for (var _i = 0, _intermediates = intermediates; _i < _intermediates.length; _i++) {
	    var i = _intermediates[_i];
	    backend.disposeIntermediateTensorInfo(i);
	  }
	  return out;
	}
	// Implements the im2row algorithm as outlined in "High Performance
	// Convolutional Neural Networks for Document Processing" (Suvisoft, 2006)
	function conv2dWithIm2Row(_ref2) {
	  var x = _ref2.x,
	    filter = _ref2.filter,
	    convInfo = _ref2.convInfo,
	    backend = _ref2.backend,
	    _ref2$bias = _ref2.bias,
	    bias = _ref2$bias === void 0 ? null : _ref2$bias,
	    _ref2$preluActivation = _ref2.preluActivationWeights,
	    preluActivationWeights = _ref2$preluActivation === void 0 ? null : _ref2$preluActivation,
	    _ref2$leakyreluAlpha = _ref2.leakyreluAlpha,
	    leakyreluAlpha = _ref2$leakyreluAlpha === void 0 ? 0 : _ref2$leakyreluAlpha,
	    _ref2$activation = _ref2.activation,
	    activation = _ref2$activation === void 0 ? null : _ref2$activation;
	  // Rearranges conv2d input so each block to be convolved over forms the
	  // column of a new matrix with shape [filterWidth * filterHeight *
	  // inChannels, outHeight * outWidth]. The filter is also rearranged so each
	  // output channel forms a row of a new matrix with shape [outChannels,
	  // filterWidth * filterHeight * inChannels]. The convolution is then
	  // computed by multiplying these matrices and reshaping the result.
	  var filterWidth = convInfo.filterWidth,
	    filterHeight = convInfo.filterHeight,
	    inChannels = convInfo.inChannels,
	    outWidth = convInfo.outWidth,
	    outHeight = convInfo.outHeight,
	    dataFormat = convInfo.dataFormat;
	  var isChannelsLast = dataFormat === 'channelsLast';
	  var sharedDim = filterWidth * filterHeight * inChannels;
	  var numCols = outHeight * outWidth;
	  var x2ColShape = [convInfo.batchSize, sharedDim, numCols];
	  var transposeA = true;
	  var transposeB = false;
	  var intermediates = [];
	  if (preluActivationWeights != null) {
	    var targetShape = getShapeForBatchMatMul(preluActivationWeights.shape, isChannelsLast);
	    if (targetShape != null) {
	      preluActivationWeights = reshape({
	        inputs: {
	          x: preluActivationWeights
	        },
	        backend: backend,
	        attrs: {
	          shape: targetShape
	        }
	      });
	      intermediates.push(preluActivationWeights);
	    }
	  }
	  if (bias != null) {
	    var _targetShape3 = getShapeForBatchMatMul(bias.shape, isChannelsLast);
	    if (_targetShape3 != null) {
	      bias = reshape({
	        inputs: {
	          x: bias
	        },
	        backend: backend,
	        attrs: {
	          shape: _targetShape3
	        }
	      });
	      intermediates.push(bias);
	    }
	  }
	  var w2Row = reshape({
	    inputs: {
	      x: filter
	    },
	    backend: backend,
	    attrs: {
	      shape: [1, sharedDim, sizeFromShape(filter.shape) / sharedDim]
	    }
	  });
	  intermediates.push(w2Row);
	  var im2ColProgram = new Im2ColPackedProgram(x2ColShape, convInfo);
	  var customValues = [x.shape, [convInfo.padInfo.top, convInfo.padInfo.left], [convInfo.strideHeight, convInfo.strideWidth], [convInfo.dilationHeight, convInfo.dilationWidth], [convInfo.inChannels], [convInfo.filterWidth * convInfo.inChannels], [convInfo.outWidth]];
	  var im2Col = backend.runWebGLProgram(im2ColProgram, [x], 'float32', customValues);
	  var im2ColReshaped = reshape({
	    inputs: {
	      x: im2Col
	    },
	    backend: backend,
	    attrs: {
	      shape: x2ColShape
	    }
	  });
	  intermediates.push(im2Col);
	  intermediates.push(im2ColReshaped);
	  var hasBias = bias != null;
	  var hasPreluActivationWeights = preluActivationWeights != null;
	  var hasLeakyreluAlpha = activation === 'leakyrelu';
	  var fusedActivation = activation ? mapActivationToShaderProgram(activation, true) : null;
	  var matmulProgram = new MatMulPackedProgram(isChannelsLast ? im2ColReshaped.shape : w2Row.shape, isChannelsLast ? w2Row.shape : im2ColReshaped.shape, isChannelsLast ? [convInfo.batchSize, numCols, convInfo.outChannels] : [convInfo.batchSize, convInfo.outChannels, numCols], transposeA, transposeB, hasBias, fusedActivation, hasPreluActivationWeights, hasLeakyreluAlpha);
	  var inputs = isChannelsLast ? [im2ColReshaped, w2Row] : [w2Row, im2ColReshaped];
	  if (bias) {
	    inputs.push(bias);
	  }
	  if (hasPreluActivationWeights) {
	    inputs.push(preluActivationWeights);
	  }
	  if (hasLeakyreluAlpha) {
	    var $leakyreluAlpha = backend.makeTensorInfo([], 'float32', createScalarValue(leakyreluAlpha, 'float32'));
	    inputs.push($leakyreluAlpha);
	    intermediates.push($leakyreluAlpha);
	  }
	  var product = backend.runWebGLProgram(matmulProgram, inputs, 'float32');
	  var out = reshape({
	    inputs: {
	      x: product
	    },
	    backend: backend,
	    attrs: {
	      shape: convInfo.outShape
	    }
	  });
	  intermediates.push(product);
	  for (var _i2 = 0, _intermediates2 = intermediates; _i2 < _intermediates2.length; _i2++) {
	    var i = _intermediates2[_i2];
	    backend.disposeIntermediateTensorInfo(i);
	  }
	  return out;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function conv2d(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    filter = inputs.filter;
	  var strides = attrs.strides,
	    pad = attrs.pad,
	    dataFormat = attrs.dataFormat,
	    dilations = attrs.dilations,
	    dimRoundingMode = attrs.dimRoundingMode;
	  var $dataFormat = convertConv2DDataFormat(dataFormat);
	  var convInfo = computeConv2DInfo(x.shape, filter.shape, strides, dilations, pad, dimRoundingMode, false /* depthwise */, $dataFormat);
	  var out;
	  if (convInfo.filterHeight === 1 && convInfo.filterWidth === 1 && convInfo.dilationHeight === 1 && convInfo.dilationWidth === 1 && convInfo.strideHeight === 1 && convInfo.strideWidth === 1 && (convInfo.padInfo.type === 'SAME' || convInfo.padInfo.type === 'VALID')) {
	    out = conv2dByMatMul({
	      x: x,
	      filter: filter,
	      convInfo: convInfo,
	      backend: backend
	    });
	  } else if (convInfo.strideWidth <= 2 && $dataFormat === 'channelsLast' && env().getBool('WEBGL_EXP_CONV')) {
	    var program = new Conv2DPackedProgram(convInfo);
	    var customValues = [[convInfo.padInfo.top, convInfo.padInfo.left], [convInfo.strideHeight, convInfo.strideWidth], [convInfo.dilationHeight, convInfo.dilationWidth], [convInfo.inHeight, convInfo.inWidth]];
	    out = backend.runWebGLProgram(program, [x, filter], 'float32', customValues);
	  } else if (env().getBool('WEBGL_CONV_IM2COL')) {
	    out = conv2dWithIm2Row({
	      x: x,
	      filter: filter,
	      convInfo: convInfo,
	      backend: backend
	    });
	  } else {
	    var _program = new Conv2DProgram(convInfo);
	    out = backend.runWebGLProgram(_program, [x, filter], 'float32');
	  }
	  var outReshaped = reshape({
	    inputs: {
	      x: out
	    },
	    backend: backend,
	    attrs: {
	      shape: convInfo.outShape
	    }
	  });
	  backend.disposeIntermediateTensorInfo(out);
	  return outReshaped;
	}
	var conv2DConfig = {
	  kernelName: Conv2D$1,
	  backendName: 'webgl',
	  kernelFunc: conv2d
	};

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var Conv2DDerFilterProgram = /*#__PURE__*/_createClass(function Conv2DDerFilterProgram(convInfo) {
	  _classCallCheck(this, Conv2DDerFilterProgram);
	  this.variableNames = ['x', 'dy'];
	  this.outputShape = convInfo.filterShape;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var padTop = convInfo.padInfo.top;
	  var padLeft = convInfo.padInfo.left;
	  var isChannelsLast = convInfo.dataFormat === 'channelsLast';
	  this.userCode = "\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int wR = coords.x;\n        int wC = coords.y;\n        int d1 = coords.z;\n        int d2 = coords.w;\n\n        // Convolve x(?, ?, d1) with dy(:, :, d2) to get dw(wR, wC, d1, d2).\n        // ? = to be determined. : = across all values in that axis.\n        float dotProd = 0.0;\n\n        for (int b = 0; b < ".concat(convInfo.batchSize, "; b++) {\n          for (int yR = 0; yR < ").concat(convInfo.outHeight, "; yR++) {\n            int xR = wR + yR * ").concat(strideHeight, " - ").concat(padTop, ";\n\n            if (xR < 0 || xR >= ").concat(convInfo.inHeight, ") {\n              continue;\n            }\n\n            for (int yC = 0; yC < ").concat(convInfo.outWidth, "; yC++) {\n              int xC = wC + yC * ").concat(strideWidth, " - ").concat(padLeft, ";\n\n              if (xC < 0 || xC >= ").concat(convInfo.inWidth, ") {\n                continue;\n              }\n\n              ").concat(isChannelsLast ? "float dyValue = getDy(b, yR, yC, d2);\n              float xValue = getX(b, xR, xC, d1);\n              dotProd += (xValue * dyValue);" : "float dyValue = getDy(b, d2, yR, yC);\n              float xValue = getX(b, d1, xR, xC);\n              dotProd += (xValue * dyValue);", "\n            }\n          }\n        }\n        setOutput(dotProd);\n      }\n    ");
	});
	var Conv2DDerInputProgram = /*#__PURE__*/_createClass(function Conv2DDerInputProgram(convInfo) {
	  _classCallCheck(this, Conv2DDerInputProgram);
	  this.variableNames = ['dy', 'W'];
	  this.outputShape = convInfo.inShape;
	  var filterHeight = convInfo.filterHeight;
	  var filterWidth = convInfo.filterWidth;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var isChannelsLast = convInfo.dataFormat === 'channelsLast';
	  var padTop = filterHeight - 1 - convInfo.padInfo.top;
	  var padLeft = filterWidth - 1 - convInfo.padInfo.left;
	  var rowDim = isChannelsLast ? 1 : 2;
	  var colDim = isChannelsLast ? 2 : 3;
	  var channelDim = isChannelsLast ? 3 : 1;
	  this.userCode = "\n      const ivec2 pads = ivec2(".concat(padTop, ", ").concat(padLeft, ");\n\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int batch = coords[0];\n        int d1 = coords[").concat(channelDim, "];\n\n        ivec2 dyCorner = ivec2(coords[").concat(rowDim, "], coords[").concat(colDim, "]) - pads;\n        int dyRCorner = dyCorner.x;\n        int dyCCorner = dyCorner.y;\n\n        // Convolve dy(?, ?, d2) with w(:, :, d1, d2) to compute dx(xR, xC, d1).\n        // ? = to be determined. : = across all values in that axis.\n        float dotProd = 0.0;\n        for (int wR = 0; wR < ").concat(filterHeight, "; wR++) {\n          float dyR = float(dyRCorner + wR) / ").concat(strideHeight, ".0;\n\n          if (dyR < 0.0 || dyR >= ").concat(convInfo.outHeight, ".0 || fract(dyR) > 0.0) {\n            continue;\n          }\n          int idyR = int(dyR);\n\n          int wRPerm = ").concat(filterHeight, " - 1 - wR;\n\n          for (int wC = 0; wC < ").concat(filterWidth, "; wC++) {\n            float dyC = float(dyCCorner + wC) / ").concat(strideWidth, ".0;\n\n            if (dyC < 0.0 || dyC >= ").concat(convInfo.outWidth, ".0 ||\n                fract(dyC) > 0.0) {\n              continue;\n            }\n            int idyC = int(dyC);\n\n            int wCPerm = ").concat(filterWidth, " - 1 - wC;\n\n            for (int d2 = 0; d2 < ").concat(convInfo.outChannels, "; d2++) {\n\n              if (").concat(isChannelsLast, ") {\n                float xValue = getDy(batch, idyR, idyC, d2);\n                float wValue = getW(wRPerm, wCPerm, d1, d2);\n                dotProd += xValue * wValue;\n              } else {\n                float xValue = getDy(batch, d2, idyR, idyC);\n                float wValue = getW(wRPerm, wCPerm, d1, d2);\n                dotProd += xValue * wValue;\n              }\n\n            }\n          }\n        }\n        setOutput(dotProd);\n      }\n    ");
	});
	var Conv3DDerFilterProgram = /*#__PURE__*/_createClass(function Conv3DDerFilterProgram(convInfo) {
	  _classCallCheck(this, Conv3DDerFilterProgram);
	  this.variableNames = ['x', 'dy'];
	  this.outputShape = convInfo.filterShape;
	  var strideDepth = convInfo.strideDepth;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var padFront = convInfo.padInfo.front;
	  var padTop = convInfo.padInfo.top;
	  var padLeft = convInfo.padInfo.left;
	  this.userCode = "\n      void main() {\n        ivec5 coords = getOutputCoords();\n        int wF = coords.x;\n        int wR = coords.y;\n        int wC = coords.z;\n        int d1 = coords.w;\n        int d2 = coords.u;\n\n        float dotProd = 0.0;\n\n        for (int b = 0; b < ".concat(convInfo.batchSize, "; b++) {\n          for (int yF = 0; yF < ").concat(convInfo.outDepth, "; yF++) {\n            int xF = wF + yF * ").concat(strideDepth, " - ").concat(padFront, ";\n\n            if (xF < 0 || xF >= ").concat(convInfo.inDepth, ") {\n              continue;\n            }\n\n            for (int yR = 0; yR < ").concat(convInfo.outHeight, "; yR++) {\n              int xR = wR + yR * ").concat(strideHeight, " - ").concat(padTop, ";\n\n              if (xR < 0 || xR >= ").concat(convInfo.inHeight, ") {\n                continue;\n              }\n\n              for (int yC = 0; yC < ").concat(convInfo.outWidth, "; yC++) {\n                int xC = wC + yC * ").concat(strideWidth, " - ").concat(padLeft, ";\n\n                if (xC < 0 || xC >= ").concat(convInfo.inWidth, ") {\n                  continue;\n                }\n\n                float dyValue = getDy(b, yF, yR, yC, d2);\n                float xValue = getX(b, xF, xR, xC, d1);\n                dotProd += (xValue * dyValue);\n              }\n            }\n          }\n        }\n        setOutput(dotProd);\n      }\n    ");
	});
	var Conv3DDerInputProgram = /*#__PURE__*/_createClass(function Conv3DDerInputProgram(convInfo) {
	  _classCallCheck(this, Conv3DDerInputProgram);
	  this.variableNames = ['dy', 'W'];
	  this.outputShape = convInfo.inShape;
	  var filterDepth = convInfo.filterDepth;
	  var filterHeight = convInfo.filterHeight;
	  var filterWidth = convInfo.filterWidth;
	  var strideDepth = convInfo.strideDepth;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var padFront = filterDepth - 1 - convInfo.padInfo.front;
	  var padTop = filterHeight - 1 - convInfo.padInfo.top;
	  var padLeft = filterWidth - 1 - convInfo.padInfo.left;
	  this.userCode = "\n      const ivec3 pads = ivec3(".concat(padFront, ", ").concat(padTop, ", ").concat(padLeft, ");\n\n      void main() {\n        ivec5 coords = getOutputCoords();\n        int batch = coords.x;\n        int d1 = coords.u;\n\n\n        ivec3 dyCorner = ivec3(coords.y, coords.z, coords.w) - pads;\n        int dyFCorner = dyCorner.x;\n        int dyRCorner = dyCorner.y;\n        int dyCCorner = dyCorner.z;\n\n        float dotProd = 0.0;\n        for (int wF = 0; wF < ").concat(filterDepth, "; wF++) {\n          float dyF = float(dyFCorner + wF) / ").concat(strideDepth, ".0;\n\n          if (dyF < 0.0 || dyF >= ").concat(convInfo.outDepth, ".0 || fract(dyF) > 0.0) {\n            continue;\n          }\n          int idyF = int(dyF);\n\n          int wFPerm = ").concat(filterDepth, " - 1 - wF;\n\n          for (int wR = 0; wR < ").concat(filterHeight, "; wR++) {\n            float dyR = float(dyRCorner + wR) / ").concat(strideHeight, ".0;\n\n            if (dyR < 0.0 || dyR >= ").concat(convInfo.outHeight, ".0 ||\n              fract(dyR) > 0.0) {\n              continue;\n            }\n            int idyR = int(dyR);\n\n            int wRPerm = ").concat(filterHeight, " - 1 - wR;\n\n            for (int wC = 0; wC < ").concat(filterWidth, "; wC++) {\n              float dyC = float(dyCCorner + wC) / ").concat(strideWidth, ".0;\n\n              if (dyC < 0.0 || dyC >= ").concat(convInfo.outWidth, ".0 ||\n                  fract(dyC) > 0.0) {\n                continue;\n              }\n              int idyC = int(dyC);\n\n              int wCPerm = ").concat(filterWidth, " - 1 - wC;\n\n              for (int d2 = 0; d2 < ").concat(convInfo.outChannels, "; d2++) {\n                float xValue = getDy(batch, idyF, idyR, idyC, d2);\n                float wValue = getW(wFPerm, wRPerm, wCPerm, d1, d2);\n                dotProd += xValue * wValue;\n              }\n            }\n          }\n        }\n        setOutput(dotProd);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function conv2DBackpropFilter(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    dy = inputs.dy;
	  var strides = attrs.strides,
	    pad = attrs.pad,
	    dataFormat = attrs.dataFormat,
	    dimRoundingMode = attrs.dimRoundingMode,
	    filterShape = attrs.filterShape;
	  var $dataFormat = convertConv2DDataFormat(dataFormat);
	  var convInfo = computeConv2DInfo(x.shape, filterShape, strides, 1 /* dilations */, pad, dimRoundingMode, false /* depthwise */, $dataFormat);
	  var program = new Conv2DDerFilterProgram(convInfo);
	  return backend.runWebGLProgram(program, [x, dy], 'float32');
	}
	var conv2DBackpropFilterConfig = {
	  kernelName: Conv2DBackpropFilter,
	  backendName: 'webgl',
	  kernelFunc: conv2DBackpropFilter
	};

	var Conv2DDerInputPackedProgram = /*#__PURE__*/_createClass(function Conv2DDerInputPackedProgram(convInfo) {
	  _classCallCheck(this, Conv2DDerInputPackedProgram);
	  this.variableNames = ['dy', 'W'];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.customUniforms = [{
	    name: 'strides',
	    type: 'vec2'
	  }];
	  this.outputShape = convInfo.inShape;
	  this.enableShapeUniforms = useShapeUniforms(this.outputShape.length);
	  var filterHeight = convInfo.filterHeight;
	  var filterWidth = convInfo.filterWidth;
	  var padTop = filterHeight - 1 - convInfo.padInfo.top;
	  var padLeft = filterWidth - 1 - convInfo.padInfo.left;
	  this.userCode = "\n      const ivec2 pads = ivec2(".concat(padTop, ", ").concat(padLeft, ");\n\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int batch = coords[0];\n        int d1 = coords[3];\n\n        ivec2 dyCorner = ivec2(coords[1], coords[2]) - pads;\n        int dyRCorner = dyCorner.x;\n        int dyCCorner = dyCorner.y;\n\n        vec4 result = vec4(0.);\n        for (int wR = 0; wR < ").concat(filterHeight, "; wR++) {\n          float dyR = float(dyRCorner + wR) / strides[0];\n          if (dyR < 0.0 || dyR >= ").concat(convInfo.outHeight, ".0 || fract(dyR) > 0.0) {\n            continue;\n          }\n          int idyR = int(dyR);\n          int wRPerm = ").concat(filterHeight, " - 1 - wR;\n\n          for (int wC = 0; wC < ").concat(filterWidth, "; wC++) {\n            int wCPerm = ").concat(filterWidth, " - 1 - wC;\n\n            float dyC = float(dyCCorner + wC) / strides[1];\n            bool idyCVal = (dyC >= 0.0) && (dyC < ").concat(convInfo.outWidth, ".0)\n              && (fract(dyC) == 0.0);\n            int idyC = int(dyC);\n\n            float dyC2 = float(dyCCorner + wC + 1) / strides[1];\n            bool idyCVal2 = (dyC2 >= 0.0) && (dyC2 < ").concat(convInfo.outWidth, ".0)\n              && (fract(dyC2) == 0.0);\n            int idyC2 = int(dyC2);\n\n            if (idyCVal && idyCVal2) {\n              for (int d2 = 0; d2 < ").concat(convInfo.outChannels, "; d2 += 2) {\n                vec4 wValue = getW(wRPerm, wCPerm, d1, d2);\n                vec4 dySample = getDy(batch, idyR, idyC, d2);\n                vec4 dySample2 = (idyC / 2 == idyC2 / 2) ?\n                  dySample : getDy(batch, idyR, idyC2, d2);\n\n                vec2 dyValue = mod(float(idyC), 2.) == 0. ?\n                  dySample.xy : dySample.zw;\n                result.xy += vec2(dot(dyValue, wValue.xy),\n                  dot(dyValue, wValue.zw));\n\n                dyValue = mod(float(idyC2), 2.) == 0. ?\n                  dySample2.xy : dySample2.zw;\n                result.zw += vec2(dot(dyValue, wValue.xy),\n                  dot(dyValue, wValue.zw));\n              }\n            } else if (idyCVal) {\n              for (int d2 = 0; d2 < ").concat(convInfo.outChannels, "; d2 += 2) {\n                vec4 wValue = getW(wRPerm, wCPerm, d1, d2);\n                vec4 dySample = getDy(batch, idyR, idyC, d2);\n                vec2 dyValue = mod(float(idyC), 2.) == 0. ?\n                  dySample.xy : dySample.zw;\n                result.xy += vec2(dot(dyValue, wValue.xy),\n                  dot(dyValue, wValue.zw));\n              }\n            } else if (idyCVal2) {\n              for (int d2 = 0; d2 < ").concat(convInfo.outChannels, "; d2 += 2) {\n                vec4 wValue = getW(wRPerm, wCPerm, d1, d2);\n                vec4 dySample = getDy(batch, idyR, idyC2, d2);\n                vec2 dyValue = mod(float(idyC2), 2.) == 0. ?\n                  dySample.xy : dySample.zw;\n                result.zw += vec2(dot(dyValue, wValue.xy),\n                  dot(dyValue, wValue.zw));\n              }\n            }\n          }\n        }\n        setOutput(result);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function conv2DBackpropInput(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var dy = inputs.dy,
	    filter = inputs.filter;
	  var inputShape = attrs.inputShape,
	    strides = attrs.strides,
	    pad = attrs.pad,
	    dataFormat = attrs.dataFormat,
	    dimRoundingMode = attrs.dimRoundingMode;
	  var $dataFormat = convertConv2DDataFormat(dataFormat);
	  var convInfo = computeConv2DInfo(inputShape, filter.shape, strides, 1 /* dilations */, pad, dimRoundingMode, false, $dataFormat);
	  if (env().getBool('WEBGL_PACK_CONV2DTRANSPOSE') && $dataFormat === 'channelsLast') {
	    var customValues = [[convInfo.strideHeight, convInfo.strideWidth]];
	    var program = new Conv2DDerInputPackedProgram(convInfo);
	    return backend.runWebGLProgram(program, [dy, filter], 'float32', customValues);
	  } else {
	    var _program = new Conv2DDerInputProgram(convInfo);
	    return backend.runWebGLProgram(_program, [dy, filter], 'float32');
	  }
	}
	var conv2DBackpropInputConfig = {
	  kernelName: Conv2DBackpropInput,
	  backendName: 'webgl',
	  kernelFunc: conv2DBackpropInput
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function conv3D(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    filter = inputs.filter;
	  var strides = attrs.strides,
	    pad = attrs.pad,
	    dilations = attrs.dilations;
	  var convInfo = computeConv3DInfo(x.shape, filter.shape, strides, dilations, pad);
	  var program = new Conv3DProgram(convInfo);
	  return backend.runWebGLProgram(program, [x, filter], 'float32');
	}
	var conv3DConfig = {
	  kernelName: Conv3D$1,
	  backendName: 'webgl',
	  kernelFunc: conv3D
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function conv3DBackpropFilterV2(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    dy = inputs.dy;
	  var strides = attrs.strides,
	    pad = attrs.pad,
	    filterShape = attrs.filterShape;
	  var convInfo = computeConv3DInfo(x.shape, filterShape, strides, 1 /* dilations */, pad);
	  var program = new Conv3DDerFilterProgram(convInfo);
	  return backend.runWebGLProgram(program, [x, dy], 'float32');
	}
	var conv3DBackpropFilterV2Config = {
	  kernelName: Conv3DBackpropFilterV2,
	  backendName: 'webgl',
	  kernelFunc: conv3DBackpropFilterV2
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function conv3DBackpropInput(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var dy = inputs.dy,
	    filter = inputs.filter;
	  var pad = attrs.pad,
	    strides = attrs.strides,
	    inputShape = attrs.inputShape;
	  var convInfo = computeConv3DInfo(inputShape, filter.shape, strides, 1 /* dilations */, pad);
	  var program = new Conv3DDerInputProgram(convInfo);
	  return backend.runWebGLProgram(program, [dy, filter], 'float32');
	}
	var conv3DBackpropInputConfig = {
	  kernelName: Conv3DBackpropInputV2,
	  backendName: 'webgl',
	  kernelFunc: conv3DBackpropInput
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var COS = CHECK_NAN_SNIPPET_UNARY + "\n  return cos(x);\n";
	var COS_PACKED = "\n  vec4 result = cos(x);\n  bvec4 isNaN = isnan(x);\n  ".concat(CHECK_NAN_SNIPPET_PACKED, "\n  return result;\n");
	var cos = unaryKernelFunc({
	  opSnippet: COS,
	  packedOpSnippet: COS_PACKED
	});
	var cosConfig = {
	  kernelName: Cos,
	  backendName: 'webgl',
	  kernelFunc: cos
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var COSH = "\n  float e2x = exp(-x);\n  return (e2x + 1.0 / e2x) / 2.0;\n";
	var cosh = unaryKernelFunc({
	  opSnippet: COSH
	});
	var coshConfig = {
	  kernelName: Cosh,
	  backendName: 'webgl',
	  kernelFunc: cosh
	};

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var CropAndResizeProgram = /*#__PURE__*/_createClass(function CropAndResizeProgram(imageShape, boxShape, cropSize, method, extrapolationValue) {
	  _classCallCheck(this, CropAndResizeProgram);
	  this.variableNames = ['Image', 'Boxes', 'BoxInd'];
	  this.outputShape = [];
	  var _imageShape = _slicedToArray(imageShape, 4),
	    batch = _imageShape[0],
	    imageHeight = _imageShape[1],
	    imageWidth = _imageShape[2],
	    depth = _imageShape[3];
	  var _boxShape = _slicedToArray(boxShape, 1),
	    numBoxes = _boxShape[0];
	  var _cropSize = _slicedToArray(cropSize, 2),
	    cropHeight = _cropSize[0],
	    cropWidth = _cropSize[1];
	  this.outputShape = [numBoxes, cropHeight, cropWidth, depth];
	  var methodId = method === 'bilinear' ? 1 : 0;
	  var inputHeightFloat = "".concat(imageHeight - 1, ".0"),
	    inputWidthFloat = "".concat(imageWidth - 1, ".0");
	  var _ref = cropHeight > 1 ? ["".concat((imageHeight - 1) / (cropHeight - 1)), '(y2-y1) * height_ratio', "y1*".concat(inputHeightFloat, " + float(y)*(height_scale)")] : ['0.0', '0.0', "0.5 * (y1+y2) * ".concat(inputHeightFloat)],
	    _ref2 = _slicedToArray(_ref, 3),
	    heightRatio = _ref2[0],
	    heightScale = _ref2[1],
	    inY = _ref2[2];
	  var _ref3 = cropWidth > 1 ? ["".concat((imageWidth - 1) / (cropWidth - 1)), '(x2-x1) * width_ratio', "x1*".concat(inputWidthFloat, " + float(x)*(width_scale)")] : ['0.0', '0.0', "0.5 * (x1+x2) * ".concat(inputWidthFloat)],
	    _ref4 = _slicedToArray(_ref3, 3),
	    widthRatio = _ref4[0],
	    widthScale = _ref4[1],
	    inX = _ref4[2];
	  // Reference implementation
	  // tslint:disable-next-line:max-line-length
	  // https://github.com/tensorflow/tensorflow/blob/master/tensorflow/core/kernels/crop_and_resize_op_gpu.cu.cc
	  this.userCode = "\n      const float height_ratio = float(".concat(heightRatio, ");\n      const float width_ratio = float(").concat(widthRatio, ");\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int b = coords[0];\n        int y = coords[1];\n        int x = coords[2];\n        int d = coords[3];\n\n        // get box vals\n        float y1 = getBoxes(b,0);\n        float x1 = getBoxes(b,1);\n        float y2 = getBoxes(b,2);\n        float x2 = getBoxes(b,3);\n\n        // get image in batch index\n        int bInd = round(getBoxInd(b));\n        if(bInd < 0 || bInd >= ").concat(batch, ") {\n          return;\n        }\n\n        float height_scale = ").concat(heightScale, ";\n        float width_scale = ").concat(widthScale, ";\n\n        float in_y = ").concat(inY, ";\n        if( in_y < 0.0 || in_y > ").concat(inputHeightFloat, " ) {\n          setOutput(float(").concat(extrapolationValue, "));\n          return;\n        }\n        float in_x = ").concat(inX, ";\n        if( in_x < 0.0 || in_x > ").concat(inputWidthFloat, " ) {\n          setOutput(float(").concat(extrapolationValue, "));\n          return;\n        }\n\n        vec2 sourceFracIndexCR = vec2(in_x,in_y);\n        if(").concat(methodId, " == 1) {\n          // Compute the four integer indices.\n          ivec2 sourceFloorCR = ivec2(sourceFracIndexCR);\n          ivec2 sourceCeilCR = ivec2(ceil(sourceFracIndexCR));\n\n          float topLeft = getImage(b, sourceFloorCR.y, sourceFloorCR.x, d);\n          float bottomLeft = getImage(b, sourceCeilCR.y, sourceFloorCR.x, d);\n          float topRight = getImage(b, sourceFloorCR.y, sourceCeilCR.x, d);\n          float bottomRight = getImage(b, sourceCeilCR.y, sourceCeilCR.x, d);\n\n          vec2 fracCR = sourceFracIndexCR - vec2(sourceFloorCR);\n\n          float top = topLeft + (topRight - topLeft) * fracCR.x;\n          float bottom = bottomLeft + (bottomRight - bottomLeft) * fracCR.x;\n          float newValue = top + (bottom - top) * fracCR.y;\n          setOutput(newValue);\n        } else {\n          // Compute the coordinators of nearest neighbor point.\n          ivec2 sourceNearestCR = ivec2(floor(\n            sourceFracIndexCR + vec2(0.5,0.5)));\n          float newValue = getImage(b, sourceNearestCR.y, sourceNearestCR.x, d);\n          setOutput(newValue);\n        }\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var cropAndResize = function cropAndResize(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var image = inputs.image,
	    boxes = inputs.boxes,
	    boxInd = inputs.boxInd;
	  var cropSize = attrs.cropSize,
	    method = attrs.method,
	    extrapolationValue = attrs.extrapolationValue;
	  var program = new CropAndResizeProgram(image.shape, boxes.shape, cropSize, method, extrapolationValue);
	  return backend.runWebGLProgram(program, [image, boxes, boxInd], 'float32');
	};
	var cropAndResizeConfig = {
	  kernelName: CropAndResize,
	  backendName: 'webgl',
	  kernelFunc: cropAndResize
	};

	var CumOpType;
	(function (CumOpType) {
	  CumOpType["Prod"] = "*";
	  CumOpType["Sum"] = "+";
	})(CumOpType || (CumOpType = {}));
	var CumProgram = /*#__PURE__*/_createClass(function CumProgram(op, outputShape, exclusive, reverse) {
	  _classCallCheck(this, CumProgram);
	  this.op = op;
	  this.outputShape = outputShape;
	  this.variableNames = ['x'];
	  this.customUniforms = [{
	    name: 'index',
	    type: 'float'
	  }];
	  var rank = this.outputShape.length;
	  var initVal = this.op === CumOpType.Prod ? '1.0' : '0.0';
	  var val = exclusive ? initVal : "getX(".concat(getCoords(rank, 'coords', this.op), ")");
	  var length = this.outputShape[this.outputShape.length - 1];
	  var condition = '';
	  var idxString = '';
	  // When exclusive is set, the cum op becomes roll op that copies the
	  // value from the previous index based on the direction specified by the
	  // reverse flag.
	  if (exclusive) {
	    condition = reverse ? "end != ".concat(length - 1) : 'end != 0';
	    idxString = reverse ? 'end + 1' : 'end - 1';
	  } else {
	    condition = reverse ? "end + pow2 < ".concat(length) : 'end >= pow2';
	    idxString = reverse ? 'end + pow2' : 'end - pow2';
	  }
	  this.userCode = "\n      void main() {\n        ".concat(getCoordsDataType(rank), " coords = getOutputCoords();\n        int end = ").concat(getFinalCoord(rank, 'coords', this.op), ";\n        float val = ").concat(val, ";\n        int pow2 = int(pow(2.0, index));\n        if (").concat(condition, ") {\n          int idx = ").concat(idxString, ";\n          ").concat(getFinalCoord(rank, 'coords', this.op), " = idx;\n          val ").concat(this.op, "= getX(").concat(getCoords(rank, 'coords', this.op), ");\n        }\n        setOutput(val);\n      }\n    ");
	});
	function getCoords(rank, name, op) {
	  if (rank === 1) {
	    return "".concat(name);
	  } else if (rank === 2) {
	    return "".concat(name, ".x, ").concat(name, ".y");
	  } else if (rank === 3) {
	    return "".concat(name, ".x, ").concat(name, ".y, ").concat(name, ".z");
	  } else if (rank === 4) {
	    return "".concat(name, ".x, ").concat(name, ".y, ").concat(name, ".z, ").concat(name, ".w");
	  } else {
	    throw new Error("Cumulative ".concat(op, " for rank ").concat(rank, " is not yet supported"));
	  }
	}
	function getFinalCoord(rank, name, op) {
	  if (rank === 1) {
	    return "".concat(name);
	  } else if (rank === 2) {
	    return "".concat(name, ".y");
	  } else if (rank === 3) {
	    return "".concat(name, ".z");
	  } else if (rank === 4) {
	    return "".concat(name, ".w");
	  } else {
	    throw new Error("Cumulative ".concat(op, " for rank ").concat(rank, " is not yet supported"));
	  }
	}

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function cumImpl(op, x, backend, axis, exclusive, reverse) {
	  var xRank = x.shape.length;
	  var permutation = getAxesPermutation([axis], xRank);
	  var permutedX = x;
	  if (permutation != null) {
	    permutedX = transpose({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        perm: permutation
	      }
	    });
	  }
	  var permutedAxis = getInnerMostAxes(1, xRank)[0];
	  if (permutedAxis !== xRank - 1) {
	    throw new Error("WebGL cumprod shader expects an inner-most axis=".concat(x.shape.length - 1, " ") + "but got axis=".concat(axis));
	  }
	  var size = permutedX.shape[permutedAxis];
	  var result = identity({
	    inputs: {
	      x: permutedX
	    },
	    backend: backend
	  });
	  // Use cum parallel algorithm, inspired by:
	  // https://developer.nvidia.com/gpugems/gpugems3/part-vi-gpu-computing/chapter-39-parallel-prefix-sum-scan-cuda
	  // Note: although the algorithm is called sum, it works for any associtative
	  // operator with an identity.
	  for (var i = 0; i <= Math.ceil(Math.log2(size)) - 1; i++) {
	    var program = new CumProgram(op, permutedX.shape, false, reverse);
	    var customValues = [[i]];
	    var prevResult = result;
	    result = backend.runWebGLProgram(program, [result], result.dtype, customValues);
	    backend.disposeIntermediateTensorInfo(prevResult);
	  }
	  // For exclusive cum, shift the end result in the direction of product or sum
	  // and add 1 for product or 0 for sum to the front index.
	  if (exclusive) {
	    var _program = new CumProgram(op, permutedX.shape, exclusive, reverse);
	    var _prevResult = result;
	    result = backend.runWebGLProgram(_program, [result], result.dtype);
	    backend.disposeIntermediateTensorInfo(_prevResult);
	  }
	  if (permutation != null) {
	    var reversePermutation = getUndoAxesPermutation(permutation);
	    var reverseTransposedResult = transpose({
	      inputs: {
	        x: result
	      },
	      backend: backend,
	      attrs: {
	        perm: reversePermutation
	      }
	    });
	    backend.disposeIntermediateTensorInfo(result);
	    backend.disposeIntermediateTensorInfo(permutedX);
	    return reverseTransposedResult;
	  }
	  return result;
	}

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function cumprod(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis,
	    exclusive = attrs.exclusive,
	    reverse = attrs.reverse;
	  return cumImpl(CumOpType.Prod, x, backend, axis, exclusive, reverse);
	}
	var cumprodConfig = {
	  kernelName: Cumprod,
	  backendName: 'webgl',
	  kernelFunc: cumprod
	};

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function cumsum(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis,
	    exclusive = attrs.exclusive,
	    reverse = attrs.reverse;
	  return cumImpl(CumOpType.Sum, x, backend, axis, exclusive, reverse);
	}
	var cumsumConfig = {
	  kernelName: Cumsum,
	  backendName: 'webgl',
	  kernelFunc: cumsum
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function denseBincount(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    weights = inputs.weights;
	  var size = attrs.size,
	    binaryOutput = attrs.binaryOutput;
	  if (x.shape.length === 1) {
	    var xVals = backend.readSync(x.dataId);
	    var weightsVals = backend.readSync(weights.dataId);
	    var outVals = bincountImplCPU(xVals, weightsVals, weights.dtype, weights.shape, size);
	    return backend.makeTensorInfo([size], weights.dtype, outVals);
	  } else if (x.shape.length === 2) {
	    var xBuf = backend.bufferSync(x);
	    var weightsBuf = backend.bufferSync(weights);
	    var outBuf = bincountReduceImplCPU(xBuf, weightsBuf, size, binaryOutput);
	    return backend.makeTensorInfo(outBuf.shape, weights.dtype, outBuf.values);
	  }
	  throw new Error("Error in denseBincount: input must be at most rank 2, but got rank" + "".concat(x.shape.length, "."));
	}
	var denseBincountConfig = {
	  kernelName: DenseBincount,
	  backendName: 'webgl',
	  kernelFunc: denseBincount
	};

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var DepthToSpaceProgram = /*#__PURE__*/function () {
	  function DepthToSpaceProgram(outputShape, blockSize, dataFormat) {
	    _classCallCheck(this, DepthToSpaceProgram);
	    this.variableNames = ['x'];
	    this.outputShape = [];
	    this.outputShape = outputShape;
	    this.blockSize = blockSize;
	    this.dataFormat = dataFormat;
	    this.userCode = "\n    void main() {\n      ivec4 coords = getOutputCoords();\n      int b = coords[0];\n      int h = ".concat(this.getHeightCoordString(), ";\n      int w = ").concat(this.getWidthCoordString(), ";\n      int d = ").concat(this.getDepthCoordString(), ";\n\n      int in_h = h / ").concat(blockSize, ";\n      int offset_h = imod(h, ").concat(blockSize, ");\n      int in_w = w / ").concat(blockSize, ";\n      int offset_w = imod(w, ").concat(blockSize, ");\n      int offset_d = (offset_h * ").concat(blockSize, " + offset_w) *\n        ").concat(this.getOutputDepthSize(), ";\n      int in_d = d + offset_d;\n\n      float result = ").concat(this.getInputSamplingString(), ";\n      setOutput(result);\n    }\n  ");
	  }
	  _createClass(DepthToSpaceProgram, [{
	    key: "getHeightCoordString",
	    value: function getHeightCoordString() {
	      if (this.dataFormat === 'NHWC') {
	        return "coords[1]";
	      } else {
	        return "coords[2]";
	      }
	    }
	  }, {
	    key: "getWidthCoordString",
	    value: function getWidthCoordString() {
	      if (this.dataFormat === 'NHWC') {
	        return "coords[2]";
	      } else {
	        return "coords[3]";
	      }
	    }
	  }, {
	    key: "getDepthCoordString",
	    value: function getDepthCoordString() {
	      if (this.dataFormat === 'NHWC') {
	        return "coords[3]";
	      } else {
	        return "coords[1]";
	      }
	    }
	  }, {
	    key: "getOutputDepthSize",
	    value: function getOutputDepthSize() {
	      if (this.dataFormat === 'NHWC') {
	        return this.outputShape[3];
	      } else {
	        return this.outputShape[1];
	      }
	    }
	  }, {
	    key: "getInputSamplingString",
	    value: function getInputSamplingString() {
	      if (this.dataFormat === 'NHWC') {
	        return "getX(b, in_h, in_w, in_d)";
	      } else {
	        return "getX(b, in_d, in_h, in_w)";
	      }
	    }
	  }]);
	  return DepthToSpaceProgram;
	}();

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function depthToSpace(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var blockSize = attrs.blockSize,
	    dataFormat = attrs.dataFormat;
	  var batchSize = x.shape[0];
	  var inputHeight = dataFormat === 'NHWC' ? x.shape[1] : x.shape[2];
	  var inputWidth = dataFormat === 'NHWC' ? x.shape[2] : x.shape[3];
	  var inputDepth = dataFormat === 'NHWC' ? x.shape[3] : x.shape[1];
	  var outputHeight = inputHeight * blockSize;
	  var outputWidth = inputWidth * blockSize;
	  var outputDepth = inputDepth / (blockSize * blockSize);
	  var outputShape = dataFormat === 'NHWC' ? [batchSize, outputHeight, outputWidth, outputDepth] : [batchSize, outputDepth, outputHeight, outputWidth];
	  var program = new DepthToSpaceProgram(outputShape, blockSize, dataFormat);
	  return backend.runWebGLProgram(program, [x], x.dtype);
	}
	var depthToSpaceConfig = {
	  kernelName: DepthToSpace,
	  backendName: 'webgl',
	  kernelFunc: depthToSpace
	};

	var DepthwiseConv2DProgram = /*#__PURE__*/_createClass(function DepthwiseConv2DProgram(convInfo) {
	  var addBias = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
	  var activation = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
	  var hasPreluActivation = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var hasLeakyReluAlpha = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
	  _classCallCheck(this, DepthwiseConv2DProgram);
	  this.variableNames = ['x', 'W'];
	  this.customUniforms = [{
	    name: 'pads',
	    type: 'ivec2'
	  }, {
	    name: 'strides',
	    type: 'ivec2'
	  }, {
	    name: 'dilations',
	    type: 'ivec2'
	  }, {
	    name: 'inDims',
	    type: 'ivec2'
	  }];
	  this.outputShape = convInfo.outShape;
	  this.enableShapeUniforms = useShapeUniforms(this.outputShape.length);
	  var filterHeight = convInfo.filterHeight;
	  var filterWidth = convInfo.filterWidth;
	  var channelMul = convInfo.outChannels / convInfo.inChannels;
	  var activationSnippet = '',
	    applyActivationSnippet = '';
	  if (activation) {
	    if (hasPreluActivation) {
	      activationSnippet = "float activation(float a) {\n          float b = getPreluActivationWeightsAtOutCoords();\n          ".concat(activation, "\n        }");
	    } else if (hasLeakyReluAlpha) {
	      activationSnippet = "float activation(float a) {\n          float b = getLeakyreluAlphaAtOutCoords();\n          ".concat(activation, "\n        }");
	    } else {
	      activationSnippet = "\n          float activation(float x) {\n            ".concat(activation, "\n          }\n        ");
	    }
	    applyActivationSnippet = "result = activation(result);";
	  }
	  var addBiasSnippet = addBias ? 'result += getBiasAtOutCoords();' : '';
	  if (addBias) {
	    this.variableNames.push('bias');
	  }
	  if (hasPreluActivation) {
	    this.variableNames.push('preluActivationWeights');
	  }
	  if (hasLeakyReluAlpha) {
	    this.variableNames.push('leakyreluAlpha');
	  }
	  this.userCode = "\n      ".concat(activationSnippet, "\n\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int batch = coords.x;\n        ivec2 xRCCorner = coords.yz * strides - pads;\n        int d2 = coords.w;\n        int d1 = d2 / ").concat(channelMul, ";\n        int q = d2 - d1 * ").concat(channelMul, ";\n\n        int xRCorner = xRCCorner.x;\n        int xCCorner = xRCCorner.y;\n\n        // Convolve x(?, ?, d1) with w(:, :, d1, q) to get y(yR, yC, d2).\n        // ? = to be determined. : = across all values in that axis.\n        float dotProd = 0.0;\n        // TO DO(dsmilkov): Flatten the two for loops and vec4 the operations.\n        for (int wR = 0; wR < ").concat(filterHeight, "; wR++) {\n          int xR = xRCorner + wR * dilations[0];\n\n          if (xR < 0 || xR >= inDims[0]) {\n            continue;\n          }\n\n          for (int wC = 0; wC < ").concat(filterWidth, "; wC++) {\n            int xC = xCCorner + wC * dilations[1];\n\n            if (xC < 0 || xC >= inDims[1]) {\n              continue;\n            }\n\n            float xVal = getX(batch, xR, xC, d1);\n            float wVal = getW(wR, wC, d1, q);\n            dotProd += xVal * wVal;\n          }\n        }\n\n        float result = dotProd;\n        ").concat(addBiasSnippet, "\n        ").concat(applyActivationSnippet, "\n        setOutput(result);\n      }\n    ");
	});

	var DepthwiseConvPacked2DProgram = /*#__PURE__*/_createClass(function DepthwiseConvPacked2DProgram(convInfo) {
	  var addBias = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
	  var activation = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
	  var hasPreluActivation = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
	  var hasLeakyReluAlpha = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
	  _classCallCheck(this, DepthwiseConvPacked2DProgram);
	  this.variableNames = ['x', 'W'];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.customUniforms = [{
	    name: 'pads',
	    type: 'ivec2'
	  }, {
	    name: 'strides',
	    type: 'ivec2'
	  }, {
	    name: 'dilations',
	    type: 'ivec2'
	  }, {
	    name: 'inDims',
	    type: 'ivec2'
	  }];
	  this.outputShape = convInfo.outShape;
	  this.enableShapeUniforms = useShapeUniforms(this.outputShape.length);
	  var channelMul = convInfo.outChannels / convInfo.inChannels;
	  var padLeft = convInfo.padInfo.left;
	  var strideWidth = convInfo.strideWidth;
	  var dilationWidth = convInfo.dilationWidth;
	  var filterHeight = convInfo.filterHeight;
	  var filterWidth = convInfo.filterWidth;
	  var texelsAcross = filterWidth;
	  var mainLoop = "\n      int xR; int xC; int xCOffset;\n      vec4 wTexel; vec4 previous; vec4 final;";
	  for (var c = 0; c < filterWidth; c++) {
	    mainLoop += "\n          vec4 xTexelC".concat(c * 2, ";\n          int xTexelC").concat(c * 2, "Ready;\n          vec4 xTexelC").concat(c * 2 + 1, ";\n          int xTexelC").concat(c * 2 + 1, "Ready;\n          vec4 xC").concat(c, ";");
	  }
	  /**
	   * This vectorized implementation works by gathering the values needed for
	   * each output channel's dot product into vec4's and then multiplying them
	   * all together (this happens in the final double for-loop below). Most of
	   * the main loop consists of constructing these vec4's with the minimum
	   * number of texture2D calls, which means making use of all four returned
	   * values from a texture2D call at once.
	   */
	  mainLoop += "\n    for (int r = 0; r < ".concat(filterHeight, "; r++) {\n      ");
	  for (var _c = 0; _c < filterWidth; _c++) {
	    mainLoop += "\n          xTexelC".concat(_c * 2, " = vec4(0.0);\n          xTexelC").concat(_c * 2, "Ready = 0;\n          xTexelC").concat(_c * 2 + 1, " = vec4(0.0);\n          xTexelC").concat(_c * 2 + 1, "Ready = 0;\n          xC").concat(_c, " = vec4(0.0);");
	  }
	  mainLoop += "\n        xR = xRCorner + r * dilations[0];\n        if (xR >=0 && xR < inDims[0]) {\n      ";
	  for (var texelC = 0; texelC < (texelsAcross + 1) / 2; texelC++) {
	    var colIndex = texelC * 2;
	    mainLoop += "\n          xC = xCCorner + ".concat(colIndex * dilationWidth, ";\n          ");
	    if (strideWidth === 1) {
	      if (colIndex < filterWidth) {
	        // If padding is odd, the outer texels have to be composed.
	        if (padLeft % 2 === 1) {
	          // TODO: Ensure vec4 previous does not result in redundant sample,
	          // and avoid setting xTexelRC's that exceed the boundary in the
	          // first place rather than resetting them to vec4(0)).
	          // To compute xCOffset:
	          // - If padding is odd, we must add 1 to ensure we ask for an
	          // even-numbered row.
	          // - We subtract 2 to access the previous texel.
	          mainLoop += "\n                xCOffset = xC + 1;\n                if (xCOffset >= 0 && xCOffset < inDims[1] && xTexelC".concat(colIndex, "Ready == 0) {\n                  xTexelC").concat(colIndex, " = getX(batch, xR, xCOffset, d1);\n\n                  // Need to manually clear unused channels in case\n                  // we're reading from recycled texture.\n                  if (xCOffset + 1 >= inDims[1]) {\n                    xTexelC").concat(colIndex, ".zw = vec2(0.0);\n                  }\n                  xTexelC").concat(colIndex, "Ready = 1;\n                }\n              ");
	          // This texel has been read in previous iteration if the dilation
	          // is 1.
	          if (dilationWidth === 1 && colIndex > 0) {
	            mainLoop += "\n                xC".concat(colIndex, " = vec4(xTexelC").concat(colIndex - 2, ".zw, xTexelC").concat(colIndex, ".xy);\n                ");
	          } else {
	            mainLoop += "\n                  xCOffset = xC + 1 - 2;\n\n                  if (xCOffset >= 0 && xCOffset < inDims[1]) {\n                    previous = getX(batch, xR, xCOffset, d1);\n\n                    // Need to manually clear unused channels in case\n                    // we're reading from recycled texture.\n                    if (xCOffset + 1 >= inDims[1]) {\n                      previous.zw = vec2(0.0);\n                    }\n\n                    xC".concat(colIndex, " = vec4(previous.zw, xTexelC").concat(colIndex, ".xy);\n                  } else {\n                    xC").concat(colIndex, " = vec4(0.0, 0.0, xTexelC").concat(colIndex, ".xy);\n                  }\n                  ");
	          }
	        } else {
	          // Padding is even, so xRC corresponds to a single texel.
	          mainLoop += "\n                if (xC >= 0 && xC < inDims[1] && xTexelC".concat(colIndex, "Ready == 0) {\n                  xTexelC").concat(colIndex, " = getX(batch, xR, xC, d1);\n                  if (xC + 1 >= inDims[1]) {\n                    xTexelC").concat(colIndex, ".zw = vec2(0.0);\n                  }\n                  xTexelC").concat(colIndex, "Ready = 1;\n                }\n\n                xC").concat(colIndex, " = xTexelC").concat(colIndex, ";\n                ");
	        }
	        if (colIndex + 1 < filterWidth) {
	          // If dilation is even, the second entry should match the first
	          // (either both are composed or both are single samples). But if
	          // dilation is odd, then the second entry should be the opposite
	          // of the first (if the first is composed, the second is a single
	          // sample, and vice versa.)
	          var nextTexelOffset = padLeft % 2 === 0 ? nearestLargerEven(dilationWidth) : dilationWidth;
	          if (dilationWidth % 2 === 0 && padLeft % 2 === 1 || dilationWidth % 2 !== 0 && padLeft % 2 !== 1) {
	            mainLoop += "\n                  xCOffset = xC + imod(pads[1], 2) + ".concat(nextTexelOffset, ";\n\n                  if (xCOffset >= 0 && xCOffset < inDims[1] && xTexelC").concat(colIndex + 1, "Ready == 0) {\n                    xTexelC").concat(colIndex + 1, " = getX(batch, xR, xCOffset, d1);\n\n                    // Need to manually clear unused channels in case\n                    // we're reading from recycled texture.\n                    if (xCOffset + 1 >= inDims[1]) {\n                      xTexelC").concat(colIndex + 1, ".zw = vec2(0.0);\n                    }\n                    xTexelC").concat(colIndex + 1, "Ready = 1;\n                  }\n                  ");
	            // If dilation > 1 then the xRC's will not be able to share any
	            // values, so each xRC will require two unique calls to getX.
	            if (dilationWidth > 1) {
	              mainLoop += "\n                    xCOffset -= 2;\n                    if (xCOffset >= 0 && xCOffset < inDims[1]) {\n                     previous = getX(batch, xR, xCOffset, d1);\n                     xC".concat(colIndex + 1, " = vec4(previous.zw, xTexelC").concat(colIndex + 1, ".xy);\n                    } else {\n                     xC").concat(colIndex + 1, " = vec4(0.0, 0.0, xTexelC").concat(colIndex + 1, ".xy);\n                    }\n                    ");
	            } else {
	              mainLoop += "\n                    xC".concat(colIndex + 1, " = vec4(xTexelC").concat(colIndex, ".zw, xTexelC").concat(colIndex + 1, ".xy);\n                    ");
	            }
	          } else {
	            // If dilation is 1 and padding is odd, we have already read the
	            // texel when constructing the previous x value. Here we can
	            // simply skip the texture read.
	            if (nextTexelOffset === 1) {
	              mainLoop += "\n                    xC".concat(colIndex + 1, " = xTexelC").concat(colIndex, ";\n                    ");
	            } else {
	              mainLoop += "\n                    xCOffset = xC + ".concat(nextTexelOffset, ";\n\n                    if (xCOffset >= 0 && xCOffset < inDims[1] && xTexelC").concat(colIndex + 1, "Ready == 0) {\n                      xTexelC").concat(colIndex + 1, " = getX(batch, xR, xCOffset, d1);\n                      if (xCOffset + 1 >= inDims[1]) {\n                        xTexelC").concat(colIndex + 1, ".zw = vec2(0.0);\n                      }\n                      xTexelC").concat(colIndex + 1, "Ready = 1;\n                    }\n\n                    xC").concat(colIndex + 1, " = xTexelC").concat(colIndex + 1, ";\n                    ");
	            }
	          }
	        }
	      }
	    } else {
	      // stride === 2
	      if (colIndex < filterWidth) {
	        // Depending on whether padLeft is even or odd, we want either the
	        // xy or zw channels from X texels for xC${colIndex}. If padLeft is
	        // even, xC${colIndex +1} is simply the zw channels of texels we've
	        // already sampled. But if padLeft is odd, xC{$c + 1}.zw will
	        // need to come from the xy channels of a new texel, hence the `
	        // vec4
	        // final` initialized below.
	        if (padLeft % 2 === 1) {
	          mainLoop += "\n                xCOffset = xC + 1 - strides[1];\n                if(xCOffset >= 0 && xCOffset < inDims[1] && xTexelC".concat(colIndex, "Ready == 0) {\n                  xTexelC").concat(colIndex, " = getX(batch, xR, xCOffset, d1);\n                  // Need to manually clear unused channels in case\n                  // we're reading from recycled texture.\n                  if (xCOffset + 1 >= inDims[1]) {\n                    xTexelC").concat(colIndex, ".zw = vec2(0.0);\n                  }\n                  xTexelC").concat(colIndex, "Ready = 1;\n                }\n\n                if(xC + 1 >= 0 && xC + 1 < inDims[1] && xTexelC").concat(colIndex + 1, "Ready == 0) {\n                  xTexelC").concat(colIndex + 1, " = getX(batch, xR, xC + 1, d1);\n                  // Need to manually clear unused channels in case\n                  // we're reading from recycled texture.\n                  if (xC + 2 >= inDims[1]) {\n                    xTexelC").concat(colIndex + 1, ".zw = vec2(0.0);\n                  }\n                  xTexelC").concat(colIndex + 1, "Ready = 1;\n                }\n\n                xC").concat(colIndex, " = vec4(xTexelC").concat(colIndex, ".zw, xTexelC").concat(colIndex + 1, ".zw);\n              ");
	          if (colIndex + 1 < filterWidth) {
	            mainLoop += "\n                  final = vec4(0.0);\n                  xCOffset = xC + 1 + strides[1];\n                  if(xCOffset >= 0 && xCOffset < inDims[1]) {\n                    final = getX(batch, xR, xCOffset, d1);\n                  }\n                  xC".concat(colIndex + 1, " = vec4(xTexelC").concat(colIndex + 1, ".xy, final.xy);\n                ");
	          }
	        } else {
	          mainLoop += "\n                if(xC >= 0 && xC < inDims[1] && xTexelC".concat(colIndex, "Ready == 0) {\n                  xTexelC").concat(colIndex, " = getX(batch, xR, xC, d1);\n                  if (xC + 1 >= inDims[1]) {\n                    xTexelC").concat(colIndex, ".zw = vec2(0.0);\n                  }\n                  xTexelC").concat(colIndex, "Ready = 1;\n                }\n\n                xCOffset = xC + strides[1];\n                if(xCOffset >= 0 && xCOffset < inDims[1] && xTexelC").concat(colIndex + 1, "Ready == 0) {\n                  xTexelC").concat(colIndex + 1, " = getX(batch, xR, xCOffset, d1);\n                  if (xCOffset + 1 >= inDims[1]) {\n                    xTexelC").concat(colIndex + 1, ".zw = vec2(0.);\n                  }\n                  xTexelC").concat(colIndex + 1, "Ready = 1;\n                }\n\n                xC").concat(colIndex, " = vec4(\n                  xTexelC").concat(colIndex, ".xy, xTexelC").concat(colIndex + 1, ".xy);\n              ");
	          if (colIndex + 1 < filterWidth) {
	            mainLoop += "\n                  xC".concat(colIndex + 1, " = vec4(xTexelC").concat(colIndex, ".zw, xTexelC").concat(colIndex + 1, ".zw);\n                ");
	          }
	        }
	      }
	    }
	    // localize the dotProd accumulation within the loop, the theory is for
	    // GPU with limited cache, accumulate sum across large amount of
	    // veriables will cause lots of cache misses. (i.e. 5x5 filter will have
	    // 50 variables)
	    if (colIndex < filterWidth) {
	      mainLoop += "\n            wTexel = getW(r, ".concat(colIndex, ", d1, q);\n            dotProd += xC").concat(colIndex, " * vec4(wTexel.xz, wTexel.xz);\n          ");
	      if (colIndex + 1 < filterWidth) {
	        mainLoop += "\n              wTexel = getW(r, ".concat(colIndex + 1, ", d1, q);\n              dotProd += xC").concat(colIndex + 1, " * vec4(wTexel.xz, wTexel.xz);\n            ");
	      }
	    }
	  }
	  mainLoop += "\n    }\n  ";
	  mainLoop += "\n      }\n    ";
	  var activationSnippet = '',
	    applyActivationSnippet = '';
	  if (activation) {
	    if (hasPreluActivation) {
	      activationSnippet = "vec4 activation(vec4 a) {\n          vec4 b = getPreluActivationWeightsAtOutCoords();\n          ".concat(activation, "\n        }");
	    } else if (hasLeakyReluAlpha) {
	      activationSnippet = "vec4 activation(vec4 a) {\n          vec4 b = getLeakyreluAlphaAtOutCoords();\n          ".concat(activation, "\n        }");
	    } else {
	      activationSnippet = "vec4 activation(vec4 x) {\n          ".concat(activation, "\n        }");
	    }
	    applyActivationSnippet = "result = activation(result);";
	  }
	  var addBiasSnippet = addBias ? 'result += getBiasAtOutCoords();' : '';
	  if (addBias) {
	    this.variableNames.push('bias');
	  }
	  if (hasPreluActivation) {
	    this.variableNames.push('preluActivationWeights');
	  }
	  if (hasLeakyReluAlpha) {
	    this.variableNames.push('leakyreluAlpha');
	  }
	  this.userCode = "\n      ".concat(activationSnippet, "\n\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int batch = coords.x;\n        ivec2 xRCCorner = coords.yz * strides - pads;\n        int d2 = coords.w;\n        int d1 = d2 / ").concat(channelMul, ";\n        int q = d2 - d1 * ").concat(channelMul, ";\n        int xRCorner = xRCCorner.x;\n        int xCCorner = xRCCorner.y;\n\n        //intialize dotProd with a small epsilon seems to reduce GPU accuracy loss.\n        vec4 dotProd = vec4(0.000000000000001);\n\n        ").concat(mainLoop, "\n\n        vec4 result = dotProd - vec4(0.000000000000001);\n        ").concat(addBiasSnippet, "\n        ").concat(applyActivationSnippet, "\n        setOutput(result);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function depthwiseConv2dNative(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    filter = inputs.filter;
	  var strides = attrs.strides,
	    pad = attrs.pad,
	    dilations = attrs.dilations,
	    dimRoundingMode = attrs.dimRoundingMode;
	  var $dilations = dilations;
	  if ($dilations == null) {
	    $dilations = [1, 1];
	  }
	  assert$1(eitherStridesOrDilationsAreOne(strides, $dilations), function () {
	    return 'Error in depthwiseConv2d: Either strides or dilations must be ' + "1. Got strides ".concat(strides, " and dilations '").concat($dilations, "'");
	  });
	  var convInfo = computeConv2DInfo(x.shape, filter.shape, strides, $dilations, pad, dimRoundingMode, true /* depthwise */);
	  var program;
	  if (env().getBool('WEBGL_PACK_DEPTHWISECONV') && convInfo.strideWidth <= 2 && convInfo.outChannels / convInfo.inChannels === 1) {
	    program = new DepthwiseConvPacked2DProgram(convInfo);
	  } else {
	    program = new DepthwiseConv2DProgram(convInfo);
	  }
	  var customValues = [[convInfo.padInfo.top, convInfo.padInfo.left], [convInfo.strideHeight, convInfo.strideWidth], [convInfo.dilationHeight, convInfo.dilationWidth], [convInfo.inHeight, convInfo.inWidth]];
	  return backend.runWebGLProgram(program, [x, filter], 'float32', customValues);
	}
	var depthwiseConv2dNativeConfig = {
	  kernelName: DepthwiseConv2dNative,
	  backendName: 'webgl',
	  kernelFunc: depthwiseConv2dNative
	};

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var DepthwiseConv2DDerFilterProgram = /*#__PURE__*/_createClass(function DepthwiseConv2DDerFilterProgram(convInfo) {
	  _classCallCheck(this, DepthwiseConv2DDerFilterProgram);
	  this.variableNames = ['x', 'dy'];
	  this.outputShape = convInfo.filterShape;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var padTop = convInfo.padInfo.top;
	  var padLeft = convInfo.padInfo.left;
	  var channelMul = convInfo.outChannels / convInfo.inChannels;
	  this.userCode = "\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int wR = coords.x;\n        int wC = coords.y;\n        int d1 = coords.z;\n        int dm = coords.w;\n        int d2 = d1 * ".concat(channelMul, " + dm;\n\n        float dotProd = 0.0;\n\n        // TO DO: Vec4 over the batch size\n        for (int b = 0; b < ").concat(convInfo.batchSize, "; b++) {\n          for (int yR = 0; yR < ").concat(convInfo.outHeight, "; yR++) {\n            int xR = wR + yR * ").concat(strideHeight, " - ").concat(padTop, ";\n\n            if (xR < 0 || xR >= ").concat(convInfo.inHeight, ") {\n              continue;\n            }\n\n            for (int yC = 0; yC < ").concat(convInfo.outWidth, "; yC++) {\n              int xC = wC + yC * ").concat(strideWidth, " - ").concat(padLeft, ";\n\n              if (xC < 0 || xC >= ").concat(convInfo.inWidth, ") {\n                continue;\n              }\n\n              float dyValue = getDy(b, yR, yC, d2);\n              float xValue = getX(b, xR, xC, d1);\n              dotProd += (xValue * dyValue);\n            }\n          }\n        }\n        setOutput(dotProd);\n      }\n    ");
	});
	var DepthwiseConv2DDerInputProgram = /*#__PURE__*/_createClass(function DepthwiseConv2DDerInputProgram(convInfo) {
	  _classCallCheck(this, DepthwiseConv2DDerInputProgram);
	  this.variableNames = ['dy', 'W'];
	  this.outputShape = convInfo.inShape;
	  var filterHeight = convInfo.filterHeight;
	  var filterWidth = convInfo.filterWidth;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var padTop = filterHeight - 1 - convInfo.padInfo.top;
	  var padLeft = filterWidth - 1 - convInfo.padInfo.left;
	  var channelMul = convInfo.outChannels / convInfo.inChannels;
	  this.userCode = "\n      const ivec2 pads = ivec2(".concat(padTop, ", ").concat(padLeft, ");\n\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int batch = coords[0];\n        int d1 = coords[3];\n        ivec2 dyCorner = coords.yz - pads;\n        int dyRCorner = dyCorner.x;\n        int dyCCorner = dyCorner.y;\n\n        float dotProd = 0.0;\n\n        for (int wR = 0; wR < ").concat(filterHeight, "; wR++) {\n          float dyR = float(dyRCorner + wR) / ").concat(strideHeight, ".0;\n\n          if (dyR < 0.0 || dyR >= ").concat(convInfo.outHeight, ".0 || fract(dyR) > 0.0) {\n            continue;\n          }\n          int idyR = int(dyR);\n\n          int wRPerm = ").concat(filterHeight, " - 1 - wR;\n\n          for (int wC = 0; wC < ").concat(filterWidth, "; wC++) {\n            float dyC = float(dyCCorner + wC) / ").concat(strideWidth, ".0;\n\n            if (dyC < 0.0 || dyC >= ").concat(convInfo.outWidth, ".0 ||\n                fract(dyC) > 0.0) {\n              continue;\n            }\n            int idyC = int(dyC);\n\n            int wCPerm = ").concat(filterWidth, " - 1 - wC;\n\n            // TO DO: Vec4 over the channelMul\n            for (int dm = 0; dm < ").concat(channelMul, "; dm++) {\n              int d2 = d1 * ").concat(channelMul, " + dm;\n              float xValue = getDy(batch, idyR, idyC, d2);\n              float wValue = getW(wRPerm, wCPerm, d1, dm);\n              dotProd += xValue * wValue;\n            }\n          }\n        }\n        setOutput(dotProd);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function depthwiseConv2dNativeBackpropFilter(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    dy = inputs.dy;
	  var strides = attrs.strides,
	    dilations = attrs.dilations,
	    pad = attrs.pad,
	    dimRoundingMode = attrs.dimRoundingMode,
	    filterShape = attrs.filterShape;
	  var convInfo = computeConv2DInfo(x.shape, filterShape, strides, dilations, pad, dimRoundingMode, true /* depthwise */);
	  var program = new DepthwiseConv2DDerFilterProgram(convInfo);
	  return backend.runWebGLProgram(program, [x, dy], 'float32');
	}
	var depthwiseConv2dNativeBackpropFilterConfig = {
	  kernelName: DepthwiseConv2dNativeBackpropFilter,
	  backendName: 'webgl',
	  kernelFunc: depthwiseConv2dNativeBackpropFilter
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function depthwiseConv2dNativeBackpropInput(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var dy = inputs.dy,
	    filter = inputs.filter;
	  var strides = attrs.strides,
	    dilations = attrs.dilations,
	    pad = attrs.pad,
	    dimRoundingMode = attrs.dimRoundingMode,
	    inputShape = attrs.inputShape;
	  var convInfo = computeConv2DInfo(inputShape, filter.shape, strides, dilations, pad, dimRoundingMode, true /* depthwise */);
	  var program = new DepthwiseConv2DDerInputProgram(convInfo);
	  return backend.runWebGLProgram(program, [dy, filter], 'float32');
	}
	var depthwiseConv2dNativeBackpropInputConfig = {
	  kernelName: DepthwiseConv2dNativeBackpropInput,
	  backendName: 'webgl',
	  kernelFunc: depthwiseConv2dNativeBackpropInput
	};

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var DiagProgram = /*#__PURE__*/_createClass(function DiagProgram(size) {
	  _classCallCheck(this, DiagProgram);
	  this.variableNames = ['X'];
	  this.outputShape = [size, size];
	  this.userCode = "\n      void main() {\n          ivec2 coords = getOutputCoords();\n          float val = coords[0] == coords[1] ? getX(coords[0]) : 0.0;\n          setOutput(val);\n      }\n    ";
	});

	function diag(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var x = inputs.x;
	  var outShape = [].concat(_toConsumableArray(x.shape), _toConsumableArray(x.shape));
	  var xSize = sizeFromShape(x.shape);
	  var flat = reshape({
	    inputs: {
	      x: x
	    },
	    backend: backend,
	    attrs: {
	      shape: [xSize]
	    }
	  });
	  var program = new DiagProgram(xSize);
	  var res = backend.runWebGLProgram(program, [flat], flat.dtype);
	  var out = reshape({
	    inputs: {
	      x: res
	    },
	    backend: backend,
	    attrs: {
	      shape: outShape
	    }
	  });
	  backend.disposeIntermediateTensorInfo(flat);
	  backend.disposeIntermediateTensorInfo(res);
	  return out;
	}
	var diagConfig = {
	  kernelName: Diag,
	  backendName: 'webgl',
	  kernelFunc: diag
	};

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var Dilation2DProgram = /*#__PURE__*/_createClass(function Dilation2DProgram(convInfo) {
	  _classCallCheck(this, Dilation2DProgram);
	  this.variableNames = ['x', 'W'];
	  this.outputShape = convInfo.outShape;
	  var inHeight = convInfo.inHeight,
	    inWidth = convInfo.inWidth,
	    padInfo = convInfo.padInfo,
	    strideHeight = convInfo.strideHeight,
	    strideWidth = convInfo.strideWidth,
	    filterHeight = convInfo.filterHeight,
	    filterWidth = convInfo.filterWidth,
	    dilationHeight = convInfo.dilationHeight,
	    dilationWidth = convInfo.dilationWidth;
	  var padTop = padInfo.top,
	    padLeft = padInfo.left;
	  this.userCode = "\n      const ivec2 strides = ivec2(".concat(strideHeight, ", ").concat(strideWidth, ");\n      const ivec2 pads = ivec2(").concat(padTop, ", ").concat(padLeft, ");\n      const float neg_infinity = -3.4e38;\n\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int batch = coords.x;\n        int d1 = coords.w;\n        ivec2 outTopLeftCorner =\n            coords.yz * strides - pads;\n        int hBeg = outTopLeftCorner.x;\n        int wBeg = outTopLeftCorner.y;\n\n        float curVal = neg_infinity;\n        for (int h = 0; h < ").concat(filterHeight, "; h++) {\n          int hIn = hBeg + h * ").concat(dilationHeight, ";\n\n          if (hIn >= 0 && hIn < ").concat(inHeight, ") {\n            for (int w = 0; w < ").concat(filterWidth, "; w++) {\n              int wIn = wBeg + w * ").concat(dilationWidth, ";\n\n              if (wIn >= 0 && wIn < ").concat(inWidth, ") {\n                float xVal = getX(batch, hIn, wIn, d1);\n                float wVal = getW(h, w, d1);\n\n                float val = xVal + wVal;\n                if (val > curVal) {\n                  curVal = val;\n                }\n              }\n            }\n          }\n        }\n\n        float result = curVal;\n        setOutput(result);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function dilation2D(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    filter = inputs.filter;
	  var strides = attrs.strides,
	    pad = attrs.pad,
	    dilations = attrs.dilations;
	  var convInfo = computeDilation2DInfo(x.shape, filter.shape, strides, pad, 'NHWC' /* dataFormat */, dilations);
	  var out;
	  var program = new Dilation2DProgram(convInfo);
	  out = backend.runWebGLProgram(program, [x, filter], 'float32');
	  var outReshaped = reshape({
	    inputs: {
	      x: out
	    },
	    backend: backend,
	    attrs: {
	      shape: convInfo.outShape
	    }
	  });
	  backend.disposeIntermediateTensorInfo(out);
	  return outReshaped;
	}
	var dilation2DConfig = {
	  kernelName: Dilation2D,
	  backendName: 'webgl',
	  kernelFunc: dilation2D
	};

	function einsum(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var equation = attrs.equation;
	  var tensors = inputs;
	  var _backend_util$decodeE = decodeEinsumEquation(equation, tensors.length),
	    allDims = _backend_util$decodeE.allDims,
	    summedDims = _backend_util$decodeE.summedDims,
	    idDims = _backend_util$decodeE.idDims;
	  checkEinsumDimSizes(allDims.length, idDims, tensors);
	  var _backend_util$getEins = getEinsumComputePath(summedDims, idDims),
	    path = _backend_util$getEins.path,
	    steps = _backend_util$getEins.steps;
	  var nSteps = steps.length;
	  var out = null;
	  var numDimsRemaining = allDims.length;
	  var tensorsToDispose = [];
	  for (var i = 0; i < nSteps; ++i) {
	    var _iterator = _createForOfIteratorHelper(steps[i]),
	      _step;
	    try {
	      for (_iterator.s(); !(_step = _iterator.n()).done;) {
	        var idTerm = _step.value;
	        var _backend_util$getEins2 = getEinsumPermutation(numDimsRemaining, idDims[idTerm]),
	          perm = _backend_util$getEins2.permutationIndices,
	          dimsToExpand = _backend_util$getEins2.expandDims;
	        var x = void 0;
	        if (isIdentityPermutation(perm)) {
	          x = tensors[idTerm];
	        } else {
	          x = transpose({
	            inputs: {
	              x: tensors[idTerm]
	            },
	            backend: backend,
	            attrs: {
	              perm: perm
	            }
	          });
	          tensorsToDispose.push(x);
	        }
	        var targetShape = x.shape.slice();
	        for (var k = 0; k < dimsToExpand.length; ++k) {
	          targetShape.splice(dimsToExpand[k], 0, 1);
	        }
	        if (!arraysEqual(x.shape, targetShape)) {
	          x = reshape({
	            inputs: {
	              x: x
	            },
	            backend: backend,
	            attrs: {
	              shape: targetShape
	            }
	          });
	          tensorsToDispose.push(x);
	        }
	        if (out === null) {
	          out = x;
	        } else {
	          // tslint:disable-next-line: no-unnecessary-type-assertion
	          out = multiply({
	            inputs: {
	              a: x,
	              b: out
	            },
	            backend: backend
	          });
	          tensorsToDispose.push(out);
	        }
	      }
	    } catch (err) {
	      _iterator.e(err);
	    } finally {
	      _iterator.f();
	    }
	    if (i < nSteps - 1) {
	      if (path[i] >= 0) {
	        out = sum({
	          inputs: {
	            x: out
	          },
	          backend: backend,
	          attrs: {
	            axis: path[i] - (allDims.length - numDimsRemaining),
	            keepDims: false
	          }
	        });
	        tensorsToDispose.push(out);
	      }
	      numDimsRemaining--;
	    }
	  }
	  // Clean up intermediate tensors.
	  for (var _i = 0, _tensorsToDispose = tensorsToDispose; _i < _tensorsToDispose.length; _i++) {
	    var tensorInfo = _tensorsToDispose[_i];
	    if (tensorInfo === out) {
	      continue;
	    }
	    backend.disposeIntermediateTensorInfo(tensorInfo);
	  }
	  return out;
	}
	var einsumConfig = {
	  kernelName: Einsum,
	  backendName: 'webgl',
	  kernelFunc: einsum
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ELU = "return (x >= 0.0) ? x : (exp(x) - 1.0);";
	var ELU_PACKED = "\n  vec4 result;\n\n  result.r = (x.r >= 0.0) ? x.r : (exp(x.r) - 1.0);\n  result.g = (x.g >= 0.0) ? x.g : (exp(x.g) - 1.0);\n  result.b = (x.b >= 0.0) ? x.b : (exp(x.b) - 1.0);\n  result.a = (x.a >= 0.0) ? x.a : (exp(x.a) - 1.0);\n\n  return result;\n";
	var elu = unaryKernelFunc({
	  opSnippet: ELU,
	  packedOpSnippet: ELU_PACKED
	});
	var eluConfig = {
	  kernelName: Elu$1,
	  backendName: 'webgl',
	  kernelFunc: elu
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ELU_DER = "return (b >= 0.0) ? a : a * (b + 1.0);";
	var ELU_DER_PACKED = "\n  vec4 bGTEZero = vec4(greaterThanEqual(b, vec4(0.)));\n  return (bGTEZero * a) + ((vec4(1.0) - bGTEZero) * (a * (b + vec4(1.0))));\n";
	var eluGrad = function eluGrad(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var dy = inputs.dy,
	    y = inputs.y;
	  var program = env().getBool('WEBGL_PACK_BINARY_OPERATIONS') ? new BinaryOpPackedProgram(ELU_DER_PACKED, dy.shape, y.shape) : new BinaryOpProgram(ELU_DER, dy.shape, y.shape);
	  return backend.runWebGLProgram(program, [dy, y], dy.dtype);
	};
	var eluGradConfig = {
	  kernelName: EluGrad,
	  backendName: 'webgl',
	  kernelFunc: eluGrad
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var PACKED_EQUAL = "\n  return vec4(equal(a, b));\n";
	var EQUAL = "return float(a == b);";
	var equal = binaryKernelFunc({
	  opSnippet: EQUAL,
	  packedOpSnippet: PACKED_EQUAL,
	  dtype: 'bool',
	  cpuKernelImpl: equalImplCPU
	});
	var equalConfig = {
	  kernelName: Equal,
	  backendName: 'webgl',
	  kernelFunc: equal
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ERF = "\n  // Error function is calculated approximately with elementary function.\n  // See \"Handbook of Mathematical Functions with Formulas,\n  // Graphs, and Mathematical Tables\", Abramowitz and Stegun.\n  float p = ".concat(ERF_P, ";\n  float a1 = ").concat(ERF_A1, ";\n  float a2 = ").concat(ERF_A2, ";\n  float a3 = ").concat(ERF_A3, ";\n  float a4 = ").concat(ERF_A4, ";\n  float a5 = ").concat(ERF_A5, ";\n\n  float sign = sign(x);\n  x = abs(x);\n  float t = 1.0 / (1.0 + p * x);\n  return sign * (1.0 - (((((a5*t + a4)*t) + a3)*t + a2)*t + a1)*t*exp(-x*x));\n");
	var erf = unaryKernelFunc({
	  opSnippet: ERF
	});
	var erfConfig = {
	  kernelName: Erf,
	  backendName: 'webgl',
	  kernelFunc: erf
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var EXP = CHECK_NAN_SNIPPET_UNARY + "\n  return exp(x);\n";
	var EXP_PACKED = "\n  vec4 result = exp(x);\n  bvec4 isNaN = isnan(x);\n  result.r = isNaN.r ? x.r : result.r;\n  result.g = isNaN.g ? x.g : result.g;\n  result.b = isNaN.b ? x.b : result.b;\n  result.a = isNaN.a ? x.a : result.a;\n\n  return result;\n";
	var exp = unaryKernelFunc({
	  opSnippet: EXP,
	  packedOpSnippet: EXP_PACKED,
	  cpuKernelImpl: expImplCPU,
	  dtype: 'float32'
	});
	var expConfig = {
	  kernelName: Exp,
	  backendName: 'webgl',
	  kernelFunc: exp
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function expandDims(args) {
	  var inputs = args.inputs,
	    attrs = args.attrs,
	    backend = args.backend;
	  var dim = attrs.dim;
	  var input = inputs.input;
	  var inputRank = input.shape.length;
	  var newShape = input.shape.slice();
	  var $dim = dim;
	  if (dim < 0) {
	    // Negative value is counted from the tail of rank.
	    assert$1(-(inputRank + 1) <= dim, function () {
	      return "Axis must be in the interval [".concat(-(inputRank + 1), ", ").concat(inputRank, "]");
	    });
	    $dim = inputRank + dim + 1;
	  }
	  newShape.splice($dim, 0, 1);
	  return reshape({
	    inputs: {
	      x: input
	    },
	    backend: backend,
	    attrs: {
	      shape: newShape
	    }
	  });
	}
	var expandDimsConfig = {
	  kernelName: ExpandDims,
	  backendName: 'webgl',
	  kernelFunc: expandDims
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var EXPM1 = "return exp(x) - 1.0;";
	var expm1 = unaryKernelFunc({
	  opSnippet: EXPM1,
	  packedOpSnippet: EXPM1,
	  cpuKernelImpl: expm1ImplCPU
	});
	var expm1Config = {
	  kernelName: Expm1,
	  backendName: 'webgl',
	  kernelFunc: expm1
	};

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var FFTProgram = /*#__PURE__*/_createClass(function FFTProgram(component, inputShape, inverse) {
	  _classCallCheck(this, FFTProgram);
	  this.variableNames = ['real', 'imag'];
	  var innerDim = inputShape[1];
	  this.outputShape = inputShape;
	  var exponentMultiplierSnippet = inverse ? "2.0 * ".concat(Math.PI) : "-2.0 * ".concat(Math.PI);
	  var resultDenominator = inverse ? "".concat(innerDim, ".0") : '1.0';
	  var opString;
	  if (component === 'real') {
	    opString = 'return real * expR - imag * expI;';
	  } else if (component === 'imag') {
	    opString = 'return real * expI + imag * expR;';
	  } else {
	    throw new Error("FFT component must be either \"real\" or \"imag\", got ".concat(component, "."));
	  }
	  this.userCode = "\n      const float exponentMultiplier = ".concat(exponentMultiplierSnippet, ";\n\n      float unaryOpComplex(float real, float expR, float imag, float expI) {\n        ").concat(opString, "\n      }\n\n      float mulMatDFT(int batch, int index) {\n        float indexRatio = float(index) / float(").concat(innerDim, ");\n        float exponentMultiplierTimesIndexRatio =\n            exponentMultiplier * indexRatio;\n\n        float result = 0.0;\n\n        for (int i = 0; i < ").concat(innerDim, "; i++) {\n          // x = (-2|2 * PI / N) * index * i;\n          float x = exponentMultiplierTimesIndexRatio * float(i);\n          float expR = cos(x);\n          float expI = sin(x);\n          float real = getReal(batch, i);\n          float imag = getImag(batch, i);\n\n          result +=\n              unaryOpComplex(real, expR, imag, expI) / ").concat(resultDenominator, ";\n        }\n\n        return result;\n      }\n\n      void main() {\n        ivec2 coords = getOutputCoords();\n        setOutput(mulMatDFT(coords[0], coords[1]));\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function fftImpl(x, inverse, backend) {
	  var xData = backend.texData.get(x.dataId);
	  var inputSize = sizeFromShape(x.shape);
	  // Collapse all outer dimensions to a single batch dimension.
	  var innerDimensionSize = x.shape[x.shape.length - 1];
	  var batch = inputSize / innerDimensionSize;
	  var input2D = reshape({
	    inputs: {
	      x: x
	    },
	    backend: backend,
	    attrs: {
	      shape: [batch, innerDimensionSize]
	    }
	  });
	  var xShape = input2D.shape;
	  var realProgram = new FFTProgram('real', xShape, inverse);
	  var imagProgram = new FFTProgram('imag', xShape, inverse);
	  var inputs = [{
	    dataId: xData.complexTensorInfos.real.dataId,
	    dtype: xData.complexTensorInfos.real.dtype,
	    shape: xShape
	  }, {
	    dataId: xData.complexTensorInfos.imag.dataId,
	    dtype: xData.complexTensorInfos.imag.dtype,
	    shape: xShape
	  }];
	  var realPart = backend.runWebGLProgram(realProgram, inputs, 'float32');
	  var imagPart = backend.runWebGLProgram(imagProgram, inputs, 'float32');
	  var complexOutput = complex({
	    inputs: {
	      real: realPart,
	      imag: imagPart
	    },
	    backend: backend
	  });
	  backend.disposeIntermediateTensorInfo(realPart);
	  backend.disposeIntermediateTensorInfo(imagPart);
	  var complexOutputReshaped = reshape({
	    inputs: {
	      x: complexOutput
	    },
	    backend: backend,
	    attrs: {
	      shape: x.shape
	    }
	  });
	  backend.disposeIntermediateTensorInfo(input2D);
	  backend.disposeIntermediateTensorInfo(complexOutput);
	  return complexOutputReshaped;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function fft(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var input = inputs.input;
	  return fftImpl(input, false /* inverse */, backend);
	}
	var fftConfig = {
	  kernelName: FFT,
	  backendName: 'webgl',
	  kernelFunc: fft
	};

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var FillProgram = /*#__PURE__*/_createClass(function FillProgram(shape, value) {
	  _classCallCheck(this, FillProgram);
	  this.outputShape = [];
	  this.customUniforms = [{
	    name: 'value',
	    type: 'float'
	  }];
	  this.variableNames = ['x'];
	  this.outputShape = shape;
	  this.userCode = "\n      void main() {\n        // Input can be obtained from uniform value.\n        setOutput(value);\n      }\n    ";
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function fill(args) {
	  var backend = args.backend,
	    attrs = args.attrs;
	  var shape = attrs.shape,
	    value = attrs.value;
	  var dtype = attrs.dtype;
	  dtype = dtype || inferDtype(value);
	  if (dtype === 'string') {
	    // String type should be handled in CPU memory.
	    var values = getArrayFromDType(dtype, sizeFromShape(shape));
	    values.fill(value);
	    return backend.makeTensorInfo(shape, dtype, values);
	  } else {
	    var program = new FillProgram(shape, value);
	    var customValues = [[value]];
	    return backend.runWebGLProgram(program, [], dtype, customValues);
	  }
	}
	var fillConfig = {
	  kernelName: Fill,
	  backendName: 'webgl',
	  kernelFunc: fill
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var FlipLeftRightProgram = /*#__PURE__*/_createClass(function FlipLeftRightProgram(imageShape) {
	  _classCallCheck(this, FlipLeftRightProgram);
	  this.variableNames = ['Image'];
	  this.outputShape = [];
	  var imageWidth = imageShape[2];
	  this.outputShape = imageShape;
	  this.userCode = "\n        void main() {\n          ivec4 coords = getOutputCoords();\n          int x = coords[2];\n\n          int coordX = ".concat(imageWidth, " - x - 1;\n          float outputValue;\n          if(coordX >= 0 && coordX < ").concat(imageWidth, ") {\n            outputValue = getImage(coords[0], coords[1], coordX, coords[3]);\n          } else {\n            outputValue = getImage(coords[0], coords[1], coords[2], coords[3]);\n          }\n          setOutput(outputValue);\n        }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var flipLeftRightConfig = {
	  kernelName: FlipLeftRight,
	  backendName: 'webgl',
	  kernelFunc: function kernelFunc(_ref) {
	    var inputs = _ref.inputs,
	      backend = _ref.backend;
	    var image = inputs.image;
	    var webglBackend = backend;
	    var program = new FlipLeftRightProgram(image.shape);
	    var output = webglBackend.runWebGLProgram(program, [image], image.dtype);
	    return output;
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var FLOOR = "return floor(x);";
	var floor = unaryKernelFunc({
	  opSnippet: FLOOR,
	  packedOpSnippet: FLOOR,
	  cpuKernelImpl: floorImplCPU
	});
	var floorConfig = {
	  kernelName: Floor,
	  backendName: 'webgl',
	  kernelFunc: floor
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	// We use native integer division to deal with floating point imprecision. Since
	// we implement floor division and glsl implements truncated division, we
	// correct for this by subtracting 1 from result when the result is negative and
	// there is a remainder.
	var INT_DIV = "\n  float s = sign(a) * sign(b);\n  int ia = round(a);\n  int ib = round(b);\n  if (ib != 0) {\n    // Windows (D3D) wants guaranteed non-zero int division at compile-time.\n    return float(idiv(ia, ib, s));\n  } else {\n    return NAN;\n  }\n";
	var INT_DIV_PACKED = "\n  ivec4 ia = round(a);\n  ivec4 ib = round(b);\n  bvec4 cond = notEqual(ib, ivec4(0));\n  ivec4 result = ivec4(0);\n  vec4 s = sign(a) * sign(b);\n\n  // Windows (D3D) wants guaranteed non-zero int division at compile-time.\n  if (cond[0]) {\n    result[0] = idiv(ia[0], ib[0], s[0]);\n  }\n  if (cond[1]) {\n    result[1] = idiv(ia[1], ib[1], s[1]);\n  }\n  if (cond[2]) {\n    result[2] = idiv(ia[2], ib[2], s[2]);\n  }\n  if (cond[3]) {\n    result[3] = idiv(ia[3], ib[3], s[3]);\n  }\n  return vec4(result);\n";
	var floorDiv = binaryKernelFunc({
	  opSnippet: INT_DIV,
	  packedOpSnippet: INT_DIV_PACKED,
	  dtype: 'int32'
	});
	var floorDivConfig = {
	  kernelName: FloorDiv,
	  backendName: 'webgl',
	  kernelFunc: floorDiv
	};

	var FromPixelsProgram = /*#__PURE__*/_createClass(function FromPixelsProgram(outputShape) {
	  _classCallCheck(this, FromPixelsProgram);
	  this.variableNames = ['A'];
	  var glsl = getGlslDifferences();
	  var _outputShape = _slicedToArray(outputShape, 2),
	    height = _outputShape[0],
	    width = _outputShape[1];
	  this.outputShape = outputShape;
	  this.userCode = "\n      void main() {\n        ivec3 coords = getOutputCoords();\n        int texR = coords[0];\n        int texC = coords[1];\n        int depth = coords[2];\n        vec2 uv = (vec2(texC, texR) + halfCR) / vec2(".concat(width, ".0, ").concat(height, ".0);\n\n        vec4 values = ").concat(glsl.texture2D, "(A, uv);\n        float value;\n        if (depth == 0) {\n          value = values.r;\n        } else if (depth == 1) {\n          value = values.g;\n        } else if (depth == 2) {\n          value = values.b;\n        } else if (depth == 3) {\n          value = values.a;\n        }\n\n        setOutput(floor(value * 255.0 + 0.5));\n      }\n    ");
	});

	var FromPixelsPackedProgram = /*#__PURE__*/_createClass(function FromPixelsPackedProgram(outputShape) {
	  _classCallCheck(this, FromPixelsPackedProgram);
	  this.variableNames = ['A'];
	  this.packedInputs = false;
	  this.packedOutput = true;
	  var glsl = getGlslDifferences();
	  var _outputShape = _slicedToArray(outputShape, 2),
	    height = _outputShape[0],
	    width = _outputShape[1];
	  this.outputShape = outputShape;
	  this.userCode = "\n      void main() {\n        ivec3 coords = getOutputCoords();\n        int texR = coords[0];\n        int texC = coords[1];\n        int depth = coords[2];\n\n        vec4 result = vec4(0.);\n\n        for(int row=0; row<=1; row++) {\n          for(int col=0; col<=1; col++) {\n            texC = coords[1] + row;\n            depth = coords[2] + col;\n\n            vec2 uv = (vec2(texC, texR) + halfCR) /\n                       vec2(".concat(width, ".0, ").concat(height, ".0);\n            vec4 values = ").concat(glsl.texture2D, "(A, uv);\n            float value;\n            if (depth == 0) {\n              value = values.r;\n            } else if (depth == 1) {\n              value = values.g;\n            } else if (depth == 2) {\n              value = values.b;\n            } else if (depth == 3) {\n              value = values.a;\n            }\n\n            result[row * 2 + col] = floor(value * 255.0 + 0.5);\n          }\n        }\n\n        ").concat(glsl.output, " = result;\n      }\n    ");
	});

	var fromPixelsConfig = {
	  kernelName: FromPixels,
	  backendName: 'webgl',
	  kernelFunc: fromPixels
	};
	var fromPixels2DContext;
	var willReadFrequently = env().getBool('CANVAS2D_WILL_READ_FREQUENTLY_FOR_GPU');
	function fromPixels(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var pixels = inputs.pixels;
	  var numChannels = attrs.numChannels;
	  var isVideo = typeof HTMLVideoElement !== 'undefined' && pixels instanceof HTMLVideoElement;
	  var isImage = typeof HTMLImageElement !== 'undefined' && pixels instanceof HTMLImageElement;
	  var _ref = isVideo ? [pixels.videoWidth, pixels.videoHeight] : [pixels.width, pixels.height],
	    _ref2 = _slicedToArray(_ref, 2),
	    width = _ref2[0],
	    height = _ref2[1];
	  var texShape = [height, width];
	  var outShape = [height, width, numChannels];
	  if (isImage || isVideo) {
	    var newWillReadFrequently = env().getBool('CANVAS2D_WILL_READ_FREQUENTLY_FOR_GPU');
	    if (fromPixels2DContext == null || newWillReadFrequently !== willReadFrequently) {
	      willReadFrequently = newWillReadFrequently;
	      fromPixels2DContext = document.createElement('canvas').getContext('2d', {
	        willReadFrequently: willReadFrequently
	      });
	    }
	    fromPixels2DContext.canvas.width = width;
	    fromPixels2DContext.canvas.height = height;
	    fromPixels2DContext.drawImage(pixels, 0, 0, width, height);
	    pixels = fromPixels2DContext.canvas;
	  }
	  var tempPixelHandle = backend.makeTensorInfo(texShape, 'int32');
	  // This is a byte texture with pixels.
	  backend.texData.get(tempPixelHandle.dataId).usage = TextureUsage.PIXELS;
	  backend.gpgpu.uploadPixelDataToTexture(backend.getTexture(tempPixelHandle.dataId), pixels);
	  var program = env().getBool('WEBGL_PACK') ? new FromPixelsPackedProgram(outShape) : new FromPixelsProgram(outShape);
	  var res = backend.runWebGLProgram(program, [tempPixelHandle], 'int32');
	  backend.disposeData(tempPixelHandle.dataId);
	  return res;
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function fusedConv2d(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    filter = inputs.filter,
	    bias = inputs.bias,
	    preluActivationWeights = inputs.preluActivationWeights;
	  var strides = attrs.strides,
	    pad = attrs.pad,
	    dataFormat = attrs.dataFormat,
	    dilations = attrs.dilations,
	    dimRoundingMode = attrs.dimRoundingMode,
	    activation = attrs.activation,
	    leakyreluAlpha = attrs.leakyreluAlpha;
	  var $dataFormat = convertConv2DDataFormat(dataFormat);
	  var convInfo = computeConv2DInfo(x.shape, filter.shape, strides, dilations, pad, dimRoundingMode, false /* depthwise */, $dataFormat);
	  var out;
	  var intermediates = [];
	  var hasBias = bias != null;
	  var hasPreluActivationWeights = preluActivationWeights != null;
	  var hasLeakyreluAlpha = activation === 'leakyrelu';
	  var prepareInputs = function prepareInputs() {
	    var inputs = [x, filter];
	    // If the input is a 1-D tensor, align it with the channels.
	    //
	    // For fusedConv2d, the inputs (x, W, bias, preluActivationWeights) are
	    // supposed to be aligned with the dataFormat. The 4-D tensor inputs or
	    // scalar inputs are originally aligned, but the 1-D tensor inputs are
	    // supposed to be aligned with the channels (only bias and PReLU activation
	    // weights could be a 1-D tensor).
	    var alignInputWithDataFormat = function alignInputWithDataFormat(input, dataFormat) {
	      if (dataFormat === 'NCHW' && input.shape.length === 1 && input.shape[0] !== 1) {
	        var alignedInput = reshape({
	          inputs: {
	            x: input
	          },
	          backend: backend,
	          attrs: {
	            shape: [input.shape[0], 1, 1]
	          }
	        });
	        intermediates.push(alignedInput);
	        return alignedInput;
	      }
	      return input;
	    };
	    if (hasBias) {
	      inputs.push(alignInputWithDataFormat(bias, dataFormat));
	    }
	    if (hasPreluActivationWeights) {
	      inputs.push(alignInputWithDataFormat(preluActivationWeights, dataFormat));
	    }
	    if (hasLeakyreluAlpha) {
	      var $leakyreluAlpha = backend.makeTensorInfo([], 'float32', createScalarValue(leakyreluAlpha, 'float32'));
	      inputs.push($leakyreluAlpha);
	      intermediates.push($leakyreluAlpha);
	    }
	    return inputs;
	  };
	  if (convInfo.filterHeight === 1 && convInfo.filterWidth === 1 && convInfo.dilationHeight === 1 && convInfo.dilationWidth === 1 && convInfo.strideHeight === 1 && convInfo.strideWidth === 1 && (convInfo.padInfo.type === 'SAME' || convInfo.padInfo.type === 'VALID')) {
	    out = conv2dByMatMul({
	      x: x,
	      filter: filter,
	      convInfo: convInfo,
	      backend: backend,
	      bias: bias,
	      activation: activation,
	      preluActivationWeights: preluActivationWeights,
	      leakyreluAlpha: leakyreluAlpha
	    });
	  } else if (convInfo.strideWidth <= 2 && $dataFormat === 'channelsLast' && env().getBool('WEBGL_EXP_CONV')) {
	    var fusedActivation = activation ? mapActivationToShaderProgram(activation, true) : null;
	    var program = new Conv2DPackedProgram(convInfo, hasBias, fusedActivation, hasPreluActivationWeights, hasLeakyreluAlpha);
	    var customValues = [[convInfo.padInfo.top, convInfo.padInfo.left], [convInfo.strideHeight, convInfo.strideWidth], [convInfo.dilationHeight, convInfo.dilationWidth], [convInfo.inHeight, convInfo.inWidth]];
	    var _inputs = prepareInputs();
	    out = backend.runWebGLProgram(program, _inputs, 'float32', customValues);
	  } else if (env().getBool('WEBGL_CONV_IM2COL')) {
	    out = conv2dWithIm2Row({
	      x: x,
	      filter: filter,
	      convInfo: convInfo,
	      backend: backend,
	      bias: bias,
	      activation: activation,
	      preluActivationWeights: preluActivationWeights,
	      leakyreluAlpha: leakyreluAlpha
	    });
	  } else {
	    var _fusedActivation = activation ? mapActivationToShaderProgram(activation, false) : null;
	    var _program = new Conv2DProgram(convInfo, hasBias, _fusedActivation, hasPreluActivationWeights, hasLeakyreluAlpha);
	    var _inputs2 = prepareInputs();
	    out = backend.runWebGLProgram(_program, _inputs2, 'float32');
	  }
	  var outReshaped = reshape({
	    inputs: {
	      x: out
	    },
	    backend: backend,
	    attrs: {
	      shape: convInfo.outShape
	    }
	  });
	  intermediates.push(out);
	  intermediates.forEach(function (t) {
	    return backend.disposeIntermediateTensorInfo(t);
	  });
	  return outReshaped;
	}
	var fusedConv2DConfig = {
	  kernelName: FusedConv2D,
	  backendName: 'webgl',
	  kernelFunc: fusedConv2d
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function fusedDepthwiseConv2D(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    filter = inputs.filter,
	    bias = inputs.bias,
	    preluActivationWeights = inputs.preluActivationWeights;
	  var strides = attrs.strides,
	    pad = attrs.pad,
	    dilations = attrs.dilations,
	    dimRoundingMode = attrs.dimRoundingMode,
	    activation = attrs.activation,
	    leakyreluAlpha = attrs.leakyreluAlpha;
	  var intermediates = [];
	  var $dilations = dilations;
	  if ($dilations == null) {
	    $dilations = [1, 1];
	  }
	  assert$1(eitherStridesOrDilationsAreOne(strides, $dilations), function () {
	    return 'Error in depthwiseConv2d: Either strides or dilations must be ' + "1. Got strides ".concat(strides, " and dilations '").concat($dilations, "'");
	  });
	  var convInfo = computeConv2DInfo(x.shape, filter.shape, strides, $dilations, pad, dimRoundingMode, true /* depthwise */);
	  var shouldPackDepthwiseConv = env().getBool('WEBGL_PACK_DEPTHWISECONV') && convInfo.strideWidth <= 2 && convInfo.outChannels / convInfo.inChannels === 1;
	  var fusedActivation = activation ? mapActivationToShaderProgram(activation, shouldPackDepthwiseConv) : null;
	  var programInputs = [x, filter];
	  var hasBias = bias != null;
	  var hasPreluActivationWeights = preluActivationWeights != null;
	  var hasLeakyreluAlpha = activation === 'leakyrelu';
	  if (hasBias) {
	    programInputs.push(bias);
	  }
	  if (hasPreluActivationWeights) {
	    programInputs.push(preluActivationWeights);
	  }
	  if (hasLeakyreluAlpha) {
	    var $leakyreluAlpha = backend.makeTensorInfo([], 'float32', createScalarValue(leakyreluAlpha, 'float32'));
	    programInputs.push($leakyreluAlpha);
	    intermediates.push($leakyreluAlpha);
	  }
	  var program;
	  if (shouldPackDepthwiseConv) {
	    program = new DepthwiseConvPacked2DProgram(convInfo, hasBias, fusedActivation, hasPreluActivationWeights, hasLeakyreluAlpha);
	  } else {
	    program = new DepthwiseConv2DProgram(convInfo, hasBias, fusedActivation, hasPreluActivationWeights, hasLeakyreluAlpha);
	  }
	  var customValues = [[convInfo.padInfo.top, convInfo.padInfo.left], [convInfo.strideHeight, convInfo.strideWidth], [convInfo.dilationHeight, convInfo.dilationWidth], [convInfo.inHeight, convInfo.inWidth]];
	  var result = backend.runWebGLProgram(program, programInputs, 'float32', customValues);
	  intermediates.forEach(function (t) {
	    return backend.disposeIntermediateTensorInfo(t);
	  });
	  return result;
	}
	var fusedDepthwiseConv2DConfig = {
	  kernelName: FusedDepthwiseConv2D,
	  backendName: 'webgl',
	  kernelFunc: fusedDepthwiseConv2D
	};

	var GatherNDProgram = /*#__PURE__*/_createClass(function GatherNDProgram(sliceDim, strides, shape, paramsShape) {
	  _classCallCheck(this, GatherNDProgram);
	  this.sliceDim = sliceDim;
	  this.strides = strides;
	  this.paramsShape = paramsShape;
	  this.variableNames = ['x', 'indices'];
	  this.outputShape = shape;
	  var dtype = getCoordsDataType(shape.length);
	  var mainLoop = "\n    int index;";
	  for (var j = 0; j < this.sliceDim; j++) {
	    mainLoop += "\n          index = round(getIndices(coords[0], ".concat(j, "));\n          out_of_bounds = out_of_bounds || index < 0;\n          out_of_bounds = out_of_bounds || index >= ").concat(this.paramsShape[j], ";\n          flattenIndex += index * ").concat(this.strides[j], ";");
	  }
	  this.userCode = "\n         void main() {\n          ".concat(dtype, " coords = getOutputCoords();\n          int flattenIndex = 0;\n          bool out_of_bounds = false;\n\n          ").concat(mainLoop, "\n\n          setOutput(out_of_bounds ? 0.0 : getX(flattenIndex, coords[1]));\n        }\n      ");
	});

	function gatherNd(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var params = inputs.params,
	    indices = inputs.indices;
	  var indicesShape = indices.shape;
	  var sliceRank = indicesShape[indicesShape.length - 1];
	  var paramsSize = sizeFromShape(params.shape);
	  var _backend_util$prepare = prepareAndValidate(params, indices),
	    _backend_util$prepare2 = _slicedToArray(_backend_util$prepare, 4),
	    resultShape = _backend_util$prepare2[0],
	    numSlices = _backend_util$prepare2[1],
	    sliceSize = _backend_util$prepare2[2],
	    strides = _backend_util$prepare2[3];
	  var flattenIndices = reshape({
	    inputs: {
	      x: indices
	    },
	    backend: backend,
	    attrs: {
	      shape: [numSlices, sliceRank]
	    }
	  });
	  var flattenX = reshape({
	    inputs: {
	      x: params
	    },
	    backend: backend,
	    attrs: {
	      shape: [sizeFromShape(params.shape) / sliceSize, sliceSize]
	    }
	  });
	  if (backend.shouldExecuteOnCPU([params, indices]) || params.dtype === 'string') {
	    var indicesData = backend.readSync(indices.dataId);
	    var paramsBuf = backend.bufferSync(params);
	    var outValue = gatherNdImplCPU(indicesData, paramsBuf, params.dtype, numSlices, sliceRank, sliceSize, strides, params.shape, paramsSize);
	    return backend.makeTensorInfo(resultShape, params.dtype, outValue.values);
	  }
	  var program = new GatherNDProgram(sliceRank, strides, [numSlices, sliceSize], params.shape);
	  var res = backend.runWebGLProgram(program, [flattenX, flattenIndices], flattenX.dtype);
	  var reshaped = reshape({
	    inputs: {
	      x: res
	    },
	    backend: backend,
	    attrs: {
	      shape: resultShape
	    }
	  });
	  backend.disposeIntermediateTensorInfo(flattenIndices);
	  backend.disposeIntermediateTensorInfo(flattenX);
	  backend.disposeIntermediateTensorInfo(res);
	  return reshaped;
	}
	var gatherNdConfig = {
	  kernelName: GatherNd,
	  backendName: 'webgl',
	  kernelFunc: gatherNd
	};

	var GatherProgram = /*#__PURE__*/_createClass(function GatherProgram(aShape, outputShape) {
	  _classCallCheck(this, GatherProgram);
	  this.variableNames = ['A', 'indices'];
	  this.outputShape = outputShape;
	  this.rank = outputShape.length;
	  var dtype = getCoordsDataType(this.rank);
	  var sourceCoords = getSourceCoords$1(aShape, 2);
	  this.userCode = "\n      void main() {\n        ".concat(dtype, " resRC = getOutputCoords();\n        int index = int(getIndices(resRC.x, resRC.z));\n        float inBounds = (index >= 0) && (index < ").concat(aShape[2], ") ? 1.0 : 0.0;\n        setOutput(inBounds * getA(").concat(sourceCoords, "));\n      }\n    ");
	});
	// The input and output are always flattened into rank 4 tensors.
	function getSourceCoords$1(aShape, axis) {
	  var currentCoords = ['resRC.x', 'resRC.y', 'resRC.z', 'resRC.w'];
	  var sourceCoords = [];
	  for (var i = 0; i < aShape.length; i++) {
	    if (i === 2) {
	      sourceCoords.push('index');
	    } else {
	      sourceCoords.push("".concat(currentCoords[i]));
	    }
	  }
	  return sourceCoords.join();
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function gatherV2(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    indices = inputs.indices;
	  var axis = attrs.axis,
	    batchDims = attrs.batchDims;
	  var parsedAxis = parseAxisParam(axis, x.shape)[0];
	  if (env().get('DEBUG')) {
	    // In debug mode, throw error when any index is out of bound.
	    // Otherwise, just fill out of bounds with zeroes.
	    var indicesVals = backend.readSync(indices.dataId);
	    var axisDim = x.shape[parsedAxis];
	    var _loop = function _loop() {
	      var index = indicesVals[i];
	      assert$1(index <= axisDim - 1 && index >= 0, function () {
	        return "GatherV2: the index value ".concat(index, " is not in [0, ").concat(axisDim - 1, "]");
	      });
	    };
	    for (var i = 0; i < indicesVals.length; ++i) {
	      _loop();
	    }
	  }
	  var shapeInfo = collectGatherOpShapeInfo(x, indices, parsedAxis, batchDims);
	  var indicesSize = sizeFromShape(indices.shape);
	  var toDispose = [];
	  var flattenX = reshape({
	    inputs: {
	      x: x
	    },
	    backend: backend,
	    attrs: {
	      shape: [shapeInfo.batchSize, shapeInfo.outerSize, shapeInfo.dimSize, shapeInfo.sliceSize]
	    }
	  });
	  var flattenIndex = reshape({
	    inputs: {
	      x: indices
	    },
	    backend: backend,
	    attrs: {
	      shape: [shapeInfo.batchSize, indicesSize / shapeInfo.batchSize]
	    }
	  });
	  toDispose.push(flattenX);
	  toDispose.push(flattenIndex);
	  var flattenOutputShape = [shapeInfo.batchSize, shapeInfo.outerSize, indicesSize / shapeInfo.batchSize, shapeInfo.sliceSize];
	  if (backend.shouldExecuteOnCPU([x, indices]) || x.dtype === 'string') {
	    var indicesBuf = backend.bufferSync(flattenIndex);
	    var xBuf = backend.bufferSync(flattenX);
	    var outBuf = gatherV2ImplCPU(xBuf, indicesBuf, flattenOutputShape);
	    toDispose.forEach(function (t) {
	      return backend.disposeIntermediateTensorInfo(t);
	    });
	    return backend.makeTensorInfo(shapeInfo.outputShape, outBuf.dtype, outBuf.values);
	  }
	  var program = new GatherProgram(flattenX.shape, flattenOutputShape);
	  var res = backend.runWebGLProgram(program, [flattenX, flattenIndex], flattenX.dtype);
	  toDispose.push(res);
	  var reshaped = reshape({
	    inputs: {
	      x: res
	    },
	    backend: backend,
	    attrs: {
	      shape: shapeInfo.outputShape
	    }
	  });
	  toDispose.forEach(function (t) {
	    return backend.disposeIntermediateTensorInfo(t);
	  });
	  return reshaped;
	}
	var gatherV2Config = {
	  kernelName: GatherV2,
	  backendName: 'webgl',
	  kernelFunc: gatherV2
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var GREATER = "return float(a > b);";
	var GREATER_PACKED = "\n  return vec4(greaterThan(a, b));\n";
	var greater = binaryKernelFunc({
	  opSnippet: GREATER,
	  packedOpSnippet: GREATER_PACKED,
	  cpuKernelImpl: greaterImplCPU,
	  dtype: 'bool'
	});
	var greaterConfig = {
	  kernelName: Greater,
	  backendName: 'webgl',
	  kernelFunc: greater
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var GREATER_EQUAL = "return float(a >= b);";
	var GREATER_EQUAL_PACKED = "\n  return vec4(greaterThanEqual(a, b));\n";
	var greaterEqual = binaryKernelFunc({
	  opSnippet: GREATER_EQUAL,
	  packedOpSnippet: GREATER_EQUAL_PACKED,
	  dtype: 'bool',
	  cpuKernelImpl: greaterEqualImplCPU
	});
	var greaterEqualConfig = {
	  kernelName: GreaterEqual,
	  backendName: 'webgl',
	  kernelFunc: greaterEqual
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function ifft(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var input = inputs.input;
	  return fftImpl(input, true /* inverse */, backend);
	}
	var ifftConfig = {
	  kernelName: IFFT,
	  backendName: 'webgl',
	  kernelFunc: ifft
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var IS_FINITE = "return float(!isnan(x) && !isinf(x));";
	var isFinite$1 = unaryKernelFunc({
	  opSnippet: IS_FINITE,
	  dtype: 'bool'
	});
	var isFiniteConfig = {
	  kernelName: IsFinite,
	  backendName: 'webgl',
	  kernelFunc: isFinite$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var IS_INF = "return float(isinf(x));";
	var isInf = unaryKernelFunc({
	  opSnippet: IS_INF,
	  dtype: 'bool'
	});
	var isInfConfig = {
	  kernelName: IsInf,
	  backendName: 'webgl',
	  kernelFunc: isInf
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var IS_NAN = "return float(isnan(x));";
	var isNaN$1 = unaryKernelFunc({
	  opSnippet: IS_NAN,
	  dtype: 'bool'
	});
	var isNaNConfig = {
	  kernelName: IsNan,
	  backendName: 'webgl',
	  kernelFunc: isNaN$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var LESS = "return float(a < b);";
	var LESS_PACKED = "\n  return vec4(lessThan(a, b));\n";
	var less = binaryKernelFunc({
	  opSnippet: LESS,
	  packedOpSnippet: LESS_PACKED,
	  cpuKernelImpl: lessImplCPU,
	  dtype: 'bool'
	});
	var lessConfig = {
	  kernelName: Less,
	  backendName: 'webgl',
	  kernelFunc: less
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var LESS_EQUAL = "return float(a <= b);";
	var LESS_EQUAL_PACKED = "\n  return vec4(lessThanEqual(a, b));\n";
	var lessEqual = binaryKernelFunc({
	  opSnippet: LESS_EQUAL,
	  packedOpSnippet: LESS_EQUAL_PACKED,
	  cpuKernelImpl: lessEqualImplCPU,
	  dtype: 'bool'
	});
	var lessEqualConfig = {
	  kernelName: LessEqual,
	  backendName: 'webgl',
	  kernelFunc: lessEqual
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function linSpace(args) {
	  var backend = args.backend,
	    attrs = args.attrs;
	  var start = attrs.start,
	    stop = attrs.stop,
	    num = attrs.num;
	  // TODO: Use CPU implementation due to the precision problem in Safari.
	  var outVals = linSpaceImplCPU(start, stop, num);
	  return backend.makeTensorInfo([outVals.length], 'float32', outVals);
	}
	var linSpaceConfig = {
	  kernelName: LinSpace,
	  backendName: 'webgl',
	  kernelFunc: linSpace
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	// Windows chrome return 0 if the input is negative value. We will specifically
	// return NaN if the input is 0 to solve compatiblity issue.
	var LOG = CHECK_NAN_SNIPPET_UNARY + "\n  return x < 0.0 ? 0./0. : log(x);\n";
	var LOG_PACKED = "\n  vec4 result = log(x);\n  bvec4 isNaN = isnan(x);\n  result.r = isNaN.r ? x.r : (x.r < 0.0 ? 0./0. : result.r);\n  result.g = isNaN.g ? x.g : (x.g < 0.0 ? 0./0. : result.g);\n  result.b = isNaN.b ? x.b : (x.b < 0.0 ? 0./0. : result.b);\n  result.a = isNaN.a ? x.a : (x.a < 0.0 ? 0./0. : result.a);\n  return result;\n";
	var log = unaryKernelFunc({
	  opSnippet: LOG,
	  packedOpSnippet: LOG_PACKED,
	  cpuKernelImpl: logImplCPU
	});
	var logConfig = {
	  kernelName: Log,
	  backendName: 'webgl',
	  kernelFunc: log
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var LOG1P = CHECK_NAN_SNIPPET_UNARY + "\n  return log(1.0 + x);\n";
	var log1p = unaryKernelFunc({
	  opSnippet: LOG1P
	});
	var log1pConfig = {
	  kernelName: Log1p,
	  backendName: 'webgl',
	  kernelFunc: log1p
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var LOGICAL_AND = "return float(a >= 1.0 && b >= 1.0);";
	var LOGICAL_AND_PACKED = "\n  return vec4(\n    vec4(greaterThanEqual(a, vec4(1.0))) *\n    vec4(greaterThanEqual(b, vec4(1.0))));\n";
	var logicalAnd = binaryKernelFunc({
	  opSnippet: LOGICAL_AND,
	  packedOpSnippet: LOGICAL_AND_PACKED,
	  dtype: 'bool'
	});
	var logicalAndConfig = {
	  kernelName: LogicalAnd,
	  backendName: 'webgl',
	  kernelFunc: logicalAnd
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var LOGICAL_NOT = "return float(!(x >= 1.0));";
	var logicalNot = unaryKernelFunc({
	  opSnippet: LOGICAL_NOT
	});
	var logicalNotConfig = {
	  kernelName: LogicalNot,
	  backendName: 'webgl',
	  kernelFunc: logicalNot
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var LOGICAL_OR = "return float(a >= 1.0 || b >= 1.0);";
	var LOGICAL_OR_PACKED = "\n  return min(\n    vec4(greaterThanEqual(a, vec4(1.0))) +\n    vec4(greaterThanEqual(b, vec4(1.0))),\n    vec4(1.0));\n";
	var logicalOr = binaryKernelFunc({
	  opSnippet: LOGICAL_OR,
	  packedOpSnippet: LOGICAL_OR_PACKED,
	  dtype: 'bool'
	});
	var logicalOrConfig = {
	  kernelName: LogicalOr,
	  backendName: 'webgl',
	  kernelFunc: logicalOr
	};

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var LRNProgram = /*#__PURE__*/_createClass(function LRNProgram(xShape, radius, bias, alpha, beta) {
	  _classCallCheck(this, LRNProgram);
	  this.variableNames = ['x'];
	  this.outputShape = [];
	  var rad = radius;
	  var maxD = xShape[3] - 1;
	  this.outputShape = xShape;
	  // optimize pow(bias + alpha * sum, -beta)
	  // src: https://github.com/tensorflow/tensorflow/..
	  // blob/26033a1644a9c4a5fbe3170ab2e864b6a4ccd4ca/..
	  // tensorflow/core/kernels/mkl_lrn_op.cc#L320
	  var powOperator;
	  var basis = "float(".concat(bias, ") + float(").concat(alpha, ") * sum");
	  if (beta === 0.5) {
	    powOperator = "inversesqrt(".concat(basis, ")");
	  } else if (beta === 1.0) {
	    powOperator = "1.0/(".concat(basis, ")");
	  } else {
	    powOperator = "exp(log(".concat(basis, ") * float(-").concat(beta, "));");
	  }
	  this.userCode = "\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int b = coords[0];\n        int r = coords[1];\n        int c = coords[2];\n        int d = coords[3];\n        float x = getX(b, r, c, d);\n        float sum = 0.0;\n        for (int j = -".concat(rad, "; j <= ").concat(rad, "; j++) {\n          int idx = d + j;\n          if (idx >= 0 && idx <=  ").concat(maxD, ") {\n            float z = getX(b, r, c, idx);\n            sum += z * z;\n          }\n        }\n        float val = x * ").concat(powOperator, ";\n        setOutput(val);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var LRNPackedProgram = /*#__PURE__*/_createClass(function LRNPackedProgram(xShape, radius, bias, alpha, beta) {
	  _classCallCheck(this, LRNPackedProgram);
	  this.variableNames = ['x'];
	  this.outputShape = [];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  var rad = radius;
	  var maxD = xShape[3] - 1;
	  this.outputShape = xShape;
	  // optimize pow(bias + alpha * sum, -beta)
	  // src: https://github.com/tensorflow/tensorflow/..
	  // blob/26033a1644a9c4a5fbe3170ab2e864b6a4ccd4ca/..
	  // tensorflow/core/kernels/mkl_lrn_op.cc#L320
	  var powOperator;
	  var basis = "float(".concat(bias, ") + float(").concat(alpha, ") * sum");
	  if (beta === 0.5) {
	    powOperator = "inversesqrt(".concat(basis, ")");
	  } else if (beta === 1.0) {
	    powOperator = "1.0/(".concat(basis, ")");
	  } else {
	    powOperator = "exp(log(".concat(basis, ") * float(-").concat(beta, "));");
	  }
	  this.userCode = "\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int b = coords.x;\n        int r = coords.y;\n        int c = coords.z;\n        int d = coords.w;\n\n        bool hasNextCol = d < ".concat(this.outputShape[3], ";\n        bool hasNextRow = c < ").concat(this.outputShape[2], ";\n\n        vec4 sum = vec4(0.);\n        vec4 xFragAtOutputCoords = getX(b, r, c, d);\n\n        vec4 xAtOutputCoords = vec4(\n          getChannel(xFragAtOutputCoords, vec2(c, d)),\n          hasNextCol ?\n            getChannel(xFragAtOutputCoords, vec2(c, d + 1)) : 0.0,\n          hasNextRow ?\n            getChannel(xFragAtOutputCoords , vec2(c + 1, d)) : 0.0,\n          (hasNextRow && hasNextCol) ?\n            getChannel(xFragAtOutputCoords, vec2(c + 1, d + 1)) : 0.0\n        );\n\n        int firstChannel = d - ").concat(rad, ";\n        vec2 cache = vec2(0.);\n        if(firstChannel >= 0){\n          vec4 firstChannelFrag = getX(b, r, c, firstChannel);\n          cache.x = getChannel(firstChannelFrag, vec2(c, firstChannel));\n            if(hasNextRow){\n              cache.y = getChannel(firstChannelFrag, vec2(c + 1, firstChannel));\n            }\n        }\n\n        ivec2 depth = ivec2(d, d + 1);\n        for (int j = - ").concat(rad, "; j <= ").concat(rad, "; j++) {\n          ivec2 idx = depth + j;\n          bvec2 aboveLowerBound = greaterThanEqual(idx, ivec2(0));\n          bvec2 belowUpperBound = lessThanEqual(idx, ivec2(").concat(maxD, "));\n\n          bool depthInRange = aboveLowerBound.x && belowUpperBound.x;\n          bool depthPlusOneInRange = aboveLowerBound.y && belowUpperBound.y;\n\n          if(depthInRange || depthPlusOneInRange){\n            vec4 z = vec4(0.);\n            vec4 xFragAtCurrentDepth;\n            z.xz = cache.xy;\n            if(depthPlusOneInRange && hasNextCol){\n              xFragAtCurrentDepth = idx.y != d ?\n                getX(b, r, c, idx.y) : xFragAtOutputCoords;\n              z.y = getChannel(xFragAtCurrentDepth, vec2(c, idx.y));\n              if(hasNextRow){\n                z.w = getChannel(xFragAtCurrentDepth, vec2(c + 1, idx.y));\n              }\n            }\n            cache.xy = z.yw;\n            sum += z * z;\n          }\n        }\n        vec4 result = xAtOutputCoords * ").concat(powOperator, ";\n        setOutput(result);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var lrn = function lrn(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var depthRadius = attrs.depthRadius,
	    bias = attrs.bias,
	    alpha = attrs.alpha,
	    beta = attrs.beta;
	  var program = env().getBool('WEBGL_PACK_NORMALIZATION') ? new LRNPackedProgram(x.shape, depthRadius, bias, alpha, beta) : new LRNProgram(x.shape, depthRadius, bias, alpha, beta);
	  return backend.runWebGLProgram(program, [x], x.dtype);
	};
	// tslint:disable-next-line: variable-name
	var LRNConfig = {
	  kernelName: LRN,
	  backendName: 'webgl',
	  kernelFunc: lrn
	};

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var LRNGradProgram = /*#__PURE__*/_createClass(function LRNGradProgram(inputShape, depthRadius, bias, alpha, beta) {
	  _classCallCheck(this, LRNGradProgram);
	  this.variableNames = ['inputImage', 'outputImage', 'dy'];
	  this.outputShape = [];
	  this.outputShape = inputShape;
	  this.depth = inputShape[3];
	  this.depthRadius = depthRadius;
	  this.bias = bias;
	  this.alpha = alpha;
	  this.beta = beta;
	  this.userCode = "\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int b = coords[0];\n        int r = coords[1];\n        int c = coords[2];\n\n        float result = 0.0;\n        for (int d = 0; d < ".concat(this.depth, "; ++d) {\n          int depthBegin = int(max(0.0, float(d - ").concat(depthRadius, ")));\n          int depthEnd = int(min(float(").concat(this.depth, "),\n              float(d + ").concat(depthRadius, " + 1)));\n\n          const int MIN_DEPTH_BEGIN = 0;\n          const int MAX_DEPTH_END = ").concat(this.depth, ";\n\n          float norm = 0.0;\n          for (int k = MIN_DEPTH_BEGIN; k < MAX_DEPTH_END; ++k) {\n            if (k < depthBegin){\n              continue;\n            }\n            else if (k >= depthBegin && k < depthEnd) {\n              norm += getInputImage(b, r, c, k) * getInputImage(b, r, c, k);\n            }\n            else {\n              break;\n            }\n          }\n\n          norm = float(").concat(alpha, ") * norm + float(").concat(bias, ");\n\n          for(int k = MIN_DEPTH_BEGIN; k < MAX_DEPTH_END; ++k){\n            if (k < depthBegin){\n              continue;\n            }\n            else if (k >= depthBegin && k < depthEnd){\n              float dyi = -2.0 * float(").concat(alpha, ")\n                * float(").concat(beta, ")\n                * getInputImage(b, r, c, k) * getOutputImage(b, r, c, d)\n                / norm;\n              if (k == d) {\n                dyi += pow(norm, -1.0 * ").concat(beta, ");\n              }\n              if (k == coords[3]) {\n                dyi *= getDy(b, r, c, d);\n                result += dyi;\n              }\n            }\n            else {\n              break;\n            }\n          }\n      }\n      setOutput(result);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var lrnGrad = function lrnGrad(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    y = inputs.y,
	    dy = inputs.dy;
	  var depthRadius = attrs.depthRadius,
	    bias = attrs.bias,
	    alpha = attrs.alpha,
	    beta = attrs.beta;
	  var program = new LRNGradProgram(x.shape, depthRadius, bias, alpha, beta);
	  return backend.runWebGLProgram(program, [x, y, dy], x.dtype);
	};
	// tslint:disable-next-line: variable-name
	var LRNGradConfig = {
	  kernelName: LRNGrad,
	  backendName: 'webgl',
	  kernelFunc: lrnGrad
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function maxImpl(x, reduceShape, outShape, backend) {
	  var inSize = sizeFromShape(reduceShape);
	  var xSize = sizeFromShape(x.shape);
	  var batchSize = xSize / inSize;
	  var reshapedInput = reshape({
	    inputs: {
	      x: x
	    },
	    attrs: {
	      shape: [batchSize, inSize]
	    },
	    backend: backend
	  });
	  var reduced = reduce(reshapedInput, x.dtype, 'max', backend);
	  var reshapedOutput = reshape({
	    inputs: {
	      x: reduced
	    },
	    attrs: {
	      shape: outShape
	    },
	    backend: backend
	  });
	  backend.disposeIntermediateTensorInfo(reshapedInput);
	  backend.disposeIntermediateTensorInfo(reduced);
	  return reshapedOutput;
	}

	function max(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var reductionIndices = attrs.reductionIndices,
	    keepDims = attrs.keepDims;
	  var xRank = x.shape.length;
	  var origAxes = parseAxisParam(reductionIndices, x.shape);
	  var axes = origAxes;
	  var permutedAxes = getAxesPermutation(axes, xRank);
	  var maxInputIsTransposed = permutedAxes != null;
	  var shouldExecuteOnCPU = backend.shouldExecuteOnCPU([x]);
	  var maxInput = x;
	  if (maxInputIsTransposed) {
	    if (shouldExecuteOnCPU) {
	      var xTexData = backend.texData.get(maxInput.dataId);
	      var values = xTexData.values;
	      var newShape = new Array(xRank);
	      for (var i = 0; i < newShape.length; i++) {
	        newShape[i] = x.shape[permutedAxes[i]];
	      }
	      var maxInputValues = transposeImplCPU(values, x.shape, x.dtype, permutedAxes, newShape);
	      maxInput = backend.makeTensorInfo(newShape, x.dtype);
	      var maxInputData = backend.texData.get(maxInput.dataId);
	      maxInputData.values = maxInputValues;
	    } else {
	      maxInput = transposeImpl(x, permutedAxes, backend);
	    }
	    axes = getInnerMostAxes(axes.length, xRank);
	  }
	  assertAxesAreInnerMostDims('max', axes, xRank);
	  var _backend_util$compute = computeOutAndReduceShapes(maxInput.shape, axes),
	    _backend_util$compute2 = _slicedToArray(_backend_util$compute, 2),
	    maxOutShape = _backend_util$compute2[0],
	    reduceShape = _backend_util$compute2[1];
	  var outShape = maxOutShape;
	  if (keepDims) {
	    // rather than reshape at the end, set the target shape here.
	    outShape = expandShapeToKeepDim(maxOutShape, origAxes);
	  }
	  var out;
	  if (shouldExecuteOnCPU) {
	    var _xTexData = backend.texData.get(maxInput.dataId);
	    var _values = _xTexData.values;
	    var outValues = maxImplCPU(_values, sizeFromShape(reduceShape), outShape, x.dtype);
	    out = backend.makeTensorInfo(outShape, x.dtype);
	    var outData = backend.texData.get(out.dataId);
	    outData.values = outValues;
	  } else {
	    out = maxImpl(maxInput, reduceShape, outShape, backend);
	  }
	  if (maxInputIsTransposed) {
	    backend.disposeIntermediateTensorInfo(maxInput);
	  }
	  return out;
	}
	var maxConfig = {
	  kernelName: Max,
	  backendName: 'webgl',
	  kernelFunc: max
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var MAXIMUM = CHECK_NAN_SNIPPET + "\n  return max(a, b);\n";
	var MAXIMUM_PACKED = "\n  vec4 result = vec4(max(a, b));\n  bvec4 isNaNA = isnan(a);\n  bvec4 isNaNB = isnan(b);\n  bvec4 isNaN = bvec4(isNaNA.x || isNaNB.x, isNaNA.y || isNaNB.y, isNaNA.z || isNaNB.z, isNaNA.w || isNaNB.w);\n  " + CHECK_NAN_SNIPPET_PACKED + "\n  return result;\n";
	var maximum = binaryKernelFunc({
	  opSnippet: MAXIMUM,
	  packedOpSnippet: MAXIMUM_PACKED,
	  cpuKernelImpl: maximumImplCPU
	});
	var maximumConfig = {
	  kernelName: Maximum$1,
	  backendName: 'webgl',
	  kernelFunc: maximum
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function maxPool(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  assertNotComplex(x, 'maxPool');
	  var filterSize = attrs.filterSize,
	    strides = attrs.strides,
	    pad = attrs.pad,
	    dimRoundingMode = attrs.dimRoundingMode;
	  var dilations = 1;
	  assert$1(eitherStridesOrDilationsAreOne(strides, dilations), function () {
	    return 'Error in maxPool: Either strides or dilations must be 1. ' + "Got strides ".concat(strides, " and dilations '").concat(dilations, "'");
	  });
	  var convInfo = computePool2DInfo(x.shape, filterSize, strides, dilations, pad, dimRoundingMode);
	  if (convInfo.filterWidth === 1 && convInfo.filterHeight === 1 && arraysEqual(convInfo.inShape, convInfo.outShape)) {
	    return identity({
	      inputs: {
	        x: x
	      },
	      backend: backend
	    });
	  }
	  var maxPoolProgram = new Pool2DProgram(convInfo, 'max', false);
	  return backend.runWebGLProgram(maxPoolProgram, [x], x.dtype);
	}
	var maxPoolConfig = {
	  kernelName: MaxPool,
	  backendName: 'webgl',
	  kernelFunc: maxPool
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function maxPool3d(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var filterSize = attrs.filterSize,
	    strides = attrs.strides,
	    pad = attrs.pad,
	    dataFormat = attrs.dataFormat,
	    dimRoundingMode = attrs.dimRoundingMode;
	  var dilations = [1, 1, 1];
	  var convInfo = computePool3DInfo(x.shape, filterSize, strides, dilations, pad, dimRoundingMode, dataFormat);
	  var maxPoolProgram = new Pool3DProgram(convInfo, 'max', false);
	  return backend.runWebGLProgram(maxPoolProgram, [x], x.dtype);
	}
	var maxPool3DConfig = {
	  kernelName: MaxPool3D,
	  backendName: 'webgl',
	  kernelFunc: maxPool3d
	};

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var MaxPool2DBackpropProgram = /*#__PURE__*/_createClass(function MaxPool2DBackpropProgram(convInfo) {
	  _classCallCheck(this, MaxPool2DBackpropProgram);
	  this.variableNames = ['dy', 'maxPos'];
	  this.outputShape = convInfo.inShape;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var dilationHeight = convInfo.dilationHeight;
	  var effectiveFilterHeight = convInfo.effectiveFilterHeight;
	  var effectiveFilterWidth = convInfo.effectiveFilterWidth;
	  var padTop = effectiveFilterHeight - 1 - convInfo.padInfo.top;
	  var padLeft = effectiveFilterWidth - 1 - convInfo.padInfo.left;
	  var lastIndex = effectiveFilterHeight * effectiveFilterWidth - 1;
	  this.userCode = "\n      const ivec2 pads = ivec2(".concat(padTop, ", ").concat(padLeft, ");\n\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int b = coords[0];\n        int d = coords[3];\n\n        ivec2 dyRCCorner = coords.yz - pads;\n        int dyRCorner = dyRCCorner.x;\n        int dyCCorner = dyRCCorner.y;\n\n        // Convolve dy(?, ?, d) with pos mask(:, :, d) to get dx(xR, xC, d).\n        // ? = to be determined. : = across all values in that axis.\n        float dotProd = 0.0;\n        for (int wR = 0; wR < ").concat(effectiveFilterHeight, ";\n          wR += ").concat(dilationHeight, ") {\n          float dyR = float(dyRCorner + wR) / ").concat(strideHeight, ".0;\n\n          if (dyR < 0.0 || dyR >= ").concat(convInfo.outHeight, ".0 || fract(dyR) > 0.0) {\n            continue;\n          }\n          int idyR = int(dyR);\n\n          for (int wC = 0; wC < ").concat(effectiveFilterWidth, "; wC++) {\n            float dyC = float(dyCCorner + wC) / ").concat(strideWidth, ".0;\n\n            if (dyC < 0.0 || dyC >= ").concat(convInfo.outWidth, ".0 ||\n                fract(dyC) > 0.0) {\n              continue;\n            }\n            int idyC = int(dyC);\n\n            float dyValue = getDy(b, idyR, idyC, d);\n            int maxPosValue = ").concat(lastIndex, " - int(getMaxPos(b, idyR, idyC, d));\n\n            // Get the current value, check it against the value from the\n            // position matrix.\n            int curPosValue = wR * ").concat(effectiveFilterWidth, " + wC;\n            float mask = float(maxPosValue == curPosValue ? 1.0 : 0.0);\n\n            dotProd += dyValue * mask;\n          }\n        }\n        setOutput(dotProd);\n      }\n    ");
	});
	var MaxPool3DBackpropProgram = /*#__PURE__*/_createClass(function MaxPool3DBackpropProgram(convInfo) {
	  _classCallCheck(this, MaxPool3DBackpropProgram);
	  this.variableNames = ['dy', 'maxPos'];
	  this.outputShape = convInfo.inShape;
	  var strideDepth = convInfo.strideDepth;
	  var strideHeight = convInfo.strideHeight;
	  var strideWidth = convInfo.strideWidth;
	  var dilationDepth = convInfo.dilationDepth;
	  var dilationHeight = convInfo.dilationHeight;
	  var dilationWidth = convInfo.dilationWidth;
	  var effectiveFilterDepth = convInfo.effectiveFilterDepth;
	  var effectiveFilterHeight = convInfo.effectiveFilterHeight;
	  var effectiveFilterWidth = convInfo.effectiveFilterWidth;
	  var padFront = effectiveFilterDepth - 1 - convInfo.padInfo.front;
	  var padTop = effectiveFilterHeight - 1 - convInfo.padInfo.top;
	  var padLeft = effectiveFilterWidth - 1 - convInfo.padInfo.left;
	  var lastIndex = effectiveFilterDepth * effectiveFilterHeight * effectiveFilterWidth - 1;
	  this.userCode = "\n      const ivec3 pads = ivec3(".concat(padFront, ", ").concat(padTop, ", ").concat(padLeft, ");\n\n      void main() {\n        ivec5 coords = getOutputCoords();\n        int batch = coords.x;\n        int ch = coords.u;\n\n        ivec3 dyCorner = ivec3(coords.y, coords.z, coords.w) - pads;\n        int dyDCorner = dyCorner.x;\n        int dyRCorner = dyCorner.y;\n        int dyCCorner = dyCorner.z;\n\n        // Convolve dy(?, ?, ?, ch) with pos mask(:, :, :, d) to get\n        // dx(xD, xR, xC, ch).\n        // ? = to be determined. : = across all values in that axis.\n        float dotProd = 0.0;\n\n        for (int wD = 0; wD < ").concat(effectiveFilterDepth, ";\n           wD += ").concat(dilationDepth, ") {\n          float dyD = float(dyDCorner + wD) / ").concat(strideDepth, ".0;\n\n          if (dyD < 0.0 || dyD >= ").concat(convInfo.outDepth, ".0 || fract(dyD) > 0.0) {\n            continue;\n          }\n          int idyD = int(dyD);\n\n          for (int wR = 0; wR < ").concat(effectiveFilterHeight, ";\n              wR += ").concat(dilationHeight, ") {\n            float dyR = float(dyRCorner + wR) / ").concat(strideHeight, ".0;\n\n            if (dyR < 0.0 || dyR >= ").concat(convInfo.outHeight, ".0 ||\n                fract(dyR) > 0.0) {\n              continue;\n            }\n            int idyR = int(dyR);\n\n            for (int wC = 0; wC < ").concat(effectiveFilterWidth, ";\n                wC += ").concat(dilationWidth, ") {\n              float dyC = float(dyCCorner + wC) / ").concat(strideWidth, ".0;\n\n              if (dyC < 0.0 || dyC >= ").concat(convInfo.outWidth, ".0 ||\n                  fract(dyC) > 0.0) {\n                continue;\n              }\n              int idyC = int(dyC);\n\n              float dyValue = getDy(batch, idyD, idyR, idyC, ch);\n              int maxPosValue = ").concat(lastIndex, " -\n                  int(getMaxPos(batch, idyD, idyR, idyC, ch));\n\n              // Get the current value, check it against the value from the\n              // position matrix.\n              int curPosValue =\n                  wD * ").concat(effectiveFilterHeight, " * ").concat(effectiveFilterWidth, " +\n                  wR * ").concat(effectiveFilterWidth, " + wC;\n              float mask = float(maxPosValue == curPosValue ? 1.0 : 0.0);\n\n              dotProd += dyValue * mask;\n            }\n          }\n        }\n        setOutput(dotProd);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function maxPool3DGrad(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var dy = inputs.dy,
	    input = inputs.input;
	  var x = input;
	  var filterSize = attrs.filterSize,
	    strides = attrs.strides,
	    pad = attrs.pad,
	    dimRoundingMode = attrs.dimRoundingMode;
	  var dilations = [1, 1, 1];
	  var convInfo = computePool3DInfo(x.shape, filterSize, strides, dilations, pad, dimRoundingMode);
	  var maxPool3dPositionsProgram = new Pool3DProgram(convInfo, 'max', true /* get positions */);
	  var maxPool3dPositions = backend.runWebGLProgram(maxPool3dPositionsProgram, [x], x.dtype);
	  var maxPoolBackpropProgram = new MaxPool3DBackpropProgram(convInfo);
	  var result = backend.runWebGLProgram(maxPoolBackpropProgram, [dy, maxPool3dPositions], x.dtype);
	  backend.disposeIntermediateTensorInfo(maxPool3dPositions);
	  return result;
	}
	var maxPool3DGradConfig = {
	  kernelName: MaxPool3DGrad,
	  backendName: 'webgl',
	  kernelFunc: maxPool3DGrad
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function maxPoolGrad(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var dy = inputs.dy,
	    input = inputs.input,
	    output = inputs.output;
	  var x = input;
	  assertNotComplex([input, output], 'maxPoolGrad');
	  var filterSize = attrs.filterSize,
	    strides = attrs.strides,
	    pad = attrs.pad,
	    dimRoundingMode = attrs.dimRoundingMode;
	  var convInfo = computePool2DInfo(x.shape, filterSize, strides, 1 /* dilations */, pad, dimRoundingMode);
	  var getPositions = true;
	  var maxPoolPositionsProgram = new Pool2DProgram(convInfo, 'max', getPositions);
	  var maxPoolPositions = backend.runWebGLProgram(maxPoolPositionsProgram, [x], x.dtype);
	  var maxPoolBackPropProgram = new MaxPool2DBackpropProgram(convInfo);
	  var result = backend.runWebGLProgram(maxPoolBackPropProgram, [dy, maxPoolPositions], x.dtype);
	  backend.disposeIntermediateTensorInfo(maxPoolPositions);
	  return result;
	}
	var maxPoolGradConfig = {
	  kernelName: MaxPoolGrad,
	  backendName: 'webgl',
	  kernelFunc: maxPoolGrad
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function maxPoolWithArgmaxImpl(x, includeBatchInIndex, convInfo, backend) {
	  var program = new Pool2DProgram(convInfo, 'max', false);
	  var poolOutput = backend.runWebGLProgram(program, [x], 'float32');
	  program = new Pool2DProgram(convInfo, 'max', true, true, includeBatchInIndex);
	  var indexOutput = backend.runWebGLProgram(program, [x], 'float32');
	  return [poolOutput, indexOutput];
	}

	var maxPoolWithArgmaxConfig = {
	  kernelName: MaxPoolWithArgmax,
	  backendName: 'webgl',
	  kernelFunc: function kernelFunc(_ref) {
	    var inputs = _ref.inputs,
	      attrs = _ref.attrs,
	      backend = _ref.backend;
	    var x = inputs.x;
	    var filterSize = attrs.filterSize,
	      strides = attrs.strides,
	      pad = attrs.pad,
	      includeBatchInIndex = attrs.includeBatchInIndex;
	    var webglBackend = backend;
	    assert$1(x.shape.length === 4, function () {
	      return "Error in maxPool: input must be rank 4 but got rank ".concat(x.shape.length, ".");
	    });
	    var dilations = [1, 1];
	    assert$1(eitherStridesOrDilationsAreOne(strides, dilations), function () {
	      return 'Error in maxPool: Either strides or dilations must be 1. ' + "Got strides ".concat(strides, " and dilations '").concat(dilations, "'");
	    });
	    var convInfo = computePool2DInfo(x.shape, filterSize, strides, dilations, pad);
	    var _maxPoolWithArgmaxImp = maxPoolWithArgmaxImpl(x, includeBatchInIndex, convInfo, webglBackend),
	      _maxPoolWithArgmaxImp2 = _slicedToArray(_maxPoolWithArgmaxImp, 2),
	      result = _maxPoolWithArgmaxImp2[0],
	      indexes = _maxPoolWithArgmaxImp2[1];
	    return [result, indexes];
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function meanImpl(x, reduceShape, outShape, backend) {
	  var inSize = sizeFromShape(reduceShape);
	  var xSize = sizeFromShape(x.shape);
	  var batchSize = xSize / inSize;
	  var reshapedInput = reshape({
	    inputs: {
	      x: x
	    },
	    attrs: {
	      shape: [batchSize, inSize]
	    },
	    backend: backend
	  });
	  var reduced = reduce(reshapedInput, 'float32', 'mean', backend);
	  var reshapedOutput = reshape({
	    inputs: {
	      x: reduced
	    },
	    attrs: {
	      shape: outShape
	    },
	    backend: backend
	  });
	  backend.disposeIntermediateTensorInfo(reshapedInput);
	  backend.disposeIntermediateTensorInfo(reduced);
	  return reshapedOutput;
	}

	var meanConfig = {
	  kernelName: Mean,
	  backendName: 'webgl',
	  kernelFunc: function kernelFunc(_ref) {
	    var inputs = _ref.inputs,
	      attrs = _ref.attrs,
	      backend = _ref.backend;
	    var x = inputs.x;
	    var keepDims = attrs.keepDims,
	      axis = attrs.axis;
	    var webglBackend = backend;
	    var xRank = x.shape.length;
	    var origAxes = parseAxisParam(axis, x.shape);
	    var axes = origAxes;
	    var permutedAxes = getAxesPermutation(axes, xRank);
	    var meanInputIsTransposed = permutedAxes != null;
	    var shouldExecuteOnCPU = webglBackend.shouldExecuteOnCPU([x]);
	    var intermediates = [];
	    var meanInput = x;
	    if (meanInputIsTransposed) {
	      if (shouldExecuteOnCPU) {
	        var xTexData = webglBackend.texData.get(meanInput.dataId);
	        var values = xTexData.values;
	        var newShape = new Array(xRank);
	        for (var i = 0; i < newShape.length; i++) {
	          newShape[i] = x.shape[permutedAxes[i]];
	        }
	        var meanInputValues = transposeImplCPU(values, x.shape, x.dtype, permutedAxes, newShape);
	        meanInput = webglBackend.makeTensorInfo(newShape, x.dtype);
	        var meanInputData = webglBackend.texData.get(meanInput.dataId);
	        meanInputData.values = meanInputValues;
	      } else {
	        meanInput = transposeImpl(x, permutedAxes, webglBackend);
	      }
	      intermediates.push(meanInput);
	      axes = getInnerMostAxes(axes.length, xRank);
	    }
	    assertAxesAreInnerMostDims('sum', axes, xRank);
	    var _backend_util$compute = computeOutAndReduceShapes(meanInput.shape, axes),
	      _backend_util$compute2 = _slicedToArray(_backend_util$compute, 2),
	      meanOutShape = _backend_util$compute2[0],
	      reduceShape = _backend_util$compute2[1];
	    var outShape = meanOutShape;
	    if (keepDims) {
	      // rather than reshape at the end, set the target shape here.
	      outShape = expandShapeToKeepDim(meanOutShape, origAxes);
	    }
	    var out = meanImpl(meanInput, reduceShape, outShape, webglBackend);
	    for (var _i = 0, _intermediates = intermediates; _i < _intermediates.length; _i++) {
	      var _i2 = _intermediates[_i];
	      webglBackend.disposeIntermediateTensorInfo(_i2);
	    }
	    return out;
	  }
	};

	function min(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis,
	    keepDims = attrs.keepDims;
	  var xRank = x.shape.length;
	  var origAxes = parseAxisParam(axis, x.shape);
	  var axes = origAxes;
	  var permutedAxes = getAxesPermutation(axes, xRank);
	  var permutedX = x;
	  if (permutedAxes != null) {
	    permutedX = transpose({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        perm: permutedAxes
	      }
	    });
	    axes = getInnerMostAxes(axes.length, x.shape.length);
	  }
	  assertAxesAreInnerMostDims('min', axes, xRank);
	  var _backend_util$compute = computeOutAndReduceShapes(permutedX.shape, axes),
	    _backend_util$compute2 = _slicedToArray(_backend_util$compute, 2),
	    outShape = _backend_util$compute2[0],
	    reduceShape = _backend_util$compute2[1];
	  var inSize = sizeFromShape(reduceShape);
	  var a2D = reshape({
	    inputs: {
	      x: permutedX
	    },
	    backend: backend,
	    attrs: {
	      shape: [-1, inSize]
	    }
	  });
	  var reduced = reduce(a2D, a2D.dtype, 'min', backend);
	  var res;
	  if (keepDims) {
	    var newShape = expandShapeToKeepDim(outShape, origAxes);
	    res = reshape({
	      inputs: {
	        x: reduced
	      },
	      backend: backend,
	      attrs: {
	        shape: newShape
	      }
	    });
	  } else {
	    res = reshape({
	      inputs: {
	        x: reduced
	      },
	      backend: backend,
	      attrs: {
	        shape: outShape
	      }
	    });
	  }
	  backend.disposeIntermediateTensorInfo(a2D);
	  backend.disposeIntermediateTensorInfo(reduced);
	  if (permutedAxes != null) {
	    backend.disposeIntermediateTensorInfo(permutedX);
	  }
	  return res;
	}
	var minConfig = {
	  kernelName: Min,
	  backendName: 'webgl',
	  kernelFunc: min
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var MINIMUM = CHECK_NAN_SNIPPET + "\n  return min(a, b);\n";
	var MINIMUM_PACKED = "\n  vec4 result = vec4(min(a, b));\n  bvec4 isNaNA = isnan(a);\n  bvec4 isNaNB = isnan(b);\n  bvec4 isNaN = bvec4(isNaNA.x || isNaNB.x, isNaNA.y || isNaNB.y, isNaNA.z || isNaNB.z, isNaNA.w || isNaNB.w);\n  " + CHECK_NAN_SNIPPET_PACKED + "\n  return result;\n";
	var minimum = binaryKernelFunc({
	  opSnippet: MINIMUM,
	  packedOpSnippet: MINIMUM_PACKED,
	  cpuKernelImpl: minimumImplCPU
	});
	var minimumConfig = {
	  kernelName: Minimum$1,
	  backendName: 'webgl',
	  kernelFunc: minimum
	};

	var MirrorPadProgram = /*#__PURE__*/_createClass(function MirrorPadProgram(xShape, paddings, mode) {
	  _classCallCheck(this, MirrorPadProgram);
	  this.variableNames = ['x'];
	  this.outputShape = paddings.map(function (p, i) {
	    return p[0] /* beforePad */ + xShape[i] + p[1];
	  } /* afterPad */);
	  var rank = xShape.length;
	  var dtype = getCoordsDataType(rank);
	  var start = paddings.map(function (p) {
	    return p[0];
	  }).join(',');
	  var end = paddings.map(function (p, i) {
	    return p[0] + xShape[i];
	  }).join(',');
	  var unpackedCoords = ['coords[0]', 'coords[1]', 'coords[2]', 'coords[3]'].slice(0, rank);
	  var offset = mode === 'reflect' ? 0 : 1;
	  if (rank === 1) {
	    this.userCode = "\n        int start = ".concat(start, ";\n        int end = ").concat(end, ";\n\n        void main() {\n          int outC = getOutputCoords();\n          if (outC < start) {\n            outC = start * 2 - outC - ").concat(offset, ";\n          } else if(outC >= end) {\n            outC = (end - 1) * 2 - outC + ").concat(offset, ";\n          }\n          setOutput(getX(outC - start));\n        }\n      ");
	    return;
	  }
	  this.userCode = "\n      ".concat(dtype, " start = ").concat(dtype, "(").concat(start, ");\n      ").concat(dtype, " end = ").concat(dtype, "(").concat(end, ");\n\n      void main() {\n        ").concat(dtype, " outC = getOutputCoords();\n        for (int i = 0; i < ").concat(rank, "; i++) {\n          if (outC[i] < start[i]) {\n            outC[i] = start[i] * 2 - outC[i] - ").concat(offset, ";\n          } else if(outC[i] >= end[i]) {\n            outC[i] = (end[i] - 1) * 2 - outC[i] + ").concat(offset, ";\n          }\n        }\n        ").concat(dtype, " coords = outC - start;\n        setOutput(getX(").concat(unpackedCoords, "));\n      }\n    ");
	});

	/**
	 * Example shader code for
	 * `mirrorPad(tf.tensor1d([1, 2, 3], 'int32'), [[2, 2]], 'reflect')`
	 * ```
	 *    const int start = int(2);
	 *    const int end = int(5);
	 *
	 *    void main() {
	 *       int outputLoc = getOutputCoords();
	 *       vec4 result = vec4(0.);
	 *
	 *       int rc = outputLoc;
	 *
	 *       int source = rc;
	 *       if (source < start) {
	 *         source = start * 2 - source - 0;
	 *       } else if (source >= end) {
	 *         source = (end - 1) * 2 - source + 0;
	 *       }
	 *       source -= start;
	 *
	 *       result[0] = getChannel(getX(source), source);
	 *       rc += 1;
	 *       if(rc < 6) {
	 *          int source = rc;
	 *          if (source < start) {
	 *            source = start * 2 - source - 0;
	 *          } else if (source >= end) {
	 *            source = (end - 1) * 2 - source + 0;
	 *          }
	 *          source -= start;
	 *
	 *         result[1] = getChannel(getX(source), source);
	 *       }
	 *
	 *       setOutput(result);
	 *     }
	 * ```
	 */
	var MirrorPadPackedProgram = /*#__PURE__*/_createClass(function MirrorPadPackedProgram(xShape, paddings, mode) {
	  _classCallCheck(this, MirrorPadPackedProgram);
	  this.variableNames = ['x'];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.outputShape = paddings.map(function (p, i) {
	    return p[0] /* beforePad */ + xShape[i] + p[1];
	  } /* afterPad */);
	  var rank = xShape.length;
	  var dtype = getCoordsDataType(rank);
	  var start = paddings.map(function (p) {
	    return p[0];
	  }).join(',');
	  var end = paddings.map(function (p, i) {
	    return p[0] + xShape[i];
	  }).join(',');
	  var coords = getChannels('rc', rank);
	  var source = getChannels('source', rank);
	  var cLimit = "".concat(coords[rank - 1], " < ").concat(this.outputShape[rank - 1]);
	  var innerDims = rank === 1 ? 'source' : "vec2(".concat(source.slice(-2).join(), ")");
	  var offset = mode === 'reflect' ? 0 : 1;
	  var mainLoop = '';
	  if (rank === 1) {
	    var padSetup = "\n        ".concat(dtype, " source = rc;\n        if (source < start) {\n          source = start * 2 - source - ").concat(offset, ";\n        } else if (source >= end) {\n          source = (end - 1) * 2 - source + ").concat(offset, ";\n        }\n        source -= start;\n      ");
	    mainLoop = "\n        ".concat(dtype, " rc = outputLoc;\n        ").concat(padSetup, "\n        result[0] = getChannel(getX(").concat(source.join(), "), ").concat(innerDims, ");\n        ").concat(coords[rank - 1], " += 1;\n        if(").concat(cLimit, ") {\n          ").concat(padSetup, "\n          result[1] = getChannel(getX(").concat(source.join(), "), ").concat(innerDims, ");\n        }\n      ");
	  } else {
	    var _padSetup = "\n        ".concat(dtype, " source = rc;\n        ").concat(dtype, " lt = ").concat(dtype, "(lessThan(source, start));\n        ").concat(dtype, " gte = ").concat(dtype, "(greaterThanEqual(source, end));\n        ").concat(dtype, " orig = 1 - (lt + gte);\n        source = orig * source +\n                lt * (start * 2 - source - ").concat(offset, ") +\n                gte * ((end - 1) * 2 - source + ").concat(offset, ");\n        source -= start;\n      ");
	    mainLoop = "\n        ".concat(dtype, " rc = outputLoc;\n        ").concat(_padSetup, "\n        result[0] = getChannel(getX(").concat(source.join(), "), ").concat(innerDims, ");\n        ").concat(coords[rank - 1], " += 1;\n        if(").concat(cLimit, ") {\n          ").concat(_padSetup, "\n          result[1] = getChannel(getX(").concat(source.join(), "), ").concat(innerDims, ");\n        }\n        rc = outputLoc;\n        ").concat(coords[rank - 2], " += 1;\n        if(").concat(coords[rank - 2], " < ").concat(this.outputShape[rank - 2], ") {\n          ").concat(_padSetup, "\n          result[2] = getChannel(getX(").concat(source.join(), "), ").concat(innerDims, ");\n          ").concat(coords[rank - 1], " += 1;\n          if(").concat(cLimit, ") {\n            ").concat(_padSetup, "\n            result[3] = getChannel(getX(").concat(source.join(), "), ").concat(innerDims, ");\n          }\n        }\n      ");
	  }
	  this.userCode = "\n      const ".concat(dtype, " start = ").concat(dtype, "(").concat(start, ");\n      const ").concat(dtype, " end = ").concat(dtype, "(").concat(end, ");\n\n      void main() {\n        ").concat(dtype, " outputLoc = getOutputCoords();\n        vec4 result = vec4(0.);\n        ").concat(mainLoop, "\n        setOutput(result);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var mirrorPadKernelFunc = function mirrorPadKernelFunc(_ref) {
	  var inputs = _ref.inputs,
	    backend = _ref.backend,
	    attrs = _ref.attrs;
	  var x = inputs.x;
	  var paddings = attrs.paddings,
	    mode = attrs.mode;
	  var program = env().getBool('WEBGL_PACK_ARRAY_OPERATIONS') ? new MirrorPadPackedProgram(x.shape, paddings, mode) : new MirrorPadProgram(x.shape, paddings, mode);
	  var output = backend.runWebGLProgram(program, [x], x.dtype);
	  return output;
	};
	var mirrorPadConfig = {
	  kernelName: MirrorPad,
	  backendName: 'webgl',
	  kernelFunc: mirrorPadKernelFunc
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var MOD = "if (b == 0.0) return NAN;\n  return mod(a, b);";
	var MOD_PACKED = "\n  vec4 result = mod(a, b);\n  bvec4 isNaN = equal(b, vec4(0.0));\n  " + CHECK_NAN_SNIPPET_PACKED + "\n  return result;\n";
	var mod = binaryKernelFunc({
	  opSnippet: MOD,
	  packedOpSnippet: MOD_PACKED
	});
	var modConfig = {
	  kernelName: Mod,
	  backendName: 'webgl',
	  kernelFunc: mod
	};

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var MultinomialProgram = /*#__PURE__*/_createClass(function MultinomialProgram(batchSize, numOutcomes, numSamples) {
	  _classCallCheck(this, MultinomialProgram);
	  this.variableNames = ['probs'];
	  this.customUniforms = [{
	    name: 'seed',
	    type: 'float'
	  }];
	  this.outputShape = [batchSize, numSamples];
	  this.userCode = "\n      void main() {\n        ivec2 coords = getOutputCoords();\n        int batch = coords[0];\n\n        float r = random(seed);\n        float cdf = 0.0;\n\n        for (int i = 0; i < ".concat(numOutcomes - 1, "; i++) {\n          cdf += getProbs(batch, i);\n\n          if (r < cdf) {\n            setOutput(float(i));\n            return;\n          }\n        }\n\n        // If no other event happened, last event happened.\n        setOutput(float(").concat(numOutcomes - 1, "));\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	// Without the equality check div produces 0.9999 for a = b, which when
	// floored can cause errors.
	var DIV = "\nif (a == b) {\n  return 1.0;\n};\nreturn a / b;";
	// We do the same as in ./binaryop_gpu, with vec4 and ivec4.
	// On Linux, the vectorized implementation produces NaNs when a and b are 0.
	var DIV_PACKED = "\n  // vec4 one = vec4(equal(a, b));\n  // return one + (vec4(1.0) - one) * a / b;\n  vec4 result = a / b;\n  if(a.x == b.x) {\n    result.x = 1.;\n  }\n  if(a.y == b.y) {\n    result.y = 1.;\n  }\n  if(a.z == b.z) {\n    result.z = 1.;\n  }\n  if(a.w == b.w) {\n    result.w = 1.;\n  }\n\n  return result;\n";
	var realDiv = binaryKernelFunc({
	  opSnippet: DIV,
	  packedOpSnippet: DIV_PACKED,
	  checkOutOfBounds: true
	});
	var realDivConfig = {
	  kernelName: RealDiv,
	  backendName: 'webgl',
	  kernelFunc: realDiv
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var SUB = 'return a - b;';
	var sub = binaryKernelFunc({
	  opSnippet: SUB,
	  packedOpSnippet: SUB,
	  supportsComplex: true,
	  cpuKernelImpl: subImplCPU
	});
	var subConfig = {
	  kernelName: Sub,
	  backendName: 'webgl',
	  kernelFunc: sub
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function softmax(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var logits = inputs.logits;
	  var dim = attrs.dim;
	  var axes = parseAxisParam([dim], logits.shape);
	  var maxLogit = max({
	    inputs: {
	      x: logits
	    },
	    backend: backend,
	    attrs: {
	      reductionIndices: axes,
	      keepDims: false
	    }
	  });
	  var expandedShape = expandShapeToKeepDim(maxLogit.shape, axes);
	  var maxLogitsReshaped = reshape({
	    inputs: {
	      x: maxLogit
	    },
	    backend: backend,
	    attrs: {
	      shape: expandedShape
	    }
	  });
	  var a = sub({
	    inputs: {
	      a: logits,
	      b: maxLogitsReshaped
	    },
	    backend: backend
	  });
	  var b = exp({
	    inputs: {
	      x: a
	    },
	    backend: backend
	  });
	  var sumExp = sum({
	    inputs: {
	      x: b
	    },
	    backend: backend,
	    attrs: {
	      axis: axes,
	      keepDims: false
	    }
	  });
	  var sumExpReshaped = reshape({
	    inputs: {
	      x: sumExp
	    },
	    backend: backend,
	    attrs: {
	      shape: expandedShape
	    }
	  });
	  var res = realDiv({
	    inputs: {
	      a: b,
	      b: sumExpReshaped
	    },
	    backend: backend
	  });
	  backend.disposeIntermediateTensorInfo(maxLogit);
	  backend.disposeIntermediateTensorInfo(maxLogitsReshaped);
	  backend.disposeIntermediateTensorInfo(a);
	  backend.disposeIntermediateTensorInfo(b);
	  backend.disposeIntermediateTensorInfo(sumExp);
	  backend.disposeIntermediateTensorInfo(sumExpReshaped);
	  return res;
	}
	var softmaxConfig = {
	  kernelName: Softmax$2,
	  backendName: 'webgl',
	  kernelFunc: softmax
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function multinomial(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var logits = inputs.logits;
	  var numSamples = attrs.numSamples,
	    seed = attrs.seed,
	    normalized = attrs.normalized;
	  var probs = normalized ? logits : softmax({
	    inputs: {
	      logits: logits
	    },
	    backend: backend,
	    attrs: {
	      dim: logits.shape.length - 1
	    }
	  });
	  var batchSize = probs.shape[0];
	  var numOutcomes = probs.shape[1];
	  var program = new MultinomialProgram(batchSize, numOutcomes, numSamples);
	  var customValues = [[seed]];
	  var res = backend.runWebGLProgram(program, [probs], 'int32', customValues);
	  if (!normalized) {
	    backend.disposeIntermediateTensorInfo(probs);
	  }
	  return res;
	}
	var multinomialConfig = {
	  kernelName: Multinomial,
	  backendName: 'webgl',
	  kernelFunc: multinomial
	};

	var NEG = CHECK_NAN_SNIPPET$1 + "\n  return -x;\n";
	var NEG_PACKED = "\n  vec4 result = -x;\n  bvec4 isNaN = isnan(x);\n\n  result.r = isNaN.r ? x.r : result.r;\n  result.g = isNaN.g ? x.g : result.g;\n  result.b = isNaN.b ? x.b : result.b;\n  result.a = isNaN.a ? x.a : result.a;\n\n  return result;\n";
	// This doesn't use unaryKernelFunc because negImplCPU is not of type
	// SimpleUnaryKernelImplCPU.
	function neg(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var x = inputs.x;
	  if (backend.shouldExecuteOnCPU([x])) {
	    var xData = backend.texData.get(x.dataId);
	    var _negImplCPU = negImplCPU(xData.values, x.shape, x.dtype),
	      _negImplCPU2 = _slicedToArray(_negImplCPU, 2),
	      outValues = _negImplCPU2[0],
	      newShape = _negImplCPU2[1];
	    return backend.makeTensorInfo(newShape, x.dtype, outValues);
	  }
	  var program;
	  if (env().getBool('WEBGL_PACK_UNARY_OPERATIONS')) {
	    program = new UnaryOpPackedProgram(x.shape, NEG_PACKED);
	  } else {
	    program = new UnaryOpProgram(x.shape, NEG);
	  }
	  return backend.runWebGLProgram(program, [x], x.dtype);
	}
	var negConfig = {
	  kernelName: Neg,
	  backendName: 'webgl',
	  kernelFunc: neg
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var nonMaxSuppressionV3Impl = nonMaxSuppressionV3Impl$2;
	function nonMaxSuppressionV3(args) {
	  warn('tf.nonMaxSuppression() in webgl locks the UI thread. ' + 'Call tf.nonMaxSuppressionAsync() instead');
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var boxes = inputs.boxes,
	    scores = inputs.scores;
	  var maxOutputSize = attrs.maxOutputSize,
	    iouThreshold = attrs.iouThreshold,
	    scoreThreshold = attrs.scoreThreshold;
	  var boxesVals = backend.readSync(boxes.dataId);
	  var scoresVals = backend.readSync(scores.dataId);
	  var _nonMaxSuppressionV3I = nonMaxSuppressionV3Impl(boxesVals, scoresVals, maxOutputSize, iouThreshold, scoreThreshold),
	    selectedIndices = _nonMaxSuppressionV3I.selectedIndices;
	  return backend.makeTensorInfo([selectedIndices.length], 'int32', new Int32Array(selectedIndices));
	}
	var nonMaxSuppressionV3Config = {
	  kernelName: NonMaxSuppressionV3,
	  backendName: 'webgl',
	  kernelFunc: nonMaxSuppressionV3
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var nonMaxSuppressionV4Impl = nonMaxSuppressionV4Impl$2;
	function nonMaxSuppressionV4(args) {
	  warn('tf.nonMaxSuppression() in webgl locks the UI thread. ' + 'Call tf.nonMaxSuppressionAsync() instead');
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var boxes = inputs.boxes,
	    scores = inputs.scores;
	  var maxOutputSize = attrs.maxOutputSize,
	    iouThreshold = attrs.iouThreshold,
	    scoreThreshold = attrs.scoreThreshold,
	    padToMaxOutputSize = attrs.padToMaxOutputSize;
	  var boxesVals = backend.readSync(boxes.dataId);
	  var scoresVals = backend.readSync(scores.dataId);
	  var _nonMaxSuppressionV4I = nonMaxSuppressionV4Impl(boxesVals, scoresVals, maxOutputSize, iouThreshold, scoreThreshold, padToMaxOutputSize),
	    selectedIndices = _nonMaxSuppressionV4I.selectedIndices,
	    validOutputs = _nonMaxSuppressionV4I.validOutputs;
	  return [backend.makeTensorInfo([selectedIndices.length], 'int32', new Int32Array(selectedIndices)), backend.makeTensorInfo([], 'int32', new Int32Array([validOutputs]))];
	}
	var nonMaxSuppressionV4Config = {
	  kernelName: NonMaxSuppressionV4,
	  backendName: 'webgl',
	  kernelFunc: nonMaxSuppressionV4
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var nonMaxSuppressionV5Impl = nonMaxSuppressionV5Impl$2;
	function nonMaxSuppressionV5(args) {
	  warn('tf.nonMaxSuppression() in webgl locks the UI thread. ' + 'Call tf.nonMaxSuppressionAsync() instead');
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var boxes = inputs.boxes,
	    scores = inputs.scores;
	  var maxOutputSize = attrs.maxOutputSize,
	    iouThreshold = attrs.iouThreshold,
	    scoreThreshold = attrs.scoreThreshold,
	    softNmsSigma = attrs.softNmsSigma;
	  var boxesVals = backend.readSync(boxes.dataId);
	  var scoresVals = backend.readSync(scores.dataId);
	  var maxOutputSizeVal = maxOutputSize;
	  var iouThresholdVal = iouThreshold;
	  var scoreThresholdVal = scoreThreshold;
	  var softNmsSigmaVal = softNmsSigma;
	  var _nonMaxSuppressionV5I = nonMaxSuppressionV5Impl(boxesVals, scoresVals, maxOutputSizeVal, iouThresholdVal, scoreThresholdVal, softNmsSigmaVal),
	    selectedIndices = _nonMaxSuppressionV5I.selectedIndices,
	    selectedScores = _nonMaxSuppressionV5I.selectedScores;
	  return [backend.makeTensorInfo([selectedIndices.length], 'int32', new Int32Array(selectedIndices)), backend.makeTensorInfo([selectedScores.length], 'float32', new Float32Array(selectedScores))];
	}
	var nonMaxSuppressionV5Config = {
	  kernelName: NonMaxSuppressionV5,
	  backendName: 'webgl',
	  kernelFunc: nonMaxSuppressionV5
	};

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var OneHotProgram = /*#__PURE__*/_createClass(function OneHotProgram(numIndices, depth, onValue, offValue) {
	  _classCallCheck(this, OneHotProgram);
	  this.variableNames = ['indices'];
	  this.outputShape = [numIndices, depth];
	  this.userCode = "\n      void main() {\n        ivec2 coords = getOutputCoords();\n        int index = round(getIndices(coords.x));\n        setOutput(mix(float(".concat(offValue, "), float(").concat(onValue, "),\n                      float(index == coords.y)));\n      }\n    ");
	});

	var oneHot = function oneHot(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var indices = inputs.indices;
	  var dtype = attrs.dtype,
	    depth = attrs.depth,
	    onValue = attrs.onValue,
	    offValue = attrs.offValue;
	  var indicesSize = sizeFromShape(indices.shape);
	  var program = new OneHotProgram(indicesSize, depth, onValue, offValue);
	  var reshaped = reshape({
	    inputs: {
	      x: indices
	    },
	    backend: backend,
	    attrs: {
	      shape: [indicesSize]
	    }
	  });
	  var result = backend.runWebGLProgram(program, [reshaped], dtype);
	  backend.disposeIntermediateTensorInfo(reshaped);
	  var outShape = [].concat(_toConsumableArray(indices.shape), [depth]);
	  var out = reshape({
	    inputs: {
	      x: result
	    },
	    backend: backend,
	    attrs: {
	      shape: outShape
	    }
	  });
	  backend.disposeIntermediateTensorInfo(result);
	  return out;
	};
	var oneHotConfig = {
	  kernelName: OneHot,
	  backendName: 'webgl',
	  kernelFunc: oneHot
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function zerosLike(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var x = inputs.x;
	  if (x.dtype === 'complex64') {
	    var realPart = real({
	      inputs: {
	        input: x
	      },
	      backend: backend
	    });
	    var r = zerosLike({
	      inputs: {
	        x: realPart
	      },
	      backend: backend
	    });
	    var imagPart = imag({
	      inputs: {
	        input: x
	      },
	      backend: backend
	    });
	    var i = zerosLike({
	      inputs: {
	        x: imagPart
	      },
	      backend: backend
	    });
	    var result = complex({
	      inputs: {
	        real: r,
	        imag: i
	      },
	      backend: backend
	    });
	    backend.disposeIntermediateTensorInfo(realPart);
	    backend.disposeIntermediateTensorInfo(r);
	    backend.disposeIntermediateTensorInfo(imagPart);
	    backend.disposeIntermediateTensorInfo(i);
	    return result;
	  } else {
	    return fill({
	      attrs: {
	        shape: x.shape,
	        dtype: x.dtype,
	        value: x.dtype === 'string' ? '' : 0
	      },
	      backend: backend
	    });
	  }
	}
	var zerosLikeConfig = {
	  kernelName: ZerosLike,
	  backendName: 'webgl',
	  kernelFunc: zerosLike
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function onesLike(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var x = inputs.x;
	  if (x.dtype === 'string') {
	    throw new Error('onesLike is not supported under string dtype');
	  } else if (x.dtype === 'complex64') {
	    var realPart = real({
	      inputs: {
	        input: x
	      },
	      backend: backend
	    });
	    var r = onesLike({
	      inputs: {
	        x: realPart
	      },
	      backend: backend
	    });
	    var imagPart = imag({
	      inputs: {
	        input: x
	      },
	      backend: backend
	    });
	    var i = zerosLike({
	      inputs: {
	        x: imagPart
	      },
	      backend: backend
	    });
	    var result = complex({
	      inputs: {
	        real: r,
	        imag: i
	      },
	      backend: backend
	    });
	    backend.disposeIntermediateTensorInfo(realPart);
	    backend.disposeIntermediateTensorInfo(r);
	    backend.disposeIntermediateTensorInfo(imagPart);
	    backend.disposeIntermediateTensorInfo(i);
	    return result;
	  } else {
	    // TODO(cais, smilkov): Add WebGL shader for onesLike:
	    //   https://github.com/tensorflow/tfjs/issues/1293
	    return fill({
	      attrs: {
	        shape: x.shape,
	        dtype: x.dtype,
	        value: 1
	      },
	      backend: backend
	    });
	  }
	}
	var onesLikeConfig = {
	  kernelName: OnesLike,
	  backendName: 'webgl',
	  kernelFunc: onesLike
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function pack(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var axis = attrs.axis;
	  if (inputs.length === 1) {
	    return expandDims({
	      inputs: {
	        input: inputs[0]
	      },
	      backend: backend,
	      attrs: {
	        dim: axis
	      }
	    });
	  }
	  var shape = inputs[0].shape;
	  var dtype = inputs[0].dtype;
	  inputs.forEach(function (t) {
	    assertShapesMatch(shape, t.shape, 'All tensors passed to stack must have matching shapes');
	    assert$1(dtype === t.dtype, function () {
	      return 'All tensors passed to stack must have matching dtypes';
	    });
	  });
	  var intermediateTensorInfos = [];
	  var expandedTensors = inputs.map(function (t) {
	    var expandedT = expandDims({
	      inputs: {
	        input: t
	      },
	      backend: backend,
	      attrs: {
	        dim: axis
	      }
	    });
	    intermediateTensorInfos.push(expandedT);
	    return expandedT;
	  });
	  var result = concat({
	    inputs: expandedTensors,
	    backend: backend,
	    attrs: {
	      axis: axis
	    }
	  });
	  intermediateTensorInfos.forEach(function (t) {
	    return backend.disposeIntermediateTensorInfo(t);
	  });
	  return result;
	}
	var packConfig = {
	  kernelName: Pack,
	  backendName: 'webgl',
	  kernelFunc: pack
	};

	var PadProgram = /*#__PURE__*/_createClass(function PadProgram(xShape, paddings, constantValue) {
	  _classCallCheck(this, PadProgram);
	  this.variableNames = ['x'];
	  this.customUniforms = [{
	    name: 'value',
	    type: 'float'
	  }];
	  this.outputShape = paddings.map(function (p, i) {
	    return p[0] /* beforePad */ + xShape[i] + p[1];
	  } /* afterPad */);
	  var rank = xShape.length;
	  var type = getCoordsDataType(rank);
	  var start = paddings.map(function (p) {
	    return p[0];
	  }).join(',');
	  var end = paddings.map(function (p, i) {
	    return p[0] + xShape[i];
	  }).join(',');
	  var unpackedCoords = ['coords[0]', 'coords[1]', 'coords[2]', 'coords[3]'].slice(0, rank);
	  if (rank === 1) {
	    this.userCode = "\n        int start = ".concat(start, ";\n        int end = ").concat(end, ";\n\n        void main() {\n          int outC = getOutputCoords();\n          if (outC < start || outC >= end) {\n            setOutput(value);\n          } else {\n            setOutput(getX(outC - start));\n          }\n        }\n      ");
	    return;
	  }
	  this.userCode = "\n      ".concat(type, " start = ").concat(type, "(").concat(start, ");\n      ").concat(type, " end = ").concat(type, "(").concat(end, ");\n\n      void main() {\n        ").concat(type, " outC = getOutputCoords();\n        if (any(lessThan(outC, start)) || any(greaterThanEqual(outC, end))) {\n          setOutput(value);\n        } else {\n          ").concat(type, " coords = outC - start;\n          setOutput(getX(").concat(unpackedCoords, "));\n        }\n      }\n    ");
	});

	var PadPackedProgram = /*#__PURE__*/_createClass(function PadPackedProgram(xShape, paddings, constantValue) {
	  _classCallCheck(this, PadPackedProgram);
	  this.variableNames = ['x'];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.customUniforms = [{
	    name: 'value',
	    type: 'float'
	  }];
	  this.outputShape = paddings.map(function (p, i) {
	    return p[0] /* beforePad */ + xShape[i] + p[1];
	  } /* afterPad */);
	  var rank = xShape.length;
	  var dtype = getCoordsDataType(rank);
	  var start = paddings.map(function (p) {
	    return p[0];
	  }).join(',');
	  var end = paddings.map(function (p, i) {
	    return p[0] + xShape[i];
	  }).join(',');
	  var coords = getChannels('rc', rank);
	  var source = getChannels('source', rank);
	  var cLimit = "".concat(coords[rank - 1], " < ").concat(this.outputShape[rank - 1]);
	  var innerDims = rank === 1 ? 'source' : "vec2(".concat(source.slice(-2).join(), ")");
	  var componentSetup = ["".concat(dtype, " rc = outputLoc;"), "".concat(coords[rank - 1], " += 1;\n       if(").concat(cLimit, ") {\n      "), rank === 1 ? '' : "}\n       rc = outputLoc;\n       ".concat(coords[rank - 2], " += 1;\n       if(").concat(coords[rank - 2], " < ").concat(this.outputShape[rank - 2], ") {"), rank === 1 ? '' : "  ".concat(coords[rank - 1], " += 1;\n         if(").concat(cLimit, ") {")];
	  var paddingArea = rank === 1 ? 'rc < start || rc >= end' : 'any(lessThan(rc, start)) || any(greaterThanEqual(rc, end))';
	  var mainLoop = '';
	  for (var i = 0, j = rank === 1 ? 2 : 4; i < j; i++) {
	    mainLoop += "\n        ".concat(componentSetup[i], "\n        if (").concat(paddingArea, ") {\n          result[").concat(i, "] = float(value);\n        } else {\n          ").concat(dtype, " source = rc - start;\n          result[").concat(i, "] = getChannel(getX(").concat(source.join(), "), ").concat(innerDims, ");\n        }\n      ");
	  }
	  mainLoop += rank === 1 ? "} " : "}}";
	  this.userCode = "\n      const ".concat(dtype, " start = ").concat(dtype, "(").concat(start, ");\n      const ").concat(dtype, " end = ").concat(dtype, "(").concat(end, ");\n\n      void main() {\n        ").concat(dtype, " outputLoc = getOutputCoords();\n        vec4 result = vec4(0.);\n        ").concat(mainLoop, "\n        setOutput(result);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var padV2 = function padV2(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var paddings = attrs.paddings,
	    constantValue = attrs.constantValue;
	  if (sizeFromShape(x.shape) === 0) {
	    // Short-circuit the computation, since x doesn't have value, only
	    // the shape is used to compute output shape to pad.
	    var outputShape = paddings.map(function (p, i) {
	      return p[0] /* beforePad */ + x.shape[i] + p[1];
	    } /* afterPad */);
	    return fill({
	      backend: backend,
	      attrs: {
	        shape: outputShape,
	        value: constantValue,
	        dtype: x.dtype
	      }
	    });
	  }
	  var program = env().getBool('WEBGL_PACK_ARRAY_OPERATIONS') ? new PadPackedProgram(x.shape, paddings, constantValue) : new PadProgram(x.shape, paddings, constantValue);
	  var customValues = [[constantValue]];
	  return backend.runWebGLProgram(program, [x], x.dtype, customValues);
	};
	var padV2Config = {
	  kernelName: PadV2,
	  backendName: 'webgl',
	  kernelFunc: padV2
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var POW = "\n  if(a < 0.0 && floor(b) < b){\n    return NAN;\n  }\n  if (b == 0.0) {\n    return 1.0;\n  }\n  return (round(mod(b, 2.0)) != 1) ?\n      pow(abs(a), b) : sign(a) * pow(abs(a), b);\n";
	var POW_PACKED = "\n  // isModRound1 has 1 for components with round(mod(b, 2.0)) == 1, 0 otherwise.\n  vec4 isModRound1 = vec4(equal(round(mod(b, 2.0)), ivec4(1)));\n  vec4 multiplier = sign(a) * isModRound1 + (vec4(1.0) - isModRound1);\n  vec4 result = multiplier * pow(abs(a), b);\n\n  // Ensure that a^0 = 1, including 0^0 = 1 as this correspond to TF and JS\n  bvec4 isExpZero = equal(b, vec4(0.0));\n  result.r = isExpZero.r ? 1.0 : result.r;\n  result.g = isExpZero.g ? 1.0 : result.g;\n  result.b = isExpZero.b ? 1.0 : result.b;\n  result.a = isExpZero.a ? 1.0 : result.a;\n\n  bvec4 isNaN1 = lessThan(a, vec4(0.0));\n  bvec4 isNaN2 = lessThan(floor(b), b);\n  bvec4 isNaN = bvec4(isNaN1.x && isNaN2.x, isNaN1.y && isNaN2.y, isNaN1.z && isNaN2.z, isNaN1.w && isNaN2.w);\n  " + CHECK_NAN_SNIPPET_PACKED + "\n  return result;\n";
	var pow = binaryKernelFunc({
	  opSnippet: POW,
	  packedOpSnippet: POW_PACKED
	});
	var powConfig = {
	  kernelName: Pow,
	  backendName: 'webgl',
	  kernelFunc: pow
	};

	function prod(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var axis = attrs.axis,
	    keepDims = attrs.keepDims;
	  var xRank = x.shape.length;
	  var toDispose = [];
	  var origAxes = parseAxisParam(axis, x.shape);
	  var axes = origAxes;
	  var permutedAxes = getAxesPermutation(axes, xRank);
	  var permutedX = x;
	  if (permutedAxes != null) {
	    permutedX = transpose({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        perm: permutedAxes
	      }
	    });
	    axes = getInnerMostAxes(axes.length, xRank);
	    toDispose.push(permutedX);
	  }
	  assertAxesAreInnerMostDims('prod', axes, xRank);
	  var res;
	  if (backend.shouldExecuteOnCPU([permutedX])) {
	    var xVals = backend.texData.get(permutedX.dataId).values;
	    var _prodImplCPU = prodImplCPU(permutedX.shape, permutedX.dtype, xVals, axes),
	      outVals = _prodImplCPU.outVals,
	      outShape = _prodImplCPU.outShape,
	      outDtype = _prodImplCPU.outDtype;
	    res = backend.makeTensorInfo(outShape, outDtype, outVals);
	  } else {
	    var _backend_util$compute = computeOutAndReduceShapes(permutedX.shape, axes),
	      _backend_util$compute2 = _slicedToArray(_backend_util$compute, 2),
	      _outShape = _backend_util$compute2[0],
	      reduceShape = _backend_util$compute2[1];
	    var inSize = sizeFromShape(reduceShape);
	    var a2D = reshape({
	      inputs: {
	        x: permutedX
	      },
	      backend: backend,
	      attrs: {
	        shape: [-1, inSize]
	      }
	    });
	    var outputDType = sumOutType(x.dtype);
	    var reduced = reduce(a2D, outputDType, 'prod', backend);
	    res = reshape({
	      inputs: {
	        x: reduced
	      },
	      backend: backend,
	      attrs: {
	        shape: _outShape
	      }
	    });
	    toDispose.push(a2D);
	    toDispose.push(reduced);
	  }
	  if (keepDims) {
	    toDispose.push(res);
	    var newShape = expandShapeToKeepDim(res.shape, origAxes);
	    res = reshape({
	      inputs: {
	        x: res
	      },
	      backend: backend,
	      attrs: {
	        shape: newShape
	      }
	    });
	  }
	  toDispose.forEach(function (t) {
	    return backend.disposeIntermediateTensorInfo(t);
	  });
	  return res;
	}
	var prodConfig = {
	  kernelName: Prod,
	  backendName: 'webgl',
	  kernelFunc: prod
	};

	function raggedGather(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var paramsNestedSplits = inputs.paramsNestedSplits,
	    paramsDenseValues = inputs.paramsDenseValues,
	    indices = inputs.indices;
	  var outputRaggedRank = attrs.outputRaggedRank;
	  var $paramsNestedSplits = paramsNestedSplits.map(function (t) {
	    return backend.readSync(t.dataId);
	  });
	  var $paramsNestedSplitsShapes = paramsNestedSplits.map(function (t) {
	    return t.shape;
	  });
	  var $paramsDenseValues = backend.readSync(paramsDenseValues.dataId);
	  var $indices = backend.readSync(indices.dataId);
	  var _raggedGatherImplCPU = raggedGatherImplCPU($paramsNestedSplits, $paramsNestedSplitsShapes, $paramsDenseValues, paramsDenseValues.shape, paramsDenseValues.dtype, $indices, indices.shape, outputRaggedRank),
	    _raggedGatherImplCPU2 = _slicedToArray(_raggedGatherImplCPU, 3),
	    outputNestedSplits = _raggedGatherImplCPU2[0],
	    outputDenseValues = _raggedGatherImplCPU2[1],
	    outputDenseValuesShape = _raggedGatherImplCPU2[2];
	  var outputNestedSplitsTensors = outputNestedSplits.map(function (splits) {
	    return backend.makeTensorInfo([splits.length], 'int32', splits);
	  });
	  var outputDenseValuesTensor = backend.makeTensorInfo(outputDenseValuesShape, paramsDenseValues.dtype, outputDenseValues);
	  return outputNestedSplitsTensors.concat([outputDenseValuesTensor]);
	}
	var raggedGatherConfig = {
	  kernelName: RaggedGather,
	  backendName: 'webgl',
	  kernelFunc: raggedGather
	};

	function raggedRange(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var starts = inputs.starts,
	    limits = inputs.limits,
	    deltas = inputs.deltas;
	  var $starts = backend.readSync(starts.dataId);
	  var $limits = backend.readSync(limits.dataId);
	  var $deltas = backend.readSync(deltas.dataId);
	  var _raggedRangeImplCPU = raggedRangeImplCPU($starts, starts.shape, starts.dtype, $limits, limits.shape, $deltas, deltas.shape),
	    _raggedRangeImplCPU2 = _slicedToArray(_raggedRangeImplCPU, 2),
	    rtNestedSplitsData = _raggedRangeImplCPU2[0],
	    rtDenseValuesData = _raggedRangeImplCPU2[1];
	  var rtNestedSplits = backend.makeTensorInfo([rtNestedSplitsData.length], 'int32', rtNestedSplitsData);
	  var rtDenseValues = backend.makeTensorInfo([rtDenseValuesData.length], starts.dtype, rtDenseValuesData);
	  return [rtNestedSplits, rtDenseValues];
	}
	var raggedRangeConfig = {
	  kernelName: RaggedRange,
	  backendName: 'webgl',
	  kernelFunc: raggedRange
	};

	function raggedTensorToTensor(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var shape = inputs.shape,
	    values = inputs.values,
	    defaultValue = inputs.defaultValue,
	    rowPartitionTensors = inputs.rowPartitionTensors;
	  var rowPartitionTypes = attrs.rowPartitionTypes;
	  var $shape = backend.readSync(shape.dataId);
	  var $values = backend.readSync(values.dataId);
	  var $defaultValue = backend.readSync(defaultValue.dataId);
	  var $rowPartitionValues = rowPartitionTensors.map(function (t) {
	    return backend.readSync(t.dataId);
	  });
	  var rowPartitionValuesShapes = rowPartitionTensors.map(function (t) {
	    return t.shape;
	  });
	  var _raggedTensorToTensor = raggedTensorToTensorImplCPU($shape, shape.shape, $values, values.shape, values.dtype, $defaultValue, defaultValue.shape, $rowPartitionValues, rowPartitionValuesShapes, rowPartitionTypes),
	    _raggedTensorToTensor2 = _slicedToArray(_raggedTensorToTensor, 2),
	    outputShape = _raggedTensorToTensor2[0],
	    output = _raggedTensorToTensor2[1];
	  return backend.makeTensorInfo(outputShape, values.dtype, output);
	}
	var raggedTensorToTensorConfig = {
	  kernelName: RaggedTensorToTensor,
	  backendName: 'webgl',
	  kernelFunc: raggedTensorToTensor
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var range = function range(args) {
	  var backend = args.backend,
	    attrs = args.attrs;
	  var start = attrs.start,
	    stop = attrs.stop,
	    step = attrs.step,
	    dtype = attrs.dtype;
	  var values = rangeImplCPU(start, stop, step, dtype);
	  return backend.makeTensorInfo([values.length], dtype, values);
	};
	var rangeConfig = {
	  kernelName: Range,
	  backendName: 'webgl',
	  kernelFunc: range
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var RECIPROCAL = "return 1.0 / x;";
	var reciprocal = unaryKernelFunc({
	  opSnippet: RECIPROCAL
	});
	var reciprocalConfig = {
	  kernelName: Reciprocal,
	  backendName: 'webgl',
	  kernelFunc: reciprocal
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var RELU = CHECK_NAN_SNIPPET$1 + "\n  return (x < 0.0) ? 0.0 : x;\n";
	var RELU_PACKED = "\n  vec4 result = x * vec4(greaterThanEqual(x, vec4(0.0)));\n  bvec4 isNaN = isnan(x);\n\n  result.r = isNaN.r ? x.r : result.r;\n  result.g = isNaN.g ? x.g : result.g;\n  result.b = isNaN.b ? x.b : result.b;\n  result.a = isNaN.a ? x.a : result.a;\n\n  return result;\n";
	var relu = unaryKernelFunc({
	  opSnippet: RELU,
	  packedOpSnippet: RELU_PACKED
	});
	var reluConfig = {
	  kernelName: Relu$1,
	  backendName: 'webgl',
	  kernelFunc: relu
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var RELU6 = CHECK_NAN_SNIPPET$1 + "\n  return (x < 0.0) ? 0.0 : min(6.0, x);\n";
	var RELU6_PACKED = "\n  vec4 result = min(x, vec4(6.)) * vec4(greaterThanEqual(x, vec4(0.0)));\n  bvec4 isNaN = isnan(x);\n\n  result.r = isNaN.r ? x.r : result.r;\n  result.g = isNaN.g ? x.g : result.g;\n  result.b = isNaN.b ? x.b : result.b;\n  result.a = isNaN.a ? x.a : result.a;\n\n  return result;\n";
	var relu6 = unaryKernelFunc({
	  opSnippet: RELU6,
	  packedOpSnippet: RELU6_PACKED
	});
	var relu6Config = {
	  kernelName: Relu6$1,
	  backendName: 'webgl',
	  kernelFunc: relu6
	};

	/**
	 * @license
	 * Copyright 2017 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ResizeBilinearProgram = /*#__PURE__*/_createClass(function ResizeBilinearProgram(inputShape, newHeight, newWidth, alignCorners, halfPixelCenters) {
	  _classCallCheck(this, ResizeBilinearProgram);
	  this.variableNames = ['A'];
	  this.outputShape = [];
	  var _inputShape = _slicedToArray(inputShape, 4),
	    batch = _inputShape[0],
	    oldHeight = _inputShape[1],
	    oldWidth = _inputShape[2],
	    depth = _inputShape[3];
	  this.outputShape = [batch, newHeight, newWidth, depth];
	  var effectiveInSize = [alignCorners && newHeight > 1 ? oldHeight - 1 : oldHeight, alignCorners && newWidth > 1 ? oldWidth - 1 : oldWidth];
	  var effectiveOutSize = [alignCorners && newHeight > 1 ? newHeight - 1 : newHeight, alignCorners && newWidth > 1 ? newWidth - 1 : newWidth];
	  var sourceFracIndexRC;
	  if (halfPixelCenters) {
	    sourceFracIndexRC = "(vec2(yRC) + vec2(0.5)) * effectiveInputOverOutputRatioRC" + " - vec2(0.5)";
	  } else {
	    sourceFracIndexRC = "vec2(yRC) * effectiveInputOverOutputRatioRC";
	  }
	  this.userCode = "\n      const vec2 effectiveInputOverOutputRatioRC = vec2(\n          ".concat(effectiveInSize[0] / effectiveOutSize[0], ",\n          ").concat(effectiveInSize[1] / effectiveOutSize[1], ");\n      const vec2 inputShapeRC = vec2(").concat(oldHeight, ".0, ").concat(oldWidth, ".0);\n\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int b = coords[0];\n        int d = coords[3];\n        ivec2 yRC = coords.yz;\n\n        // Fractional source index.\n        vec2 sourceFracIndexRC = ").concat(sourceFracIndexRC, ";\n\n        // Compute the four integer indices.\n        ivec2 sourceFloorRC = ivec2(max(sourceFracIndexRC, vec2(0.0)));\n        ivec2 sourceCeilRC = ivec2(\n          min(inputShapeRC - 1.0, ceil(sourceFracIndexRC)));\n\n        float topLeft = getA(b, sourceFloorRC.x, sourceFloorRC.y, d);\n        float bottomLeft = getA(b, sourceCeilRC.x, sourceFloorRC.y, d);\n        float topRight = getA(b, sourceFloorRC.x, sourceCeilRC.y, d);\n        float bottomRight = getA(b, sourceCeilRC.x, sourceCeilRC.y, d);\n\n        vec2 fracRC = sourceFracIndexRC - vec2(sourceFloorRC);\n\n        float top = topLeft + (topRight - topLeft) * fracRC.y;\n        float bottom = bottomLeft + (bottomRight - bottomLeft) * fracRC.y;\n        float newValue = top + (bottom - top) * fracRC.x;\n\n        setOutput(newValue);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ResizeBilinearPackedProgram = /*#__PURE__*/_createClass(function ResizeBilinearPackedProgram(inputShape, newHeight, newWidth, alignCorners, halfPixelCenters) {
	  _classCallCheck(this, ResizeBilinearPackedProgram);
	  this.variableNames = ['A'];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.outputShape = [];
	  var _inputShape = _slicedToArray(inputShape, 4),
	    batch = _inputShape[0],
	    oldHeight = _inputShape[1],
	    oldWidth = _inputShape[2],
	    depth = _inputShape[3];
	  this.outputShape = [batch, newHeight, newWidth, depth];
	  var effectiveInSize = [alignCorners && newHeight > 1 ? oldHeight - 1 : oldHeight, alignCorners && newWidth > 1 ? oldWidth - 1 : oldWidth];
	  var effectiveOutSize = [alignCorners && newHeight > 1 ? newHeight - 1 : newHeight, alignCorners && newWidth > 1 ? newWidth - 1 : newWidth];
	  var sourceFracIndexRC;
	  if (halfPixelCenters) {
	    sourceFracIndexRC = "(vec3(yRC) + vec3(0.5)) * " + "effectiveInputOverOutputRatioRC - vec3(0.5)";
	  } else {
	    sourceFracIndexRC = "vec3(yRC) * effectiveInputOverOutputRatioRC";
	  }
	  this.userCode = "\n      const vec3 effectiveInputOverOutputRatioRC = vec3(\n          ".concat(effectiveInSize[0] / effectiveOutSize[0], ",\n          ").concat(effectiveInSize[1] / effectiveOutSize[1], ",\n          ").concat(effectiveInSize[1] / effectiveOutSize[1], ");\n      const vec3 inputShapeRC = vec3(").concat(oldHeight, ".0, ").concat(oldWidth, ".0,\n                                     ").concat(oldWidth, ".0);\n\n      float getAValue(int b, int r, int c, int d) {\n        return getChannel(getA(b, r, c, d), vec2(c, d));\n      }\n\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int b = coords[0];\n        int d = coords[3];\n        // Calculate values for next column in yRC.z.\n        ivec3 yRC = coords.yzz + ivec3(0, 0, 1);\n\n        // Fractional source index.\n        vec3 sourceFracIndexRC = ").concat(sourceFracIndexRC, ";\n\n        // Compute the four integer indices.\n        ivec3 sourceFloorRC = ivec3(max(sourceFracIndexRC, vec3(0.0)));\n        ivec3 sourceCeilRC = ivec3(\n          min(inputShapeRC - 1.0, ceil(sourceFracIndexRC)));\n\n        // Should we calculate next column and row elements in 2x2 packed cell.\n        bool hasNextCol = d < ").concat(depth - 1, ";\n        bool hasNextRow = coords.z < ").concat(newWidth - 1, ";\n\n        // In parallel, construct four corners for all four components in\n        // packed 2x2 cell.\n        vec4 topLeft = vec4(\n          getAValue(b, sourceFloorRC.x, sourceFloorRC.y, d),\n          hasNextCol ? getAValue(b, sourceFloorRC.x, sourceFloorRC.y, d + 1)\n                     : 0.0,\n          hasNextRow ? getAValue(b, sourceFloorRC.x, sourceFloorRC.z, d)\n                     : 0.0,\n          (hasNextRow && hasNextCol) ?\n            getAValue(b, sourceFloorRC.x, sourceFloorRC.z, d + 1) : 0.0);\n\n        vec4 bottomLeft = vec4(\n          getAValue(b, sourceCeilRC.x, sourceFloorRC.y, d),\n          hasNextCol ? getAValue(b, sourceCeilRC.x, sourceFloorRC.y, d + 1)\n                     : 0.0,\n          hasNextRow ? getAValue(b, sourceCeilRC.x, sourceFloorRC.z, d)\n                     : 0.0,\n          (hasNextRow && hasNextCol) ?\n            getAValue(b, sourceCeilRC.x, sourceFloorRC.z, d + 1) : 0.0);\n\n        vec4 topRight = vec4(\n          getAValue(b, sourceFloorRC.x, sourceCeilRC.y, d),\n          hasNextCol ? getAValue(b, sourceFloorRC.x, sourceCeilRC.y, d + 1)\n                     : 0.0,\n          hasNextRow ? getAValue(b, sourceFloorRC.x, sourceCeilRC.z, d)\n                     : 0.0,\n          (hasNextRow && hasNextCol) ?\n            getAValue(b, sourceFloorRC.x, sourceCeilRC.z, d + 1) : 0.0);\n\n        vec4 bottomRight = vec4(\n          getAValue(b, sourceCeilRC.x, sourceCeilRC.y, d),\n          hasNextCol ? getAValue(b, sourceCeilRC.x, sourceCeilRC.y, d + 1)\n                     : 0.0,\n          hasNextRow ? getAValue(b, sourceCeilRC.x, sourceCeilRC.z, d)\n                     : 0.0,\n          (hasNextRow && hasNextCol) ?\n            getAValue(b, sourceCeilRC.x, sourceCeilRC.z, d + 1) : 0.0);\n\n        vec3 fracRC = sourceFracIndexRC - vec3(sourceFloorRC);\n\n        vec4 top = mix(topLeft, topRight, fracRC.yyzz);\n        vec4 bottom = mix(bottomLeft, bottomRight, fracRC.yyzz);\n        vec4 newValue = mix(top, bottom, fracRC.x);\n\n        setOutput(newValue);\n      }\n    ");
	});

	function resizeBilinear(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var images = inputs.images;
	  var alignCorners = attrs.alignCorners,
	    halfPixelCenters = attrs.halfPixelCenters,
	    size = attrs.size;
	  var _size = _slicedToArray(size, 2),
	    newHeight = _size[0],
	    newWidth = _size[1];
	  var program = env().getBool('WEBGL_PACK_IMAGE_OPERATIONS') ? new ResizeBilinearPackedProgram(images.shape, newHeight, newWidth, alignCorners, halfPixelCenters) : new ResizeBilinearProgram(images.shape, newHeight, newWidth, alignCorners, halfPixelCenters);
	  return backend.runWebGLProgram(program, [images], 'float32');
	}
	var resizeBilinearConfig = {
	  kernelName: ResizeBilinear,
	  backendName: 'webgl',
	  kernelFunc: resizeBilinear
	};

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ResizeBilinearBackpropProgram = /*#__PURE__*/_createClass(function ResizeBilinearBackpropProgram(dyShape, inputShape, alignCorners) {
	  _classCallCheck(this, ResizeBilinearBackpropProgram);
	  this.variableNames = ['dy'];
	  this.outputShape = [];
	  this.outputShape = inputShape;
	  var _inputShape = _slicedToArray(inputShape, 3),
	    xHeight = _inputShape[1],
	    xWidth = _inputShape[2];
	  var _dyShape = _slicedToArray(dyShape, 3),
	    yHeight = _dyShape[1],
	    yWidth = _dyShape[2];
	  // In the backwards pass, we want to find the pixels that were generated for
	  // each pixel in the input image the forward pass and add the corresponding
	  // coefficient from dy to the gradient (with some interpolation).
	  var effectiveXSize = [alignCorners && yHeight > 1 ? xHeight - 1 : xHeight, alignCorners && yWidth > 1 ? xWidth - 1 : xWidth];
	  var effectiveYSize = [alignCorners && yHeight > 1 ? yHeight - 1 : yHeight, alignCorners && yWidth > 1 ? yWidth - 1 : yWidth];
	  var heightScale = effectiveXSize[0] / effectiveYSize[0];
	  var widthScale = effectiveXSize[1] / effectiveYSize[1];
	  var invHeightScale = 1 / heightScale;
	  var invWidthScale = 1 / widthScale;
	  // This defines the size of the window of values around a particular
	  // index in dy that we want to search for contributions to dx.
	  var winHeight = Math.ceil(invHeightScale) * 2 + 2;
	  var winWidth = Math.ceil(invWidthScale) * 2 + 2;
	  this.userCode = "\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int b = coords[0];\n        int d = coords[3];\n        int r = coords[1];\n        int c = coords[2];\n\n        float accumulator = 0.0;\n\n        const float heightScale = float(".concat(heightScale, ");\n        const float widthScale = float(").concat(widthScale, ");\n\n        const float invHeightScale = float(").concat(invHeightScale, ");\n        const float invWidthScale = float(").concat(invWidthScale, ");\n\n        const int winHeight = int(").concat(winHeight, ");\n        const int winWidth = int(").concat(winWidth, ");\n\n        // Compute bounds for where in dy we will look\n        float startRLerp = floor(float(r) * invHeightScale);\n        int startDyR = int(startRLerp - float(winHeight / 2));\n\n        float startCLerp = floor(float(c) * invWidthScale);\n        int startDyC = int(startCLerp - float(winWidth / 2));\n\n        // Loop over dy\n        for (int dyROffset = 0; dyROffset < winHeight; dyROffset++) {\n          int dyR = dyROffset + startDyR;\n\n          // Guard against the window exceeding the bounds of dy\n          if (dyR < 0 || dyR >= ").concat(yHeight, ") {\n            continue;\n          }\n\n          for (int dyCOffset = 0; dyCOffset < winWidth; dyCOffset++) {\n            int dyC = dyCOffset + startDyC;\n\n            // Guard against the window exceeding the bounds of dy\n            if (dyC < 0 || dyC >= ").concat(yWidth, ") {\n              continue;\n            }\n\n            float dxR = float(dyR) * heightScale;\n            int topDxRIndex = int(floor(dxR));\n            int bottomDxRIndex = int(min(ceil(dxR), ").concat(xHeight - 1, ".0));\n            float dxRLerp = dxR - float(topDxRIndex);\n            float inverseDxRLerp = 1.0 - dxRLerp;\n\n            float dxC = float(dyC) * widthScale;\n            int leftDxCIndex = int(floor(dxC));\n            int rightDxCIndex = int(min(ceil(dxC), ").concat(xWidth - 1, ".0));\n            float dxCLerp = dxC - float(leftDxCIndex);\n            float inverseDxCLerp = 1.0 - dxCLerp;\n\n            if (r == topDxRIndex && c == leftDxCIndex) {\n              // topLeft\n              accumulator +=\n                getDy(b, dyR, dyC, d) * inverseDxRLerp * inverseDxCLerp;\n            }\n\n            if (r == topDxRIndex && c == rightDxCIndex) {\n              // topRight\n              accumulator += getDy(b, dyR, dyC, d) * inverseDxRLerp * dxCLerp;\n            }\n\n            if (r == bottomDxRIndex && c == leftDxCIndex) {\n              // bottomLeft\n              accumulator += getDy(b, dyR, dyC, d) * dxRLerp * inverseDxCLerp;\n            }\n\n            if (r == bottomDxRIndex && c == rightDxCIndex) {\n              // bottomRight\n              accumulator += getDy(b, dyR, dyC, d) * dxRLerp * dxCLerp;\n            }\n          }\n        }\n        // End loop over dy\n\n        setOutput(accumulator);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function resizeBilinearGrad(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var images = inputs.images,
	    dy = inputs.dy;
	  var alignCorners = attrs.alignCorners;
	  var program = new ResizeBilinearBackpropProgram(dy.shape, images.shape, alignCorners);
	  return backend.runWebGLProgram(program, [dy], dy.dtype);
	}
	var resizeBilinearGradConfig = {
	  kernelName: ResizeBilinearGrad,
	  backendName: 'webgl',
	  kernelFunc: resizeBilinearGrad
	};

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ResizeNearestNeighborProgram = /*#__PURE__*/_createClass(function ResizeNearestNeighborProgram(inputShape, newHeight, newWidth, alignCorners, halfPixelCenters) {
	  _classCallCheck(this, ResizeNearestNeighborProgram);
	  this.variableNames = ['A'];
	  this.outputShape = [];
	  var _inputShape = _slicedToArray(inputShape, 4),
	    batch = _inputShape[0],
	    oldHeight = _inputShape[1],
	    oldWidth = _inputShape[2],
	    depth = _inputShape[3];
	  this.outputShape = [batch, newHeight, newWidth, depth];
	  var effectiveInSize = [alignCorners && newHeight > 1 ? oldHeight - 1 : oldHeight, alignCorners && newWidth > 1 ? oldWidth - 1 : oldWidth];
	  var effectiveOutSize = [alignCorners && newHeight > 1 ? newHeight - 1 : newHeight, alignCorners && newWidth > 1 ? newWidth - 1 : newWidth];
	  // When align corners is false, we rounds the value with floor.
	  var roundBase = alignCorners ? '0.5' : '0.0';
	  var sourceFracIndexRC;
	  if (halfPixelCenters) {
	    sourceFracIndexRC = "max((vec2(yRC) + vec2(0.5)) * effectiveInputOverOutputRatioRC" + ", vec2(0.0))";
	  } else {
	    sourceFracIndexRC = "vec2(yRC) * effectiveInputOverOutputRatioRC";
	  }
	  this.userCode = "\n      const vec2 effectiveInputOverOutputRatioRC = vec2(\n          ".concat(effectiveInSize[0] / effectiveOutSize[0], ",\n          ").concat(effectiveInSize[1] / effectiveOutSize[1], ");\n      const vec2 inputShapeRC = vec2(").concat(oldHeight, ".0, ").concat(oldWidth, ".0);\n\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int b = coords[0];\n        int d = coords[3];\n        ivec2 yRC = coords.yz;\n\n        // Fractional source index.\n        vec2 sourceFracIndexRC = ").concat(sourceFracIndexRC, ";\n\n        // Compute the coordinators of nearest neighbor point.\n        ivec2 sourceNearestRC = ivec2(\n          min(inputShapeRC - 1.0, floor(sourceFracIndexRC + ").concat(roundBase, ")));\n        float newValue = getA(b, sourceNearestRC.x, sourceNearestRC.y, d);\n\n        setOutput(newValue);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ResizeNearestNeighborPackedProgram = /*#__PURE__*/_createClass(function ResizeNearestNeighborPackedProgram(inputShape, newHeight, newWidth, alignCorners, halfPixelCenters) {
	  _classCallCheck(this, ResizeNearestNeighborPackedProgram);
	  this.variableNames = ['A'];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.outputShape = [];
	  var _inputShape = _slicedToArray(inputShape, 4),
	    batch = _inputShape[0],
	    oldHeight = _inputShape[1],
	    oldWidth = _inputShape[2],
	    depth = _inputShape[3];
	  this.outputShape = [batch, newHeight, newWidth, depth];
	  var effectiveInSize = [alignCorners && newHeight > 1 ? oldHeight - 1 : oldHeight, alignCorners && newWidth > 1 ? oldWidth - 1 : oldWidth];
	  var effectiveOutSize = [alignCorners && newHeight > 1 ? newHeight - 1 : newHeight, alignCorners && newWidth > 1 ? newWidth - 1 : newWidth];
	  // When align corners is false, we rounds the value with floor.
	  var roundBase = alignCorners ? '0.5' : '0.0';
	  var sourceFracIndexRC;
	  if (halfPixelCenters) {
	    sourceFracIndexRC = "max((vec3(yRC) + vec3(0.5)) * " + "effectiveInputOverOutputRatioRC, vec3(0.0))";
	  } else {
	    sourceFracIndexRC = "vec3(yRC) * effectiveInputOverOutputRatioRC";
	  }
	  this.userCode = "\n      const vec3 effectiveInputOverOutputRatioRC = vec3(\n          ".concat(effectiveInSize[0] / effectiveOutSize[0], ",\n          ").concat(effectiveInSize[1] / effectiveOutSize[1], ",\n          ").concat(effectiveInSize[1] / effectiveOutSize[1], ");\n      const vec3 inputShapeRC = vec3(").concat(oldHeight, ".0, ").concat(oldWidth, ".0,\n                                     ").concat(oldWidth, ".0);\n\n      float getAValue(int b, int r, int c, int d) {\n        return getChannel(getA(b, r, c, d), vec2(c, d));\n      }\n\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int b = coords[0];\n        int d = coords[3];\n        // Calculate values for next column in yRC.z.\n        ivec3 yRC = coords.yzz + ivec3(0, 0, 1);\n\n        // Fractional source index.\n        vec3 sourceFracIndexRC = ").concat(sourceFracIndexRC, ";\n\n        // Compute the coordinators of nearest neighbor point.\n        ivec3 sourceNearestRC = ivec3(\n          min(inputShapeRC - 1.0, floor(sourceFracIndexRC + ").concat(roundBase, ")));\n\n        // Should we calculate next column and row elements in 2x2 packed cell.\n        bool hasNextCol = d < ").concat(depth - 1, ";\n        bool hasNextRow = coords.z < ").concat(newWidth - 1, ";\n\n        vec4 newValue = vec4(\n          getAValue(b, sourceNearestRC.x, sourceNearestRC.y, d),\n          hasNextCol ? getAValue(b, sourceNearestRC.x, sourceNearestRC.y, d + 1)\n                     : 0.0,\n          hasNextRow ? getAValue(b, sourceNearestRC.x, sourceNearestRC.z, d)\n                     : 0.0,\n          (hasNextRow && hasNextCol) ?\n            getAValue(b, sourceNearestRC.x, sourceNearestRC.z, d + 1) : 0.0);\n\n        setOutput(newValue);\n      }\n    ");
	});

	function resizeNearestNeighbor(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var images = inputs.images;
	  var alignCorners = attrs.alignCorners,
	    halfPixelCenters = attrs.halfPixelCenters,
	    size = attrs.size;
	  var _size = _slicedToArray(size, 2),
	    newHeight = _size[0],
	    newWidth = _size[1];
	  var program = env().getBool('WEBGL_PACK_IMAGE_OPERATIONS') ? new ResizeNearestNeighborPackedProgram(images.shape, newHeight, newWidth, alignCorners, halfPixelCenters) : new ResizeNearestNeighborProgram(images.shape, newHeight, newWidth, alignCorners, halfPixelCenters);
	  return backend.runWebGLProgram(program, [images], images.dtype);
	}
	var resizeNearestNeighborConfig = {
	  kernelName: ResizeNearestNeighbor,
	  backendName: 'webgl',
	  kernelFunc: resizeNearestNeighbor
	};

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ResizeNearestNeigborBackpropProgram = /*#__PURE__*/_createClass(function ResizeNearestNeigborBackpropProgram(dyShape, inputShape, alignCorners) {
	  _classCallCheck(this, ResizeNearestNeigborBackpropProgram);
	  this.variableNames = ['dy'];
	  this.outputShape = [];
	  this.outputShape = inputShape;
	  var _inputShape = _slicedToArray(inputShape, 3),
	    xHeight = _inputShape[1],
	    xWidth = _inputShape[2];
	  var _dyShape = _slicedToArray(dyShape, 3),
	    yHeight = _dyShape[1],
	    yWidth = _dyShape[2];
	  // In the backwards pass, we want to find the pixels that were generated for
	  // each pixel in the input image the forward pass and add the corresponding
	  // coefficient from dy to the gradient (with some interpolation).
	  var effectiveXSize = [alignCorners && yHeight > 1 ? xHeight - 1 : xHeight, alignCorners && yWidth > 1 ? xWidth - 1 : xWidth];
	  var effectiveYSize = [alignCorners && yHeight > 1 ? yHeight - 1 : yHeight, alignCorners && yWidth > 1 ? yWidth - 1 : yWidth];
	  var heightScale = effectiveXSize[0] / effectiveYSize[0];
	  var widthScale = effectiveXSize[1] / effectiveYSize[1];
	  var invHeightScale = 1 / heightScale;
	  var invWidthScale = 1 / widthScale;
	  // This defines the size of the window of values around a particular
	  // index in dy that we want to search for contributions to dx.
	  var winHeight = Math.ceil(invHeightScale) * 2 + 2;
	  var winWidth = Math.ceil(invWidthScale) * 2 + 2;
	  this.userCode = "\n      void main() {\n        ivec4 coords = getOutputCoords();\n        int b = coords[0];\n        int d = coords[3];\n        int r = coords[1];\n        int c = coords[2];\n\n        float accumulator = 0.0;\n\n        const float heightScale = float(".concat(heightScale, ");\n        const float widthScale = float(").concat(widthScale, ");\n\n        const float invHeightScale = float(").concat(invHeightScale, ");\n        const float invWidthScale = float(").concat(invWidthScale, ");\n\n        const int winHeight = int(").concat(winHeight, ");\n        const int winWidth = int(").concat(winWidth, ");\n\n        // Compute bounds for where in dy we will look\n        float startRLerp = floor(float(r) * invHeightScale);\n        int startDyR = int(floor(startRLerp - float(winHeight / 2)));\n\n        float startCLerp = floor(float(c) * invWidthScale);\n        int startDyC = int(floor(startCLerp - float(winWidth / 2)));\n\n        // Loop over dy\n        for (int dyROffset = 0; dyROffset < winHeight; dyROffset++) {\n          int dyR = dyROffset + startDyR;\n\n          // Guard against the window exceeding the bounds of dy\n          if (dyR < 0 || dyR >= ").concat(yHeight, ") {\n            continue;\n          }\n\n          for (int dyCOffset = 0; dyCOffset < winWidth; dyCOffset++) {\n            int dyC = dyCOffset + startDyC;\n\n            // Guard against the window exceeding the bounds of dy\n            if (dyC < 0 || dyC >= ").concat(yWidth, ") {\n              continue;\n            }\n\n            float sourceFracRow =\n              float(").concat(effectiveXSize[0], ") *\n                (float(dyR) / float(").concat(effectiveYSize[0], "));\n\n            float sourceFracCol =\n                float(").concat(effectiveXSize[1], ") *\n                  (float(dyC) / float(").concat(effectiveYSize[1], "));\n\n            int sourceNearestRow = int(min(\n                float(int(").concat(xHeight, ") - 1),\n                ").concat(alignCorners, " ? float(round(sourceFracRow)) :\n                                  float(floor(sourceFracRow))));\n\n            int sourceNearestCol = int(min(\n                float(int(").concat(xWidth, ") - 1),\n                ").concat(alignCorners, " ? float(round(sourceFracCol)) :\n                                  float(floor(sourceFracCol))));\n\n            if (r == sourceNearestRow && c == sourceNearestCol) {\n              accumulator += getDy(b, dyR, dyC, d);\n            }\n          }\n        }\n        // End loop over dy\n\n        setOutput(accumulator);\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function resizeNearestNeighborGrad(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var images = inputs.images,
	    dy = inputs.dy;
	  var alignCorners = attrs.alignCorners;
	  var program = new ResizeNearestNeigborBackpropProgram(dy.shape, images.shape, alignCorners);
	  return backend.runWebGLProgram(program, [dy], dy.dtype);
	}
	var resizeNearestNeighborGradConfig = {
	  kernelName: ResizeNearestNeighborGrad,
	  backendName: 'webgl',
	  kernelFunc: resizeNearestNeighborGrad
	};

	var ReverseProgram = /*#__PURE__*/_createClass(function ReverseProgram(xShape, axis) {
	  _classCallCheck(this, ReverseProgram);
	  this.variableNames = ['x'];
	  var rank = xShape.length;
	  if (rank > 4) {
	    throw new Error("WebGL backend: Reverse of rank-".concat(rank, " tensor is not yet supported"));
	  }
	  this.outputShape = xShape;
	  if (rank === 1) {
	    this.userCode = "\n        void main() {\n          int coord = getOutputCoords();\n          setOutput(getX(".concat(xShape[0], " - coord - 1));\n        }\n      ");
	    return;
	  }
	  var getInCoord = function getInCoord(i) {
	    if (axis.indexOf(i) !== -1 && xShape[i] !== 1) {
	      return "".concat(xShape[i], " - coords[").concat(i, "] - 1");
	    }
	    return "coords[".concat(i, "]");
	  };
	  var inCoords = xShape.map(function (_, i) {
	    return getInCoord(i);
	  }).join(',');
	  var type = getCoordsDataType(rank);
	  this.userCode = "\n      void main() {\n        ".concat(type, " coords = getOutputCoords();\n        setOutput(getX(").concat(inCoords, "));\n      }\n    ");
	});

	var ReversePackedProgram = /*#__PURE__*/_createClass(function ReversePackedProgram(xShape, axis) {
	  _classCallCheck(this, ReversePackedProgram);
	  this.variableNames = ['x'];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  var rank = xShape.length;
	  if (rank > 4) {
	    throw new Error("WebGL backend: Reverse of rank-".concat(rank, " tensor is not yet supported"));
	  }
	  this.outputShape = xShape;
	  var channels = getChannels('rc', rank);
	  var nextColumn = "".concat(channels[rank - 1], " + 1 < ").concat(this.outputShape[rank - 1]);
	  var nextRow = "".concat(channels[rank - 2], " + 1 < ").concat(this.outputShape[rank - 2]);
	  var type = getCoordsDataType(rank);
	  if (rank === 1) {
	    this.userCode = "\n        void main(){\n          int rc = getOutputCoords();\n          vec4 result = vec4(0.);\n          result.r = getChannel(getX(".concat(xShape[0], " - rc - 1),\n            ").concat(xShape[0], " - rc - 1);\n          if(").concat(nextColumn, "){\n              result.g = getChannel(getX(").concat(xShape[0], " - (rc  + 1) - 1),\n                ").concat(xShape[0], " - (rc  + 1) - 1);\n          }\n          setOutput(result);\n        }\n      ");
	  } else {
	    this.userCode = "\n        void main() {\n          ".concat(type, " rc = getOutputCoords();\n          vec4 result = vec4(0.);\n          result.r = ").concat(getR(channels.slice()), ";\n          if(").concat(nextColumn, "){\n            result.g = ").concat(getG(channels.slice()), ";\n          }\n          if(").concat(nextRow, ") {\n            result.b = ").concat(getB(channels.slice()), ";\n            if(").concat(nextColumn, ") {\n              result.a = ").concat(getA(channels.slice()), ";\n            }\n          }\n          setOutput(result);\n        }\n    ");
	  }
	  function getR(channels) {
	    return getChannel(channels);
	  }
	  function getG(channels) {
	    channels[rank - 1] = '(' + channels[rank - 1] + " + 1)";
	    return getChannel(channels);
	  }
	  function getB(channels) {
	    channels[rank - 2] = '(' + channels[rank - 2] + " + 1)";
	    return getChannel(channels);
	  }
	  function getA(channels) {
	    channels[rank - 1] = '(' + channels[rank - 1] + " + 1)";
	    channels[rank - 2] = '(' + channels[rank - 2] + " + 1)";
	    return getChannel(channels);
	  }
	  function getChannel(channels) {
	    var inCoordsArray = xShape.map(function (_, i) {
	      return getInCoord(i, channels);
	    });
	    var inCoords = inCoordsArray.join(',');
	    var innerDims = inCoordsArray.slice(-2).join(',');
	    return "getChannel(getX(".concat(inCoords, "), vec2(").concat(innerDims, "))");
	  }
	  function getInCoord(i, channels1) {
	    if (axis.indexOf(i) !== -1 && xShape[i] !== 1) {
	      return "".concat(xShape[i], " - ").concat(channels1[i], " - 1");
	    } else {
	      return "".concat(channels1[i]);
	    }
	  }
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function reverse(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var dims = attrs.dims;
	  var xRank = x.shape.length;
	  var $dims = parseAxisParam(dims, x.shape);
	  if (xRank === 0) {
	    return identity({
	      inputs: {
	        x: x
	      },
	      backend: backend
	    });
	  }
	  var program = env().getBool('WEBGL_PACK_ARRAY_OPERATIONS') ? new ReversePackedProgram(x.shape, $dims) : new ReverseProgram(x.shape, $dims);
	  return backend.runWebGLProgram(program, [x], x.dtype);
	}
	var reverseConfig = {
	  kernelName: Reverse,
	  backendName: 'webgl',
	  kernelFunc: reverse
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var RotateProgram = /*#__PURE__*/_createClass(function RotateProgram(imageShape, fillValue) {
	  _classCallCheck(this, RotateProgram);
	  this.variableNames = ['Image'];
	  this.outputShape = [];
	  this.customUniforms = [{
	    name: 'params',
	    type: 'vec4'
	  }];
	  var imageHeight = imageShape[1];
	  var imageWidth = imageShape[2];
	  this.outputShape = imageShape;
	  var fillSnippet = '';
	  if (typeof fillValue === 'number') {
	    fillSnippet = "float outputValue = ".concat(fillValue.toFixed(2), ";");
	  } else {
	    fillSnippet = "\n        vec3 fill = vec3(".concat(fillValue.join(','), ");\n        float outputValue = fill[coords[3]];");
	  }
	  this.userCode = "\n        void main() {\n          ivec4 coords = getOutputCoords();\n          int x = coords[2];\n          int y = coords[1];\n          float coordXFloat = (float(x) - params[0]) * params[3] -\n            (float(y) - params[1]) * params[2];\n          float coordYFloat = (float(x) - params[0]) * params[2] +\n            (float(y) - params[1]) * params[3];\n          int coordX = int(round(coordXFloat + params[0]));\n          int coordY = int(round(coordYFloat + params[1]));\n          ".concat(fillSnippet, "\n          if(coordX >= 0 && coordX < ").concat(imageWidth, " && coordY >= 0 && coordY < ").concat(imageHeight, ") {\n            outputValue = getImage(coords[0], coordY, coordX, coords[3]);\n          }\n          setOutput(outputValue);\n        }\n    ");
	});

	var rotateWithOffsetConfig = {
	  kernelName: RotateWithOffset,
	  backendName: 'webgl',
	  kernelFunc: function kernelFunc(_ref) {
	    var inputs = _ref.inputs,
	      attrs = _ref.attrs,
	      backend = _ref.backend;
	    var image = inputs.image;
	    var radians = attrs.radians,
	      fillValue = attrs.fillValue,
	      center = attrs.center;
	    var webglBackend = backend;
	    var program = new RotateProgram(image.shape, fillValue);
	    var _backend_util$getImag = getImageCenter(center, image.shape[1], image.shape[2]),
	      _backend_util$getImag2 = _slicedToArray(_backend_util$getImag, 2),
	      centerX = _backend_util$getImag2[0],
	      centerY = _backend_util$getImag2[1];
	    var customValues = [[centerX, centerY, Math.sin(radians), Math.cos(radians)]];
	    var output = webglBackend.runWebGLProgram(program, [image], image.dtype, customValues);
	    return output;
	  }
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var ROUND = "\n  // OpenGL ES does not support round function.\n  // The algorithm is based on banker's rounding.\n  float base = floor(x);\n  if ((x - base) < 0.5) {\n    return floor(x);\n  } else if ((x - base) > 0.5) {\n    return ceil(x);\n  } else {\n    if (mod(base, 2.0) == 0.0) {\n      return base;\n    } else {\n      return base + 1.0;\n    }\n  }\n";
	var round = unaryKernelFunc({
	  opSnippet: ROUND
	});
	var roundConfig = {
	  kernelName: Round,
	  backendName: 'webgl',
	  kernelFunc: round
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var RSQRT = "return inversesqrt(x);";
	var rsqrt = unaryKernelFunc({
	  opSnippet: RSQRT,
	  cpuKernelImpl: rsqrtImplCPU
	});
	var rsqrtConfig = {
	  kernelName: Rsqrt,
	  backendName: 'webgl',
	  kernelFunc: rsqrt
	};

	var ScatterProgram = /*#__PURE__*/_createClass(function ScatterProgram(updateSize, sliceDim, indicesRank, updatesRank, strides, shape) {
	  var summingDupeIndex = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : true;
	  var defaultIsTensor = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : false;
	  _classCallCheck(this, ScatterProgram);
	  this.variableNames = ['updates', 'indices', 'defaultValue'];
	  this.outputShape = shape;
	  var stridesType = getCoordsDataType(strides.length);
	  var dtype = getCoordsDataType(shape.length);
	  var indicesString = '';
	  if (indicesRank === 1) {
	    indicesString = 'i';
	  } else if (indicesRank === 2) {
	    indicesString = 'i, j';
	  }
	  var indicesSnippet = "getIndices(".concat(indicesString, ")");
	  var updatesString = '';
	  if (updatesRank === 1) {
	    updatesString = 'i';
	  } else if (updatesRank === 2) {
	    updatesString = 'i, coords[1]';
	  }
	  var updatesSnippet = "getUpdates(".concat(updatesString, ")");
	  var defaultValuesString = '';
	  if (defaultIsTensor) {
	    defaultValuesString = 'coords[0], coords[1]';
	  }
	  var defaultValueSnippet = "getDefaultValue(".concat(defaultValuesString, ")");
	  var strideString = sliceDim > 1 ? 'strides[j]' : 'strides';
	  this.userCode = "\n        ".concat(stridesType, " strides = ").concat(stridesType, "(").concat(strides, ");\n\n        void main() {\n          ").concat(dtype, " coords = getOutputCoords();\n          float sum = 0.0;\n          bool found = false;\n          for (int i = 0; i < ").concat(updateSize, "; i++) {\n            int flattenedIndex = 0;\n            for (int j = 0; j < ").concat(sliceDim, "; j++) {\n              int index = round(").concat(indicesSnippet, ");\n              flattenedIndex += index * ").concat(strideString, ";\n            }\n            if (flattenedIndex == coords[0]) {\n              sum += ").concat(updatesSnippet, ";\n              found = true;\n            }\n          }\n          setOutput(mix(").concat(defaultValueSnippet, ", sum, float(found)));\n        }\n      ");
	});

	var ScatterPackedProgram = /*#__PURE__*/_createClass(function ScatterPackedProgram(updateSize, sliceDim, indicesRank, updatesRank, strides, shape) {
	  var summingDupeIndex = arguments.length > 6 && arguments[6] !== undefined ? arguments[6] : true;
	  var defaultIsTensor = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : false;
	  _classCallCheck(this, ScatterPackedProgram);
	  this.variableNames = ['updates', 'indices', 'defaultValue'];
	  this.packedInputs = true;
	  this.packedOutput = true;
	  this.outputShape = shape;
	  var stridesType = getCoordsDataType(strides.length);
	  var dtype = getCoordsDataType(shape.length);
	  var indicesString = '';
	  if (indicesRank === 1) {
	    indicesString = 'i';
	  } else if (indicesRank === 2) {
	    indicesString = 'i, j';
	  }
	  var indicesSnippet = "getIndices(".concat(indicesString, ")");
	  var updatesString = '';
	  if (updatesRank === 1) {
	    updatesString = 'i';
	  } else if (updatesRank === 2) {
	    updatesString = 'i, coords[1]';
	  }
	  var updatesSnippet = "getUpdates(".concat(updatesString, ")");
	  var defaultValuesString = '';
	  if (defaultIsTensor) {
	    defaultValuesString = 'coords[0], coords[1]';
	  }
	  var defaultValueSnippet = "getDefaultValue(".concat(defaultValuesString, ")");
	  var strideString = sliceDim > 1 ? 'strides[j]' : 'strides';
	  var strideString2 = sliceDim > 1 ? 'strides[j + 1]' : 'strides';
	  this.userCode = "\n        ".concat(stridesType, " strides = ").concat(stridesType, "(").concat(strides, ");\n\n        void main() {\n          ").concat(dtype, " coords = getOutputCoords();\n          vec4 sum = vec4(0.);\n          vec4 found = vec4(0.);\n          for (int i = 0; i < ").concat(updateSize, "; i+=2) {\n            ivec2 flattenedIndex = ivec2(0);\n            for (int j = 0; j < ").concat(sliceDim, "; j+=2) {\n              ivec4 index = round(").concat(indicesSnippet, ");\n              flattenedIndex += index.xz * ").concat(strideString, ";\n              if (j + 1 < ").concat(sliceDim, ") {\n                flattenedIndex += index.yw * ").concat(strideString2, ";\n              }\n            }\n            if (flattenedIndex[0] == coords[0] || flattenedIndex[1] == coords[0] ||\n                flattenedIndex[0] == coords[0] + 1 || flattenedIndex[1] == coords[0] + 1) {\n              vec4 updVals = ").concat(updatesSnippet, ";\n              if (flattenedIndex[0] == coords[0]) {\n                sum.xy += updVals.xy;\n                found.xy = vec2(1.);\n              } else if (flattenedIndex[0] == coords[0] + 1) {\n                sum.zw += updVals.xy;\n                found.zw = vec2(1.);\n              }\n              if (flattenedIndex[1] == coords[0]) {\n                sum.xy += updVals.zw;\n                found.xy = vec2(1.);\n              } else if (flattenedIndex[1] == coords[0] + 1) {\n                sum.zw += updVals.zw;\n                found.zw = vec2(1.);\n              }\n            }\n          }\n          setOutput(mix(").concat(defaultValueSnippet, ", sum, found));\n        }\n      ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function scatterNd(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var indices = inputs.indices,
	    updates = inputs.updates;
	  var shape = attrs.shape;
	  var _backend_util$calcula = calculateShapes(updates, indices, shape),
	    sliceRank = _backend_util$calcula.sliceRank,
	    numUpdates = _backend_util$calcula.numUpdates,
	    sliceSize = _backend_util$calcula.sliceSize,
	    strides = _backend_util$calcula.strides,
	    outputSize = _backend_util$calcula.outputSize;
	  var flattenShape = [outputSize / sliceSize, sliceSize];
	  if (outputSize === 0) {
	    return backend.makeTensorInfo(shape, indices.dtype);
	  }
	  var flattenIndices = reshape({
	    inputs: {
	      x: indices
	    },
	    backend: backend,
	    attrs: {
	      shape: [numUpdates, sliceRank]
	    }
	  });
	  var flattenX = reshape({
	    inputs: {
	      x: updates
	    },
	    backend: backend,
	    attrs: {
	      shape: [numUpdates, sliceSize]
	    }
	  });
	  var defaultValue = backend.makeTensorInfo([], 'float32', new Float32Array([0])); // scalar(0)
	  var program;
	  if (env().getBool('WEBGL_PACK')) {
	    program = new ScatterPackedProgram(numUpdates, sliceRank, flattenIndices.shape.length, flattenX.shape.length, strides, flattenShape);
	  } else {
	    program = new ScatterProgram(numUpdates, sliceRank, flattenIndices.shape.length, flattenX.shape.length, strides, flattenShape);
	  }
	  var res = backend.runWebGLProgram(program, [flattenX, flattenIndices, defaultValue], flattenX.dtype);
	  var reshaped = reshape({
	    inputs: {
	      x: res
	    },
	    backend: backend,
	    attrs: {
	      shape: shape
	    }
	  });
	  backend.disposeIntermediateTensorInfo(flattenIndices);
	  backend.disposeIntermediateTensorInfo(flattenX);
	  backend.disposeIntermediateTensorInfo(res);
	  backend.disposeIntermediateTensorInfo(defaultValue);
	  return reshaped;
	}
	var scatterNdConfig = {
	  kernelName: ScatterNd,
	  backendName: 'webgl',
	  kernelFunc: scatterNd
	};

	var SearchSortedProgram = /*#__PURE__*/_createClass(function SearchSortedProgram(batchSize, numInputs, numValues, side) {
	  _classCallCheck(this, SearchSortedProgram);
	  this.variableNames = ['sortedSequence', 'values'];
	  this.customUniforms = [{
	    name: 'numInputs',
	    type: 'int'
	  }];
	  this.outputShape = [batchSize, numValues];
	  var webGL2LoopHead = 'while (left < right) {';
	  // WebGL1 doesn't accept non constant loop conditions, so upper bound loop
	  // iterations.
	  var webGL1LoopHead = "for (int i = 0; i < ".concat(Math.ceil(Math.log2(numInputs + 1)), "; ++i) { if (left >= right) break;");
	  var loopHead = env().getNumber('WEBGL_VERSION') === 2 ? webGL2LoopHead : webGL1LoopHead;
	  // left corresponds to lower bound and right to upper bound.
	  var boundComparator = side === 'left' ? '<' : '<=';
	  this.userCode = "\n       int findBound(int batch, float value) {\n         int left = 0;\n         int right = numInputs;\n         int mid;\n         ".concat(loopHead, "\n           mid = (left + right) / 2;\n           if (getSortedSequence(batch, mid) ").concat(boundComparator, " value) {\n             left = mid + 1;\n           } else {\n             right = mid;\n           }\n         }\n         return right;\n       }\n\n       void main() {\n         ivec2 coords = getOutputCoords();\n         int batch = coords[0];\n         int valueIndex = coords[1];\n\n         float value = getValues(batch, valueIndex);\n\n         setOutput(float(findBound(batch, value)));\n       }\n     ");
	});

	/**
	 * @license
	 * Copyright 2022 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function searchSorted(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var sortedSequence = inputs.sortedSequence,
	    values = inputs.values;
	  var side = attrs.side;
	  var program = new SearchSortedProgram(sortedSequence.shape[0], sortedSequence.shape[1], values.shape[1], side);
	  var customValues = [[sortedSequence.shape[1]]];
	  return backend.runWebGLProgram(program, [sortedSequence, values], 'int32', customValues);
	}
	var searchSortedConfig = {
	  kernelName: SearchSorted,
	  backendName: 'webgl',
	  kernelFunc: searchSorted
	};

	var SelectProgram = /*#__PURE__*/_createClass(function SelectProgram(cRank, shape, rank) {
	  _classCallCheck(this, SelectProgram);
	  this.variableNames = ['c', 'a', 'b'];
	  this.outputShape = shape;
	  var cCoords;
	  var abCoords;
	  if (rank > 4) {
	    throw Error("Where for rank ".concat(rank, " is not yet supported"));
	  }
	  if (rank === 1) {
	    abCoords = "resRC";
	    cCoords = "resRC";
	  } else {
	    var currentCoords = ['resRC.x', 'resRC.y', 'resRC.z', 'resRC.w'];
	    var cCoordVars = [];
	    var abCoordVars = [];
	    for (var i = 0; i < shape.length; i++) {
	      abCoordVars.push("".concat(currentCoords[i]));
	      if (i < cRank) {
	        cCoordVars.push("".concat(currentCoords[i]));
	      }
	    }
	    cCoords = cCoordVars.join();
	    abCoords = abCoordVars.join();
	  }
	  var dtype = getCoordsDataType(rank);
	  this.userCode = "\n      void main() {\n        ".concat(dtype, " resRC = getOutputCoords();\n        float cVal = getC(").concat(cCoords, ");\n        if (cVal >= 1.0) {\n          setOutput(getA(").concat(abCoords, "));\n        } else {\n          setOutput(getB(").concat(abCoords, "));\n        }\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function select(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var condition = inputs.condition,
	    t = inputs.t,
	    e = inputs.e;
	  var program = new SelectProgram(condition.shape.length, t.shape, t.shape.length);
	  return backend.runWebGLProgram(program, [condition, t, e], upcastType(t.dtype, e.dtype));
	}
	var selectConfig = {
	  kernelName: Select,
	  backendName: 'webgl',
	  kernelFunc: select
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var SELU = "\n  // Stable and Attracting Fixed Point (0, 1) for Normalized Weights.\n  // see: https://arxiv.org/abs/1706.02515\n  float scaleAlpha = ".concat(SELU_SCALEALPHA, ";\n  float scale = ").concat(SELU_SCALE, ";\n  return (x >= 0.0) ? scale * x : scaleAlpha * (exp(x) - 1.0);\n");
	var selu = unaryKernelFunc({
	  opSnippet: SELU
	});
	var seluConfig = {
	  kernelName: Selu$1,
	  backendName: 'webgl',
	  kernelFunc: selu
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var SIGMOID = CHECK_NAN_SNIPPET_UNARY + "\n  return 1.0 / (1.0 + exp(-1.0 * x));\n";
	var SIGMOID_PACKED = "\n  vec4 result = 1.0 / (1.0 + exp(-1.0 * x));\n  bvec4 isNaN = isnan(x);\n\n  result.r = isNaN.r ? x.r : result.r;\n  result.g = isNaN.g ? x.g : result.g;\n  result.b = isNaN.b ? x.b : result.b;\n  result.a = isNaN.a ? x.a : result.a;\n\n  return result;\n";
	var sigmoid = unaryKernelFunc({
	  opSnippet: SIGMOID,
	  packedOpSnippet: SIGMOID_PACKED,
	  cpuKernelImpl: sigmoidImplCPU
	});
	var sigmoidConfig = {
	  kernelName: Sigmoid$1,
	  backendName: 'webgl',
	  kernelFunc: sigmoid
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	// Sign does not propagate NANs.
	var SIGN = "\n  if (isnan(x)) { return 0.0; }\n  return sign(x);\n";
	var sign = unaryKernelFunc({
	  opSnippet: SIGN
	});
	var signConfig = {
	  kernelName: Sign,
	  backendName: 'webgl',
	  kernelFunc: sign
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var SIN = CHECK_NAN_SNIPPET_UNARY + "\n  return sin(x);\n";
	var SIN_PACKED = "\n  vec4 result = sin(x);\n  bvec4 isNaN = isnan(x);\n  ".concat(CHECK_NAN_SNIPPET_PACKED, "\n  return result;\n");
	var sin = unaryKernelFunc({
	  opSnippet: SIN,
	  packedOpSnippet: SIN_PACKED
	});
	var sinConfig = {
	  kernelName: Sin,
	  backendName: 'webgl',
	  kernelFunc: sin
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var SINH = "\n  float e2x = exp(x);\n  return (e2x - 1.0 / e2x) / 2.0;\n";
	var sinh = unaryKernelFunc({
	  opSnippet: SINH
	});
	var sinhConfig = {
	  kernelName: Sinh,
	  backendName: 'webgl',
	  kernelFunc: sinh
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var SOFTPLUS = "\n  float epsilon = 1.1920928955078125e-7;\n  float threshold = log(epsilon) + 2.0;\n\n  bool too_large = x > -threshold;\n  bool too_small = x < threshold;\n\n  float result;\n  float exp_x = exp(x);\n\n  if (too_large){\n    result = x;\n  }\n  else if (too_small){\n    result = exp_x;\n  }\n  else{\n    result = log(exp_x + 1.0);\n  }\n  return result;\n";
	var softplus = unaryKernelFunc({
	  opSnippet: SOFTPLUS
	});
	var softplusConfig = {
	  kernelName: Softplus$1,
	  backendName: 'webgl',
	  kernelFunc: softplus
	};

	var spaceToBatchND = function spaceToBatchND(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var blockShape = attrs.blockShape,
	    paddings = attrs.paddings;
	  assert$1(x.shape.length <= 4, function () {
	    return 'spaceToBatchND for rank > 4 with a WebGL backend not ' + 'implemented yet';
	  });
	  var prod = blockShape.reduce(function (a, b) {
	    return a * b;
	  });
	  var completePaddings = [[0, 0]];
	  completePaddings.push.apply(completePaddings, _toConsumableArray(paddings));
	  for (var i = 1 + blockShape.length; i < x.shape.length; ++i) {
	    completePaddings.push([0, 0]);
	  }
	  var toDispose = [];
	  var paddedX = padV2({
	    inputs: {
	      x: x
	    },
	    backend: backend,
	    attrs: {
	      paddings: completePaddings,
	      constantValue: 0
	    }
	  });
	  var reshapedPaddedShape = getReshaped(paddedX.shape, blockShape, prod, false);
	  var permutedReshapedPaddedPermutation = getPermuted(reshapedPaddedShape.length, blockShape.length, false);
	  var flattenShape = getReshapedPermuted(paddedX.shape, blockShape, prod, false);
	  var reshapedPaddedX = reshape({
	    inputs: {
	      x: paddedX
	    },
	    backend: backend,
	    attrs: {
	      shape: reshapedPaddedShape
	    }
	  });
	  var paddedXT = transpose({
	    inputs: {
	      x: reshapedPaddedX
	    },
	    backend: backend,
	    attrs: {
	      perm: permutedReshapedPaddedPermutation
	    }
	  });
	  var result = reshape({
	    inputs: {
	      x: paddedXT
	    },
	    backend: backend,
	    attrs: {
	      shape: flattenShape
	    }
	  });
	  toDispose.push(paddedX);
	  toDispose.push(reshapedPaddedX);
	  toDispose.push(paddedXT);
	  toDispose.forEach(function (t) {
	    return backend.disposeIntermediateTensorInfo(t);
	  });
	  return result;
	};
	var spaceToBatchNDConfig = {
	  kernelName: SpaceToBatchND,
	  backendName: 'webgl',
	  kernelFunc: spaceToBatchND
	};

	function sparseFillEmptyRows(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var indices = inputs.indices,
	    values = inputs.values,
	    denseShape = inputs.denseShape,
	    defaultValue = inputs.defaultValue;
	  if (denseShape.shape.length !== 1) {
	    throw new Error("Dense shape must be a vector, saw:\n         ".concat(denseShape.shape));
	  }
	  if (indices.shape.length !== 2) {
	    throw new Error("Indices must be a matrix, saw:\n         ".concat(indices.shape));
	  }
	  if (values.shape.length !== 1) {
	    throw new Error("Values must be a vector, saw:\n         ".concat(values.shape));
	  }
	  if (defaultValue.shape.length !== 0) {
	    throw new Error("Default value must be a scalar, saw:\n        ".concat(defaultValue.shape));
	  }
	  var $indices = backend.readSync(indices.dataId);
	  var $values = backend.readSync(values.dataId);
	  var $denseShape = backend.readSync(denseShape.dataId);
	  var $defaultValue = backend.readSync(defaultValue.dataId)[0];
	  var _sparseFillEmptyRowsI = sparseFillEmptyRowsImplCPU($indices, indices.shape, indices.dtype, $values, values.dtype, $denseShape, $defaultValue),
	    _sparseFillEmptyRowsI2 = _slicedToArray(_sparseFillEmptyRowsI, 5),
	    outputIndices = _sparseFillEmptyRowsI2[0],
	    outputIndicesShape = _sparseFillEmptyRowsI2[1],
	    outputValues = _sparseFillEmptyRowsI2[2],
	    emptyRowIndicator = _sparseFillEmptyRowsI2[3],
	    reverseIndexMap = _sparseFillEmptyRowsI2[4];
	  return [backend.makeTensorInfo(outputIndicesShape, indices.dtype, outputIndices), backend.makeTensorInfo([outputIndicesShape[0]], values.dtype, outputValues), backend.makeTensorInfo([emptyRowIndicator.length], 'bool', new Uint8Array(emptyRowIndicator.map(function (value) {
	    return Number(value);
	  }))), backend.makeTensorInfo([reverseIndexMap.length], indices.dtype, new Int32Array(reverseIndexMap))];
	}
	var sparseFillEmptyRowsConfig = {
	  kernelName: SparseFillEmptyRows,
	  backendName: 'webgl',
	  kernelFunc: sparseFillEmptyRows
	};

	function sparseReshape(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var inputIndices = inputs.inputIndices,
	    inputShape = inputs.inputShape,
	    newShape = inputs.newShape;
	  if (inputIndices.shape.length !== 2) {
	    throw new Error("Input indices should be a matrix but received shape ".concat(inputIndices.shape));
	  }
	  if (inputShape.shape.length !== 1) {
	    throw new Error("Input shape should be a vector but received shape ".concat(inputShape.shape));
	  }
	  if (newShape.shape.length !== 1) {
	    throw new Error("Target shape should be a vector but received shape ".concat(newShape.shape));
	  }
	  var $inputShape = Array.from(backend.readSync(inputShape.dataId));
	  var $inputIndices = backend.readSync(inputIndices.dataId);
	  var targetShape = Array.from(backend.readSync(newShape.dataId));
	  var _sparseReshapeImplCPU = sparseReshapeImplCPU($inputIndices, inputIndices.shape, inputIndices.dtype, $inputShape, targetShape),
	    _sparseReshapeImplCPU2 = _slicedToArray(_sparseReshapeImplCPU, 3),
	    newIndices = _sparseReshapeImplCPU2[0],
	    indicesShape = _sparseReshapeImplCPU2[1],
	    outputShape = _sparseReshapeImplCPU2[2];
	  return [backend.makeTensorInfo(indicesShape, inputIndices.dtype, newIndices), backend.makeTensorInfo([outputShape.length], newShape.dtype, new Int32Array(outputShape))];
	}
	var sparseReshapeConfig = {
	  kernelName: SparseReshape,
	  backendName: 'webgl',
	  kernelFunc: sparseReshape
	};

	function sparseSegmentMean(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var data = inputs.data,
	    indices = inputs.indices,
	    segmentIds = inputs.segmentIds;
	  if (data.shape.length < 1) {
	    throw new Error("Data should be at least 1 dimensional but received scalar");
	  }
	  if (indices.shape.length !== 1) {
	    throw new Error("Indices should be a vector but received shape\n              ".concat(indices.shape));
	  }
	  if (segmentIds.shape.length !== 1) {
	    throw new Error("Segment ids should be a vector but received shape\n              ".concat(segmentIds.shape));
	  }
	  var $data = backend.readSync(data.dataId);
	  var $indices = backend.readSync(indices.dataId);
	  var $segmentIds = backend.readSync(segmentIds.dataId);
	  var _sparseSegmentReducti = sparseSegmentReductionImplCPU($data, data.shape, data.dtype, $indices, $segmentIds, true),
	    _sparseSegmentReducti2 = _slicedToArray(_sparseSegmentReducti, 2),
	    outputData = _sparseSegmentReducti2[0],
	    outputDataShape = _sparseSegmentReducti2[1];
	  return backend.makeTensorInfo(outputDataShape, data.dtype, outputData);
	}
	var sparseSegmentMeanConfig = {
	  kernelName: SparseSegmentMean,
	  backendName: 'webgl',
	  kernelFunc: sparseSegmentMean
	};

	function sparseSegmentSum(args) {
	  var inputs = args.inputs,
	    backend = args.backend;
	  var data = inputs.data,
	    indices = inputs.indices,
	    segmentIds = inputs.segmentIds;
	  if (data.shape.length < 1) {
	    throw new Error("Data should be at least 1 dimensional but received scalar");
	  }
	  if (indices.shape.length !== 1) {
	    throw new Error("Indices should be a vector but received shape\n             ".concat(indices.shape));
	  }
	  if (segmentIds.shape.length !== 1) {
	    throw new Error("Segment ids should be a vector but received shape\n             ".concat(segmentIds.shape));
	  }
	  var $data = backend.readSync(data.dataId);
	  var $indices = backend.readSync(indices.dataId);
	  var $segmentIds = backend.readSync(segmentIds.dataId);
	  var _sparseSegmentReducti = sparseSegmentReductionImplCPU($data, data.shape, data.dtype, $indices, $segmentIds),
	    _sparseSegmentReducti2 = _slicedToArray(_sparseSegmentReducti, 2),
	    outputData = _sparseSegmentReducti2[0],
	    outputDataShape = _sparseSegmentReducti2[1];
	  return backend.makeTensorInfo(outputDataShape, data.dtype, outputData);
	}
	var sparseSegmentSumConfig = {
	  kernelName: SparseSegmentSum,
	  backendName: 'webgl',
	  kernelFunc: sparseSegmentSum
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function sparseToDense(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var sparseIndices = inputs.sparseIndices,
	    sparseValues = inputs.sparseValues,
	    defaultValue = inputs.defaultValue;
	  var outputShape = attrs.outputShape;
	  var _backend_util$calcula = calculateShapes(sparseValues, sparseIndices, outputShape),
	    sliceRank = _backend_util$calcula.sliceRank,
	    numUpdates = _backend_util$calcula.numUpdates,
	    sliceSize = _backend_util$calcula.sliceSize,
	    strides = _backend_util$calcula.strides,
	    outputSize = _backend_util$calcula.outputSize;
	  var sumDupeIndices = false;
	  if (sparseValues.dtype === 'string') {
	    var indicesBuf = backend.bufferSync(sparseIndices);
	    var updatesBuf = backend.bufferSync(sparseValues);
	    var $defaultValue = decodeString(backend.readSync(defaultValue.dataId)[0]);
	    var outBuf = scatterImplCPU(indicesBuf, updatesBuf, outputShape, outputSize, sliceSize, numUpdates, sliceRank, strides, $defaultValue, sumDupeIndices);
	    return backend.makeTensorInfo(outputShape, outBuf.dtype, outBuf.values);
	  }
	  var program = new ScatterProgram(numUpdates, sliceRank, sparseIndices.shape.length, sparseValues.shape.length, strides, [outputSize, 1], sumDupeIndices);
	  var res = backend.runWebGLProgram(program, [sparseValues, sparseIndices, defaultValue], sparseValues.dtype);
	  var reshaped = reshape({
	    inputs: {
	      x: res
	    },
	    backend: backend,
	    attrs: {
	      shape: outputShape
	    }
	  });
	  backend.disposeIntermediateTensorInfo(res);
	  return reshaped;
	}
	var sparseToDenseConfig = {
	  kernelName: SparseToDense,
	  backendName: 'webgl',
	  kernelFunc: sparseToDense
	};

	function splitV(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var numOrSizeSplits = attrs.numOrSizeSplits,
	    axis = attrs.axis;
	  var $axis = parseAxisParam(axis, x.shape)[0];
	  var splitSizes = prepareSplitSize(x, numOrSizeSplits, $axis);
	  var xRank = x.shape.length;
	  var begin = new Array(xRank).fill(0);
	  var size = x.shape.slice();
	  return splitSizes.map(function (s) {
	    var sliceSize = _toConsumableArray(size);
	    sliceSize[$axis] = s;
	    var sliceT = slice({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        begin: begin,
	        size: sliceSize
	      }
	    });
	    begin[$axis] += s;
	    return sliceT;
	  });
	}
	var splitVConfig = {
	  kernelName: SplitV,
	  backendName: 'webgl',
	  kernelFunc: splitV
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var SQRT = "return sqrt(x);";
	var sqrt = unaryKernelFunc({
	  opSnippet: SQRT,
	  packedOpSnippet: SQRT,
	  cpuKernelImpl: sqrtImplCPU
	});
	var sqrtConfig = {
	  kernelName: Sqrt,
	  backendName: 'webgl',
	  kernelFunc: sqrt
	};

	/**
	 * @license
	 * Copyright 2019 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var SQUARE = "return x * x;";
	var square = unaryKernelFunc({
	  opSnippet: SQUARE
	});
	var squareConfig = {
	  kernelName: Square,
	  backendName: 'webgl',
	  kernelFunc: square
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var SQUARED_DIFFERENCE = 'return (a - b) * (a - b);';
	var squaredDifference = binaryKernelFunc({
	  opSnippet: SQUARED_DIFFERENCE,
	  packedOpSnippet: SQUARED_DIFFERENCE
	});
	var squaredDifferenceConfig = {
	  kernelName: SquaredDifference,
	  backendName: 'webgl',
	  kernelFunc: squaredDifference
	};

	/**
	 * @license
	 * Copyright 2023 Google LLC.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function staticRegexReplace(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  if (x.dtype !== 'string') {
	    throw new Error('Input must be of datatype string');
	  }
	  var $x = backend.readSync(x.dataId);
	  var stringInput = fromUint8ToStringArray($x);
	  var output = staticRegexReplaceImplCPU(stringInput, 'string', attrs);
	  return backend.makeTensorInfo(x.shape, 'string', output);
	}
	var staticRegexReplaceConfig = {
	  kernelName: StaticRegexReplace,
	  backendName: 'webgl',
	  kernelFunc: staticRegexReplace
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function step(_ref) {
	  var inputs = _ref.inputs,
	    attrs = _ref.attrs,
	    backend = _ref.backend;
	  var x = inputs.x;
	  var opSnippet = CHECK_NAN_SNIPPET$1 + "\n    return x > 0.0 ? 1.0 : float(".concat(attrs.alpha, ");\n  ");
	  var program = new UnaryOpProgram(x.shape, opSnippet);
	  return backend.runWebGLProgram(program, [x], x.dtype);
	}
	var stepConfig = {
	  kernelName: Step,
	  backendName: 'webgl',
	  kernelFunc: step
	};

	var StridedSliceProgram = /*#__PURE__*/_createClass(function StridedSliceProgram(begin, strides, size) {
	  _classCallCheck(this, StridedSliceProgram);
	  this.variableNames = ['x'];
	  this.outputShape = size;
	  var rank = size.length;
	  var inputDtype = getCoordsDataType(size.length);
	  var dtype = getCoordsDataType(size.length);
	  var newCoords = '';
	  if (rank === 1) {
	    newCoords = 'coords * strides + begin';
	  } else {
	    var outputAxis = 0;
	    newCoords = size.map(function (_, i) {
	      outputAxis++;
	      return size.length === 1 ? "coords * strides[".concat(i, "] + begin[").concat(i, "]") : "coords[".concat(outputAxis - 1, "] * strides[").concat(i, "] + begin[").concat(i, "]");
	    }).join(',');
	  }
	  this.userCode = "\n      ".concat(inputDtype, " begin = ").concat(inputDtype, "(").concat(begin, ");\n      ").concat(inputDtype, " strides = ").concat(inputDtype, "(").concat(strides, ");\n\n      void main() {\n        ").concat(dtype, " coords = getOutputCoords();\n        setOutput(getX(").concat(newCoords, "));\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function stridedSlice(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var begin = attrs.begin,
	    end = attrs.end,
	    strides = attrs.strides,
	    beginMask = attrs.beginMask,
	    endMask = attrs.endMask,
	    ellipsisMask = attrs.ellipsisMask,
	    newAxisMask = attrs.newAxisMask,
	    shrinkAxisMask = attrs.shrinkAxisMask;
	  var _slice_util$sliceInfo = sliceInfo(x.shape, begin, end, strides, beginMask, endMask, ellipsisMask, newAxisMask, shrinkAxisMask),
	    finalShapeSparse = _slice_util$sliceInfo.finalShapeSparse,
	    finalShape = _slice_util$sliceInfo.finalShape,
	    isIdentity = _slice_util$sliceInfo.isIdentity,
	    sliceDim0 = _slice_util$sliceInfo.sliceDim0,
	    isSimpleSlice = _slice_util$sliceInfo.isSimpleSlice,
	    $begin = _slice_util$sliceInfo.begin,
	    $end = _slice_util$sliceInfo.end,
	    $strides = _slice_util$sliceInfo.strides;
	  var result;
	  if (isIdentity) {
	    // Optimization #1, slice is a no-op plus reshape
	    result = reshape({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        shape: finalShape
	      }
	    });
	  } else if (sliceDim0 || isSimpleSlice) {
	    // Optimization #2, slice is memory contiguous (only occurs in dim 0)
	    assert$1(x.shape.length >= 1, function () {
	      return "Input must have rank at least 1, got: ".concat(x.shape.length);
	    });
	    var size = computeOutShape$2($begin, $end, $strides);
	    // To tolerate begin[0] > end[0] (a 0-output slice), we min(begin, end).
	    var sliced = slice({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        begin: $begin,
	        size: size
	      }
	    });
	    result = reshape({
	      inputs: {
	        x: sliced
	      },
	      backend: backend,
	      attrs: {
	        shape: finalShape
	      }
	    });
	    backend.disposeIntermediateTensorInfo(sliced);
	  } else {
	    var shouldExecuteOnCPU = backend.shouldExecuteOnCPU([x]);
	    if (shouldExecuteOnCPU) {
	      // tslint:disable-next-line: no-unnecessary-type-assertion
	      var values = backend.readSync(x.dataId);
	      // tslint:disable-next-line: no-unnecessary-type-assertion
	      var xBuf = buffer(x.shape, x.dtype, values);
	      var resultValues = stridedSliceImplCPU(finalShapeSparse, xBuf, $strides, $begin);
	      result = backend.makeTensorInfo(finalShape, x.dtype, resultValues.values);
	    } else {
	      var program = new StridedSliceProgram($begin, $strides, finalShapeSparse);
	      result = backend.runWebGLProgram(program, [x], x.dtype);
	    }
	  }
	  var resultReshaped = reshape({
	    inputs: {
	      x: result
	    },
	    backend: backend,
	    attrs: {
	      shape: finalShape
	    }
	  });
	  backend.disposeIntermediateTensorInfo(result);
	  return resultReshaped;
	}
	var stridedSliceConfig = {
	  kernelName: StridedSlice,
	  backendName: 'webgl',
	  kernelFunc: stridedSlice
	};

	function stringNGrams(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var separator = attrs.separator,
	    nGramWidths = attrs.nGramWidths,
	    leftPad = attrs.leftPad,
	    rightPad = attrs.rightPad,
	    padWidth = attrs.padWidth,
	    preserveShortSequences = attrs.preserveShortSequences;
	  var data = inputs.data,
	    dataSplits = inputs.dataSplits;
	  var $data = backend.readSync(data.dataId);
	  var $dataSplits = backend.readSync(dataSplits.dataId);
	  var _stringNGramsImplCPU = stringNGramsImplCPU($data, $dataSplits, separator, nGramWidths, leftPad, rightPad, padWidth, preserveShortSequences),
	    _stringNGramsImplCPU2 = _slicedToArray(_stringNGramsImplCPU, 2),
	    nGrams = _stringNGramsImplCPU2[0],
	    nGramsSplits = _stringNGramsImplCPU2[1];
	  return [backend.makeTensorInfo([nGrams.length], 'string', nGrams), backend.makeTensorInfo(dataSplits.shape, 'int32', nGramsSplits)];
	}
	var stringNGramsConfig = {
	  kernelName: StringNGrams,
	  backendName: 'webgl',
	  kernelFunc: stringNGrams
	};

	function stringSplit(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var skipEmpty = attrs.skipEmpty;
	  var input = inputs.input,
	    delimiter = inputs.delimiter;
	  if (input.dtype !== 'string') {
	    throw new Error('Input must be of datatype string');
	  }
	  if (input.shape.length !== 1) {
	    throw new Error("Input must be a vector, got shape: ".concat(input.shape));
	  }
	  if (delimiter.shape.length !== 0) {
	    throw new Error("Delimiter must be a scalar, got shape: ".concat(delimiter.shape));
	  }
	  var $input = backend.readSync(input.dataId);
	  var $delimiter = backend.readSync(delimiter.dataId)[0];
	  var _stringSplitImplCPU = stringSplitImplCPU($input, $delimiter, skipEmpty),
	    _stringSplitImplCPU2 = _slicedToArray(_stringSplitImplCPU, 3),
	    indices = _stringSplitImplCPU2[0],
	    values = _stringSplitImplCPU2[1],
	    shape = _stringSplitImplCPU2[2];
	  var outputSize = values.length;
	  return [backend.makeTensorInfo([outputSize, 2], 'int32', indices), backend.makeTensorInfo([outputSize], 'string', values), backend.makeTensorInfo([2], 'int32', new Int32Array(shape))];
	}
	var stringSplitConfig = {
	  kernelName: StringSplit,
	  backendName: 'webgl',
	  kernelFunc: stringSplit
	};

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function stringToHashBucketFast(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var numBuckets = attrs.numBuckets;
	  var input = inputs.input;
	  if (input.dtype !== 'string') {
	    throw new Error('Input must be of datatype string');
	  }
	  if (numBuckets <= 0) {
	    throw new Error("Number of buckets must be at least 1");
	  }
	  var $input = backend.readSync(input.dataId);
	  var output = stringToHashBucketFastImplCPU($input, numBuckets);
	  return backend.makeTensorInfo(input.shape, 'int32', output);
	}
	var stringToHashBucketFastConfig = {
	  kernelName: StringToHashBucketFast,
	  backendName: 'webgl',
	  kernelFunc: stringToHashBucketFast
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var TAN = "return tan(x);";
	var tan = unaryKernelFunc({
	  opSnippet: TAN
	});
	var tanConfig = {
	  kernelName: Tan,
	  backendName: 'webgl',
	  kernelFunc: tan
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var TANH = "\n  float e2x = exp(-2.0 * abs(x));\n  return sign(x) * (1.0 - e2x) / (1.0 + e2x);\n";
	var tanh = unaryKernelFunc({
	  opSnippet: TANH
	});
	var tanhConfig = {
	  kernelName: Tanh$1,
	  backendName: 'webgl',
	  kernelFunc: tanh
	};

	function tensorScatterUpdate(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var tensor = inputs.tensor,
	    indices = inputs.indices,
	    updates = inputs.updates;
	  _objectDestructuringEmpty(attrs);
	  var _backend_util$calcula = calculateShapes(updates, indices, tensor.shape),
	    sliceRank = _backend_util$calcula.sliceRank,
	    numUpdates = _backend_util$calcula.numUpdates,
	    sliceSize = _backend_util$calcula.sliceSize,
	    strides = _backend_util$calcula.strides,
	    outputSize = _backend_util$calcula.outputSize;
	  var flattenShape = [outputSize / sliceSize, sliceSize];
	  if (outputSize === 0) {
	    return backend.makeTensorInfo(tensor.shape, indices.dtype);
	  }
	  var flattenIndices = reshape({
	    inputs: {
	      x: indices
	    },
	    backend: backend,
	    attrs: {
	      shape: [numUpdates, sliceRank]
	    }
	  });
	  var flattenX = reshape({
	    inputs: {
	      x: updates
	    },
	    backend: backend,
	    attrs: {
	      shape: [numUpdates, sliceSize]
	    }
	  });
	  var flattenTensor = reshape({
	    inputs: {
	      x: tensor
	    },
	    backend: backend,
	    attrs: {
	      shape: flattenShape
	    }
	  });
	  var program = new ScatterProgram(numUpdates, sliceRank, flattenIndices.shape.length, flattenX.shape.length, strides, flattenShape, false, true);
	  var res = backend.runWebGLProgram(program, [flattenX, flattenIndices, flattenTensor], flattenTensor.dtype);
	  var reshaped = reshape({
	    inputs: {
	      x: res
	    },
	    backend: backend,
	    attrs: {
	      shape: tensor.shape
	    }
	  });
	  backend.disposeIntermediateTensorInfo(flattenIndices);
	  backend.disposeIntermediateTensorInfo(flattenX);
	  backend.disposeIntermediateTensorInfo(flattenTensor);
	  backend.disposeIntermediateTensorInfo(res);
	  return reshaped;
	}
	var tensorScatterUpdateConfig = {
	  kernelName: TensorScatterUpdate,
	  backendName: 'webgl',
	  kernelFunc: tensorScatterUpdate
	};

	var TileProgram = /*#__PURE__*/_createClass(function TileProgram(aShape, reps) {
	  _classCallCheck(this, TileProgram);
	  this.variableNames = ['A'];
	  var outputShape = new Array(aShape.length);
	  for (var i = 0; i < outputShape.length; i++) {
	    outputShape[i] = aShape[i] * reps[i];
	  }
	  this.outputShape = outputShape;
	  this.rank = outputShape.length;
	  var dtype = getCoordsDataType(this.rank);
	  var sourceCoords = getSourceCoords(aShape);
	  this.userCode = "\n      void main() {\n        ".concat(dtype, " resRC = getOutputCoords();\n        setOutput(getA(").concat(sourceCoords, "));\n      }\n    ");
	});
	function getSourceCoords(aShape) {
	  var rank = aShape.length;
	  if (rank > 5) {
	    throw Error("Tile for rank ".concat(rank, " is not yet supported"));
	  }
	  if (rank === 1) {
	    return "imod(resRC, ".concat(aShape[0], ")");
	  }
	  var currentCoords = ['resRC.x', 'resRC.y', 'resRC.z', 'resRC.w', 'resRC.u'];
	  var sourceCoords = [];
	  for (var i = 0; i < aShape.length; i++) {
	    sourceCoords.push("imod(".concat(currentCoords[i], ", ").concat(aShape[i], ")"));
	  }
	  return sourceCoords.join();
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function tile(params) {
	  var inputs = params.inputs,
	    backend = params.backend,
	    attrs = params.attrs;
	  var x = inputs.x;
	  var reps = attrs.reps;
	  // tile gpu program cannot handle rank > 5 case.
	  if (x.dtype === 'string' || x.shape.length > 5) {
	    // Even thought string tensor is always on CPU, just to be consistent on how
	    // to access tensor data.
	    var data = backend.readSync(x.dataId);
	    var value = x.dtype === 'string' ? data.map(function (d) {
	      return decodeString(d);
	    }) : data;
	    var buf = buffer(x.shape, x.dtype, value);
	    var outBuf = tileImplCPU(buf, reps);
	    return backend.makeTensorInfo(outBuf.shape, outBuf.dtype, outBuf.values);
	  }
	  var program = new TileProgram(x.shape, reps);
	  var output = backend.runWebGLProgram(program, [x], x.dtype);
	  return output;
	}
	var tileConfig = {
	  kernelName: Tile,
	  backendName: 'webgl',
	  kernelFunc: tile
	};

	// Based on Algorithm 2 of Bitonic Top K, ref:
	// https://anilshanbhag.in/static/papers/gputopk_sigmod18.pdf
	// The original algorithm is based on computing the top K only, however
	// since for TFJS we require the indices of the top K values as well then the
	// algorithm found here is a bit modified. Rather than producing the values
	// at each step, the indices containing the top K are generated instead.
	// The output values are not generated to reduce the number of outputs in the
	// GPU, the values can easily be retrieved from the indices using a gather
	// op.
	var SwapProgram = /*#__PURE__*/_createClass(
	/**
	 * @param shape desired output shape (can be larger than input shape, output
	 *                                    will be padded with -Infinity)
	 */
	function SwapProgram(shape) {
	  _classCallCheck(this, SwapProgram);
	  this.variableNames = ['x', 'indices'];
	  // |n| Size of the original input of TopK.
	  // |firstPass|indicates if this is the first time swap is being used which
	  // means no indices input containing the top K is present yet.
	  // |inc| Swaps pairs of indices (0, inc), (1, inc + 1), (2, inc + 2) ...
	  this.customUniforms = [{
	    name: 'n',
	    type: 'int'
	  }, {
	    name: 'firstPass',
	    type: 'int'
	  }, {
	    name: 'negativeInf',
	    type: 'float'
	  }, {
	    name: 'dir',
	    type: 'int'
	  }, {
	    name: 'inc',
	    type: 'int'
	  }];
	  this.outputShape = shape;
	  this.userCode = "\n       void main() {\n         ivec2 coords = getOutputCoords();\n         int batch = coords[0];\n         int elemIdx = coords[1];\n\n         // We compare elements pair-wise within a group of size 2 * inc.\n         // The comparing rule for each group alternates between ascending\n         // and descending. Within each group, we compare each pair at\n         // positions i and i+inc. To decide whether an element at position i\n         // is x0 or x1, we mod it by 2 * inc, if the result is smaller than\n         // inc, it is in the first half of the group, we denote it as x0,\n         // otherwise we denote it as x1.\n         // For example, as shown in the Bitonic top K paper referenced above,\n         // Figure5(a) shows that element[1] is in the\n         // second half of the group when group size is 2, but it is in the\n         // first half of the group when group size is 4.\n\n         bool isFirstInPair = imod(elemIdx, 2 * inc) < inc;\n         int i = isFirstInPair ? elemIdx : elemIdx - inc;\n\n         int i0 = firstPass == 1 ? i : int(getIndices(batch, i));\n         int i1 = firstPass == 1 ? i + inc : int(getIndices(batch, i + inc));\n         float x0 = i0 < n ? getX(batch, i0) : negativeInf;\n         float x1 = i1 < n ? getX(batch, i1) : negativeInf;\n\n         // Denotes which direction indices are in (ascending or descending).\n         bool reverse = imod(elemIdx, 2 * dir) >= dir;\n         bool isGreater = x0 > x1 || (x0 == x1 && i1 > i0);\n         if (reverse == isGreater) { // Elements in opposite order of direction\n           int iTemp = i0;\n           i0 = i1;\n           i1 = iTemp;\n         }\n         if (isFirstInPair) {\n            setOutput(float(i0));\n         } else {\n            setOutput(float(i1));\n         }\n       }\n     ";
	});
	var MergeProgram = /*#__PURE__*/_createClass(
	/**
	 * @param shape desired output shape (must be half of the input size)
	 */
	function MergeProgram(shape) {
	  _classCallCheck(this, MergeProgram);
	  this.variableNames = ['x', 'indices'];
	  // |n| Size of the original input of TopK
	  // |firstPass| indicates if this is the first time swap is being used which
	  // means no indices input containing the top K is present yet.
	  // |k| Top k elements desired
	  this.customUniforms = [{
	    name: 'n',
	    type: 'int'
	  }, {
	    name: 'firstPass',
	    type: 'int'
	  }, {
	    name: 'k',
	    type: 'int'
	  }];
	  this.outputShape = shape;
	  this.userCode = "\n    void main() {\n         // Takes max of indices (0, k), (1, k + 1), (2, k + 2) ...\n         ivec2 coords = getOutputCoords();\n         int batch = coords[0];\n         int elemIdx = coords[1];\n\n         // The output size is half of the previous size.\n         // If the previous sequence is | | | | _ _ _ _  | | | |  _ _ _ _ (k=4),\n         // we only need to output the indices at positions |, the indices at\n         // positions _ can be thrown away, see Figure5(b) After Phase 2\n         // (Merge phase) in the Bitonic Top K paper referenced above.\n         // For example, the paper shows we only need to output the orange bars.\n         // The output sequence should look like this | | | | | | | |.\n         // Because the sequence is halved, to map the output index back\n         // to the previous sequence to find the corresponding value,\n         // we need to double the index. When we double the index,\n         // we basically interpolate a position, so 2i looks like\n         // | _ | _ | _ | _ | _ | _ | _. We move the | to the first k position\n         // of each 2k positions by - elemIdx % k. E.g. for output at\n         // index 4,5,6,7, we want to get the corresponding element at\n         // original index 8,9,10,11, for output at index 8,9,10,11,\n         // we want to get the corresponding element at original index\n         // 16,17,18,19, so on and so forth.\n\n         int i = elemIdx < k ? elemIdx : (elemIdx * 2 - imod(elemIdx, k));\n         int i0 = firstPass == 1 ? i : int(getIndices(batch, i));\n         int i1 = firstPass == 1 ? i + k : int(getIndices(batch, i + k));\n\n         float x0 = getX(batch, i0);\n         float x1 = i1 < n ? getX(batch, i1) : x0;\n\n         setOutput(x0 >= x1 ? float(i0) : float(i1));\n       }\n     ";
	});

	function disposeIntermediateTensorInfoOrNull(backend, tensorInfo) {
	  if (tensorInfo !== null) {
	    backend.disposeIntermediateTensorInfo(tensorInfo);
	  }
	}
	function roundUpToPow2(num) {
	  var pow2 = 1;
	  while (pow2 < num) {
	    pow2 *= 2;
	  }
	  return pow2;
	}
	// Based on Algorithm 2 of Bitonic Top K, ref:
	// https://anilshanbhag.in/static/papers/gputopk_sigmod18.pdf
	function topK(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x;
	  var k = attrs.k,
	    sorted = attrs.sorted;
	  // Empirically determined constant used to determine last dim threshold for
	  // handing off execution to the CPU.
	  var TOPK_LAST_DIM_CPU_HANDOFF_SIZE_THRESHOLD = env().getNumber('TOPK_LAST_DIM_CPU_HANDOFF_SIZE_THRESHOLD');
	  // Empirically determined constant used to determine k threshold for handing
	  // off execution to the CPU.
	  var TOPK_K_CPU_HANDOFF_THRESHOLD = env().getNumber('TOPK_K_CPU_HANDOFF_THRESHOLD');
	  var xShape = x.shape;
	  var lastDim = xShape[xShape.length - 1];
	  if (backend.shouldExecuteOnCPU([x]) || lastDim < TOPK_LAST_DIM_CPU_HANDOFF_SIZE_THRESHOLD || k > TOPK_K_CPU_HANDOFF_THRESHOLD) {
	    var xVals = backend.readSync(x.dataId);
	    var _topKImplCPU = topKImplCPU(xVals, xShape, x.dtype, k, sorted),
	      _topKImplCPU2 = _slicedToArray(_topKImplCPU, 2),
	      allTopKVals = _topKImplCPU2[0],
	      allTopKIndices = _topKImplCPU2[1];
	    return [backend.makeTensorInfo(allTopKVals.shape, allTopKVals.dtype, allTopKVals.values), backend.makeTensorInfo(allTopKIndices.shape, allTopKIndices.dtype, allTopKIndices.values)];
	  }
	  if (k === 0) {
	    xShape[xShape.length - 1] = 0;
	    return [backend.makeTensorInfo(xShape, x.dtype, []), backend.makeTensorInfo(xShape, 'int32', [])];
	  }
	  if (lastDim === 1 /* firstPass */) {
	    return [x, fill({
	      attrs: {
	        shape: xShape,
	        dtype: 'int32',
	        value: 0
	      },
	      backend: backend
	    })];
	  }
	  // Eagerly unpack x input since it is passed in to all the shaders which
	  // require unpacked inputs.
	  var xtexData = backend.texData.get(x.dataId);
	  var xIsPacked = xtexData !== null && xtexData.isPacked;
	  var xUnPacked = xIsPacked ? backend.unpackTensor(x) : x;
	  // Reshape into a 2d tensor [batch, lastDim] and compute topk along lastDim.
	  var xSize = sizeFromShape(xShape);
	  var batch = xSize / lastDim;
	  var x2D = reshape({
	    inputs: {
	      x: xUnPacked
	    },
	    attrs: {
	      shape: [batch, lastDim]
	    },
	    backend: backend
	  });
	  if (xIsPacked) {
	    disposeIntermediateTensorInfoOrNull(backend, xUnPacked);
	  }
	  var kPow2 = roundUpToPow2(k);
	  var lastDimPow2 = roundUpToPow2(lastDim);
	  // Only the indices containing the top K are kept at every step to reduce
	  // number of outputs in the GPU algorithms, so once the final set of indices
	  // is computed then gather is used to grab the corresponding values
	  // from the original input.
	  var indices = null;
	  // GPU algorithm always takes in an indices input but this input is not used
	  // on the first run of a GPU algorithm, therefore if indices is null we simply
	  // pass in x2D instead of it but the value will not actually be used
	  var getInputs = function getInputs() {
	    return indices === null ? [x2D, x2D] : [x2D, indices];
	  };
	  var runSwap = function runSwap(dir, inc, shape) {
	    var inputs = getInputs();
	    var program = new SwapProgram(shape);
	    var fistPass = indices === null ? 1 : 0;
	    var customValues = [[lastDim], [fistPass], [Number.NEGATIVE_INFINITY], [dir], [inc]];
	    var prevIndices = indices;
	    indices = backend.runWebGLProgram(program, inputs, 'int32', customValues);
	    disposeIntermediateTensorInfoOrNull(backend, prevIndices);
	  };
	  // Step 1: local sort
	  for (var len = 1; len < kPow2; len *= 2) {
	    var dir = len * 2;
	    for (var inc = len; inc >= 1; inc /= 2) {
	      runSwap(dir, inc, [batch, lastDimPow2]);
	    }
	  }
	  // Step 2: merge
	  for (var indicesSize = lastDimPow2; indicesSize > kPow2; indicesSize /= 2) {
	    var _inputs = getInputs();
	    var mergeProgram = new MergeProgram([batch, indicesSize / 2]);
	    var firstPass = indices === null ? 1 : 0;
	    var customValues = [[lastDim], [firstPass], [kPow2]];
	    var _prevIndices = indices;
	    indices = backend.runWebGLProgram(mergeProgram, _inputs, 'int32', customValues);
	    disposeIntermediateTensorInfoOrNull(backend, _prevIndices);
	    // Step 3: rebuild
	    var _len = kPow2 / 2;
	    var _dir = _len * 2;
	    for (var _inc = _len; _inc >= 1; _inc /= 2) {
	      runSwap(_dir, _inc, indices.shape);
	    }
	  }
	  // Keep only the requested top K results instead of kPow2
	  var prevIndices = indices;
	  indices = slice({
	    inputs: {
	      x: indices
	    },
	    backend: backend,
	    attrs: {
	      begin: 0,
	      size: [batch, k]
	    }
	  });
	  disposeIntermediateTensorInfoOrNull(backend, prevIndices);
	  // Gather values on last dimension
	  var values = gatherV2({
	    inputs: {
	      x: x2D,
	      indices: indices
	    },
	    backend: backend,
	    attrs: {
	      axis: 1,
	      batchDims: 1
	    }
	  });
	  disposeIntermediateTensorInfoOrNull(backend, x2D);
	  // Reshape back to the original input shape, except that the last
	  // dimension is k.
	  var newShape = xShape.slice(0, -1);
	  newShape.push(k);
	  prevIndices = indices;
	  indices = reshape({
	    inputs: {
	      x: indices
	    },
	    attrs: {
	      shape: newShape
	    },
	    backend: backend
	  });
	  disposeIntermediateTensorInfoOrNull(backend, prevIndices);
	  var prevValues = values;
	  values = reshape({
	    inputs: {
	      x: values
	    },
	    attrs: {
	      shape: newShape
	    },
	    backend: backend
	  });
	  disposeIntermediateTensorInfoOrNull(backend, prevValues);
	  return [values, indices];
	}
	var topKConfig = {
	  kernelName: TopK,
	  backendName: 'webgl',
	  kernelFunc: topK
	};

	/**
	 * @license
	 * Copyright 2021 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var TransformProgram = /*#__PURE__*/_createClass(function TransformProgram(imageHeight, imageWidth, interpolation, fillMode, fillValue, outShape) {
	  _classCallCheck(this, TransformProgram);
	  this.variableNames = ['Image', 'Transforms'];
	  this.outputShape = outShape;
	  var interpolationModeId = interpolation === 'nearest' ? 1 : 2;
	  var fillModeId;
	  switch (fillMode) {
	    case 'constant':
	      fillModeId = 1;
	      break;
	    case 'reflect':
	      fillModeId = 2;
	      break;
	    case 'wrap':
	      fillModeId = 3;
	      break;
	    case 'nearest':
	      fillModeId = 4;
	      break;
	    default:
	      fillModeId = 1;
	      break;
	  }
	  this.userCode = "\n            float mapCoord(float outCoord, float len) {\n              float inCoord = outCoord;\n              if(".concat(fillModeId, " == 2) {\n                if (inCoord < 0.0) {\n                  if (len <= 1.0) {\n                    inCoord = 0.0;\n                  } else {\n                    float sz2 = 2.0 * len;\n                    if (inCoord < sz2) {\n                      inCoord = sz2 * float(int(float(-inCoord / sz2))) +\n                      inCoord;\n                    }\n                    inCoord = inCoord < -len ? inCoord + sz2 : -inCoord - 1.0;\n                  }\n                } else if (inCoord > len - 1.0) {\n                  if (len <= 1.0) {\n                    inCoord = 0.0;\n                  } else {\n                    float sz2 = 2.0 * len;\n                    inCoord -= sz2 * float(int(float(inCoord / sz2)));\n                    if (inCoord >= len) {\n                      inCoord = sz2 - inCoord - 1.0;\n                    }\n                  }\n                }\n                return clamp(inCoord, 0.0, len - 1.0);\n              } else if (").concat(fillModeId, " == 3) {\n                if (inCoord < 0.0) {\n                  if (len <= 1.0) {\n                    inCoord = 0.0;\n                  } else {\n                    float sz = len - 1.0;\n                    inCoord += len * (float(int(float(-inCoord / sz))) + 1.0);\n                  }\n                } else if (inCoord > len - 1.0) {\n                  if (len <= 1.0) {\n                    inCoord = 0.0;\n                  } else {\n                    float sz = len - 1.0;\n                    inCoord -= len * float(int(float(inCoord / sz)));\n                  }\n                }\n                return clamp(inCoord, 0.0, len - 1.0);\n              } else if (").concat(fillModeId, " == 4) {\n                return clamp(outCoord, 0.0, len - 1.0);\n              } else {\n                return outCoord;\n              }\n            }\n\n            float readWithFillValue(int batch, int coordY, int coordX,\n              int channel) {\n              float outputValue;\n              if (0 <= coordY && coordY < ").concat(imageHeight, " && 0 <= coordX && coordX < ").concat(imageWidth, ") {\n                  outputValue = getImage(batch, coordY, coordX, channel);\n              } else {\n                outputValue = float(").concat(fillValue, ");\n              }\n              return outputValue;\n            }\n\n            void main() {\n              ivec4 coords = getOutputCoords();\n              float outputValue;\n              int batch = coords[0];\n              int x = coords[2];\n              int y = coords[1];\n              int channel = coords[3];\n              float xf = float(x);\n              float yf = float(y);\n              float a1 = getTransforms(batch, 0);\n              float a2 = getTransforms(batch, 1);\n              float a3 = getTransforms(batch, 2);\n              float b1 = getTransforms(batch, 3);\n              float b2 = getTransforms(batch, 4);\n              float b3 = getTransforms(batch, 5);\n              float c1 = getTransforms(batch, 6);\n              float c2 = getTransforms(batch, 7);\n              float projection = c1 * xf + c2 * yf + 1.0;\n              if (projection == 0.0) {\n                outputValue = float(").concat(fillValue, ");\n              } else {\n                float inX = (a1 * xf + a2 * yf + a3) / projection;\n                float inY = (b1 * xf + b2 * yf + b3) / projection;\n                float mapX = mapCoord(inX, float(").concat(imageWidth, "));\n                float mapY = mapCoord(inY, float(").concat(imageHeight, "));\n\n                if (").concat(interpolationModeId, " == 1) {\n                  int coordY = int(round(mapY));\n                  int coordX = int(round(mapX));\n                  outputValue = readWithFillValue(batch, coordY, coordX,\n                    channel);\n                } else {\n                  float yFloor = floor(mapY);\n                  float xFloor = floor(mapX);\n                  float yCeil = yFloor + 1.0;\n                  float xCeil = xFloor + 1.0;\n                  float valueYFloor = (xCeil - mapX) *\n                  readWithFillValue(batch, int(yFloor), int(xFloor), channel) +\n                  (mapX - xFloor) *\n                  readWithFillValue(batch, int(yFloor), int(xCeil), channel);\n                  float valueYCeil = (xCeil - mapX) *\n                  readWithFillValue(batch, int(yCeil), int(xFloor), channel) +\n                  (mapX - xFloor) *\n                  readWithFillValue(batch, int(yCeil), int(xCeil), channel);\n                  outputValue = (yCeil - mapY) * valueYFloor +\n                  (mapY - yFloor) * valueYCeil;\n                }\n              }\n              setOutput(outputValue);\n            }\n        ");
	});

	function transform(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var image = inputs.image,
	    transforms = inputs.transforms;
	  var interpolation = attrs.interpolation,
	    fillMode = attrs.fillMode,
	    fillValue = attrs.fillValue,
	    outputShape = attrs.outputShape;
	  var _image$shape = _slicedToArray(image.shape, 4),
	    batch = _image$shape[0],
	    imageHeight = _image$shape[1],
	    imageWidth = _image$shape[2],
	    numChannels = _image$shape[3];
	  var _ref = outputShape != null ? outputShape : [imageHeight, imageWidth],
	    _ref2 = _slicedToArray(_ref, 2),
	    outHeight = _ref2[0],
	    outWidth = _ref2[1];
	  var outShape = [batch, outHeight, outWidth, numChannels];
	  var program = new TransformProgram(imageHeight, imageWidth, interpolation, fillMode, fillValue, outShape);
	  return backend.runWebGLProgram(program, [image, transforms], 'float32');
	}
	var transformConfig = {
	  kernelName: Transform,
	  backendName: 'webgl',
	  kernelFunc: transform
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the License);
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an AS IS BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function unique(args) {
	  var inputs = args.inputs,
	    attrs = args.attrs,
	    backend = args.backend;
	  var axis = attrs.axis;
	  var x = inputs.x;
	  assertNotComplex(x, 'unique');
	  // For now, always forward calculation to the CPU backend.
	  console.warn('WARNING: ', 'UI might be locked temporarily as data is being downloaded');
	  var values = backend.readSync(x.dataId);
	  var _uniqueImplCPU = uniqueImplCPU(values, axis, x.shape, x.dtype),
	    outputValues = _uniqueImplCPU.outputValues,
	    outputShape = _uniqueImplCPU.outputShape,
	    indices = _uniqueImplCPU.indices;
	  return [backend.makeTensorInfo(outputShape, x.dtype, outputValues), backend.makeTensorInfo([indices.length], 'int32', indices)];
	}
	var uniqueConfig = {
	  kernelName: Unique,
	  backendName: 'webgl',
	  kernelFunc: unique
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function unpack(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var value = inputs.value;
	  var axis = attrs.axis;
	  if (axis < 0) {
	    axis += value.shape.length;
	  }
	  var x = value;
	  var xRank = x.shape.length;
	  var num = value.shape[axis];
	  var outShape = new Array(xRank - 1);
	  var outIndex = 0;
	  for (var i = 0; i < xRank; i++) {
	    if (i !== axis) {
	      outShape[outIndex++] = x.shape[i];
	    }
	  }
	  var toDispose = [];
	  var begin = new Array(xRank).fill(0);
	  var size = x.shape.slice();
	  size[axis] = 1;
	  var res = new Array(num);
	  for (var _i = 0; _i < res.length; _i++) {
	    begin[axis] = _i;
	    var sliced = slice({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        begin: begin,
	        size: size
	      }
	    });
	    var reshaped = reshape({
	      inputs: {
	        x: sliced
	      },
	      backend: backend,
	      attrs: {
	        shape: outShape
	      }
	    });
	    res[_i] = reshaped;
	    toDispose.push(sliced);
	  }
	  toDispose.forEach(function (t) {
	    return backend.disposeIntermediateTensorInfo(t);
	  });
	  return res;
	}
	var unpackConfig = {
	  kernelName: Unpack,
	  backendName: 'webgl',
	  kernelFunc: unpack
	};

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var SegmentOpProgram = /*#__PURE__*/_createClass(function SegmentOpProgram(segOpInfo, segOpType) {
	  _classCallCheck(this, SegmentOpProgram);
	  this.variableNames = ['x', 'segmentIds'];
	  var windowSize = segOpInfo.windowSize;
	  var batchSize = segOpInfo.batchSize;
	  var inSize = segOpInfo.inSize;
	  var numSegments = segOpInfo.numSegments;
	  var outSize = numSegments * Math.ceil(inSize / windowSize);
	  this.outputShape = [batchSize, outSize];
	  var initializationValue = '0.0';
	  var returnValue = "sumValue";
	  var windowSizeNearestVec4 = Math.floor(windowSize / 4) * 4;
	  var windowSizeVec4Remainder = windowSize % 4;
	  var updateSnippet = "\n        sumValue += dot(values, segFilter);\n    ";
	  var checkValueOutOfBounds = '';
	  if (inSize % windowSize > 0) {
	    checkValueOutOfBounds = "\n        if (inIdx < 0 || inIdx >= ".concat(inSize, ") {\n          return initializationValue;\n        }\n      ");
	  }
	  var checkSegmentIdOutOfBounds = '';
	  if (inSize % windowSize > 0) {
	    checkSegmentIdOutOfBounds = "\n        if (inIdx < 0 || inIdx >= ".concat(inSize, ") {\n          return -1.0;\n        }\n      ");
	  }
	  this.userCode = "\n      const float initializationValue = ".concat(initializationValue, ";\n\n      float getValue(int batch, int inIdx) {\n        ").concat(checkValueOutOfBounds, "\n        return getX(batch, inIdx);\n      }\n\n      float getSegmentIdAtIndex(int inIdx) {\n        ").concat(checkSegmentIdOutOfBounds, "\n        return getSegmentIds(inIdx);\n      }\n\n      void main() {\n        ivec2 coords = getOutputCoords();\n        int batch = coords[0];\n        int outIdx = coords[1];\n        int inOffset = int(floor(float(outIdx) / float(\n          ").concat(numSegments, ")) * float(").concat(windowSize, "));\n        int currentSeg = int(mod(float(outIdx), float(").concat(numSegments, ")));\n\n        float sumValue = 0.0;\n\n        for (int i = 0; i < ").concat(windowSizeNearestVec4, "; i += 4) {\n          int inIdx = inOffset + i;\n          vec4 values = vec4(\n            getValue(batch, inIdx),\n            getValue(batch, inIdx + 1),\n            getValue(batch, inIdx + 2),\n            getValue(batch, inIdx + 3)\n          );\n\n          vec4 segFilter = vec4(\n            int(getSegmentIdAtIndex(inIdx)) == currentSeg ? 1 : 0,\n            int(getSegmentIdAtIndex(inIdx + 1)) == currentSeg ? 1 : 0,\n            int(getSegmentIdAtIndex(inIdx + 2)) == currentSeg ? 1 : 0,\n            int(getSegmentIdAtIndex(inIdx + 3)) == currentSeg ? 1 : 0\n          );\n\n          ").concat(updateSnippet, "\n        }\n\n        int inIdx = inOffset + ").concat(windowSizeNearestVec4, ";\n        if (").concat(windowSizeVec4Remainder === 1, ") {\n          vec4 values = vec4(\n            getValue(batch, inIdx),\n            initializationValue,\n            initializationValue,\n            initializationValue\n          );\n\n          int inIdxSeg = int(getSegmentIdAtIndex(inIdx));\n\n          vec4 segFilter = vec4(\n            int(getSegmentIdAtIndex(inIdx)) == currentSeg ? 1 : 0,\n            0,\n            0,\n            0\n          );\n\n          ").concat(updateSnippet, "\n        } else if (").concat(windowSizeVec4Remainder === 2, ") {\n          vec4 values = vec4(\n            getValue(batch, inIdx),\n            getValue(batch, inIdx + 1),\n            initializationValue,\n            initializationValue\n          );\n\n          vec4 segFilter = vec4(\n            int(getSegmentIdAtIndex(inIdx)) == currentSeg ? 1 : 0,\n            int(getSegmentIdAtIndex(inIdx + 1)) == currentSeg ? 1 : 0,\n              0,\n              0\n          );\n\n          ").concat(updateSnippet, "\n        } else if (").concat(windowSizeVec4Remainder === 3, ") {\n          vec4 values = vec4(\n            getValue(batch, inIdx),\n            getValue(batch, inIdx + 1),\n            getValue(batch, inIdx + 2),\n            initializationValue\n          );\n\n          vec4 segFilter = vec4(\n            int(getSegmentIdAtIndex(inIdx)) == currentSeg ? 1 : 0,\n            int(getSegmentIdAtIndex(inIdx + 1)) == currentSeg ? 1 : 0,\n            int(getSegmentIdAtIndex(inIdx + 2)) == currentSeg ? 1 : 0,\n            0\n          );\n\n          ").concat(updateSnippet, "\n        }\n        setOutput(").concat(returnValue, ");\n      }\n    ");
	});

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	function unsortedSegmentSum(args) {
	  var inputs = args.inputs,
	    backend = args.backend,
	    attrs = args.attrs;
	  var x = inputs.x,
	    segmentIds = inputs.segmentIds;
	  var numSegments = attrs.numSegments;
	  var xRank = x.shape.length;
	  var toDispose = [];
	  var axis = 0;
	  var permutation = getAxesPermutation([axis], xRank);
	  var permutedX = x;
	  if (permutation != null) {
	    permutedX = transpose({
	      inputs: {
	        x: x
	      },
	      backend: backend,
	      attrs: {
	        perm: permutation
	      }
	    });
	    toDispose.push(permutedX);
	    axis = getInnerMostAxes(1, xRank)[0];
	  }
	  var outShape = computeOutShape(permutedX.shape, axis, numSegments);
	  var inSize = sizeFromShape([permutedX.shape[axis]]);
	  var a2D = reshape({
	    inputs: {
	      x: permutedX
	    },
	    backend: backend,
	    attrs: {
	      shape: [-1, inSize]
	    }
	  });
	  toDispose.push(a2D);
	  var outputDType = sumOutType(x.dtype);
	  var segOpCompute = function segOpCompute(x, segOpType, segmentIds, dtype, numSegments) {
	    var batchSize = x.shape[0];
	    var inSize = x.shape[1];
	    var windowSize = segOpComputeOptimalWindowSize(inSize, numSegments);
	    var segOpInfo = {
	      windowSize: windowSize,
	      inSize: inSize,
	      batchSize: batchSize,
	      numSegments: numSegments
	    };
	    var program = new SegmentOpProgram(segOpInfo, segOpType);
	    var output = backend.compileAndRun(program, [x, segmentIds], dtype);
	    toDispose.push(output);
	    // No need to run another GPGPU program.
	    if (output.shape[1] === numSegments) {
	      return output;
	    }
	    var rangeInfo = range({
	      backend: backend,
	      attrs: {
	        start: 0,
	        stop: numSegments,
	        step: 1,
	        dtype: 'float32'
	      }
	    });
	    var tileInfo = tile({
	      inputs: {
	        x: rangeInfo
	      },
	      backend: backend,
	      attrs: {
	        reps: [inSize / windowSize]
	      }
	    });
	    toDispose.push(rangeInfo);
	    toDispose.push(tileInfo);
	    var result = segOpCompute(output, segOpType, tileInfo, dtype, numSegments);
	    return result;
	  };
	  var segOpResult = segOpCompute(a2D, 'unsortedSegmentSum', segmentIds, outputDType, numSegments);
	  var reshaped = reshape({
	    inputs: {
	      x: segOpResult
	    },
	    backend: backend,
	    attrs: {
	      shape: outShape
	    }
	  });
	  var result = reshaped;
	  if (permutation != null) {
	    toDispose.push(reshaped);
	    var perm = getUndoAxesPermutation(permutation);
	    result = transpose({
	      inputs: {
	        x: result
	      },
	      backend: backend,
	      attrs: {
	        perm: perm
	      }
	    });
	  }
	  toDispose.forEach(function (t) {
	    return backend.disposeIntermediateTensorInfo(t);
	  });
	  return result;
	}
	var unsortedSegmentSumConfig = {
	  kernelName: UnsortedSegmentSum,
	  backendName: 'webgl',
	  kernelFunc: unsortedSegmentSum
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	// List all kernel configs here
	var kernelConfigs = [_fusedMatMulConfig, absConfig, acosConfig, acoshConfig, addConfig, addNConfig, allConfig, anyConfig, argMaxConfig, argMinConfig, asinConfig, asinhConfig, atanConfig, atan2Config, atanhConfig, avgPoolConfig, avgPool3DConfig, avgPool3DGradConfig, avgPoolGradConfig, batchMatMulConfig, batchNormConfig, batchToSpaceNDConfig, bincountConfig, bitwiseAndConfig, broadcastArgsConfig, castConfig, ceilConfig, clipByValueConfig, complexConfig, complexAbsConfig, concatConfig, conv2DConfig, conv2DBackpropFilterConfig, conv2DBackpropInputConfig, conv3DConfig, conv3DBackpropFilterV2Config, conv3DBackpropInputConfig, cosConfig, coshConfig, cropAndResizeConfig, cumprodConfig, cumsumConfig, denseBincountConfig, depthToSpaceConfig, depthwiseConv2dNativeConfig, depthwiseConv2dNativeBackpropFilterConfig, depthwiseConv2dNativeBackpropInputConfig, diagConfig, dilation2DConfig, einsumConfig, eluConfig, eluGradConfig, equalConfig, erfConfig, expConfig, expandDimsConfig, expm1Config, fftConfig, fillConfig, flipLeftRightConfig, floorConfig, floorDivConfig, fromPixelsConfig, fusedConv2DConfig, fusedDepthwiseConv2DConfig, gatherNdConfig, gatherV2Config, greaterConfig, greaterEqualConfig, identityConfig, ifftConfig, imagConfig, isFiniteConfig, isInfConfig, isNaNConfig, leakyReluConfig, lessConfig, lessEqualConfig, linSpaceConfig, logConfig, log1pConfig, logicalAndConfig, logicalNotConfig, logicalOrConfig, LRNConfig, LRNGradConfig, maxConfig, maximumConfig, maxPoolConfig, maxPool3DConfig, maxPool3DGradConfig, maxPoolGradConfig, maxPoolWithArgmaxConfig, meanConfig, minConfig, minimumConfig, mirrorPadConfig, modConfig, multinomialConfig, multiplyConfig, negConfig, nonMaxSuppressionV3Config, nonMaxSuppressionV4Config, nonMaxSuppressionV5Config, notEqualConfig, oneHotConfig, onesLikeConfig, packConfig, padV2Config, powConfig, preluConfig, prodConfig, raggedGatherConfig, raggedRangeConfig, raggedTensorToTensorConfig, rangeConfig, realConfig, realDivConfig, reciprocalConfig, reluConfig, relu6Config, reshapeConfig, resizeBilinearConfig, resizeBilinearGradConfig, resizeNearestNeighborConfig, resizeNearestNeighborGradConfig, reverseConfig, rotateWithOffsetConfig, roundConfig, rsqrtConfig, scatterNdConfig, searchSortedConfig, selectConfig, seluConfig, sigmoidConfig, signConfig, sinConfig, sinhConfig, sliceConfig, softmaxConfig, softplusConfig, spaceToBatchNDConfig, sparseFillEmptyRowsConfig, sparseReshapeConfig, sparseSegmentMeanConfig, sparseSegmentSumConfig, sparseToDenseConfig, splitVConfig, sqrtConfig, squareConfig, squaredDifferenceConfig, staticRegexReplaceConfig, stepConfig, stridedSliceConfig, stringNGramsConfig, stringSplitConfig, stringToHashBucketFastConfig, subConfig, sumConfig, tanConfig, tanhConfig, tensorScatterUpdateConfig, tileConfig, topKConfig, transformConfig, transposeConfig, uniqueConfig, unpackConfig, unsortedSegmentSumConfig, zerosLikeConfig];
	for (var _i = 0, _kernelConfigs = kernelConfigs; _i < _kernelConfigs.length; _i++) {
	  var kernelConfig = _kernelConfigs[_i];
	  registerKernel(kernelConfig);
	}

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */

	/** @license See the LICENSE file. */
	// This code is auto-generated, do not modify this file!
	var version$1 = '4.22.0';

	/**
	 * @license
	 * Copyright 2018 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */
	var version = {
	    'tfjs-core': version$7,
	    'tfjs-backend-cpu': version$3,
	    'tfjs-backend-webgl': version$2,
	    'tfjs-data': version$4,
	    'tfjs-layers': version$6,
	    'tfjs-converter': version$5,
	    'tfjs': version$1
	};

	/**
	 * @license
	 * Copyright 2020 Google LLC. All Rights Reserved.
	 * Licensed under the Apache License, Version 2.0 (the "License");
	 * you may not use this file except in compliance with the License.
	 * You may obtain a copy of the License at
	 *
	 * http://www.apache.org/licenses/LICENSE-2.0
	 *
	 * Unless required by applicable law or agreed to in writing, software
	 * distributed under the License is distributed on an "AS IS" BASIS,
	 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	 * See the License for the specific language governing permissions and
	 * limitations under the License.
	 * =============================================================================
	 */

	exports.Abs = Abs;
	exports.Acos = Acos;
	exports.Acosh = Acosh;
	exports.AdadeltaOptimizer = AdadeltaOptimizer;
	exports.AdagradOptimizer = AdagradOptimizer;
	exports.AdamOptimizer = AdamOptimizer;
	exports.AdamaxOptimizer = AdamaxOptimizer;
	exports.Add = Add$1;
	exports.AddN = AddN;
	exports.All = All;
	exports.Any = Any;
	exports.ArgMax = ArgMax;
	exports.ArgMin = ArgMin;
	exports.Asin = Asin;
	exports.Asinh = Asinh;
	exports.Atan = Atan;
	exports.Atan2 = Atan2;
	exports.Atanh = Atanh;
	exports.AvgPool = AvgPool;
	exports.AvgPool3D = AvgPool3D;
	exports.AvgPool3DGrad = AvgPool3DGrad;
	exports.AvgPoolGrad = AvgPoolGrad;
	exports.BatchMatMul = BatchMatMul;
	exports.BatchToSpaceND = BatchToSpaceND;
	exports.Bincount = Bincount;
	exports.BitwiseAnd = BitwiseAnd;
	exports.BroadcastArgs = BroadcastArgs;
	exports.BroadcastTo = BroadcastTo;
	exports.Callback = Callback;
	exports.CallbackList = CallbackList;
	exports.Cast = Cast;
	exports.Ceil = Ceil;
	exports.ClipByValue = ClipByValue;
	exports.Complex = Complex;
	exports.ComplexAbs = ComplexAbs;
	exports.Concat = Concat;
	exports.Conv2D = Conv2D$1;
	exports.Conv2DBackpropFilter = Conv2DBackpropFilter;
	exports.Conv2DBackpropInput = Conv2DBackpropInput;
	exports.Conv3D = Conv3D$1;
	exports.Conv3DBackpropFilterV2 = Conv3DBackpropFilterV2;
	exports.Conv3DBackpropInputV2 = Conv3DBackpropInputV2;
	exports.Cos = Cos;
	exports.Cosh = Cosh;
	exports.CropAndResize = CropAndResize;
	exports.Cumprod = Cumprod;
	exports.Cumsum = Cumsum;
	exports.CustomCallback = CustomCallback;
	exports.DataStorage = DataStorage;
	exports.DenseBincount = DenseBincount;
	exports.DepthToSpace = DepthToSpace;
	exports.DepthwiseConv2dNative = DepthwiseConv2dNative;
	exports.DepthwiseConv2dNativeBackpropFilter = DepthwiseConv2dNativeBackpropFilter;
	exports.DepthwiseConv2dNativeBackpropInput = DepthwiseConv2dNativeBackpropInput;
	exports.Diag = Diag;
	exports.Dilation2D = Dilation2D;
	exports.Dilation2DBackpropFilter = Dilation2DBackpropFilter;
	exports.Dilation2DBackpropInput = Dilation2DBackpropInput;
	exports.Draw = Draw;
	exports.EarlyStopping = EarlyStopping;
	exports.Einsum = Einsum;
	exports.Elu = Elu$1;
	exports.EluGrad = EluGrad;
	exports.Environment = Environment;
	exports.Equal = Equal;
	exports.Erf = Erf;
	exports.Exp = Exp;
	exports.ExpandDims = ExpandDims;
	exports.Expm1 = Expm1;
	exports.FFT = FFT;
	exports.Fill = Fill;
	exports.FlipLeftRight = FlipLeftRight;
	exports.Floor = Floor;
	exports.FloorDiv = FloorDiv;
	exports.FromPixels = FromPixels;
	exports.FusedBatchNorm = FusedBatchNorm;
	exports.FusedConv2D = FusedConv2D;
	exports.FusedDepthwiseConv2D = FusedDepthwiseConv2D;
	exports.GPGPUContext = GPGPUContext;
	exports.GatherNd = GatherNd;
	exports.GatherV2 = GatherV2;
	exports.GraphModel = GraphModel;
	exports.Greater = Greater;
	exports.GreaterEqual = GreaterEqual;
	exports.History = History;
	exports.IFFT = IFFT;
	exports.Identity = Identity$1;
	exports.Imag = Imag;
	exports.InputSpec = InputSpec;
	exports.IsFinite = IsFinite;
	exports.IsInf = IsInf;
	exports.IsNan = IsNan;
	exports.KernelBackend = KernelBackend;
	exports.LRN = LRN;
	exports.LRNGrad = LRNGrad;
	exports.LayerVariable = LayerVariable;
	exports.LayersModel = LayersModel;
	exports.LeakyRelu = LeakyRelu;
	exports.Less = Less;
	exports.LessEqual = LessEqual;
	exports.LinSpace = LinSpace;
	exports.Log = Log;
	exports.Log1p = Log1p;
	exports.LogSoftmax = LogSoftmax$1;
	exports.LogicalAnd = LogicalAnd;
	exports.LogicalNot = LogicalNot;
	exports.LogicalOr = LogicalOr;
	exports.LogicalXor = LogicalXor;
	exports.LowerBound = LowerBound;
	exports.MathBackendCPU = MathBackendCPU;
	exports.MathBackendWebGL = MathBackendWebGL;
	exports.MatrixBandPart = MatrixBandPart;
	exports.Max = Max;
	exports.MaxPool = MaxPool;
	exports.MaxPool3D = MaxPool3D;
	exports.MaxPool3DGrad = MaxPool3DGrad;
	exports.MaxPoolGrad = MaxPoolGrad;
	exports.MaxPoolWithArgmax = MaxPoolWithArgmax;
	exports.Maximum = Maximum$1;
	exports.Mean = Mean;
	exports.Min = Min;
	exports.Minimum = Minimum$1;
	exports.MirrorPad = MirrorPad;
	exports.Mod = Mod;
	exports.MomentumOptimizer = MomentumOptimizer;
	exports.Multinomial = Multinomial;
	exports.Multiply = Multiply$1;
	exports.Neg = Neg;
	exports.NonMaxSuppressionV3 = NonMaxSuppressionV3;
	exports.NonMaxSuppressionV4 = NonMaxSuppressionV4;
	exports.NonMaxSuppressionV5 = NonMaxSuppressionV5;
	exports.NotEqual = NotEqual;
	exports.OP_SCOPE_SUFFIX = OP_SCOPE_SUFFIX;
	exports.OneHot = OneHot;
	exports.OnesLike = OnesLike;
	exports.Optimizer = Optimizer;
	exports.OptimizerConstructors = OptimizerConstructors;
	exports.Pack = Pack;
	exports.PadV2 = PadV2;
	exports.Pool = Pool;
	exports.Pow = Pow;
	exports.Prelu = Prelu;
	exports.Prod = Prod;
	exports.RMSPropOptimizer = RMSPropOptimizer;
	exports.RNN = RNN;
	exports.RaggedGather = RaggedGather;
	exports.RaggedRange = RaggedRange;
	exports.RaggedTensorToTensor = RaggedTensorToTensor;
	exports.Range = Range;
	exports.Real = Real;
	exports.RealDiv = RealDiv;
	exports.Reciprocal = Reciprocal;
	exports.Relu = Relu$1;
	exports.Relu6 = Relu6$1;
	exports.Reshape = Reshape$1;
	exports.ResizeBilinear = ResizeBilinear;
	exports.ResizeBilinearGrad = ResizeBilinearGrad;
	exports.ResizeNearestNeighbor = ResizeNearestNeighbor;
	exports.ResizeNearestNeighborGrad = ResizeNearestNeighborGrad;
	exports.Reverse = Reverse;
	exports.RotateWithOffset = RotateWithOffset;
	exports.Round = Round;
	exports.Rsqrt = Rsqrt;
	exports.SGDOptimizer = SGDOptimizer;
	exports.ScatterNd = ScatterNd;
	exports.SearchSorted = SearchSorted;
	exports.Select = Select;
	exports.Selu = Selu$1;
	exports.Sequential = Sequential;
	exports.Sigmoid = Sigmoid$1;
	exports.Sign = Sign;
	exports.Sin = Sin;
	exports.Sinh = Sinh;
	exports.Slice = Slice;
	exports.Softmax = Softmax$2;
	exports.Softplus = Softplus$1;
	exports.SpaceToBatchND = SpaceToBatchND;
	exports.SparseFillEmptyRows = SparseFillEmptyRows;
	exports.SparseReshape = SparseReshape;
	exports.SparseSegmentMean = SparseSegmentMean;
	exports.SparseSegmentSum = SparseSegmentSum;
	exports.SparseToDense = SparseToDense;
	exports.SplitV = SplitV;
	exports.Sqrt = Sqrt;
	exports.Square = Square;
	exports.SquaredDifference = SquaredDifference;
	exports.StaticRegexReplace = StaticRegexReplace;
	exports.Step = Step;
	exports.StridedSlice = StridedSlice;
	exports.StringNGrams = StringNGrams;
	exports.StringSplit = StringSplit;
	exports.StringToHashBucketFast = StringToHashBucketFast;
	exports.Sub = Sub;
	exports.Sum = Sum;
	exports.SymbolicTensor = SymbolicTensor;
	exports.Tan = Tan;
	exports.Tanh = Tanh$1;
	exports.Tensor = Tensor;
	exports.TensorBuffer = TensorBuffer;
	exports.TensorScatterUpdate = TensorScatterUpdate;
	exports.Tile = Tile;
	exports.TopK = TopK;
	exports.Transform = Transform;
	exports.Transpose = Transpose;
	exports.Unique = Unique;
	exports.Unpack = Unpack;
	exports.UnsortedSegmentSum = UnsortedSegmentSum;
	exports.UpperBound = UpperBound;
	exports.Variable = Variable;
	exports.ZerosLike = ZerosLike;
	exports._FusedMatMul = _FusedMatMul;
	exports.abs = abs$2;
	exports.acos = acos$2;
	exports.acosh = acosh$2;
	exports.add = add$3;
	exports.addN = addN$2;
	exports.all = all$2;
	exports.any = any$2;
	exports.argMax = argMax$2;
	exports.argMin = argMin$2;
	exports.asin = asin$2;
	exports.asinh = asinh$2;
	exports.atan = atan$2;
	exports.atan2 = atan2$2;
	exports.atanh = atanh$2;
	exports.avgPool = avgPool$2;
	exports.avgPool3d = avgPool3d$1;
	exports.backend = backend$1;
	exports.backend_util = backend_util;
	exports.basicLSTMCell = basicLSTMCell;
	exports.batchNorm = batchNorm$2;
	exports.batchNorm2d = batchNorm2d;
	exports.batchNorm3d = batchNorm3d;
	exports.batchNorm4d = batchNorm4d;
	exports.batchToSpaceND = batchToSpaceND$2;
	exports.bincount = bincount$2;
	exports.bitwiseAnd = bitwiseAnd$2;
	exports.booleanMaskAsync = booleanMaskAsync;
	exports.broadcastArgs = broadcastArgs$2;
	exports.broadcastTo = broadcastTo;
	exports.broadcast_util = broadcast_util;
	exports.browser = browser;
	exports.buffer = buffer;
	exports.callbacks = callbacks;
	exports.cast = cast$3;
	exports.ceil = ceil$2;
	exports.clipByValue = clipByValue$2;
	exports.clone = clone;
	exports.complex = complex$2;
	exports.concat = concat$2;
	exports.concat1d = concat1d;
	exports.concat2d = concat2d;
	exports.concat3d = concat3d;
	exports.concat4d = concat4d;
	exports.constraints = exports_constraints;
	exports.conv1d = conv1d$2;
	exports.conv2d = conv2d$4;
	exports.conv2dTranspose = conv2dTranspose$1;
	exports.conv3d = conv3d$2;
	exports.conv3dTranspose = conv3dTranspose$1;
	exports.copyRegisteredKernels = copyRegisteredKernels;
	exports.cos = cos$2;
	exports.cosh = cosh$2;
	exports.cosineWindow = cosineWindow;
	exports.cumprod = cumprod$2;
	exports.cumsum = cumsum$2;
	exports.customGrad = customGrad;
	exports.data = index;
	exports.denseBincount = denseBincount$2;
	exports.deprecationWarn = deprecationWarn;
	exports.depthToSpace = depthToSpace$2;
	exports.depthwiseConv2d = depthwiseConv2d$3;
	exports.deregisterOp = deregisterOp;
	exports.device_util = device_util;
	exports.diag = diag$2;
	exports.dilation2d = dilation2d;
	exports.disableDeprecationWarnings = disableDeprecationWarnings;
	exports.dispose = dispose;
	exports.disposeVariables = disposeVariables;
	exports.div = div$1;
	exports.divNoNan = divNoNan;
	exports.dot = dot$2;
	exports.dropout = dropout$2;
	exports.einsum = einsum$2;
	exports.elu = elu$4;
	exports.enableDebugMode = enableDebugMode;
	exports.enableProdMode = enableProdMode;
	exports.enclosingPowerOfTwo = enclosingPowerOfTwo;
	exports.engine = engine;
	exports.ensureShape = ensureShape;
	exports.env = env;
	exports.equal = equal$2;
	exports.erf = erf$2;
	exports.euclideanNorm = euclideanNorm;
	exports.exp = exp$2;
	exports.expandDims = expandDims$3;
	exports.expm1 = expm1$2;
	exports.eye = eye;
	exports.fft = fft$2;
	exports.fill = fill$2;
	exports.findBackend = findBackend;
	exports.findBackendFactory = findBackendFactory;
	exports.floor = floor$2;
	exports.floorDiv = floorDiv$2;
	exports.forceHalfFloat = forceHalfFloat;
	exports.fused = fused_ops;
	exports.gather = gather$1;
	exports.gatherND = gatherND;
	exports.gather_util = gather_nd_util;
	exports.getBackend = getBackend$1;
	exports.getGradient = getGradient;
	exports.getKernel = getKernel;
	exports.getKernelsForBackend = getKernelsForBackend;
	exports.gpgpu_util = gpgpu_util;
	exports.grad = grad;
	exports.grads = grads;
	exports.greater = greater$3;
	exports.greaterEqual = greaterEqual$2;
	exports.ifft = ifft$2;
	exports.imag = imag$2;
	exports.image = image$1;
	exports.inTopKAsync = inTopKAsync;
	exports.initializers = exports_initializers;
	exports.input = input;
	exports.io = io;
	exports.irfft = irfft;
	exports.isFinite = isFinite$3;
	exports.isInf = isInf$2;
	exports.isNaN = isNaN$3;
	exports.keep = keep;
	exports.kernel_impls = kernel_impls;
	exports.layers = exports_layers;
	exports.leakyRelu = leakyRelu$2;
	exports.less = less$3;
	exports.lessEqual = lessEqual$2;
	exports.linalg = linalg;
	exports.linspace = linspace;
	exports.loadGraphModel = loadGraphModel;
	exports.loadGraphModelSync = loadGraphModelSync;
	exports.loadLayersModel = loadLayersModel;
	exports.localResponseNormalization = localResponseNormalization;
	exports.log = log$2;
	exports.log1p = log1p$2;
	exports.logSigmoid = logSigmoid;
	exports.logSoftmax = logSoftmax;
	exports.logSumExp = logSumExp;
	exports.logicalAnd = logicalAnd$2;
	exports.logicalNot = logicalNot$2;
	exports.logicalOr = logicalOr$2;
	exports.logicalXor = logicalXor;
	exports.losses = losses;
	exports.lowerBound = lowerBound$1;
	exports.matMul = matMul$1;
	exports.math = math;
	exports.max = max$3;
	exports.maxPool = maxPool$2;
	exports.maxPool3d = maxPool3d$1;
	exports.maxPoolWithArgmax = maxPoolWithArgmax;
	exports.maximum = maximum$4;
	exports.mean = mean$3;
	exports.memory = memory;
	exports.meshgrid = meshgrid;
	exports.metrics = exports_metrics;
	exports.min = min$3;
	exports.minimum = minimum$4;
	exports.mirrorPad = mirrorPad$1;
	exports.mod = mod$2;
	exports.model = model;
	exports.models = exports_models;
	exports.moments = moments;
	exports.movingAverage = movingAverage;
	exports.mul = mul;
	exports.multiRNNCell = multiRNNCell;
	exports.multinomial = multinomial$2;
	exports.neg = neg$2;
	exports.nextFrame = nextFrame;
	exports.norm = norm;
	exports.notEqual = notEqual$2;
	exports.oneHot = oneHot$3;
	exports.ones = ones$1;
	exports.onesLike = onesLike$3;
	exports.op = op;
	exports.outerProduct = outerProduct;
	exports.pad = pad;
	exports.pad1d = pad1d;
	exports.pad2d = pad2d;
	exports.pad3d = pad3d;
	exports.pad4d = pad4d;
	exports.pool = pool$1;
	exports.pow = pow$3;
	exports.prelu = prelu$3;
	exports.print = print;
	exports.prod = prod$2;
	exports.profile = profile;
	exports.raggedGather = raggedGather$2;
	exports.raggedRange = raggedRange$2;
	exports.raggedTensorToTensor = raggedTensorToTensor$2;
	exports.rand = rand;
	exports.randomGamma = randomGamma;
	exports.randomNormal = randomNormal$2;
	exports.randomStandardNormal = randomStandardNormal;
	exports.randomUniform = randomUniform$1;
	exports.randomUniformInt = randomUniformInt;
	exports.range = range$3;
	exports.ready = ready;
	exports.real = real$2;
	exports.reciprocal = reciprocal$2;
	exports.registerBackend = registerBackend;
	exports.registerCallbackConstructor = registerCallbackConstructor;
	exports.registerGradient = registerGradient;
	exports.registerKernel = registerKernel;
	exports.registerOp = registerOp;
	exports.regularizers = exports_regularizers;
	exports.relu = relu$2;
	exports.relu6 = relu6$2;
	exports.removeBackend = removeBackend;
	exports.reshape = reshape$3;
	exports.reverse = reverse$2;
	exports.reverse1d = reverse1d;
	exports.reverse2d = reverse2d;
	exports.reverse3d = reverse3d;
	exports.reverse4d = reverse4d;
	exports.rfft = rfft;
	exports.round = round$2;
	exports.rsqrt = rsqrt$2;
	exports.scalar = scalar;
	exports.scatterND = scatterND;
	exports.scatter_util = scatter_nd_util;
	exports.searchSorted = searchSorted$2;
	exports.selu = selu$2;
	exports.separableConv2d = separableConv2d$1;
	exports.sequential = sequential;
	exports.serialization = serialization;
	exports.setBackend = setBackend$1;
	exports.setPlatform = setPlatform;
	exports.setWebGLContext = setWebGLContext;
	exports.setdiff1dAsync = setdiff1dAsync;
	exports.shared = shared;
	exports.sigmoid = sigmoid$2;
	exports.sign = sign$3;
	exports.signal = signal;
	exports.sin = sin$2;
	exports.sinh = sinh$2;
	exports.slice = slice$2;
	exports.slice1d = slice1d;
	exports.slice2d = slice2d;
	exports.slice3d = slice3d;
	exports.slice4d = slice4d;
	exports.slice_util = slice_util;
	exports.softmax = softmax$3;
	exports.softplus = softplus$2;
	exports.spaceToBatchND = spaceToBatchND$2;
	exports.sparse = sparse$1;
	exports.sparseToDense = sparseToDense$2;
	exports.spectral = spectral$1;
	exports.split = split$3;
	exports.sqrt = sqrt$2;
	exports.square = square$2;
	exports.squaredDifference = squaredDifference$2;
	exports.squeeze = squeeze;
	exports.stack = stack;
	exports.step = step$2;
	exports.stridedSlice = stridedSlice$2;
	exports.string = string$1;
	exports.sub = sub$2;
	exports.sum = sum$3;
	exports.sumOutType = sumOutType;
	exports.tan = tan$2;
	exports.tanh = tanh$2;
	exports.tensor = tensor;
	exports.tensor1d = tensor1d;
	exports.tensor2d = tensor2d;
	exports.tensor3d = tensor3d;
	exports.tensor4d = tensor4d;
	exports.tensor5d = tensor5d;
	exports.tensor6d = tensor6d;
	exports.tensorScatterUpdate = tensorScatterUpdate$2;
	exports.tensor_util = tensor_util;
	exports.test_util = test_util;
	exports.tidy = tidy;
	exports.tile = tile$3;
	exports.time = time;
	exports.topk = topk;
	exports.train = train;
	exports.transpose = transpose$2;
	exports.truncatedNormal = truncatedNormal$1;
	exports.unique = unique$3;
	exports.unregisterGradient = unregisterGradient;
	exports.unregisterKernel = unregisterKernel;
	exports.unsortedSegmentSum = unsortedSegmentSum$2;
	exports.unstack = unstack;
	exports.upcastType = upcastType;
	exports.upperBound = upperBound$1;
	exports.util = util;
	exports.valueAndGrad = valueAndGrad;
	exports.valueAndGrads = valueAndGrads;
	exports.variable = variable$1;
	exports.variableGrads = variableGrads;
	exports.version = version;
	exports.version_converter = version$5;
	exports.version_core = version$7;
	exports.version_cpu = version$3;
	exports.version_layers = version$6;
	exports.version_webgl = version$2;
	exports.webgl = webgl;
	exports.webgl_util = webgl_util;
	exports.where = where;
	exports.whereAsync = whereAsync;
	exports.zeros = zeros$2;
	exports.zerosLike = zerosLike$3;

}));
//# sourceMappingURL=tf.js.map
